import{s as t,b as r,a,S as s}from"./chunk-NQ4KR5QH-B1-5ysjE.js";import{_ as i}from"./index-s5i_VGjE.js";import"./chunk-55IACEB6-u4CbMXtK.js";import"./chunk-KX2RTZJC-CVyxbm7o.js";var l={parser:a,get db(){return new s(2)},renderer:r,styles:t,init:i(e=>{e.state||(e.state={}),e.state.arrowMarkerAbsolute=e.arrowMarkerAbsolute},"init")};export{l as diagram};
