const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/dagre-KLK3FWXG-DYoQLW-T.js","assets/graph-AjB_XypD.js","assets/_baseUniq-BMhhKA5S.js","assets/layout-BRK7EdHA.js","assets/_basePickBy-Yn2l-vli.js","assets/clone-5AlM7gEL.js","assets/cose-bilkent-S5V4N54A-C3_YBITk.js","assets/cytoscape.esm-BQaXIfA_.js","assets/c4Diagram-IC4MRINW-BaXTKGs2.js","assets/chunk-JSJVCQXG-DjKR5zwL.js","assets/flowDiagram-PKNHOUZH-BaREyS8h.js","assets/chunk-FMBD7UC4-Dippca2-.js","assets/chunk-55IACEB6-u4CbMXtK.js","assets/chunk-KX2RTZJC-CVyxbm7o.js","assets/channel-BLCrmKqd.js","assets/erDiagram-INFDFZHY-DlYNFU2m.js","assets/gitGraphDiagram-K3NZZRJ6-CNWI3sZx.js","assets/chunk-4BX2VUAB-Dr8RApeV.js","assets/chunk-QZHKN3VN-DnvquI5K.js","assets/treemap-KZPCXAKY-Cgb7GbhX.js","assets/ganttDiagram-A5KZAMGK-Ceb4PZms.js","assets/linear-CgAHOiC9.js","assets/init-Gi6I4Gst.js","assets/defaultLocale-DX6XiGOO.js","assets/infoDiagram-LFFYTUFH-B6ydU_iG.js","assets/pieDiagram-SKSYHLDU-C1INl7Ml.js","assets/arc-C-nXCcwD.js","assets/ordinal-Cboi1Yqb.js","assets/quadrantDiagram-337W2JSQ-DGfdmrvg.js","assets/xychartDiagram-JWTSCODW-Dtt2ETxZ.js","assets/requirementDiagram-Z7DCOOCP-CyRB6RdG.js","assets/sequenceDiagram-2WXFIKYE-DKBJvqmJ.js","assets/classDiagram-VBA2DB6C-BL2VNw79.js","assets/chunk-WL4C6EOR-BWQXTPSr.js","assets/classDiagram-v2-RAHNMMFH-BL2VNw79.js","assets/stateDiagram-RAJIS63D-BLT77eAV.js","assets/chunk-NQ4KR5QH-B1-5ysjE.js","assets/stateDiagram-v2-FVOUBMTO-DcuudiXa.js","assets/journeyDiagram-4ABVD52K-CUkYVcgS.js","assets/timeline-definition-YZTLITO2-CDM6T3Yp.js","assets/mindmap-definition-YRQLILUH-KtHN9f12.js","assets/kanban-definition-K7BYSVSG-eHoob3tt.js","assets/sankeyDiagram-WA2Y5GQK-DwafNq5T.js","assets/diagram-P4PSJMXO-DBDi3c6t.js","assets/diagram-IFDJBPK2-C-1rIxmK.js","assets/blockDiagram-WCTKOSBZ-BTJGh8U1.js","assets/architectureDiagram-2XIMDMQ5-C2oMw5nu.js","assets/diagram-E7M64L7V-C85R0vod.js"])))=>i.map(i=>d[i]);
var jG=Object.defineProperty;var HG=(e,t,n)=>t in e?jG(e,t,{enumerable:!0,configurable:!0,writable:!0,value:n}):e[t]=n;var tn=(e,t,n)=>HG(e,typeof t!="symbol"?t+"":t,n);function GG(e,t){for(var n=0;n<t.length;n++){const r=t[n];if(typeof r!="string"&&!Array.isArray(r)){for(const a in r)if(a!=="default"&&!(a in e)){const i=Object.getOwnPropertyDescriptor(r,a);i&&Object.defineProperty(e,a,i.get?i:{enumerable:!0,get:()=>r[a]})}}}return Object.freeze(Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}))}(function(){const t=document.createElement("link").relList;if(t&&t.supports&&t.supports("modulepreload"))return;for(const a of document.querySelectorAll('link[rel="modulepreload"]'))r(a);new MutationObserver(a=>{for(const i of a)if(i.type==="childList")for(const o of i.addedNodes)o.tagName==="LINK"&&o.rel==="modulepreload"&&r(o)}).observe(document,{childList:!0,subtree:!0});function n(a){const i={};return a.integrity&&(i.integrity=a.integrity),a.referrerPolicy&&(i.referrerPolicy=a.referrerPolicy),a.crossOrigin==="use-credentials"?i.credentials="include":a.crossOrigin==="anonymous"?i.credentials="omit":i.credentials="same-origin",i}function r(a){if(a.ep)return;a.ep=!0;const i=n(a);fetch(a.href,i)}})();function qh(e){return e&&e.__esModule&&Object.prototype.hasOwnProperty.call(e,"default")?e.default:e}function sEe(e){if(Object.prototype.hasOwnProperty.call(e,"__esModule"))return e;var t=e.default;if(typeof t=="function"){var n=function r(){return this instanceof r?Reflect.construct(t,arguments,this.constructor):t.apply(this,arguments)};n.prototype=t.prototype}else n={};return Object.defineProperty(n,"__esModule",{value:!0}),Object.keys(e).forEach(function(r){var a=Object.getOwnPropertyDescriptor(e,r);Object.defineProperty(n,r,a.get?a:{enumerable:!0,get:function(){return e[r]}})}),n}var N1={exports:{}},Nd={};/**
 * @license React
 * react-jsx-runtime.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var m6;function qG(){if(m6)return Nd;m6=1;var e=Symbol.for("react.transitional.element"),t=Symbol.for("react.fragment");function n(r,a,i){var o=null;if(i!==void 0&&(o=""+i),a.key!==void 0&&(o=""+a.key),"key"in a){i={};for(var l in a)l!=="key"&&(i[l]=a[l])}else i=a;return a=i.ref,{$$typeof:e,type:r,key:o,ref:a!==void 0?a:null,props:i}}return Nd.Fragment=t,Nd.jsx=n,Nd.jsxs=n,Nd}var g6;function WG(){return g6||(g6=1,N1.exports=qG()),N1.exports}var T=WG(),O1={exports:{}},bt={};/**
 * @license React
 * react.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var b6;function VG(){if(b6)return bt;b6=1;var e=Symbol.for("react.transitional.element"),t=Symbol.for("react.portal"),n=Symbol.for("react.fragment"),r=Symbol.for("react.strict_mode"),a=Symbol.for("react.profiler"),i=Symbol.for("react.consumer"),o=Symbol.for("react.context"),l=Symbol.for("react.forward_ref"),u=Symbol.for("react.suspense"),d=Symbol.for("react.memo"),h=Symbol.for("react.lazy"),f=Symbol.for("react.activity"),m=Symbol.iterator;function b(Y){return Y===null||typeof Y!="object"?null:(Y=m&&Y[m]||Y["@@iterator"],typeof Y=="function"?Y:null)}var y={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},v=Object.assign,w={};function S(Y,oe,U){this.props=Y,this.context=oe,this.refs=w,this.updater=U||y}S.prototype.isReactComponent={},S.prototype.setState=function(Y,oe){if(typeof Y!="object"&&typeof Y!="function"&&Y!=null)throw Error("takes an object of state variables to update or a function which returns an object of state variables.");this.updater.enqueueSetState(this,Y,oe,"setState")},S.prototype.forceUpdate=function(Y){this.updater.enqueueForceUpdate(this,Y,"forceUpdate")};function k(){}k.prototype=S.prototype;function R(Y,oe,U){this.props=Y,this.context=oe,this.refs=w,this.updater=U||y}var I=R.prototype=new k;I.constructor=R,v(I,S.prototype),I.isPureReactComponent=!0;var L=Array.isArray;function A(){}var M={H:null,A:null,T:null,S:null},P=Object.prototype.hasOwnProperty;function G(Y,oe,U){var be=U.ref;return{$$typeof:e,type:Y,key:oe,ref:be!==void 0?be:null,props:U}}function B(Y,oe){return G(Y.type,oe,Y.props)}function H(Y){return typeof Y=="object"&&Y!==null&&Y.$$typeof===e}function Z(Y){var oe={"=":"=0",":":"=2"};return"$"+Y.replace(/[=:]/g,function(U){return oe[U]})}var V=/\/+/g;function q(Y,oe){return typeof Y=="object"&&Y!==null&&Y.key!=null?Z(""+Y.key):oe.toString(36)}function X(Y){switch(Y.status){case"fulfilled":return Y.value;case"rejected":throw Y.reason;default:switch(typeof Y.status=="string"?Y.then(A,A):(Y.status="pending",Y.then(function(oe){Y.status==="pending"&&(Y.status="fulfilled",Y.value=oe)},function(oe){Y.status==="pending"&&(Y.status="rejected",Y.reason=oe)})),Y.status){case"fulfilled":return Y.value;case"rejected":throw Y.reason}}throw Y}function $(Y,oe,U,be,ge){var fe=typeof Y;(fe==="undefined"||fe==="boolean")&&(Y=null);var Ee=!1;if(Y===null)Ee=!0;else switch(fe){case"bigint":case"string":case"number":Ee=!0;break;case"object":switch(Y.$$typeof){case e:case t:Ee=!0;break;case h:return Ee=Y._init,$(Ee(Y._payload),oe,U,be,ge)}}if(Ee)return ge=ge(Y),Ee=be===""?"."+q(Y,0):be,L(ge)?(U="",Ee!=null&&(U=Ee.replace(V,"$&/")+"/"),$(ge,oe,U,"",function(De){return De})):ge!=null&&(H(ge)&&(ge=B(ge,U+(ge.key==null||Y&&Y.key===ge.key?"":(""+ge.key).replace(V,"$&/")+"/")+Ee)),oe.push(ge)),1;Ee=0;var Ae=be===""?".":be+":";if(L(Y))for(var ve=0;ve<Y.length;ve++)be=Y[ve],fe=Ae+q(be,ve),Ee+=$(be,oe,U,fe,ge);else if(ve=b(Y),typeof ve=="function")for(Y=ve.call(Y),ve=0;!(be=Y.next()).done;)be=be.value,fe=Ae+q(be,ve++),Ee+=$(be,oe,U,fe,ge);else if(fe==="object"){if(typeof Y.then=="function")return $(X(Y),oe,U,be,ge);throw oe=String(Y),Error("Objects are not valid as a React child (found: "+(oe==="[object Object]"?"object with keys {"+Object.keys(Y).join(", ")+"}":oe)+"). If you meant to render a collection of children, use an array instead.")}return Ee}function Q(Y,oe,U){if(Y==null)return Y;var be=[],ge=0;return $(Y,be,"","",function(fe){return oe.call(U,fe,ge++)}),be}function J(Y){if(Y._status===-1){var oe=Y._result;oe=oe(),oe.then(function(U){(Y._status===0||Y._status===-1)&&(Y._status=1,Y._result=U)},function(U){(Y._status===0||Y._status===-1)&&(Y._status=2,Y._result=U)}),Y._status===-1&&(Y._status=0,Y._result=oe)}if(Y._status===1)return Y._result.default;throw Y._result}var ie=typeof reportError=="function"?reportError:function(Y){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var oe=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof Y=="object"&&Y!==null&&typeof Y.message=="string"?String(Y.message):String(Y),error:Y});if(!window.dispatchEvent(oe))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",Y);return}console.error(Y)},F={map:Q,forEach:function(Y,oe,U){Q(Y,function(){oe.apply(this,arguments)},U)},count:function(Y){var oe=0;return Q(Y,function(){oe++}),oe},toArray:function(Y){return Q(Y,function(oe){return oe})||[]},only:function(Y){if(!H(Y))throw Error("React.Children.only expected to receive a single React element child.");return Y}};return bt.Activity=f,bt.Children=F,bt.Component=S,bt.Fragment=n,bt.Profiler=a,bt.PureComponent=R,bt.StrictMode=r,bt.Suspense=u,bt.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=M,bt.__COMPILER_RUNTIME={__proto__:null,c:function(Y){return M.H.useMemoCache(Y)}},bt.cache=function(Y){return function(){return Y.apply(null,arguments)}},bt.cacheSignal=function(){return null},bt.cloneElement=function(Y,oe,U){if(Y==null)throw Error("The argument must be a React element, but you passed "+Y+".");var be=v({},Y.props),ge=Y.key;if(oe!=null)for(fe in oe.key!==void 0&&(ge=""+oe.key),oe)!P.call(oe,fe)||fe==="key"||fe==="__self"||fe==="__source"||fe==="ref"&&oe.ref===void 0||(be[fe]=oe[fe]);var fe=arguments.length-2;if(fe===1)be.children=U;else if(1<fe){for(var Ee=Array(fe),Ae=0;Ae<fe;Ae++)Ee[Ae]=arguments[Ae+2];be.children=Ee}return G(Y.type,ge,be)},bt.createContext=function(Y){return Y={$$typeof:o,_currentValue:Y,_currentValue2:Y,_threadCount:0,Provider:null,Consumer:null},Y.Provider=Y,Y.Consumer={$$typeof:i,_context:Y},Y},bt.createElement=function(Y,oe,U){var be,ge={},fe=null;if(oe!=null)for(be in oe.key!==void 0&&(fe=""+oe.key),oe)P.call(oe,be)&&be!=="key"&&be!=="__self"&&be!=="__source"&&(ge[be]=oe[be]);var Ee=arguments.length-2;if(Ee===1)ge.children=U;else if(1<Ee){for(var Ae=Array(Ee),ve=0;ve<Ee;ve++)Ae[ve]=arguments[ve+2];ge.children=Ae}if(Y&&Y.defaultProps)for(be in Ee=Y.defaultProps,Ee)ge[be]===void 0&&(ge[be]=Ee[be]);return G(Y,fe,ge)},bt.createRef=function(){return{current:null}},bt.forwardRef=function(Y){return{$$typeof:l,render:Y}},bt.isValidElement=H,bt.lazy=function(Y){return{$$typeof:h,_payload:{_status:-1,_result:Y},_init:J}},bt.memo=function(Y,oe){return{$$typeof:d,type:Y,compare:oe===void 0?null:oe}},bt.startTransition=function(Y){var oe=M.T,U={};M.T=U;try{var be=Y(),ge=M.S;ge!==null&&ge(U,be),typeof be=="object"&&be!==null&&typeof be.then=="function"&&be.then(A,ie)}catch(fe){ie(fe)}finally{oe!==null&&U.types!==null&&(oe.types=U.types),M.T=oe}},bt.unstable_useCacheRefresh=function(){return M.H.useCacheRefresh()},bt.use=function(Y){return M.H.use(Y)},bt.useActionState=function(Y,oe,U){return M.H.useActionState(Y,oe,U)},bt.useCallback=function(Y,oe){return M.H.useCallback(Y,oe)},bt.useContext=function(Y){return M.H.useContext(Y)},bt.useDebugValue=function(){},bt.useDeferredValue=function(Y,oe){return M.H.useDeferredValue(Y,oe)},bt.useEffect=function(Y,oe){return M.H.useEffect(Y,oe)},bt.useEffectEvent=function(Y){return M.H.useEffectEvent(Y)},bt.useId=function(){return M.H.useId()},bt.useImperativeHandle=function(Y,oe,U){return M.H.useImperativeHandle(Y,oe,U)},bt.useInsertionEffect=function(Y,oe){return M.H.useInsertionEffect(Y,oe)},bt.useLayoutEffect=function(Y,oe){return M.H.useLayoutEffect(Y,oe)},bt.useMemo=function(Y,oe){return M.H.useMemo(Y,oe)},bt.useOptimistic=function(Y,oe){return M.H.useOptimistic(Y,oe)},bt.useReducer=function(Y,oe,U){return M.H.useReducer(Y,oe,U)},bt.useRef=function(Y){return M.H.useRef(Y)},bt.useState=function(Y){return M.H.useState(Y)},bt.useSyncExternalStore=function(Y,oe,U){return M.H.useSyncExternalStore(Y,oe,U)},bt.useTransition=function(){return M.H.useTransition()},bt.version="19.2.4",bt}var y6;function Jm(){return y6||(y6=1,O1.exports=VG()),O1.exports}var _=Jm();const fr=qh(_),j2=GG({__proto__:null,default:fr},[_]);var I1={exports:{}},Od={},L1={exports:{}},D1={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var v6;function YG(){return v6||(v6=1,(function(e){function t($,Q){var J=$.length;$.push(Q);e:for(;0<J;){var ie=J-1>>>1,F=$[ie];if(0<a(F,Q))$[ie]=Q,$[J]=F,J=ie;else break e}}function n($){return $.length===0?null:$[0]}function r($){if($.length===0)return null;var Q=$[0],J=$.pop();if(J!==Q){$[0]=J;e:for(var ie=0,F=$.length,Y=F>>>1;ie<Y;){var oe=2*(ie+1)-1,U=$[oe],be=oe+1,ge=$[be];if(0>a(U,J))be<F&&0>a(ge,U)?($[ie]=ge,$[be]=J,ie=be):($[ie]=U,$[oe]=J,ie=oe);else if(be<F&&0>a(ge,J))$[ie]=ge,$[be]=J,ie=be;else break e}}return Q}function a($,Q){var J=$.sortIndex-Q.sortIndex;return J!==0?J:$.id-Q.id}if(e.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var i=performance;e.unstable_now=function(){return i.now()}}else{var o=Date,l=o.now();e.unstable_now=function(){return o.now()-l}}var u=[],d=[],h=1,f=null,m=3,b=!1,y=!1,v=!1,w=!1,S=typeof setTimeout=="function"?setTimeout:null,k=typeof clearTimeout=="function"?clearTimeout:null,R=typeof setImmediate<"u"?setImmediate:null;function I($){for(var Q=n(d);Q!==null;){if(Q.callback===null)r(d);else if(Q.startTime<=$)r(d),Q.sortIndex=Q.expirationTime,t(u,Q);else break;Q=n(d)}}function L($){if(v=!1,I($),!y)if(n(u)!==null)y=!0,A||(A=!0,Z());else{var Q=n(d);Q!==null&&X(L,Q.startTime-$)}}var A=!1,M=-1,P=5,G=-1;function B(){return w?!0:!(e.unstable_now()-G<P)}function H(){if(w=!1,A){var $=e.unstable_now();G=$;var Q=!0;try{e:{y=!1,v&&(v=!1,k(M),M=-1),b=!0;var J=m;try{t:{for(I($),f=n(u);f!==null&&!(f.expirationTime>$&&B());){var ie=f.callback;if(typeof ie=="function"){f.callback=null,m=f.priorityLevel;var F=ie(f.expirationTime<=$);if($=e.unstable_now(),typeof F=="function"){f.callback=F,I($),Q=!0;break t}f===n(u)&&r(u),I($)}else r(u);f=n(u)}if(f!==null)Q=!0;else{var Y=n(d);Y!==null&&X(L,Y.startTime-$),Q=!1}}break e}finally{f=null,m=J,b=!1}Q=void 0}}finally{Q?Z():A=!1}}}var Z;if(typeof R=="function")Z=function(){R(H)};else if(typeof MessageChannel<"u"){var V=new MessageChannel,q=V.port2;V.port1.onmessage=H,Z=function(){q.postMessage(null)}}else Z=function(){S(H,0)};function X($,Q){M=S(function(){$(e.unstable_now())},Q)}e.unstable_IdlePriority=5,e.unstable_ImmediatePriority=1,e.unstable_LowPriority=4,e.unstable_NormalPriority=3,e.unstable_Profiling=null,e.unstable_UserBlockingPriority=2,e.unstable_cancelCallback=function($){$.callback=null},e.unstable_forceFrameRate=function($){0>$||125<$?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):P=0<$?Math.floor(1e3/$):5},e.unstable_getCurrentPriorityLevel=function(){return m},e.unstable_next=function($){switch(m){case 1:case 2:case 3:var Q=3;break;default:Q=m}var J=m;m=Q;try{return $()}finally{m=J}},e.unstable_requestPaint=function(){w=!0},e.unstable_runWithPriority=function($,Q){switch($){case 1:case 2:case 3:case 4:case 5:break;default:$=3}var J=m;m=$;try{return Q()}finally{m=J}},e.unstable_scheduleCallback=function($,Q,J){var ie=e.unstable_now();switch(typeof J=="object"&&J!==null?(J=J.delay,J=typeof J=="number"&&0<J?ie+J:ie):J=ie,$){case 1:var F=-1;break;case 2:F=250;break;case 5:F=1073741823;break;case 4:F=1e4;break;default:F=5e3}return F=J+F,$={id:h++,callback:Q,priorityLevel:$,startTime:J,expirationTime:F,sortIndex:-1},J>ie?($.sortIndex=J,t(d,$),n(u)===null&&$===n(d)&&(v?(k(M),M=-1):v=!0,X(L,J-ie))):($.sortIndex=F,t(u,$),y||b||(y=!0,A||(A=!0,Z()))),$},e.unstable_shouldYield=B,e.unstable_wrapCallback=function($){var Q=m;return function(){var J=m;m=Q;try{return $.apply(this,arguments)}finally{m=J}}}})(D1)),D1}var x6;function XG(){return x6||(x6=1,L1.exports=YG()),L1.exports}var M1={exports:{}},dr={};/**
 * @license React
 * react-dom.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var S6;function KG(){if(S6)return dr;S6=1;var e=Jm();function t(u){var d="https://react.dev/errors/"+u;if(1<arguments.length){d+="?args[]="+encodeURIComponent(arguments[1]);for(var h=2;h<arguments.length;h++)d+="&args[]="+encodeURIComponent(arguments[h])}return"Minified React error #"+u+"; visit "+d+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function n(){}var r={d:{f:n,r:function(){throw Error(t(522))},D:n,C:n,L:n,m:n,X:n,S:n,M:n},p:0,findDOMNode:null},a=Symbol.for("react.portal");function i(u,d,h){var f=3<arguments.length&&arguments[3]!==void 0?arguments[3]:null;return{$$typeof:a,key:f==null?null:""+f,children:u,containerInfo:d,implementation:h}}var o=e.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE;function l(u,d){if(u==="font")return"";if(typeof d=="string")return d==="use-credentials"?d:""}return dr.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=r,dr.createPortal=function(u,d){var h=2<arguments.length&&arguments[2]!==void 0?arguments[2]:null;if(!d||d.nodeType!==1&&d.nodeType!==9&&d.nodeType!==11)throw Error(t(299));return i(u,d,null,h)},dr.flushSync=function(u){var d=o.T,h=r.p;try{if(o.T=null,r.p=2,u)return u()}finally{o.T=d,r.p=h,r.d.f()}},dr.preconnect=function(u,d){typeof u=="string"&&(d?(d=d.crossOrigin,d=typeof d=="string"?d==="use-credentials"?d:"":void 0):d=null,r.d.C(u,d))},dr.prefetchDNS=function(u){typeof u=="string"&&r.d.D(u)},dr.preinit=function(u,d){if(typeof u=="string"&&d&&typeof d.as=="string"){var h=d.as,f=l(h,d.crossOrigin),m=typeof d.integrity=="string"?d.integrity:void 0,b=typeof d.fetchPriority=="string"?d.fetchPriority:void 0;h==="style"?r.d.S(u,typeof d.precedence=="string"?d.precedence:void 0,{crossOrigin:f,integrity:m,fetchPriority:b}):h==="script"&&r.d.X(u,{crossOrigin:f,integrity:m,fetchPriority:b,nonce:typeof d.nonce=="string"?d.nonce:void 0})}},dr.preinitModule=function(u,d){if(typeof u=="string")if(typeof d=="object"&&d!==null){if(d.as==null||d.as==="script"){var h=l(d.as,d.crossOrigin);r.d.M(u,{crossOrigin:h,integrity:typeof d.integrity=="string"?d.integrity:void 0,nonce:typeof d.nonce=="string"?d.nonce:void 0})}}else d==null&&r.d.M(u)},dr.preload=function(u,d){if(typeof u=="string"&&typeof d=="object"&&d!==null&&typeof d.as=="string"){var h=d.as,f=l(h,d.crossOrigin);r.d.L(u,h,{crossOrigin:f,integrity:typeof d.integrity=="string"?d.integrity:void 0,nonce:typeof d.nonce=="string"?d.nonce:void 0,type:typeof d.type=="string"?d.type:void 0,fetchPriority:typeof d.fetchPriority=="string"?d.fetchPriority:void 0,referrerPolicy:typeof d.referrerPolicy=="string"?d.referrerPolicy:void 0,imageSrcSet:typeof d.imageSrcSet=="string"?d.imageSrcSet:void 0,imageSizes:typeof d.imageSizes=="string"?d.imageSizes:void 0,media:typeof d.media=="string"?d.media:void 0})}},dr.preloadModule=function(u,d){if(typeof u=="string")if(d){var h=l(d.as,d.crossOrigin);r.d.m(u,{as:typeof d.as=="string"&&d.as!=="script"?d.as:void 0,crossOrigin:h,integrity:typeof d.integrity=="string"?d.integrity:void 0})}else r.d.m(u)},dr.requestFormReset=function(u){r.d.r(u)},dr.unstable_batchedUpdates=function(u,d){return u(d)},dr.useFormState=function(u,d,h){return o.H.useFormState(u,d,h)},dr.useFormStatus=function(){return o.H.useHostTransitionStatus()},dr.version="19.2.4",dr}var w6;function K8(){if(w6)return M1.exports;w6=1;function e(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(e)}catch(t){console.error(t)}}return e(),M1.exports=KG(),M1.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var E6;function ZG(){if(E6)return Od;E6=1;var e=XG(),t=Jm(),n=K8();function r(s){var c="https://react.dev/errors/"+s;if(1<arguments.length){c+="?args[]="+encodeURIComponent(arguments[1]);for(var p=2;p<arguments.length;p++)c+="&args[]="+encodeURIComponent(arguments[p])}return"Minified React error #"+s+"; visit "+c+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function a(s){return!(!s||s.nodeType!==1&&s.nodeType!==9&&s.nodeType!==11)}function i(s){var c=s,p=s;if(s.alternate)for(;c.return;)c=c.return;else{s=c;do c=s,(c.flags&4098)!==0&&(p=c.return),s=c.return;while(s)}return c.tag===3?p:null}function o(s){if(s.tag===13){var c=s.memoizedState;if(c===null&&(s=s.alternate,s!==null&&(c=s.memoizedState)),c!==null)return c.dehydrated}return null}function l(s){if(s.tag===31){var c=s.memoizedState;if(c===null&&(s=s.alternate,s!==null&&(c=s.memoizedState)),c!==null)return c.dehydrated}return null}function u(s){if(i(s)!==s)throw Error(r(188))}function d(s){var c=s.alternate;if(!c){if(c=i(s),c===null)throw Error(r(188));return c!==s?null:s}for(var p=s,g=c;;){var x=p.return;if(x===null)break;var E=x.alternate;if(E===null){if(g=x.return,g!==null){p=g;continue}break}if(x.child===E.child){for(E=x.child;E;){if(E===p)return u(x),s;if(E===g)return u(x),c;E=E.sibling}throw Error(r(188))}if(p.return!==g.return)p=x,g=E;else{for(var D=!1,j=x.child;j;){if(j===p){D=!0,p=x,g=E;break}if(j===g){D=!0,g=x,p=E;break}j=j.sibling}if(!D){for(j=E.child;j;){if(j===p){D=!0,p=E,g=x;break}if(j===g){D=!0,g=E,p=x;break}j=j.sibling}if(!D)throw Error(r(189))}}if(p.alternate!==g)throw Error(r(190))}if(p.tag!==3)throw Error(r(188));return p.stateNode.current===p?s:c}function h(s){var c=s.tag;if(c===5||c===26||c===27||c===6)return s;for(s=s.child;s!==null;){if(c=h(s),c!==null)return c;s=s.sibling}return null}var f=Object.assign,m=Symbol.for("react.element"),b=Symbol.for("react.transitional.element"),y=Symbol.for("react.portal"),v=Symbol.for("react.fragment"),w=Symbol.for("react.strict_mode"),S=Symbol.for("react.profiler"),k=Symbol.for("react.consumer"),R=Symbol.for("react.context"),I=Symbol.for("react.forward_ref"),L=Symbol.for("react.suspense"),A=Symbol.for("react.suspense_list"),M=Symbol.for("react.memo"),P=Symbol.for("react.lazy"),G=Symbol.for("react.activity"),B=Symbol.for("react.memo_cache_sentinel"),H=Symbol.iterator;function Z(s){return s===null||typeof s!="object"?null:(s=H&&s[H]||s["@@iterator"],typeof s=="function"?s:null)}var V=Symbol.for("react.client.reference");function q(s){if(s==null)return null;if(typeof s=="function")return s.$$typeof===V?null:s.displayName||s.name||null;if(typeof s=="string")return s;switch(s){case v:return"Fragment";case S:return"Profiler";case w:return"StrictMode";case L:return"Suspense";case A:return"SuspenseList";case G:return"Activity"}if(typeof s=="object")switch(s.$$typeof){case y:return"Portal";case R:return s.displayName||"Context";case k:return(s._context.displayName||"Context")+".Consumer";case I:var c=s.render;return s=s.displayName,s||(s=c.displayName||c.name||"",s=s!==""?"ForwardRef("+s+")":"ForwardRef"),s;case M:return c=s.displayName||null,c!==null?c:q(s.type)||"Memo";case P:c=s._payload,s=s._init;try{return q(s(c))}catch{}}return null}var X=Array.isArray,$=t.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,Q=n.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,J={pending:!1,data:null,method:null,action:null},ie=[],F=-1;function Y(s){return{current:s}}function oe(s){0>F||(s.current=ie[F],ie[F]=null,F--)}function U(s,c){F++,ie[F]=s.current,s.current=c}var be=Y(null),ge=Y(null),fe=Y(null),Ee=Y(null);function Ae(s,c){switch(U(fe,c),U(ge,s),U(be,null),c.nodeType){case 9:case 11:s=(s=c.documentElement)&&(s=s.namespaceURI)?z5(s):0;break;default:if(s=c.tagName,c=c.namespaceURI)c=z5(c),s=$5(c,s);else switch(s){case"svg":s=1;break;case"math":s=2;break;default:s=0}}oe(be),U(be,s)}function ve(){oe(be),oe(ge),oe(fe)}function De(s){s.memoizedState!==null&&U(Ee,s);var c=be.current,p=$5(c,s.type);c!==p&&(U(ge,s),U(be,p))}function Le(s){ge.current===s&&(oe(be),oe(ge)),Ee.current===s&&(oe(Ee),_d._currentValue=J)}var rt,Xe;function gt(s){if(rt===void 0)try{throw Error()}catch(p){var c=p.stack.trim().match(/\n( *(at )?)/);rt=c&&c[1]||"",Xe=-1<p.stack.indexOf(`
    at`)?" (<anonymous>)":-1<p.stack.indexOf("@")?"@unknown:0:0":""}return`
`+rt+s+Xe}var Xt=!1;function er(s,c){if(!s||Xt)return"";Xt=!0;var p=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var g={DetermineComponentFrameRoot:function(){try{if(c){var Se=function(){throw Error()};if(Object.defineProperty(Se.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(Se,[])}catch(pe){var he=pe}Reflect.construct(s,[],Se)}else{try{Se.call()}catch(pe){he=pe}s.call(Se.prototype)}}else{try{throw Error()}catch(pe){he=pe}(Se=s())&&typeof Se.catch=="function"&&Se.catch(function(){})}}catch(pe){if(pe&&he&&typeof pe.stack=="string")return[pe.stack,he.stack]}return[null,null]}};g.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var x=Object.getOwnPropertyDescriptor(g.DetermineComponentFrameRoot,"name");x&&x.configurable&&Object.defineProperty(g.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var E=g.DetermineComponentFrameRoot(),D=E[0],j=E[1];if(D&&j){var ne=D.split(`
`),de=j.split(`
`);for(x=g=0;g<ne.length&&!ne[g].includes("DetermineComponentFrameRoot");)g++;for(;x<de.length&&!de[x].includes("DetermineComponentFrameRoot");)x++;if(g===ne.length||x===de.length)for(g=ne.length-1,x=de.length-1;1<=g&&0<=x&&ne[g]!==de[x];)x--;for(;1<=g&&0<=x;g--,x--)if(ne[g]!==de[x]){if(g!==1||x!==1)do if(g--,x--,0>x||ne[g]!==de[x]){var ye=`
`+ne[g].replace(" at new "," at ");return s.displayName&&ye.includes("<anonymous>")&&(ye=ye.replace("<anonymous>",s.displayName)),ye}while(1<=g&&0<=x);break}}}finally{Xt=!1,Error.prepareStackTrace=p}return(p=s?s.displayName||s.name:"")?gt(p):""}function Tr(s,c){switch(s.tag){case 26:case 27:case 5:return gt(s.type);case 16:return gt("Lazy");case 13:return s.child!==c&&c!==null?gt("Suspense Fallback"):gt("Suspense");case 19:return gt("SuspenseList");case 0:case 15:return er(s.type,!1);case 11:return er(s.type.render,!1);case 1:return er(s.type,!0);case 31:return gt("Activity");default:return""}}function Hn(s){try{var c="",p=null;do c+=Tr(s,p),p=s,s=s.return;while(s);return c}catch(g){return`
Error generating stack: `+g.message+`
`+g.stack}}var Cn=Object.prototype.hasOwnProperty,Zn=e.unstable_scheduleCallback,wa=e.unstable_cancelCallback,di=e.unstable_shouldYield,qe=e.unstable_requestPaint,yt=e.unstable_now,ur=e.unstable_getCurrentPriorityLevel,me=e.unstable_ImmediatePriority,Te=e.unstable_UserBlockingPriority,We=e.unstable_NormalPriority,ut=e.unstable_LowPriority,It=e.unstable_IdlePriority,En=e.log,_r=e.unstable_setDisableYieldValue,In=null,hn=null;function pn(s){if(typeof En=="function"&&_r(s),hn&&typeof hn.setStrictMode=="function")try{hn.setStrictMode(In,s)}catch{}}var zt=Math.clz32?Math.clz32:wb,Ea=Math.log,Cr=Math.LN2;function wb(s){return s>>>=0,s===0?32:31-(Ea(s)/Cr|0)|0}var Hi=256,Gi=262144,zl=4194304;function na(s){var c=s&42;if(c!==0)return c;switch(s&-s){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:return 128;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:return s&261888;case 262144:case 524288:case 1048576:case 2097152:return s&3932160;case 4194304:case 8388608:case 16777216:case 33554432:return s&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return s}}function $l(s,c,p){var g=s.pendingLanes;if(g===0)return 0;var x=0,E=s.suspendedLanes,D=s.pingedLanes;s=s.warmLanes;var j=g&134217727;return j!==0?(g=j&~E,g!==0?x=na(g):(D&=j,D!==0?x=na(D):p||(p=j&~s,p!==0&&(x=na(p))))):(j=g&~E,j!==0?x=na(j):D!==0?x=na(D):p||(p=g&~s,p!==0&&(x=na(p)))),x===0?0:c!==0&&c!==x&&(c&E)===0&&(E=x&-x,p=c&-c,E>=p||E===32&&(p&4194048)!==0)?c:x}function Fs(s,c){return(s.pendingLanes&~(s.suspendedLanes&~s.pingedLanes)&c)===0}function An(s,c){switch(s){case 1:case 2:case 4:case 8:case 64:return c+250;case 16:case 32:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return c+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function qi(){var s=zl;return zl<<=1,(zl&62914560)===0&&(zl=4194304),s}function Mu(s){for(var c=[],p=0;31>p;p++)c.push(s);return c}function Fo(s,c){s.pendingLanes|=c,c!==268435456&&(s.suspendedLanes=0,s.pingedLanes=0,s.warmLanes=0)}function Bu(s,c,p,g,x,E){var D=s.pendingLanes;s.pendingLanes=p,s.suspendedLanes=0,s.pingedLanes=0,s.warmLanes=0,s.expiredLanes&=p,s.entangledLanes&=p,s.errorRecoveryDisabledLanes&=p,s.shellSuspendCounter=0;var j=s.entanglements,ne=s.expirationTimes,de=s.hiddenUpdates;for(p=D&~p;0<p;){var ye=31-zt(p),Se=1<<ye;j[ye]=0,ne[ye]=-1;var he=de[ye];if(he!==null)for(de[ye]=null,ye=0;ye<he.length;ye++){var pe=he[ye];pe!==null&&(pe.lane&=-536870913)}p&=~Se}g!==0&&Fu(s,g,0),E!==0&&x===0&&s.tag!==0&&(s.suspendedLanes|=E&~(D&~c))}function Fu(s,c,p){s.pendingLanes|=c,s.suspendedLanes&=~c;var g=31-zt(c);s.entangledLanes|=c,s.entanglements[g]=s.entanglements[g]|1073741824|p&261930}function zu(s,c){var p=s.entangledLanes|=c;for(s=s.entanglements;p;){var g=31-zt(p),x=1<<g;x&c|s[g]&c&&(s[g]|=c),p&=~x}}function _p(s,c){var p=c&-c;return p=(p&42)!==0?1:Ur(p),(p&(s.suspendedLanes|c))!==0?0:p}function Ur(s){switch(s){case 2:s=1;break;case 8:s=4;break;case 32:s=16;break;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:s=128;break;case 268435456:s=134217728;break;default:s=0}return s}function Ya(s){return s&=-s,2<s?8<s?(s&134217727)!==0?32:268435456:8:2}function $u(){var s=Q.p;return s!==0?s:(s=window.event,s===void 0?32:l6(s.type))}function Pu(s,c){var p=Q.p;try{return Q.p=s,c()}finally{Q.p=p}}var ka=Math.random().toString(36).slice(2),Ln="__reactFiber$"+ka,fn="__reactProps$"+ka,Wi="__reactContainer$"+ka,Pl="__reactEvents$"+ka,Cp="__reactListeners$"+ka,Ap="__reactHandles$"+ka,Rp="__reactResources$"+ka,Ke="__reactMarker$"+ka;function re(s){delete s[Ln],delete s[fn],delete s[Pl],delete s[Cp],delete s[Ap]}function _e(s){var c=s[Ln];if(c)return c;for(var p=s.parentNode;p;){if(c=p[Wi]||p[Ln]){if(p=c.alternate,c.child!==null||p!==null&&p.child!==null)for(s=W5(s);s!==null;){if(p=s[Ln])return p;s=W5(s)}return c}s=p,p=s.parentNode}return null}function $e(s){if(s=s[Ln]||s[Wi]){var c=s.tag;if(c===5||c===6||c===13||c===31||c===26||c===27||c===3)return s}return null}function Vt(s){var c=s.tag;if(c===5||c===26||c===27||c===6)return s.stateNode;throw Error(r(33))}function xn(s){var c=s[Rp];return c||(c=s[Rp]={hoistableStyles:new Map,hoistableScripts:new Map}),c}function Tt(s){s[Ke]=!0}var tr=new Set,Ta={};function jr(s,c){hi(s,c),hi(s+"Capture",c)}function hi(s,c){for(Ta[s]=c,s=0;s<c.length;s++)tr.add(c[s])}var Gn=RegExp("^[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD][:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$"),Uu={},ju={};function Dj(s){return Cn.call(ju,s)?!0:Cn.call(Uu,s)?!1:Gn.test(s)?ju[s]=!0:(Uu[s]=!0,!1)}function Np(s,c,p){if(Dj(c))if(p===null)s.removeAttribute(c);else{switch(typeof p){case"undefined":case"function":case"symbol":s.removeAttribute(c);return;case"boolean":var g=c.toLowerCase().slice(0,5);if(g!=="data-"&&g!=="aria-"){s.removeAttribute(c);return}}s.setAttribute(c,""+p)}}function Op(s,c,p){if(p===null)s.removeAttribute(c);else{switch(typeof p){case"undefined":case"function":case"symbol":case"boolean":s.removeAttribute(c);return}s.setAttribute(c,""+p)}}function Vi(s,c,p,g){if(g===null)s.removeAttribute(p);else{switch(typeof g){case"undefined":case"function":case"symbol":case"boolean":s.removeAttribute(p);return}s.setAttributeNS(c,p,""+g)}}function _a(s){switch(typeof s){case"bigint":case"boolean":case"number":case"string":case"undefined":return s;case"object":return s;default:return""}}function NC(s){var c=s.type;return(s=s.nodeName)&&s.toLowerCase()==="input"&&(c==="checkbox"||c==="radio")}function Mj(s,c,p){var g=Object.getOwnPropertyDescriptor(s.constructor.prototype,c);if(!s.hasOwnProperty(c)&&typeof g<"u"&&typeof g.get=="function"&&typeof g.set=="function"){var x=g.get,E=g.set;return Object.defineProperty(s,c,{configurable:!0,get:function(){return x.call(this)},set:function(D){p=""+D,E.call(this,D)}}),Object.defineProperty(s,c,{enumerable:g.enumerable}),{getValue:function(){return p},setValue:function(D){p=""+D},stopTracking:function(){s._valueTracker=null,delete s[c]}}}}function Eb(s){if(!s._valueTracker){var c=NC(s)?"checked":"value";s._valueTracker=Mj(s,c,""+s[c])}}function OC(s){if(!s)return!1;var c=s._valueTracker;if(!c)return!0;var p=c.getValue(),g="";return s&&(g=NC(s)?s.checked?"true":"false":s.value),s=g,s!==p?(c.setValue(s),!0):!1}function Ip(s){if(s=s||(typeof document<"u"?document:void 0),typeof s>"u")return null;try{return s.activeElement||s.body}catch{return s.body}}var Bj=/[\n"\\]/g;function Ca(s){return s.replace(Bj,function(c){return"\\"+c.charCodeAt(0).toString(16)+" "})}function kb(s,c,p,g,x,E,D,j){s.name="",D!=null&&typeof D!="function"&&typeof D!="symbol"&&typeof D!="boolean"?s.type=D:s.removeAttribute("type"),c!=null?D==="number"?(c===0&&s.value===""||s.value!=c)&&(s.value=""+_a(c)):s.value!==""+_a(c)&&(s.value=""+_a(c)):D!=="submit"&&D!=="reset"||s.removeAttribute("value"),c!=null?Tb(s,D,_a(c)):p!=null?Tb(s,D,_a(p)):g!=null&&s.removeAttribute("value"),x==null&&E!=null&&(s.defaultChecked=!!E),x!=null&&(s.checked=x&&typeof x!="function"&&typeof x!="symbol"),j!=null&&typeof j!="function"&&typeof j!="symbol"&&typeof j!="boolean"?s.name=""+_a(j):s.removeAttribute("name")}function IC(s,c,p,g,x,E,D,j){if(E!=null&&typeof E!="function"&&typeof E!="symbol"&&typeof E!="boolean"&&(s.type=E),c!=null||p!=null){if(!(E!=="submit"&&E!=="reset"||c!=null)){Eb(s);return}p=p!=null?""+_a(p):"",c=c!=null?""+_a(c):p,j||c===s.value||(s.value=c),s.defaultValue=c}g=g??x,g=typeof g!="function"&&typeof g!="symbol"&&!!g,s.checked=j?s.checked:!!g,s.defaultChecked=!!g,D!=null&&typeof D!="function"&&typeof D!="symbol"&&typeof D!="boolean"&&(s.name=D),Eb(s)}function Tb(s,c,p){c==="number"&&Ip(s.ownerDocument)===s||s.defaultValue===""+p||(s.defaultValue=""+p)}function Ul(s,c,p,g){if(s=s.options,c){c={};for(var x=0;x<p.length;x++)c["$"+p[x]]=!0;for(p=0;p<s.length;p++)x=c.hasOwnProperty("$"+s[p].value),s[p].selected!==x&&(s[p].selected=x),x&&g&&(s[p].defaultSelected=!0)}else{for(p=""+_a(p),c=null,x=0;x<s.length;x++){if(s[x].value===p){s[x].selected=!0,g&&(s[x].defaultSelected=!0);return}c!==null||s[x].disabled||(c=s[x])}c!==null&&(c.selected=!0)}}function LC(s,c,p){if(c!=null&&(c=""+_a(c),c!==s.value&&(s.value=c),p==null)){s.defaultValue!==c&&(s.defaultValue=c);return}s.defaultValue=p!=null?""+_a(p):""}function DC(s,c,p,g){if(c==null){if(g!=null){if(p!=null)throw Error(r(92));if(X(g)){if(1<g.length)throw Error(r(93));g=g[0]}p=g}p==null&&(p=""),c=p}p=_a(c),s.defaultValue=p,g=s.textContent,g===p&&g!==""&&g!==null&&(s.value=g),Eb(s)}function jl(s,c){if(c){var p=s.firstChild;if(p&&p===s.lastChild&&p.nodeType===3){p.nodeValue=c;return}}s.textContent=c}var Fj=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function MC(s,c,p){var g=c.indexOf("--")===0;p==null||typeof p=="boolean"||p===""?g?s.setProperty(c,""):c==="float"?s.cssFloat="":s[c]="":g?s.setProperty(c,p):typeof p!="number"||p===0||Fj.has(c)?c==="float"?s.cssFloat=p:s[c]=(""+p).trim():s[c]=p+"px"}function BC(s,c,p){if(c!=null&&typeof c!="object")throw Error(r(62));if(s=s.style,p!=null){for(var g in p)!p.hasOwnProperty(g)||c!=null&&c.hasOwnProperty(g)||(g.indexOf("--")===0?s.setProperty(g,""):g==="float"?s.cssFloat="":s[g]="");for(var x in c)g=c[x],c.hasOwnProperty(x)&&p[x]!==g&&MC(s,x,g)}else for(var E in c)c.hasOwnProperty(E)&&MC(s,E,c[E])}function _b(s){if(s.indexOf("-")===-1)return!1;switch(s){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var zj=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),$j=/^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*:/i;function Lp(s){return $j.test(""+s)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":s}function Yi(){}var Cb=null;function Ab(s){return s=s.target||s.srcElement||window,s.correspondingUseElement&&(s=s.correspondingUseElement),s.nodeType===3?s.parentNode:s}var Hl=null,Gl=null;function FC(s){var c=$e(s);if(c&&(s=c.stateNode)){var p=s[fn]||null;e:switch(s=c.stateNode,c.type){case"input":if(kb(s,p.value,p.defaultValue,p.defaultValue,p.checked,p.defaultChecked,p.type,p.name),c=p.name,p.type==="radio"&&c!=null){for(p=s;p.parentNode;)p=p.parentNode;for(p=p.querySelectorAll('input[name="'+Ca(""+c)+'"][type="radio"]'),c=0;c<p.length;c++){var g=p[c];if(g!==s&&g.form===s.form){var x=g[fn]||null;if(!x)throw Error(r(90));kb(g,x.value,x.defaultValue,x.defaultValue,x.checked,x.defaultChecked,x.type,x.name)}}for(c=0;c<p.length;c++)g=p[c],g.form===s.form&&OC(g)}break e;case"textarea":LC(s,p.value,p.defaultValue);break e;case"select":c=p.value,c!=null&&Ul(s,!!p.multiple,c,!1)}}}var Rb=!1;function zC(s,c,p){if(Rb)return s(c,p);Rb=!0;try{var g=s(c);return g}finally{if(Rb=!1,(Hl!==null||Gl!==null)&&(Sf(),Hl&&(c=Hl,s=Gl,Gl=Hl=null,FC(c),s)))for(c=0;c<s.length;c++)FC(s[c])}}function Hu(s,c){var p=s.stateNode;if(p===null)return null;var g=p[fn]||null;if(g===null)return null;p=g[c];e:switch(c){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(g=!g.disabled)||(s=s.type,g=!(s==="button"||s==="input"||s==="select"||s==="textarea")),s=!g;break e;default:s=!1}if(s)return null;if(p&&typeof p!="function")throw Error(r(231,c,typeof p));return p}var Xi=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),Nb=!1;if(Xi)try{var Gu={};Object.defineProperty(Gu,"passive",{get:function(){Nb=!0}}),window.addEventListener("test",Gu,Gu),window.removeEventListener("test",Gu,Gu)}catch{Nb=!1}var zo=null,Ob=null,Dp=null;function $C(){if(Dp)return Dp;var s,c=Ob,p=c.length,g,x="value"in zo?zo.value:zo.textContent,E=x.length;for(s=0;s<p&&c[s]===x[s];s++);var D=p-s;for(g=1;g<=D&&c[p-g]===x[E-g];g++);return Dp=x.slice(s,1<g?1-g:void 0)}function Mp(s){var c=s.keyCode;return"charCode"in s?(s=s.charCode,s===0&&c===13&&(s=13)):s=c,s===10&&(s=13),32<=s||s===13?s:0}function Bp(){return!0}function PC(){return!1}function Hr(s){function c(p,g,x,E,D){this._reactName=p,this._targetInst=x,this.type=g,this.nativeEvent=E,this.target=D,this.currentTarget=null;for(var j in s)s.hasOwnProperty(j)&&(p=s[j],this[j]=p?p(E):E[j]);return this.isDefaultPrevented=(E.defaultPrevented!=null?E.defaultPrevented:E.returnValue===!1)?Bp:PC,this.isPropagationStopped=PC,this}return f(c.prototype,{preventDefault:function(){this.defaultPrevented=!0;var p=this.nativeEvent;p&&(p.preventDefault?p.preventDefault():typeof p.returnValue!="unknown"&&(p.returnValue=!1),this.isDefaultPrevented=Bp)},stopPropagation:function(){var p=this.nativeEvent;p&&(p.stopPropagation?p.stopPropagation():typeof p.cancelBubble!="unknown"&&(p.cancelBubble=!0),this.isPropagationStopped=Bp)},persist:function(){},isPersistent:Bp}),c}var zs={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(s){return s.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},Fp=Hr(zs),qu=f({},zs,{view:0,detail:0}),Pj=Hr(qu),Ib,Lb,Wu,zp=f({},qu,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:Mb,button:0,buttons:0,relatedTarget:function(s){return s.relatedTarget===void 0?s.fromElement===s.srcElement?s.toElement:s.fromElement:s.relatedTarget},movementX:function(s){return"movementX"in s?s.movementX:(s!==Wu&&(Wu&&s.type==="mousemove"?(Ib=s.screenX-Wu.screenX,Lb=s.screenY-Wu.screenY):Lb=Ib=0,Wu=s),Ib)},movementY:function(s){return"movementY"in s?s.movementY:Lb}}),UC=Hr(zp),Uj=f({},zp,{dataTransfer:0}),jj=Hr(Uj),Hj=f({},qu,{relatedTarget:0}),Db=Hr(Hj),Gj=f({},zs,{animationName:0,elapsedTime:0,pseudoElement:0}),qj=Hr(Gj),Wj=f({},zs,{clipboardData:function(s){return"clipboardData"in s?s.clipboardData:window.clipboardData}}),Vj=Hr(Wj),Yj=f({},zs,{data:0}),jC=Hr(Yj),Xj={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},Kj={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},Zj={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function Qj(s){var c=this.nativeEvent;return c.getModifierState?c.getModifierState(s):(s=Zj[s])?!!c[s]:!1}function Mb(){return Qj}var Jj=f({},qu,{key:function(s){if(s.key){var c=Xj[s.key]||s.key;if(c!=="Unidentified")return c}return s.type==="keypress"?(s=Mp(s),s===13?"Enter":String.fromCharCode(s)):s.type==="keydown"||s.type==="keyup"?Kj[s.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:Mb,charCode:function(s){return s.type==="keypress"?Mp(s):0},keyCode:function(s){return s.type==="keydown"||s.type==="keyup"?s.keyCode:0},which:function(s){return s.type==="keypress"?Mp(s):s.type==="keydown"||s.type==="keyup"?s.keyCode:0}}),eH=Hr(Jj),tH=f({},zp,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),HC=Hr(tH),nH=f({},qu,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:Mb}),rH=Hr(nH),aH=f({},zs,{propertyName:0,elapsedTime:0,pseudoElement:0}),iH=Hr(aH),oH=f({},zp,{deltaX:function(s){return"deltaX"in s?s.deltaX:"wheelDeltaX"in s?-s.wheelDeltaX:0},deltaY:function(s){return"deltaY"in s?s.deltaY:"wheelDeltaY"in s?-s.wheelDeltaY:"wheelDelta"in s?-s.wheelDelta:0},deltaZ:0,deltaMode:0}),sH=Hr(oH),lH=f({},zs,{newState:0,oldState:0}),cH=Hr(lH),uH=[9,13,27,32],Bb=Xi&&"CompositionEvent"in window,Vu=null;Xi&&"documentMode"in document&&(Vu=document.documentMode);var dH=Xi&&"TextEvent"in window&&!Vu,GC=Xi&&(!Bb||Vu&&8<Vu&&11>=Vu),qC=" ",WC=!1;function VC(s,c){switch(s){case"keyup":return uH.indexOf(c.keyCode)!==-1;case"keydown":return c.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function YC(s){return s=s.detail,typeof s=="object"&&"data"in s?s.data:null}var ql=!1;function hH(s,c){switch(s){case"compositionend":return YC(c);case"keypress":return c.which!==32?null:(WC=!0,qC);case"textInput":return s=c.data,s===qC&&WC?null:s;default:return null}}function pH(s,c){if(ql)return s==="compositionend"||!Bb&&VC(s,c)?(s=$C(),Dp=Ob=zo=null,ql=!1,s):null;switch(s){case"paste":return null;case"keypress":if(!(c.ctrlKey||c.altKey||c.metaKey)||c.ctrlKey&&c.altKey){if(c.char&&1<c.char.length)return c.char;if(c.which)return String.fromCharCode(c.which)}return null;case"compositionend":return GC&&c.locale!=="ko"?null:c.data;default:return null}}var fH={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function XC(s){var c=s&&s.nodeName&&s.nodeName.toLowerCase();return c==="input"?!!fH[s.type]:c==="textarea"}function KC(s,c,p,g){Hl?Gl?Gl.push(g):Gl=[g]:Hl=g,c=Af(c,"onChange"),0<c.length&&(p=new Fp("onChange","change",null,p,g),s.push({event:p,listeners:c}))}var Yu=null,Xu=null;function mH(s){I5(s,0)}function $p(s){var c=Vt(s);if(OC(c))return s}function ZC(s,c){if(s==="change")return c}var QC=!1;if(Xi){var Fb;if(Xi){var zb="oninput"in document;if(!zb){var JC=document.createElement("div");JC.setAttribute("oninput","return;"),zb=typeof JC.oninput=="function"}Fb=zb}else Fb=!1;QC=Fb&&(!document.documentMode||9<document.documentMode)}function eA(){Yu&&(Yu.detachEvent("onpropertychange",tA),Xu=Yu=null)}function tA(s){if(s.propertyName==="value"&&$p(Xu)){var c=[];KC(c,Xu,s,Ab(s)),zC(mH,c)}}function gH(s,c,p){s==="focusin"?(eA(),Yu=c,Xu=p,Yu.attachEvent("onpropertychange",tA)):s==="focusout"&&eA()}function bH(s){if(s==="selectionchange"||s==="keyup"||s==="keydown")return $p(Xu)}function yH(s,c){if(s==="click")return $p(c)}function vH(s,c){if(s==="input"||s==="change")return $p(c)}function xH(s,c){return s===c&&(s!==0||1/s===1/c)||s!==s&&c!==c}var ra=typeof Object.is=="function"?Object.is:xH;function Ku(s,c){if(ra(s,c))return!0;if(typeof s!="object"||s===null||typeof c!="object"||c===null)return!1;var p=Object.keys(s),g=Object.keys(c);if(p.length!==g.length)return!1;for(g=0;g<p.length;g++){var x=p[g];if(!Cn.call(c,x)||!ra(s[x],c[x]))return!1}return!0}function nA(s){for(;s&&s.firstChild;)s=s.firstChild;return s}function rA(s,c){var p=nA(s);s=0;for(var g;p;){if(p.nodeType===3){if(g=s+p.textContent.length,s<=c&&g>=c)return{node:p,offset:c-s};s=g}e:{for(;p;){if(p.nextSibling){p=p.nextSibling;break e}p=p.parentNode}p=void 0}p=nA(p)}}function aA(s,c){return s&&c?s===c?!0:s&&s.nodeType===3?!1:c&&c.nodeType===3?aA(s,c.parentNode):"contains"in s?s.contains(c):s.compareDocumentPosition?!!(s.compareDocumentPosition(c)&16):!1:!1}function iA(s){s=s!=null&&s.ownerDocument!=null&&s.ownerDocument.defaultView!=null?s.ownerDocument.defaultView:window;for(var c=Ip(s.document);c instanceof s.HTMLIFrameElement;){try{var p=typeof c.contentWindow.location.href=="string"}catch{p=!1}if(p)s=c.contentWindow;else break;c=Ip(s.document)}return c}function $b(s){var c=s&&s.nodeName&&s.nodeName.toLowerCase();return c&&(c==="input"&&(s.type==="text"||s.type==="search"||s.type==="tel"||s.type==="url"||s.type==="password")||c==="textarea"||s.contentEditable==="true")}var SH=Xi&&"documentMode"in document&&11>=document.documentMode,Wl=null,Pb=null,Zu=null,Ub=!1;function oA(s,c,p){var g=p.window===p?p.document:p.nodeType===9?p:p.ownerDocument;Ub||Wl==null||Wl!==Ip(g)||(g=Wl,"selectionStart"in g&&$b(g)?g={start:g.selectionStart,end:g.selectionEnd}:(g=(g.ownerDocument&&g.ownerDocument.defaultView||window).getSelection(),g={anchorNode:g.anchorNode,anchorOffset:g.anchorOffset,focusNode:g.focusNode,focusOffset:g.focusOffset}),Zu&&Ku(Zu,g)||(Zu=g,g=Af(Pb,"onSelect"),0<g.length&&(c=new Fp("onSelect","select",null,c,p),s.push({event:c,listeners:g}),c.target=Wl)))}function $s(s,c){var p={};return p[s.toLowerCase()]=c.toLowerCase(),p["Webkit"+s]="webkit"+c,p["Moz"+s]="moz"+c,p}var Vl={animationend:$s("Animation","AnimationEnd"),animationiteration:$s("Animation","AnimationIteration"),animationstart:$s("Animation","AnimationStart"),transitionrun:$s("Transition","TransitionRun"),transitionstart:$s("Transition","TransitionStart"),transitioncancel:$s("Transition","TransitionCancel"),transitionend:$s("Transition","TransitionEnd")},jb={},sA={};Xi&&(sA=document.createElement("div").style,"AnimationEvent"in window||(delete Vl.animationend.animation,delete Vl.animationiteration.animation,delete Vl.animationstart.animation),"TransitionEvent"in window||delete Vl.transitionend.transition);function Ps(s){if(jb[s])return jb[s];if(!Vl[s])return s;var c=Vl[s],p;for(p in c)if(c.hasOwnProperty(p)&&p in sA)return jb[s]=c[p];return s}var lA=Ps("animationend"),cA=Ps("animationiteration"),uA=Ps("animationstart"),wH=Ps("transitionrun"),EH=Ps("transitionstart"),kH=Ps("transitioncancel"),dA=Ps("transitionend"),hA=new Map,Hb="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll toggle touchMove waiting wheel".split(" ");Hb.push("scrollEnd");function Xa(s,c){hA.set(s,c),jr(c,[s])}var Pp=typeof reportError=="function"?reportError:function(s){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var c=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof s=="object"&&s!==null&&typeof s.message=="string"?String(s.message):String(s),error:s});if(!window.dispatchEvent(c))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",s);return}console.error(s)},Aa=[],Yl=0,Gb=0;function Up(){for(var s=Yl,c=Gb=Yl=0;c<s;){var p=Aa[c];Aa[c++]=null;var g=Aa[c];Aa[c++]=null;var x=Aa[c];Aa[c++]=null;var E=Aa[c];if(Aa[c++]=null,g!==null&&x!==null){var D=g.pending;D===null?x.next=x:(x.next=D.next,D.next=x),g.pending=x}E!==0&&pA(p,x,E)}}function jp(s,c,p,g){Aa[Yl++]=s,Aa[Yl++]=c,Aa[Yl++]=p,Aa[Yl++]=g,Gb|=g,s.lanes|=g,s=s.alternate,s!==null&&(s.lanes|=g)}function qb(s,c,p,g){return jp(s,c,p,g),Hp(s)}function Us(s,c){return jp(s,null,null,c),Hp(s)}function pA(s,c,p){s.lanes|=p;var g=s.alternate;g!==null&&(g.lanes|=p);for(var x=!1,E=s.return;E!==null;)E.childLanes|=p,g=E.alternate,g!==null&&(g.childLanes|=p),E.tag===22&&(s=E.stateNode,s===null||s._visibility&1||(x=!0)),s=E,E=E.return;return s.tag===3?(E=s.stateNode,x&&c!==null&&(x=31-zt(p),s=E.hiddenUpdates,g=s[x],g===null?s[x]=[c]:g.push(c),c.lane=p|536870912),E):null}function Hp(s){if(50<vd)throw vd=0,e1=null,Error(r(185));for(var c=s.return;c!==null;)s=c,c=s.return;return s.tag===3?s.stateNode:null}var Xl={};function TH(s,c,p,g){this.tag=s,this.key=p,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=c,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=g,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function aa(s,c,p,g){return new TH(s,c,p,g)}function Wb(s){return s=s.prototype,!(!s||!s.isReactComponent)}function Ki(s,c){var p=s.alternate;return p===null?(p=aa(s.tag,c,s.key,s.mode),p.elementType=s.elementType,p.type=s.type,p.stateNode=s.stateNode,p.alternate=s,s.alternate=p):(p.pendingProps=c,p.type=s.type,p.flags=0,p.subtreeFlags=0,p.deletions=null),p.flags=s.flags&65011712,p.childLanes=s.childLanes,p.lanes=s.lanes,p.child=s.child,p.memoizedProps=s.memoizedProps,p.memoizedState=s.memoizedState,p.updateQueue=s.updateQueue,c=s.dependencies,p.dependencies=c===null?null:{lanes:c.lanes,firstContext:c.firstContext},p.sibling=s.sibling,p.index=s.index,p.ref=s.ref,p.refCleanup=s.refCleanup,p}function fA(s,c){s.flags&=65011714;var p=s.alternate;return p===null?(s.childLanes=0,s.lanes=c,s.child=null,s.subtreeFlags=0,s.memoizedProps=null,s.memoizedState=null,s.updateQueue=null,s.dependencies=null,s.stateNode=null):(s.childLanes=p.childLanes,s.lanes=p.lanes,s.child=p.child,s.subtreeFlags=0,s.deletions=null,s.memoizedProps=p.memoizedProps,s.memoizedState=p.memoizedState,s.updateQueue=p.updateQueue,s.type=p.type,c=p.dependencies,s.dependencies=c===null?null:{lanes:c.lanes,firstContext:c.firstContext}),s}function Gp(s,c,p,g,x,E){var D=0;if(g=s,typeof s=="function")Wb(s)&&(D=1);else if(typeof s=="string")D=NG(s,p,be.current)?26:s==="html"||s==="head"||s==="body"?27:5;else e:switch(s){case G:return s=aa(31,p,c,x),s.elementType=G,s.lanes=E,s;case v:return js(p.children,x,E,c);case w:D=8,x|=24;break;case S:return s=aa(12,p,c,x|2),s.elementType=S,s.lanes=E,s;case L:return s=aa(13,p,c,x),s.elementType=L,s.lanes=E,s;case A:return s=aa(19,p,c,x),s.elementType=A,s.lanes=E,s;default:if(typeof s=="object"&&s!==null)switch(s.$$typeof){case R:D=10;break e;case k:D=9;break e;case I:D=11;break e;case M:D=14;break e;case P:D=16,g=null;break e}D=29,p=Error(r(130,s===null?"null":typeof s,"")),g=null}return c=aa(D,p,c,x),c.elementType=s,c.type=g,c.lanes=E,c}function js(s,c,p,g){return s=aa(7,s,g,c),s.lanes=p,s}function Vb(s,c,p){return s=aa(6,s,null,c),s.lanes=p,s}function mA(s){var c=aa(18,null,null,0);return c.stateNode=s,c}function Yb(s,c,p){return c=aa(4,s.children!==null?s.children:[],s.key,c),c.lanes=p,c.stateNode={containerInfo:s.containerInfo,pendingChildren:null,implementation:s.implementation},c}var gA=new WeakMap;function Ra(s,c){if(typeof s=="object"&&s!==null){var p=gA.get(s);return p!==void 0?p:(c={value:s,source:c,stack:Hn(c)},gA.set(s,c),c)}return{value:s,source:c,stack:Hn(c)}}var Kl=[],Zl=0,qp=null,Qu=0,Na=[],Oa=0,$o=null,pi=1,fi="";function Zi(s,c){Kl[Zl++]=Qu,Kl[Zl++]=qp,qp=s,Qu=c}function bA(s,c,p){Na[Oa++]=pi,Na[Oa++]=fi,Na[Oa++]=$o,$o=s;var g=pi;s=fi;var x=32-zt(g)-1;g&=~(1<<x),p+=1;var E=32-zt(c)+x;if(30<E){var D=x-x%5;E=(g&(1<<D)-1).toString(32),g>>=D,x-=D,pi=1<<32-zt(c)+x|p<<x|g,fi=E+s}else pi=1<<E|p<<x|g,fi=s}function Xb(s){s.return!==null&&(Zi(s,1),bA(s,1,0))}function Kb(s){for(;s===qp;)qp=Kl[--Zl],Kl[Zl]=null,Qu=Kl[--Zl],Kl[Zl]=null;for(;s===$o;)$o=Na[--Oa],Na[Oa]=null,fi=Na[--Oa],Na[Oa]=null,pi=Na[--Oa],Na[Oa]=null}function yA(s,c){Na[Oa++]=pi,Na[Oa++]=fi,Na[Oa++]=$o,pi=c.id,fi=c.overflow,$o=s}var nr=null,sn=null,Bt=!1,Po=null,Ia=!1,Zb=Error(r(519));function Uo(s){var c=Error(r(418,1<arguments.length&&arguments[1]!==void 0&&arguments[1]?"text":"HTML",""));throw Ju(Ra(c,s)),Zb}function vA(s){var c=s.stateNode,p=s.type,g=s.memoizedProps;switch(c[Ln]=s,c[fn]=g,p){case"dialog":Nt("cancel",c),Nt("close",c);break;case"iframe":case"object":case"embed":Nt("load",c);break;case"video":case"audio":for(p=0;p<Sd.length;p++)Nt(Sd[p],c);break;case"source":Nt("error",c);break;case"img":case"image":case"link":Nt("error",c),Nt("load",c);break;case"details":Nt("toggle",c);break;case"input":Nt("invalid",c),IC(c,g.value,g.defaultValue,g.checked,g.defaultChecked,g.type,g.name,!0);break;case"select":Nt("invalid",c);break;case"textarea":Nt("invalid",c),DC(c,g.value,g.defaultValue,g.children)}p=g.children,typeof p!="string"&&typeof p!="number"&&typeof p!="bigint"||c.textContent===""+p||g.suppressHydrationWarning===!0||B5(c.textContent,p)?(g.popover!=null&&(Nt("beforetoggle",c),Nt("toggle",c)),g.onScroll!=null&&Nt("scroll",c),g.onScrollEnd!=null&&Nt("scrollend",c),g.onClick!=null&&(c.onclick=Yi),c=!0):c=!1,c||Uo(s,!0)}function xA(s){for(nr=s.return;nr;)switch(nr.tag){case 5:case 31:case 13:Ia=!1;return;case 27:case 3:Ia=!0;return;default:nr=nr.return}}function Ql(s){if(s!==nr)return!1;if(!Bt)return xA(s),Bt=!0,!1;var c=s.tag,p;if((p=c!==3&&c!==27)&&((p=c===5)&&(p=s.type,p=!(p!=="form"&&p!=="button")||m1(s.type,s.memoizedProps)),p=!p),p&&sn&&Uo(s),xA(s),c===13){if(s=s.memoizedState,s=s!==null?s.dehydrated:null,!s)throw Error(r(317));sn=q5(s)}else if(c===31){if(s=s.memoizedState,s=s!==null?s.dehydrated:null,!s)throw Error(r(317));sn=q5(s)}else c===27?(c=sn,ts(s.type)?(s=x1,x1=null,sn=s):sn=c):sn=nr?Da(s.stateNode.nextSibling):null;return!0}function Hs(){sn=nr=null,Bt=!1}function Qb(){var s=Po;return s!==null&&(Vr===null?Vr=s:Vr.push.apply(Vr,s),Po=null),s}function Ju(s){Po===null?Po=[s]:Po.push(s)}var Jb=Y(null),Gs=null,Qi=null;function jo(s,c,p){U(Jb,c._currentValue),c._currentValue=p}function Ji(s){s._currentValue=Jb.current,oe(Jb)}function ey(s,c,p){for(;s!==null;){var g=s.alternate;if((s.childLanes&c)!==c?(s.childLanes|=c,g!==null&&(g.childLanes|=c)):g!==null&&(g.childLanes&c)!==c&&(g.childLanes|=c),s===p)break;s=s.return}}function ty(s,c,p,g){var x=s.child;for(x!==null&&(x.return=s);x!==null;){var E=x.dependencies;if(E!==null){var D=x.child;E=E.firstContext;e:for(;E!==null;){var j=E;E=x;for(var ne=0;ne<c.length;ne++)if(j.context===c[ne]){E.lanes|=p,j=E.alternate,j!==null&&(j.lanes|=p),ey(E.return,p,s),g||(D=null);break e}E=j.next}}else if(x.tag===18){if(D=x.return,D===null)throw Error(r(341));D.lanes|=p,E=D.alternate,E!==null&&(E.lanes|=p),ey(D,p,s),D=null}else D=x.child;if(D!==null)D.return=x;else for(D=x;D!==null;){if(D===s){D=null;break}if(x=D.sibling,x!==null){x.return=D.return,D=x;break}D=D.return}x=D}}function Jl(s,c,p,g){s=null;for(var x=c,E=!1;x!==null;){if(!E){if((x.flags&524288)!==0)E=!0;else if((x.flags&262144)!==0)break}if(x.tag===10){var D=x.alternate;if(D===null)throw Error(r(387));if(D=D.memoizedProps,D!==null){var j=x.type;ra(x.pendingProps.value,D.value)||(s!==null?s.push(j):s=[j])}}else if(x===Ee.current){if(D=x.alternate,D===null)throw Error(r(387));D.memoizedState.memoizedState!==x.memoizedState.memoizedState&&(s!==null?s.push(_d):s=[_d])}x=x.return}s!==null&&ty(c,s,p,g),c.flags|=262144}function Wp(s){for(s=s.firstContext;s!==null;){if(!ra(s.context._currentValue,s.memoizedValue))return!0;s=s.next}return!1}function qs(s){Gs=s,Qi=null,s=s.dependencies,s!==null&&(s.firstContext=null)}function rr(s){return SA(Gs,s)}function Vp(s,c){return Gs===null&&qs(s),SA(s,c)}function SA(s,c){var p=c._currentValue;if(c={context:c,memoizedValue:p,next:null},Qi===null){if(s===null)throw Error(r(308));Qi=c,s.dependencies={lanes:0,firstContext:c},s.flags|=524288}else Qi=Qi.next=c;return p}var _H=typeof AbortController<"u"?AbortController:function(){var s=[],c=this.signal={aborted:!1,addEventListener:function(p,g){s.push(g)}};this.abort=function(){c.aborted=!0,s.forEach(function(p){return p()})}},CH=e.unstable_scheduleCallback,AH=e.unstable_NormalPriority,Dn={$$typeof:R,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function ny(){return{controller:new _H,data:new Map,refCount:0}}function ed(s){s.refCount--,s.refCount===0&&CH(AH,function(){s.controller.abort()})}var td=null,ry=0,ec=0,tc=null;function RH(s,c){if(td===null){var p=td=[];ry=0,ec=o1(),tc={status:"pending",value:void 0,then:function(g){p.push(g)}}}return ry++,c.then(wA,wA),c}function wA(){if(--ry===0&&td!==null){tc!==null&&(tc.status="fulfilled");var s=td;td=null,ec=0,tc=null;for(var c=0;c<s.length;c++)(0,s[c])()}}function NH(s,c){var p=[],g={status:"pending",value:null,reason:null,then:function(x){p.push(x)}};return s.then(function(){g.status="fulfilled",g.value=c;for(var x=0;x<p.length;x++)(0,p[x])(c)},function(x){for(g.status="rejected",g.reason=x,x=0;x<p.length;x++)(0,p[x])(void 0)}),g}var EA=$.S;$.S=function(s,c){o5=yt(),typeof c=="object"&&c!==null&&typeof c.then=="function"&&RH(s,c),EA!==null&&EA(s,c)};var Ws=Y(null);function ay(){var s=Ws.current;return s!==null?s:nn.pooledCache}function Yp(s,c){c===null?U(Ws,Ws.current):U(Ws,c.pool)}function kA(){var s=ay();return s===null?null:{parent:Dn._currentValue,pool:s}}var nc=Error(r(460)),iy=Error(r(474)),Xp=Error(r(542)),Kp={then:function(){}};function TA(s){return s=s.status,s==="fulfilled"||s==="rejected"}function _A(s,c,p){switch(p=s[p],p===void 0?s.push(c):p!==c&&(c.then(Yi,Yi),c=p),c.status){case"fulfilled":return c.value;case"rejected":throw s=c.reason,AA(s),s;default:if(typeof c.status=="string")c.then(Yi,Yi);else{if(s=nn,s!==null&&100<s.shellSuspendCounter)throw Error(r(482));s=c,s.status="pending",s.then(function(g){if(c.status==="pending"){var x=c;x.status="fulfilled",x.value=g}},function(g){if(c.status==="pending"){var x=c;x.status="rejected",x.reason=g}})}switch(c.status){case"fulfilled":return c.value;case"rejected":throw s=c.reason,AA(s),s}throw Ys=c,nc}}function Vs(s){try{var c=s._init;return c(s._payload)}catch(p){throw p!==null&&typeof p=="object"&&typeof p.then=="function"?(Ys=p,nc):p}}var Ys=null;function CA(){if(Ys===null)throw Error(r(459));var s=Ys;return Ys=null,s}function AA(s){if(s===nc||s===Xp)throw Error(r(483))}var rc=null,nd=0;function Zp(s){var c=nd;return nd+=1,rc===null&&(rc=[]),_A(rc,s,c)}function rd(s,c){c=c.props.ref,s.ref=c!==void 0?c:null}function Qp(s,c){throw c.$$typeof===m?Error(r(525)):(s=Object.prototype.toString.call(c),Error(r(31,s==="[object Object]"?"object with keys {"+Object.keys(c).join(", ")+"}":s)))}function RA(s){function c(ce,ae){if(s){var ue=ce.deletions;ue===null?(ce.deletions=[ae],ce.flags|=16):ue.push(ae)}}function p(ce,ae){if(!s)return null;for(;ae!==null;)c(ce,ae),ae=ae.sibling;return null}function g(ce){for(var ae=new Map;ce!==null;)ce.key!==null?ae.set(ce.key,ce):ae.set(ce.index,ce),ce=ce.sibling;return ae}function x(ce,ae){return ce=Ki(ce,ae),ce.index=0,ce.sibling=null,ce}function E(ce,ae,ue){return ce.index=ue,s?(ue=ce.alternate,ue!==null?(ue=ue.index,ue<ae?(ce.flags|=67108866,ae):ue):(ce.flags|=67108866,ae)):(ce.flags|=1048576,ae)}function D(ce){return s&&ce.alternate===null&&(ce.flags|=67108866),ce}function j(ce,ae,ue,xe){return ae===null||ae.tag!==6?(ae=Vb(ue,ce.mode,xe),ae.return=ce,ae):(ae=x(ae,ue),ae.return=ce,ae)}function ne(ce,ae,ue,xe){var tt=ue.type;return tt===v?ye(ce,ae,ue.props.children,xe,ue.key):ae!==null&&(ae.elementType===tt||typeof tt=="object"&&tt!==null&&tt.$$typeof===P&&Vs(tt)===ae.type)?(ae=x(ae,ue.props),rd(ae,ue),ae.return=ce,ae):(ae=Gp(ue.type,ue.key,ue.props,null,ce.mode,xe),rd(ae,ue),ae.return=ce,ae)}function de(ce,ae,ue,xe){return ae===null||ae.tag!==4||ae.stateNode.containerInfo!==ue.containerInfo||ae.stateNode.implementation!==ue.implementation?(ae=Yb(ue,ce.mode,xe),ae.return=ce,ae):(ae=x(ae,ue.children||[]),ae.return=ce,ae)}function ye(ce,ae,ue,xe,tt){return ae===null||ae.tag!==7?(ae=js(ue,ce.mode,xe,tt),ae.return=ce,ae):(ae=x(ae,ue),ae.return=ce,ae)}function Se(ce,ae,ue){if(typeof ae=="string"&&ae!==""||typeof ae=="number"||typeof ae=="bigint")return ae=Vb(""+ae,ce.mode,ue),ae.return=ce,ae;if(typeof ae=="object"&&ae!==null){switch(ae.$$typeof){case b:return ue=Gp(ae.type,ae.key,ae.props,null,ce.mode,ue),rd(ue,ae),ue.return=ce,ue;case y:return ae=Yb(ae,ce.mode,ue),ae.return=ce,ae;case P:return ae=Vs(ae),Se(ce,ae,ue)}if(X(ae)||Z(ae))return ae=js(ae,ce.mode,ue,null),ae.return=ce,ae;if(typeof ae.then=="function")return Se(ce,Zp(ae),ue);if(ae.$$typeof===R)return Se(ce,Vp(ce,ae),ue);Qp(ce,ae)}return null}function he(ce,ae,ue,xe){var tt=ae!==null?ae.key:null;if(typeof ue=="string"&&ue!==""||typeof ue=="number"||typeof ue=="bigint")return tt!==null?null:j(ce,ae,""+ue,xe);if(typeof ue=="object"&&ue!==null){switch(ue.$$typeof){case b:return ue.key===tt?ne(ce,ae,ue,xe):null;case y:return ue.key===tt?de(ce,ae,ue,xe):null;case P:return ue=Vs(ue),he(ce,ae,ue,xe)}if(X(ue)||Z(ue))return tt!==null?null:ye(ce,ae,ue,xe,null);if(typeof ue.then=="function")return he(ce,ae,Zp(ue),xe);if(ue.$$typeof===R)return he(ce,ae,Vp(ce,ue),xe);Qp(ce,ue)}return null}function pe(ce,ae,ue,xe,tt){if(typeof xe=="string"&&xe!==""||typeof xe=="number"||typeof xe=="bigint")return ce=ce.get(ue)||null,j(ae,ce,""+xe,tt);if(typeof xe=="object"&&xe!==null){switch(xe.$$typeof){case b:return ce=ce.get(xe.key===null?ue:xe.key)||null,ne(ae,ce,xe,tt);case y:return ce=ce.get(xe.key===null?ue:xe.key)||null,de(ae,ce,xe,tt);case P:return xe=Vs(xe),pe(ce,ae,ue,xe,tt)}if(X(xe)||Z(xe))return ce=ce.get(ue)||null,ye(ae,ce,xe,tt,null);if(typeof xe.then=="function")return pe(ce,ae,ue,Zp(xe),tt);if(xe.$$typeof===R)return pe(ce,ae,ue,Vp(ae,xe),tt);Qp(ae,xe)}return null}function Pe(ce,ae,ue,xe){for(var tt=null,$t=null,Ze=ae,xt=ae=0,Dt=null;Ze!==null&&xt<ue.length;xt++){Ze.index>xt?(Dt=Ze,Ze=null):Dt=Ze.sibling;var Pt=he(ce,Ze,ue[xt],xe);if(Pt===null){Ze===null&&(Ze=Dt);break}s&&Ze&&Pt.alternate===null&&c(ce,Ze),ae=E(Pt,ae,xt),$t===null?tt=Pt:$t.sibling=Pt,$t=Pt,Ze=Dt}if(xt===ue.length)return p(ce,Ze),Bt&&Zi(ce,xt),tt;if(Ze===null){for(;xt<ue.length;xt++)Ze=Se(ce,ue[xt],xe),Ze!==null&&(ae=E(Ze,ae,xt),$t===null?tt=Ze:$t.sibling=Ze,$t=Ze);return Bt&&Zi(ce,xt),tt}for(Ze=g(Ze);xt<ue.length;xt++)Dt=pe(Ze,ce,xt,ue[xt],xe),Dt!==null&&(s&&Dt.alternate!==null&&Ze.delete(Dt.key===null?xt:Dt.key),ae=E(Dt,ae,xt),$t===null?tt=Dt:$t.sibling=Dt,$t=Dt);return s&&Ze.forEach(function(os){return c(ce,os)}),Bt&&Zi(ce,xt),tt}function ot(ce,ae,ue,xe){if(ue==null)throw Error(r(151));for(var tt=null,$t=null,Ze=ae,xt=ae=0,Dt=null,Pt=ue.next();Ze!==null&&!Pt.done;xt++,Pt=ue.next()){Ze.index>xt?(Dt=Ze,Ze=null):Dt=Ze.sibling;var os=he(ce,Ze,Pt.value,xe);if(os===null){Ze===null&&(Ze=Dt);break}s&&Ze&&os.alternate===null&&c(ce,Ze),ae=E(os,ae,xt),$t===null?tt=os:$t.sibling=os,$t=os,Ze=Dt}if(Pt.done)return p(ce,Ze),Bt&&Zi(ce,xt),tt;if(Ze===null){for(;!Pt.done;xt++,Pt=ue.next())Pt=Se(ce,Pt.value,xe),Pt!==null&&(ae=E(Pt,ae,xt),$t===null?tt=Pt:$t.sibling=Pt,$t=Pt);return Bt&&Zi(ce,xt),tt}for(Ze=g(Ze);!Pt.done;xt++,Pt=ue.next())Pt=pe(Ze,ce,xt,Pt.value,xe),Pt!==null&&(s&&Pt.alternate!==null&&Ze.delete(Pt.key===null?xt:Pt.key),ae=E(Pt,ae,xt),$t===null?tt=Pt:$t.sibling=Pt,$t=Pt);return s&&Ze.forEach(function(UG){return c(ce,UG)}),Bt&&Zi(ce,xt),tt}function en(ce,ae,ue,xe){if(typeof ue=="object"&&ue!==null&&ue.type===v&&ue.key===null&&(ue=ue.props.children),typeof ue=="object"&&ue!==null){switch(ue.$$typeof){case b:e:{for(var tt=ue.key;ae!==null;){if(ae.key===tt){if(tt=ue.type,tt===v){if(ae.tag===7){p(ce,ae.sibling),xe=x(ae,ue.props.children),xe.return=ce,ce=xe;break e}}else if(ae.elementType===tt||typeof tt=="object"&&tt!==null&&tt.$$typeof===P&&Vs(tt)===ae.type){p(ce,ae.sibling),xe=x(ae,ue.props),rd(xe,ue),xe.return=ce,ce=xe;break e}p(ce,ae);break}else c(ce,ae);ae=ae.sibling}ue.type===v?(xe=js(ue.props.children,ce.mode,xe,ue.key),xe.return=ce,ce=xe):(xe=Gp(ue.type,ue.key,ue.props,null,ce.mode,xe),rd(xe,ue),xe.return=ce,ce=xe)}return D(ce);case y:e:{for(tt=ue.key;ae!==null;){if(ae.key===tt)if(ae.tag===4&&ae.stateNode.containerInfo===ue.containerInfo&&ae.stateNode.implementation===ue.implementation){p(ce,ae.sibling),xe=x(ae,ue.children||[]),xe.return=ce,ce=xe;break e}else{p(ce,ae);break}else c(ce,ae);ae=ae.sibling}xe=Yb(ue,ce.mode,xe),xe.return=ce,ce=xe}return D(ce);case P:return ue=Vs(ue),en(ce,ae,ue,xe)}if(X(ue))return Pe(ce,ae,ue,xe);if(Z(ue)){if(tt=Z(ue),typeof tt!="function")throw Error(r(150));return ue=tt.call(ue),ot(ce,ae,ue,xe)}if(typeof ue.then=="function")return en(ce,ae,Zp(ue),xe);if(ue.$$typeof===R)return en(ce,ae,Vp(ce,ue),xe);Qp(ce,ue)}return typeof ue=="string"&&ue!==""||typeof ue=="number"||typeof ue=="bigint"?(ue=""+ue,ae!==null&&ae.tag===6?(p(ce,ae.sibling),xe=x(ae,ue),xe.return=ce,ce=xe):(p(ce,ae),xe=Vb(ue,ce.mode,xe),xe.return=ce,ce=xe),D(ce)):p(ce,ae)}return function(ce,ae,ue,xe){try{nd=0;var tt=en(ce,ae,ue,xe);return rc=null,tt}catch(Ze){if(Ze===nc||Ze===Xp)throw Ze;var $t=aa(29,Ze,null,ce.mode);return $t.lanes=xe,$t.return=ce,$t}finally{}}}var Xs=RA(!0),NA=RA(!1),Ho=!1;function oy(s){s.updateQueue={baseState:s.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function sy(s,c){s=s.updateQueue,c.updateQueue===s&&(c.updateQueue={baseState:s.baseState,firstBaseUpdate:s.firstBaseUpdate,lastBaseUpdate:s.lastBaseUpdate,shared:s.shared,callbacks:null})}function Go(s){return{lane:s,tag:0,payload:null,callback:null,next:null}}function qo(s,c,p){var g=s.updateQueue;if(g===null)return null;if(g=g.shared,(Ht&2)!==0){var x=g.pending;return x===null?c.next=c:(c.next=x.next,x.next=c),g.pending=c,c=Hp(s),pA(s,null,p),c}return jp(s,g,c,p),Hp(s)}function ad(s,c,p){if(c=c.updateQueue,c!==null&&(c=c.shared,(p&4194048)!==0)){var g=c.lanes;g&=s.pendingLanes,p|=g,c.lanes=p,zu(s,p)}}function ly(s,c){var p=s.updateQueue,g=s.alternate;if(g!==null&&(g=g.updateQueue,p===g)){var x=null,E=null;if(p=p.firstBaseUpdate,p!==null){do{var D={lane:p.lane,tag:p.tag,payload:p.payload,callback:null,next:null};E===null?x=E=D:E=E.next=D,p=p.next}while(p!==null);E===null?x=E=c:E=E.next=c}else x=E=c;p={baseState:g.baseState,firstBaseUpdate:x,lastBaseUpdate:E,shared:g.shared,callbacks:g.callbacks},s.updateQueue=p;return}s=p.lastBaseUpdate,s===null?p.firstBaseUpdate=c:s.next=c,p.lastBaseUpdate=c}var cy=!1;function id(){if(cy){var s=tc;if(s!==null)throw s}}function od(s,c,p,g){cy=!1;var x=s.updateQueue;Ho=!1;var E=x.firstBaseUpdate,D=x.lastBaseUpdate,j=x.shared.pending;if(j!==null){x.shared.pending=null;var ne=j,de=ne.next;ne.next=null,D===null?E=de:D.next=de,D=ne;var ye=s.alternate;ye!==null&&(ye=ye.updateQueue,j=ye.lastBaseUpdate,j!==D&&(j===null?ye.firstBaseUpdate=de:j.next=de,ye.lastBaseUpdate=ne))}if(E!==null){var Se=x.baseState;D=0,ye=de=ne=null,j=E;do{var he=j.lane&-536870913,pe=he!==j.lane;if(pe?(Lt&he)===he:(g&he)===he){he!==0&&he===ec&&(cy=!0),ye!==null&&(ye=ye.next={lane:0,tag:j.tag,payload:j.payload,callback:null,next:null});e:{var Pe=s,ot=j;he=c;var en=p;switch(ot.tag){case 1:if(Pe=ot.payload,typeof Pe=="function"){Se=Pe.call(en,Se,he);break e}Se=Pe;break e;case 3:Pe.flags=Pe.flags&-65537|128;case 0:if(Pe=ot.payload,he=typeof Pe=="function"?Pe.call(en,Se,he):Pe,he==null)break e;Se=f({},Se,he);break e;case 2:Ho=!0}}he=j.callback,he!==null&&(s.flags|=64,pe&&(s.flags|=8192),pe=x.callbacks,pe===null?x.callbacks=[he]:pe.push(he))}else pe={lane:he,tag:j.tag,payload:j.payload,callback:j.callback,next:null},ye===null?(de=ye=pe,ne=Se):ye=ye.next=pe,D|=he;if(j=j.next,j===null){if(j=x.shared.pending,j===null)break;pe=j,j=pe.next,pe.next=null,x.lastBaseUpdate=pe,x.shared.pending=null}}while(!0);ye===null&&(ne=Se),x.baseState=ne,x.firstBaseUpdate=de,x.lastBaseUpdate=ye,E===null&&(x.shared.lanes=0),Ko|=D,s.lanes=D,s.memoizedState=Se}}function OA(s,c){if(typeof s!="function")throw Error(r(191,s));s.call(c)}function IA(s,c){var p=s.callbacks;if(p!==null)for(s.callbacks=null,s=0;s<p.length;s++)OA(p[s],c)}var ac=Y(null),Jp=Y(0);function LA(s,c){s=lo,U(Jp,s),U(ac,c),lo=s|c.baseLanes}function uy(){U(Jp,lo),U(ac,ac.current)}function dy(){lo=Jp.current,oe(ac),oe(Jp)}var ia=Y(null),La=null;function Wo(s){var c=s.alternate;U(Rn,Rn.current&1),U(ia,s),La===null&&(c===null||ac.current!==null||c.memoizedState!==null)&&(La=s)}function hy(s){U(Rn,Rn.current),U(ia,s),La===null&&(La=s)}function DA(s){s.tag===22?(U(Rn,Rn.current),U(ia,s),La===null&&(La=s)):Vo()}function Vo(){U(Rn,Rn.current),U(ia,ia.current)}function oa(s){oe(ia),La===s&&(La=null),oe(Rn)}var Rn=Y(0);function ef(s){for(var c=s;c!==null;){if(c.tag===13){var p=c.memoizedState;if(p!==null&&(p=p.dehydrated,p===null||y1(p)||v1(p)))return c}else if(c.tag===19&&(c.memoizedProps.revealOrder==="forwards"||c.memoizedProps.revealOrder==="backwards"||c.memoizedProps.revealOrder==="unstable_legacy-backwards"||c.memoizedProps.revealOrder==="together")){if((c.flags&128)!==0)return c}else if(c.child!==null){c.child.return=c,c=c.child;continue}if(c===s)break;for(;c.sibling===null;){if(c.return===null||c.return===s)return null;c=c.return}c.sibling.return=c.return,c=c.sibling}return null}var eo=0,vt=null,Qt=null,Mn=null,tf=!1,ic=!1,Ks=!1,nf=0,sd=0,oc=null,OH=0;function kn(){throw Error(r(321))}function py(s,c){if(c===null)return!1;for(var p=0;p<c.length&&p<s.length;p++)if(!ra(s[p],c[p]))return!1;return!0}function fy(s,c,p,g,x,E){return eo=E,vt=c,c.memoizedState=null,c.updateQueue=null,c.lanes=0,$.H=s===null||s.memoizedState===null?b3:Ry,Ks=!1,E=p(g,x),Ks=!1,ic&&(E=BA(c,p,g,x)),MA(s),E}function MA(s){$.H=ud;var c=Qt!==null&&Qt.next!==null;if(eo=0,Mn=Qt=vt=null,tf=!1,sd=0,oc=null,c)throw Error(r(300));s===null||Bn||(s=s.dependencies,s!==null&&Wp(s)&&(Bn=!0))}function BA(s,c,p,g){vt=s;var x=0;do{if(ic&&(oc=null),sd=0,ic=!1,25<=x)throw Error(r(301));if(x+=1,Mn=Qt=null,s.updateQueue!=null){var E=s.updateQueue;E.lastEffect=null,E.events=null,E.stores=null,E.memoCache!=null&&(E.memoCache.index=0)}$.H=y3,E=c(p,g)}while(ic);return E}function IH(){var s=$.H,c=s.useState()[0];return c=typeof c.then=="function"?ld(c):c,s=s.useState()[0],(Qt!==null?Qt.memoizedState:null)!==s&&(vt.flags|=1024),c}function my(){var s=nf!==0;return nf=0,s}function gy(s,c,p){c.updateQueue=s.updateQueue,c.flags&=-2053,s.lanes&=~p}function by(s){if(tf){for(s=s.memoizedState;s!==null;){var c=s.queue;c!==null&&(c.pending=null),s=s.next}tf=!1}eo=0,Mn=Qt=vt=null,ic=!1,sd=nf=0,oc=null}function Ar(){var s={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return Mn===null?vt.memoizedState=Mn=s:Mn=Mn.next=s,Mn}function Nn(){if(Qt===null){var s=vt.alternate;s=s!==null?s.memoizedState:null}else s=Qt.next;var c=Mn===null?vt.memoizedState:Mn.next;if(c!==null)Mn=c,Qt=s;else{if(s===null)throw vt.alternate===null?Error(r(467)):Error(r(310));Qt=s,s={memoizedState:Qt.memoizedState,baseState:Qt.baseState,baseQueue:Qt.baseQueue,queue:Qt.queue,next:null},Mn===null?vt.memoizedState=Mn=s:Mn=Mn.next=s}return Mn}function rf(){return{lastEffect:null,events:null,stores:null,memoCache:null}}function ld(s){var c=sd;return sd+=1,oc===null&&(oc=[]),s=_A(oc,s,c),c=vt,(Mn===null?c.memoizedState:Mn.next)===null&&(c=c.alternate,$.H=c===null||c.memoizedState===null?b3:Ry),s}function af(s){if(s!==null&&typeof s=="object"){if(typeof s.then=="function")return ld(s);if(s.$$typeof===R)return rr(s)}throw Error(r(438,String(s)))}function yy(s){var c=null,p=vt.updateQueue;if(p!==null&&(c=p.memoCache),c==null){var g=vt.alternate;g!==null&&(g=g.updateQueue,g!==null&&(g=g.memoCache,g!=null&&(c={data:g.data.map(function(x){return x.slice()}),index:0})))}if(c==null&&(c={data:[],index:0}),p===null&&(p=rf(),vt.updateQueue=p),p.memoCache=c,p=c.data[c.index],p===void 0)for(p=c.data[c.index]=Array(s),g=0;g<s;g++)p[g]=B;return c.index++,p}function to(s,c){return typeof c=="function"?c(s):c}function of(s){var c=Nn();return vy(c,Qt,s)}function vy(s,c,p){var g=s.queue;if(g===null)throw Error(r(311));g.lastRenderedReducer=p;var x=s.baseQueue,E=g.pending;if(E!==null){if(x!==null){var D=x.next;x.next=E.next,E.next=D}c.baseQueue=x=E,g.pending=null}if(E=s.baseState,x===null)s.memoizedState=E;else{c=x.next;var j=D=null,ne=null,de=c,ye=!1;do{var Se=de.lane&-536870913;if(Se!==de.lane?(Lt&Se)===Se:(eo&Se)===Se){var he=de.revertLane;if(he===0)ne!==null&&(ne=ne.next={lane:0,revertLane:0,gesture:null,action:de.action,hasEagerState:de.hasEagerState,eagerState:de.eagerState,next:null}),Se===ec&&(ye=!0);else if((eo&he)===he){de=de.next,he===ec&&(ye=!0);continue}else Se={lane:0,revertLane:de.revertLane,gesture:null,action:de.action,hasEagerState:de.hasEagerState,eagerState:de.eagerState,next:null},ne===null?(j=ne=Se,D=E):ne=ne.next=Se,vt.lanes|=he,Ko|=he;Se=de.action,Ks&&p(E,Se),E=de.hasEagerState?de.eagerState:p(E,Se)}else he={lane:Se,revertLane:de.revertLane,gesture:de.gesture,action:de.action,hasEagerState:de.hasEagerState,eagerState:de.eagerState,next:null},ne===null?(j=ne=he,D=E):ne=ne.next=he,vt.lanes|=Se,Ko|=Se;de=de.next}while(de!==null&&de!==c);if(ne===null?D=E:ne.next=j,!ra(E,s.memoizedState)&&(Bn=!0,ye&&(p=tc,p!==null)))throw p;s.memoizedState=E,s.baseState=D,s.baseQueue=ne,g.lastRenderedState=E}return x===null&&(g.lanes=0),[s.memoizedState,g.dispatch]}function xy(s){var c=Nn(),p=c.queue;if(p===null)throw Error(r(311));p.lastRenderedReducer=s;var g=p.dispatch,x=p.pending,E=c.memoizedState;if(x!==null){p.pending=null;var D=x=x.next;do E=s(E,D.action),D=D.next;while(D!==x);ra(E,c.memoizedState)||(Bn=!0),c.memoizedState=E,c.baseQueue===null&&(c.baseState=E),p.lastRenderedState=E}return[E,g]}function FA(s,c,p){var g=vt,x=Nn(),E=Bt;if(E){if(p===void 0)throw Error(r(407));p=p()}else p=c();var D=!ra((Qt||x).memoizedState,p);if(D&&(x.memoizedState=p,Bn=!0),x=x.queue,Ey(PA.bind(null,g,x,s),[s]),x.getSnapshot!==c||D||Mn!==null&&Mn.memoizedState.tag&1){if(g.flags|=2048,sc(9,{destroy:void 0},$A.bind(null,g,x,p,c),null),nn===null)throw Error(r(349));E||(eo&127)!==0||zA(g,c,p)}return p}function zA(s,c,p){s.flags|=16384,s={getSnapshot:c,value:p},c=vt.updateQueue,c===null?(c=rf(),vt.updateQueue=c,c.stores=[s]):(p=c.stores,p===null?c.stores=[s]:p.push(s))}function $A(s,c,p,g){c.value=p,c.getSnapshot=g,UA(c)&&jA(s)}function PA(s,c,p){return p(function(){UA(c)&&jA(s)})}function UA(s){var c=s.getSnapshot;s=s.value;try{var p=c();return!ra(s,p)}catch{return!0}}function jA(s){var c=Us(s,2);c!==null&&Yr(c,s,2)}function Sy(s){var c=Ar();if(typeof s=="function"){var p=s;if(s=p(),Ks){pn(!0);try{p()}finally{pn(!1)}}}return c.memoizedState=c.baseState=s,c.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:to,lastRenderedState:s},c}function HA(s,c,p,g){return s.baseState=p,vy(s,Qt,typeof g=="function"?g:to)}function LH(s,c,p,g,x){if(cf(s))throw Error(r(485));if(s=c.action,s!==null){var E={payload:x,action:s,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(D){E.listeners.push(D)}};$.T!==null?p(!0):E.isTransition=!1,g(E),p=c.pending,p===null?(E.next=c.pending=E,GA(c,E)):(E.next=p.next,c.pending=p.next=E)}}function GA(s,c){var p=c.action,g=c.payload,x=s.state;if(c.isTransition){var E=$.T,D={};$.T=D;try{var j=p(x,g),ne=$.S;ne!==null&&ne(D,j),qA(s,c,j)}catch(de){wy(s,c,de)}finally{E!==null&&D.types!==null&&(E.types=D.types),$.T=E}}else try{E=p(x,g),qA(s,c,E)}catch(de){wy(s,c,de)}}function qA(s,c,p){p!==null&&typeof p=="object"&&typeof p.then=="function"?p.then(function(g){WA(s,c,g)},function(g){return wy(s,c,g)}):WA(s,c,p)}function WA(s,c,p){c.status="fulfilled",c.value=p,VA(c),s.state=p,c=s.pending,c!==null&&(p=c.next,p===c?s.pending=null:(p=p.next,c.next=p,GA(s,p)))}function wy(s,c,p){var g=s.pending;if(s.pending=null,g!==null){g=g.next;do c.status="rejected",c.reason=p,VA(c),c=c.next;while(c!==g)}s.action=null}function VA(s){s=s.listeners;for(var c=0;c<s.length;c++)(0,s[c])()}function YA(s,c){return c}function XA(s,c){if(Bt){var p=nn.formState;if(p!==null){e:{var g=vt;if(Bt){if(sn){t:{for(var x=sn,E=Ia;x.nodeType!==8;){if(!E){x=null;break t}if(x=Da(x.nextSibling),x===null){x=null;break t}}E=x.data,x=E==="F!"||E==="F"?x:null}if(x){sn=Da(x.nextSibling),g=x.data==="F!";break e}}Uo(g)}g=!1}g&&(c=p[0])}}return p=Ar(),p.memoizedState=p.baseState=c,g={pending:null,lanes:0,dispatch:null,lastRenderedReducer:YA,lastRenderedState:c},p.queue=g,p=f3.bind(null,vt,g),g.dispatch=p,g=Sy(!1),E=Ay.bind(null,vt,!1,g.queue),g=Ar(),x={state:c,dispatch:null,action:s,pending:null},g.queue=x,p=LH.bind(null,vt,x,E,p),x.dispatch=p,g.memoizedState=s,[c,p,!1]}function KA(s){var c=Nn();return ZA(c,Qt,s)}function ZA(s,c,p){if(c=vy(s,c,YA)[0],s=of(to)[0],typeof c=="object"&&c!==null&&typeof c.then=="function")try{var g=ld(c)}catch(D){throw D===nc?Xp:D}else g=c;c=Nn();var x=c.queue,E=x.dispatch;return p!==c.memoizedState&&(vt.flags|=2048,sc(9,{destroy:void 0},DH.bind(null,x,p),null)),[g,E,s]}function DH(s,c){s.action=c}function QA(s){var c=Nn(),p=Qt;if(p!==null)return ZA(c,p,s);Nn(),c=c.memoizedState,p=Nn();var g=p.queue.dispatch;return p.memoizedState=s,[c,g,!1]}function sc(s,c,p,g){return s={tag:s,create:p,deps:g,inst:c,next:null},c=vt.updateQueue,c===null&&(c=rf(),vt.updateQueue=c),p=c.lastEffect,p===null?c.lastEffect=s.next=s:(g=p.next,p.next=s,s.next=g,c.lastEffect=s),s}function JA(){return Nn().memoizedState}function sf(s,c,p,g){var x=Ar();vt.flags|=s,x.memoizedState=sc(1|c,{destroy:void 0},p,g===void 0?null:g)}function lf(s,c,p,g){var x=Nn();g=g===void 0?null:g;var E=x.memoizedState.inst;Qt!==null&&g!==null&&py(g,Qt.memoizedState.deps)?x.memoizedState=sc(c,E,p,g):(vt.flags|=s,x.memoizedState=sc(1|c,E,p,g))}function e3(s,c){sf(8390656,8,s,c)}function Ey(s,c){lf(2048,8,s,c)}function MH(s){vt.flags|=4;var c=vt.updateQueue;if(c===null)c=rf(),vt.updateQueue=c,c.events=[s];else{var p=c.events;p===null?c.events=[s]:p.push(s)}}function t3(s){var c=Nn().memoizedState;return MH({ref:c,nextImpl:s}),function(){if((Ht&2)!==0)throw Error(r(440));return c.impl.apply(void 0,arguments)}}function n3(s,c){return lf(4,2,s,c)}function r3(s,c){return lf(4,4,s,c)}function a3(s,c){if(typeof c=="function"){s=s();var p=c(s);return function(){typeof p=="function"?p():c(null)}}if(c!=null)return s=s(),c.current=s,function(){c.current=null}}function i3(s,c,p){p=p!=null?p.concat([s]):null,lf(4,4,a3.bind(null,c,s),p)}function ky(){}function o3(s,c){var p=Nn();c=c===void 0?null:c;var g=p.memoizedState;return c!==null&&py(c,g[1])?g[0]:(p.memoizedState=[s,c],s)}function s3(s,c){var p=Nn();c=c===void 0?null:c;var g=p.memoizedState;if(c!==null&&py(c,g[1]))return g[0];if(g=s(),Ks){pn(!0);try{s()}finally{pn(!1)}}return p.memoizedState=[g,c],g}function Ty(s,c,p){return p===void 0||(eo&1073741824)!==0&&(Lt&261930)===0?s.memoizedState=c:(s.memoizedState=p,s=l5(),vt.lanes|=s,Ko|=s,p)}function l3(s,c,p,g){return ra(p,c)?p:ac.current!==null?(s=Ty(s,p,g),ra(s,c)||(Bn=!0),s):(eo&42)===0||(eo&1073741824)!==0&&(Lt&261930)===0?(Bn=!0,s.memoizedState=p):(s=l5(),vt.lanes|=s,Ko|=s,c)}function c3(s,c,p,g,x){var E=Q.p;Q.p=E!==0&&8>E?E:8;var D=$.T,j={};$.T=j,Ay(s,!1,c,p);try{var ne=x(),de=$.S;if(de!==null&&de(j,ne),ne!==null&&typeof ne=="object"&&typeof ne.then=="function"){var ye=NH(ne,g);cd(s,c,ye,ca(s))}else cd(s,c,g,ca(s))}catch(Se){cd(s,c,{then:function(){},status:"rejected",reason:Se},ca())}finally{Q.p=E,D!==null&&j.types!==null&&(D.types=j.types),$.T=D}}function BH(){}function _y(s,c,p,g){if(s.tag!==5)throw Error(r(476));var x=u3(s).queue;c3(s,x,c,J,p===null?BH:function(){return d3(s),p(g)})}function u3(s){var c=s.memoizedState;if(c!==null)return c;c={memoizedState:J,baseState:J,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:to,lastRenderedState:J},next:null};var p={};return c.next={memoizedState:p,baseState:p,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:to,lastRenderedState:p},next:null},s.memoizedState=c,s=s.alternate,s!==null&&(s.memoizedState=c),c}function d3(s){var c=u3(s);c.next===null&&(c=s.alternate.memoizedState),cd(s,c.next.queue,{},ca())}function Cy(){return rr(_d)}function h3(){return Nn().memoizedState}function p3(){return Nn().memoizedState}function FH(s){for(var c=s.return;c!==null;){switch(c.tag){case 24:case 3:var p=ca();s=Go(p);var g=qo(c,s,p);g!==null&&(Yr(g,c,p),ad(g,c,p)),c={cache:ny()},s.payload=c;return}c=c.return}}function zH(s,c,p){var g=ca();p={lane:g,revertLane:0,gesture:null,action:p,hasEagerState:!1,eagerState:null,next:null},cf(s)?m3(c,p):(p=qb(s,c,p,g),p!==null&&(Yr(p,s,g),g3(p,c,g)))}function f3(s,c,p){var g=ca();cd(s,c,p,g)}function cd(s,c,p,g){var x={lane:g,revertLane:0,gesture:null,action:p,hasEagerState:!1,eagerState:null,next:null};if(cf(s))m3(c,x);else{var E=s.alternate;if(s.lanes===0&&(E===null||E.lanes===0)&&(E=c.lastRenderedReducer,E!==null))try{var D=c.lastRenderedState,j=E(D,p);if(x.hasEagerState=!0,x.eagerState=j,ra(j,D))return jp(s,c,x,0),nn===null&&Up(),!1}catch{}finally{}if(p=qb(s,c,x,g),p!==null)return Yr(p,s,g),g3(p,c,g),!0}return!1}function Ay(s,c,p,g){if(g={lane:2,revertLane:o1(),gesture:null,action:g,hasEagerState:!1,eagerState:null,next:null},cf(s)){if(c)throw Error(r(479))}else c=qb(s,p,g,2),c!==null&&Yr(c,s,2)}function cf(s){var c=s.alternate;return s===vt||c!==null&&c===vt}function m3(s,c){ic=tf=!0;var p=s.pending;p===null?c.next=c:(c.next=p.next,p.next=c),s.pending=c}function g3(s,c,p){if((p&4194048)!==0){var g=c.lanes;g&=s.pendingLanes,p|=g,c.lanes=p,zu(s,p)}}var ud={readContext:rr,use:af,useCallback:kn,useContext:kn,useEffect:kn,useImperativeHandle:kn,useLayoutEffect:kn,useInsertionEffect:kn,useMemo:kn,useReducer:kn,useRef:kn,useState:kn,useDebugValue:kn,useDeferredValue:kn,useTransition:kn,useSyncExternalStore:kn,useId:kn,useHostTransitionStatus:kn,useFormState:kn,useActionState:kn,useOptimistic:kn,useMemoCache:kn,useCacheRefresh:kn};ud.useEffectEvent=kn;var b3={readContext:rr,use:af,useCallback:function(s,c){return Ar().memoizedState=[s,c===void 0?null:c],s},useContext:rr,useEffect:e3,useImperativeHandle:function(s,c,p){p=p!=null?p.concat([s]):null,sf(4194308,4,a3.bind(null,c,s),p)},useLayoutEffect:function(s,c){return sf(4194308,4,s,c)},useInsertionEffect:function(s,c){sf(4,2,s,c)},useMemo:function(s,c){var p=Ar();c=c===void 0?null:c;var g=s();if(Ks){pn(!0);try{s()}finally{pn(!1)}}return p.memoizedState=[g,c],g},useReducer:function(s,c,p){var g=Ar();if(p!==void 0){var x=p(c);if(Ks){pn(!0);try{p(c)}finally{pn(!1)}}}else x=c;return g.memoizedState=g.baseState=x,s={pending:null,lanes:0,dispatch:null,lastRenderedReducer:s,lastRenderedState:x},g.queue=s,s=s.dispatch=zH.bind(null,vt,s),[g.memoizedState,s]},useRef:function(s){var c=Ar();return s={current:s},c.memoizedState=s},useState:function(s){s=Sy(s);var c=s.queue,p=f3.bind(null,vt,c);return c.dispatch=p,[s.memoizedState,p]},useDebugValue:ky,useDeferredValue:function(s,c){var p=Ar();return Ty(p,s,c)},useTransition:function(){var s=Sy(!1);return s=c3.bind(null,vt,s.queue,!0,!1),Ar().memoizedState=s,[!1,s]},useSyncExternalStore:function(s,c,p){var g=vt,x=Ar();if(Bt){if(p===void 0)throw Error(r(407));p=p()}else{if(p=c(),nn===null)throw Error(r(349));(Lt&127)!==0||zA(g,c,p)}x.memoizedState=p;var E={value:p,getSnapshot:c};return x.queue=E,e3(PA.bind(null,g,E,s),[s]),g.flags|=2048,sc(9,{destroy:void 0},$A.bind(null,g,E,p,c),null),p},useId:function(){var s=Ar(),c=nn.identifierPrefix;if(Bt){var p=fi,g=pi;p=(g&~(1<<32-zt(g)-1)).toString(32)+p,c="_"+c+"R_"+p,p=nf++,0<p&&(c+="H"+p.toString(32)),c+="_"}else p=OH++,c="_"+c+"r_"+p.toString(32)+"_";return s.memoizedState=c},useHostTransitionStatus:Cy,useFormState:XA,useActionState:XA,useOptimistic:function(s){var c=Ar();c.memoizedState=c.baseState=s;var p={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return c.queue=p,c=Ay.bind(null,vt,!0,p),p.dispatch=c,[s,c]},useMemoCache:yy,useCacheRefresh:function(){return Ar().memoizedState=FH.bind(null,vt)},useEffectEvent:function(s){var c=Ar(),p={impl:s};return c.memoizedState=p,function(){if((Ht&2)!==0)throw Error(r(440));return p.impl.apply(void 0,arguments)}}},Ry={readContext:rr,use:af,useCallback:o3,useContext:rr,useEffect:Ey,useImperativeHandle:i3,useInsertionEffect:n3,useLayoutEffect:r3,useMemo:s3,useReducer:of,useRef:JA,useState:function(){return of(to)},useDebugValue:ky,useDeferredValue:function(s,c){var p=Nn();return l3(p,Qt.memoizedState,s,c)},useTransition:function(){var s=of(to)[0],c=Nn().memoizedState;return[typeof s=="boolean"?s:ld(s),c]},useSyncExternalStore:FA,useId:h3,useHostTransitionStatus:Cy,useFormState:KA,useActionState:KA,useOptimistic:function(s,c){var p=Nn();return HA(p,Qt,s,c)},useMemoCache:yy,useCacheRefresh:p3};Ry.useEffectEvent=t3;var y3={readContext:rr,use:af,useCallback:o3,useContext:rr,useEffect:Ey,useImperativeHandle:i3,useInsertionEffect:n3,useLayoutEffect:r3,useMemo:s3,useReducer:xy,useRef:JA,useState:function(){return xy(to)},useDebugValue:ky,useDeferredValue:function(s,c){var p=Nn();return Qt===null?Ty(p,s,c):l3(p,Qt.memoizedState,s,c)},useTransition:function(){var s=xy(to)[0],c=Nn().memoizedState;return[typeof s=="boolean"?s:ld(s),c]},useSyncExternalStore:FA,useId:h3,useHostTransitionStatus:Cy,useFormState:QA,useActionState:QA,useOptimistic:function(s,c){var p=Nn();return Qt!==null?HA(p,Qt,s,c):(p.baseState=s,[s,p.queue.dispatch])},useMemoCache:yy,useCacheRefresh:p3};y3.useEffectEvent=t3;function Ny(s,c,p,g){c=s.memoizedState,p=p(g,c),p=p==null?c:f({},c,p),s.memoizedState=p,s.lanes===0&&(s.updateQueue.baseState=p)}var Oy={enqueueSetState:function(s,c,p){s=s._reactInternals;var g=ca(),x=Go(g);x.payload=c,p!=null&&(x.callback=p),c=qo(s,x,g),c!==null&&(Yr(c,s,g),ad(c,s,g))},enqueueReplaceState:function(s,c,p){s=s._reactInternals;var g=ca(),x=Go(g);x.tag=1,x.payload=c,p!=null&&(x.callback=p),c=qo(s,x,g),c!==null&&(Yr(c,s,g),ad(c,s,g))},enqueueForceUpdate:function(s,c){s=s._reactInternals;var p=ca(),g=Go(p);g.tag=2,c!=null&&(g.callback=c),c=qo(s,g,p),c!==null&&(Yr(c,s,p),ad(c,s,p))}};function v3(s,c,p,g,x,E,D){return s=s.stateNode,typeof s.shouldComponentUpdate=="function"?s.shouldComponentUpdate(g,E,D):c.prototype&&c.prototype.isPureReactComponent?!Ku(p,g)||!Ku(x,E):!0}function x3(s,c,p,g){s=c.state,typeof c.componentWillReceiveProps=="function"&&c.componentWillReceiveProps(p,g),typeof c.UNSAFE_componentWillReceiveProps=="function"&&c.UNSAFE_componentWillReceiveProps(p,g),c.state!==s&&Oy.enqueueReplaceState(c,c.state,null)}function Zs(s,c){var p=c;if("ref"in c){p={};for(var g in c)g!=="ref"&&(p[g]=c[g])}if(s=s.defaultProps){p===c&&(p=f({},p));for(var x in s)p[x]===void 0&&(p[x]=s[x])}return p}function S3(s){Pp(s)}function w3(s){console.error(s)}function E3(s){Pp(s)}function uf(s,c){try{var p=s.onUncaughtError;p(c.value,{componentStack:c.stack})}catch(g){setTimeout(function(){throw g})}}function k3(s,c,p){try{var g=s.onCaughtError;g(p.value,{componentStack:p.stack,errorBoundary:c.tag===1?c.stateNode:null})}catch(x){setTimeout(function(){throw x})}}function Iy(s,c,p){return p=Go(p),p.tag=3,p.payload={element:null},p.callback=function(){uf(s,c)},p}function T3(s){return s=Go(s),s.tag=3,s}function _3(s,c,p,g){var x=p.type.getDerivedStateFromError;if(typeof x=="function"){var E=g.value;s.payload=function(){return x(E)},s.callback=function(){k3(c,p,g)}}var D=p.stateNode;D!==null&&typeof D.componentDidCatch=="function"&&(s.callback=function(){k3(c,p,g),typeof x!="function"&&(Zo===null?Zo=new Set([this]):Zo.add(this));var j=g.stack;this.componentDidCatch(g.value,{componentStack:j!==null?j:""})})}function $H(s,c,p,g,x){if(p.flags|=32768,g!==null&&typeof g=="object"&&typeof g.then=="function"){if(c=p.alternate,c!==null&&Jl(c,p,x,!0),p=ia.current,p!==null){switch(p.tag){case 31:case 13:return La===null?wf():p.alternate===null&&Tn===0&&(Tn=3),p.flags&=-257,p.flags|=65536,p.lanes=x,g===Kp?p.flags|=16384:(c=p.updateQueue,c===null?p.updateQueue=new Set([g]):c.add(g),r1(s,g,x)),!1;case 22:return p.flags|=65536,g===Kp?p.flags|=16384:(c=p.updateQueue,c===null?(c={transitions:null,markerInstances:null,retryQueue:new Set([g])},p.updateQueue=c):(p=c.retryQueue,p===null?c.retryQueue=new Set([g]):p.add(g)),r1(s,g,x)),!1}throw Error(r(435,p.tag))}return r1(s,g,x),wf(),!1}if(Bt)return c=ia.current,c!==null?((c.flags&65536)===0&&(c.flags|=256),c.flags|=65536,c.lanes=x,g!==Zb&&(s=Error(r(422),{cause:g}),Ju(Ra(s,p)))):(g!==Zb&&(c=Error(r(423),{cause:g}),Ju(Ra(c,p))),s=s.current.alternate,s.flags|=65536,x&=-x,s.lanes|=x,g=Ra(g,p),x=Iy(s.stateNode,g,x),ly(s,x),Tn!==4&&(Tn=2)),!1;var E=Error(r(520),{cause:g});if(E=Ra(E,p),yd===null?yd=[E]:yd.push(E),Tn!==4&&(Tn=2),c===null)return!0;g=Ra(g,p),p=c;do{switch(p.tag){case 3:return p.flags|=65536,s=x&-x,p.lanes|=s,s=Iy(p.stateNode,g,s),ly(p,s),!1;case 1:if(c=p.type,E=p.stateNode,(p.flags&128)===0&&(typeof c.getDerivedStateFromError=="function"||E!==null&&typeof E.componentDidCatch=="function"&&(Zo===null||!Zo.has(E))))return p.flags|=65536,x&=-x,p.lanes|=x,x=T3(x),_3(x,s,p,g),ly(p,x),!1}p=p.return}while(p!==null);return!1}var Ly=Error(r(461)),Bn=!1;function ar(s,c,p,g){c.child=s===null?NA(c,null,p,g):Xs(c,s.child,p,g)}function C3(s,c,p,g,x){p=p.render;var E=c.ref;if("ref"in g){var D={};for(var j in g)j!=="ref"&&(D[j]=g[j])}else D=g;return qs(c),g=fy(s,c,p,D,E,x),j=my(),s!==null&&!Bn?(gy(s,c,x),no(s,c,x)):(Bt&&j&&Xb(c),c.flags|=1,ar(s,c,g,x),c.child)}function A3(s,c,p,g,x){if(s===null){var E=p.type;return typeof E=="function"&&!Wb(E)&&E.defaultProps===void 0&&p.compare===null?(c.tag=15,c.type=E,R3(s,c,E,g,x)):(s=Gp(p.type,null,g,c,c.mode,x),s.ref=c.ref,s.return=c,c.child=s)}if(E=s.child,!Uy(s,x)){var D=E.memoizedProps;if(p=p.compare,p=p!==null?p:Ku,p(D,g)&&s.ref===c.ref)return no(s,c,x)}return c.flags|=1,s=Ki(E,g),s.ref=c.ref,s.return=c,c.child=s}function R3(s,c,p,g,x){if(s!==null){var E=s.memoizedProps;if(Ku(E,g)&&s.ref===c.ref)if(Bn=!1,c.pendingProps=g=E,Uy(s,x))(s.flags&131072)!==0&&(Bn=!0);else return c.lanes=s.lanes,no(s,c,x)}return Dy(s,c,p,g,x)}function N3(s,c,p,g){var x=g.children,E=s!==null?s.memoizedState:null;if(s===null&&c.stateNode===null&&(c.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),g.mode==="hidden"){if((c.flags&128)!==0){if(E=E!==null?E.baseLanes|p:p,s!==null){for(g=c.child=s.child,x=0;g!==null;)x=x|g.lanes|g.childLanes,g=g.sibling;g=x&~E}else g=0,c.child=null;return O3(s,c,E,p,g)}if((p&536870912)!==0)c.memoizedState={baseLanes:0,cachePool:null},s!==null&&Yp(c,E!==null?E.cachePool:null),E!==null?LA(c,E):uy(),DA(c);else return g=c.lanes=536870912,O3(s,c,E!==null?E.baseLanes|p:p,p,g)}else E!==null?(Yp(c,E.cachePool),LA(c,E),Vo(),c.memoizedState=null):(s!==null&&Yp(c,null),uy(),Vo());return ar(s,c,x,p),c.child}function dd(s,c){return s!==null&&s.tag===22||c.stateNode!==null||(c.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),c.sibling}function O3(s,c,p,g,x){var E=ay();return E=E===null?null:{parent:Dn._currentValue,pool:E},c.memoizedState={baseLanes:p,cachePool:E},s!==null&&Yp(c,null),uy(),DA(c),s!==null&&Jl(s,c,g,!0),c.childLanes=x,null}function df(s,c){return c=pf({mode:c.mode,children:c.children},s.mode),c.ref=s.ref,s.child=c,c.return=s,c}function I3(s,c,p){return Xs(c,s.child,null,p),s=df(c,c.pendingProps),s.flags|=2,oa(c),c.memoizedState=null,s}function PH(s,c,p){var g=c.pendingProps,x=(c.flags&128)!==0;if(c.flags&=-129,s===null){if(Bt){if(g.mode==="hidden")return s=df(c,g),c.lanes=536870912,dd(null,s);if(hy(c),(s=sn)?(s=G5(s,Ia),s=s!==null&&s.data==="&"?s:null,s!==null&&(c.memoizedState={dehydrated:s,treeContext:$o!==null?{id:pi,overflow:fi}:null,retryLane:536870912,hydrationErrors:null},p=mA(s),p.return=c,c.child=p,nr=c,sn=null)):s=null,s===null)throw Uo(c);return c.lanes=536870912,null}return df(c,g)}var E=s.memoizedState;if(E!==null){var D=E.dehydrated;if(hy(c),x)if(c.flags&256)c.flags&=-257,c=I3(s,c,p);else if(c.memoizedState!==null)c.child=s.child,c.flags|=128,c=null;else throw Error(r(558));else if(Bn||Jl(s,c,p,!1),x=(p&s.childLanes)!==0,Bn||x){if(g=nn,g!==null&&(D=_p(g,p),D!==0&&D!==E.retryLane))throw E.retryLane=D,Us(s,D),Yr(g,s,D),Ly;wf(),c=I3(s,c,p)}else s=E.treeContext,sn=Da(D.nextSibling),nr=c,Bt=!0,Po=null,Ia=!1,s!==null&&yA(c,s),c=df(c,g),c.flags|=4096;return c}return s=Ki(s.child,{mode:g.mode,children:g.children}),s.ref=c.ref,c.child=s,s.return=c,s}function hf(s,c){var p=c.ref;if(p===null)s!==null&&s.ref!==null&&(c.flags|=4194816);else{if(typeof p!="function"&&typeof p!="object")throw Error(r(284));(s===null||s.ref!==p)&&(c.flags|=4194816)}}function Dy(s,c,p,g,x){return qs(c),p=fy(s,c,p,g,void 0,x),g=my(),s!==null&&!Bn?(gy(s,c,x),no(s,c,x)):(Bt&&g&&Xb(c),c.flags|=1,ar(s,c,p,x),c.child)}function L3(s,c,p,g,x,E){return qs(c),c.updateQueue=null,p=BA(c,g,p,x),MA(s),g=my(),s!==null&&!Bn?(gy(s,c,E),no(s,c,E)):(Bt&&g&&Xb(c),c.flags|=1,ar(s,c,p,E),c.child)}function D3(s,c,p,g,x){if(qs(c),c.stateNode===null){var E=Xl,D=p.contextType;typeof D=="object"&&D!==null&&(E=rr(D)),E=new p(g,E),c.memoizedState=E.state!==null&&E.state!==void 0?E.state:null,E.updater=Oy,c.stateNode=E,E._reactInternals=c,E=c.stateNode,E.props=g,E.state=c.memoizedState,E.refs={},oy(c),D=p.contextType,E.context=typeof D=="object"&&D!==null?rr(D):Xl,E.state=c.memoizedState,D=p.getDerivedStateFromProps,typeof D=="function"&&(Ny(c,p,D,g),E.state=c.memoizedState),typeof p.getDerivedStateFromProps=="function"||typeof E.getSnapshotBeforeUpdate=="function"||typeof E.UNSAFE_componentWillMount!="function"&&typeof E.componentWillMount!="function"||(D=E.state,typeof E.componentWillMount=="function"&&E.componentWillMount(),typeof E.UNSAFE_componentWillMount=="function"&&E.UNSAFE_componentWillMount(),D!==E.state&&Oy.enqueueReplaceState(E,E.state,null),od(c,g,E,x),id(),E.state=c.memoizedState),typeof E.componentDidMount=="function"&&(c.flags|=4194308),g=!0}else if(s===null){E=c.stateNode;var j=c.memoizedProps,ne=Zs(p,j);E.props=ne;var de=E.context,ye=p.contextType;D=Xl,typeof ye=="object"&&ye!==null&&(D=rr(ye));var Se=p.getDerivedStateFromProps;ye=typeof Se=="function"||typeof E.getSnapshotBeforeUpdate=="function",j=c.pendingProps!==j,ye||typeof E.UNSAFE_componentWillReceiveProps!="function"&&typeof E.componentWillReceiveProps!="function"||(j||de!==D)&&x3(c,E,g,D),Ho=!1;var he=c.memoizedState;E.state=he,od(c,g,E,x),id(),de=c.memoizedState,j||he!==de||Ho?(typeof Se=="function"&&(Ny(c,p,Se,g),de=c.memoizedState),(ne=Ho||v3(c,p,ne,g,he,de,D))?(ye||typeof E.UNSAFE_componentWillMount!="function"&&typeof E.componentWillMount!="function"||(typeof E.componentWillMount=="function"&&E.componentWillMount(),typeof E.UNSAFE_componentWillMount=="function"&&E.UNSAFE_componentWillMount()),typeof E.componentDidMount=="function"&&(c.flags|=4194308)):(typeof E.componentDidMount=="function"&&(c.flags|=4194308),c.memoizedProps=g,c.memoizedState=de),E.props=g,E.state=de,E.context=D,g=ne):(typeof E.componentDidMount=="function"&&(c.flags|=4194308),g=!1)}else{E=c.stateNode,sy(s,c),D=c.memoizedProps,ye=Zs(p,D),E.props=ye,Se=c.pendingProps,he=E.context,de=p.contextType,ne=Xl,typeof de=="object"&&de!==null&&(ne=rr(de)),j=p.getDerivedStateFromProps,(de=typeof j=="function"||typeof E.getSnapshotBeforeUpdate=="function")||typeof E.UNSAFE_componentWillReceiveProps!="function"&&typeof E.componentWillReceiveProps!="function"||(D!==Se||he!==ne)&&x3(c,E,g,ne),Ho=!1,he=c.memoizedState,E.state=he,od(c,g,E,x),id();var pe=c.memoizedState;D!==Se||he!==pe||Ho||s!==null&&s.dependencies!==null&&Wp(s.dependencies)?(typeof j=="function"&&(Ny(c,p,j,g),pe=c.memoizedState),(ye=Ho||v3(c,p,ye,g,he,pe,ne)||s!==null&&s.dependencies!==null&&Wp(s.dependencies))?(de||typeof E.UNSAFE_componentWillUpdate!="function"&&typeof E.componentWillUpdate!="function"||(typeof E.componentWillUpdate=="function"&&E.componentWillUpdate(g,pe,ne),typeof E.UNSAFE_componentWillUpdate=="function"&&E.UNSAFE_componentWillUpdate(g,pe,ne)),typeof E.componentDidUpdate=="function"&&(c.flags|=4),typeof E.getSnapshotBeforeUpdate=="function"&&(c.flags|=1024)):(typeof E.componentDidUpdate!="function"||D===s.memoizedProps&&he===s.memoizedState||(c.flags|=4),typeof E.getSnapshotBeforeUpdate!="function"||D===s.memoizedProps&&he===s.memoizedState||(c.flags|=1024),c.memoizedProps=g,c.memoizedState=pe),E.props=g,E.state=pe,E.context=ne,g=ye):(typeof E.componentDidUpdate!="function"||D===s.memoizedProps&&he===s.memoizedState||(c.flags|=4),typeof E.getSnapshotBeforeUpdate!="function"||D===s.memoizedProps&&he===s.memoizedState||(c.flags|=1024),g=!1)}return E=g,hf(s,c),g=(c.flags&128)!==0,E||g?(E=c.stateNode,p=g&&typeof p.getDerivedStateFromError!="function"?null:E.render(),c.flags|=1,s!==null&&g?(c.child=Xs(c,s.child,null,x),c.child=Xs(c,null,p,x)):ar(s,c,p,x),c.memoizedState=E.state,s=c.child):s=no(s,c,x),s}function M3(s,c,p,g){return Hs(),c.flags|=256,ar(s,c,p,g),c.child}var My={dehydrated:null,treeContext:null,retryLane:0,hydrationErrors:null};function By(s){return{baseLanes:s,cachePool:kA()}}function Fy(s,c,p){return s=s!==null?s.childLanes&~p:0,c&&(s|=la),s}function B3(s,c,p){var g=c.pendingProps,x=!1,E=(c.flags&128)!==0,D;if((D=E)||(D=s!==null&&s.memoizedState===null?!1:(Rn.current&2)!==0),D&&(x=!0,c.flags&=-129),D=(c.flags&32)!==0,c.flags&=-33,s===null){if(Bt){if(x?Wo(c):Vo(),(s=sn)?(s=G5(s,Ia),s=s!==null&&s.data!=="&"?s:null,s!==null&&(c.memoizedState={dehydrated:s,treeContext:$o!==null?{id:pi,overflow:fi}:null,retryLane:536870912,hydrationErrors:null},p=mA(s),p.return=c,c.child=p,nr=c,sn=null)):s=null,s===null)throw Uo(c);return v1(s)?c.lanes=32:c.lanes=536870912,null}var j=g.children;return g=g.fallback,x?(Vo(),x=c.mode,j=pf({mode:"hidden",children:j},x),g=js(g,x,p,null),j.return=c,g.return=c,j.sibling=g,c.child=j,g=c.child,g.memoizedState=By(p),g.childLanes=Fy(s,D,p),c.memoizedState=My,dd(null,g)):(Wo(c),zy(c,j))}var ne=s.memoizedState;if(ne!==null&&(j=ne.dehydrated,j!==null)){if(E)c.flags&256?(Wo(c),c.flags&=-257,c=$y(s,c,p)):c.memoizedState!==null?(Vo(),c.child=s.child,c.flags|=128,c=null):(Vo(),j=g.fallback,x=c.mode,g=pf({mode:"visible",children:g.children},x),j=js(j,x,p,null),j.flags|=2,g.return=c,j.return=c,g.sibling=j,c.child=g,Xs(c,s.child,null,p),g=c.child,g.memoizedState=By(p),g.childLanes=Fy(s,D,p),c.memoizedState=My,c=dd(null,g));else if(Wo(c),v1(j)){if(D=j.nextSibling&&j.nextSibling.dataset,D)var de=D.dgst;D=de,g=Error(r(419)),g.stack="",g.digest=D,Ju({value:g,source:null,stack:null}),c=$y(s,c,p)}else if(Bn||Jl(s,c,p,!1),D=(p&s.childLanes)!==0,Bn||D){if(D=nn,D!==null&&(g=_p(D,p),g!==0&&g!==ne.retryLane))throw ne.retryLane=g,Us(s,g),Yr(D,s,g),Ly;y1(j)||wf(),c=$y(s,c,p)}else y1(j)?(c.flags|=192,c.child=s.child,c=null):(s=ne.treeContext,sn=Da(j.nextSibling),nr=c,Bt=!0,Po=null,Ia=!1,s!==null&&yA(c,s),c=zy(c,g.children),c.flags|=4096);return c}return x?(Vo(),j=g.fallback,x=c.mode,ne=s.child,de=ne.sibling,g=Ki(ne,{mode:"hidden",children:g.children}),g.subtreeFlags=ne.subtreeFlags&65011712,de!==null?j=Ki(de,j):(j=js(j,x,p,null),j.flags|=2),j.return=c,g.return=c,g.sibling=j,c.child=g,dd(null,g),g=c.child,j=s.child.memoizedState,j===null?j=By(p):(x=j.cachePool,x!==null?(ne=Dn._currentValue,x=x.parent!==ne?{parent:ne,pool:ne}:x):x=kA(),j={baseLanes:j.baseLanes|p,cachePool:x}),g.memoizedState=j,g.childLanes=Fy(s,D,p),c.memoizedState=My,dd(s.child,g)):(Wo(c),p=s.child,s=p.sibling,p=Ki(p,{mode:"visible",children:g.children}),p.return=c,p.sibling=null,s!==null&&(D=c.deletions,D===null?(c.deletions=[s],c.flags|=16):D.push(s)),c.child=p,c.memoizedState=null,p)}function zy(s,c){return c=pf({mode:"visible",children:c},s.mode),c.return=s,s.child=c}function pf(s,c){return s=aa(22,s,null,c),s.lanes=0,s}function $y(s,c,p){return Xs(c,s.child,null,p),s=zy(c,c.pendingProps.children),s.flags|=2,c.memoizedState=null,s}function F3(s,c,p){s.lanes|=c;var g=s.alternate;g!==null&&(g.lanes|=c),ey(s.return,c,p)}function Py(s,c,p,g,x,E){var D=s.memoizedState;D===null?s.memoizedState={isBackwards:c,rendering:null,renderingStartTime:0,last:g,tail:p,tailMode:x,treeForkCount:E}:(D.isBackwards=c,D.rendering=null,D.renderingStartTime=0,D.last=g,D.tail=p,D.tailMode=x,D.treeForkCount=E)}function z3(s,c,p){var g=c.pendingProps,x=g.revealOrder,E=g.tail;g=g.children;var D=Rn.current,j=(D&2)!==0;if(j?(D=D&1|2,c.flags|=128):D&=1,U(Rn,D),ar(s,c,g,p),g=Bt?Qu:0,!j&&s!==null&&(s.flags&128)!==0)e:for(s=c.child;s!==null;){if(s.tag===13)s.memoizedState!==null&&F3(s,p,c);else if(s.tag===19)F3(s,p,c);else if(s.child!==null){s.child.return=s,s=s.child;continue}if(s===c)break e;for(;s.sibling===null;){if(s.return===null||s.return===c)break e;s=s.return}s.sibling.return=s.return,s=s.sibling}switch(x){case"forwards":for(p=c.child,x=null;p!==null;)s=p.alternate,s!==null&&ef(s)===null&&(x=p),p=p.sibling;p=x,p===null?(x=c.child,c.child=null):(x=p.sibling,p.sibling=null),Py(c,!1,x,p,E,g);break;case"backwards":case"unstable_legacy-backwards":for(p=null,x=c.child,c.child=null;x!==null;){if(s=x.alternate,s!==null&&ef(s)===null){c.child=x;break}s=x.sibling,x.sibling=p,p=x,x=s}Py(c,!0,p,null,E,g);break;case"together":Py(c,!1,null,null,void 0,g);break;default:c.memoizedState=null}return c.child}function no(s,c,p){if(s!==null&&(c.dependencies=s.dependencies),Ko|=c.lanes,(p&c.childLanes)===0)if(s!==null){if(Jl(s,c,p,!1),(p&c.childLanes)===0)return null}else return null;if(s!==null&&c.child!==s.child)throw Error(r(153));if(c.child!==null){for(s=c.child,p=Ki(s,s.pendingProps),c.child=p,p.return=c;s.sibling!==null;)s=s.sibling,p=p.sibling=Ki(s,s.pendingProps),p.return=c;p.sibling=null}return c.child}function Uy(s,c){return(s.lanes&c)!==0?!0:(s=s.dependencies,!!(s!==null&&Wp(s)))}function UH(s,c,p){switch(c.tag){case 3:Ae(c,c.stateNode.containerInfo),jo(c,Dn,s.memoizedState.cache),Hs();break;case 27:case 5:De(c);break;case 4:Ae(c,c.stateNode.containerInfo);break;case 10:jo(c,c.type,c.memoizedProps.value);break;case 31:if(c.memoizedState!==null)return c.flags|=128,hy(c),null;break;case 13:var g=c.memoizedState;if(g!==null)return g.dehydrated!==null?(Wo(c),c.flags|=128,null):(p&c.child.childLanes)!==0?B3(s,c,p):(Wo(c),s=no(s,c,p),s!==null?s.sibling:null);Wo(c);break;case 19:var x=(s.flags&128)!==0;if(g=(p&c.childLanes)!==0,g||(Jl(s,c,p,!1),g=(p&c.childLanes)!==0),x){if(g)return z3(s,c,p);c.flags|=128}if(x=c.memoizedState,x!==null&&(x.rendering=null,x.tail=null,x.lastEffect=null),U(Rn,Rn.current),g)break;return null;case 22:return c.lanes=0,N3(s,c,p,c.pendingProps);case 24:jo(c,Dn,s.memoizedState.cache)}return no(s,c,p)}function $3(s,c,p){if(s!==null)if(s.memoizedProps!==c.pendingProps)Bn=!0;else{if(!Uy(s,p)&&(c.flags&128)===0)return Bn=!1,UH(s,c,p);Bn=(s.flags&131072)!==0}else Bn=!1,Bt&&(c.flags&1048576)!==0&&bA(c,Qu,c.index);switch(c.lanes=0,c.tag){case 16:e:{var g=c.pendingProps;if(s=Vs(c.elementType),c.type=s,typeof s=="function")Wb(s)?(g=Zs(s,g),c.tag=1,c=D3(null,c,s,g,p)):(c.tag=0,c=Dy(null,c,s,g,p));else{if(s!=null){var x=s.$$typeof;if(x===I){c.tag=11,c=C3(null,c,s,g,p);break e}else if(x===M){c.tag=14,c=A3(null,c,s,g,p);break e}}throw c=q(s)||s,Error(r(306,c,""))}}return c;case 0:return Dy(s,c,c.type,c.pendingProps,p);case 1:return g=c.type,x=Zs(g,c.pendingProps),D3(s,c,g,x,p);case 3:e:{if(Ae(c,c.stateNode.containerInfo),s===null)throw Error(r(387));g=c.pendingProps;var E=c.memoizedState;x=E.element,sy(s,c),od(c,g,null,p);var D=c.memoizedState;if(g=D.cache,jo(c,Dn,g),g!==E.cache&&ty(c,[Dn],p,!0),id(),g=D.element,E.isDehydrated)if(E={element:g,isDehydrated:!1,cache:D.cache},c.updateQueue.baseState=E,c.memoizedState=E,c.flags&256){c=M3(s,c,g,p);break e}else if(g!==x){x=Ra(Error(r(424)),c),Ju(x),c=M3(s,c,g,p);break e}else{switch(s=c.stateNode.containerInfo,s.nodeType){case 9:s=s.body;break;default:s=s.nodeName==="HTML"?s.ownerDocument.body:s}for(sn=Da(s.firstChild),nr=c,Bt=!0,Po=null,Ia=!0,p=NA(c,null,g,p),c.child=p;p;)p.flags=p.flags&-3|4096,p=p.sibling}else{if(Hs(),g===x){c=no(s,c,p);break e}ar(s,c,g,p)}c=c.child}return c;case 26:return hf(s,c),s===null?(p=K5(c.type,null,c.pendingProps,null))?c.memoizedState=p:Bt||(p=c.type,s=c.pendingProps,g=Rf(fe.current).createElement(p),g[Ln]=c,g[fn]=s,ir(g,p,s),Tt(g),c.stateNode=g):c.memoizedState=K5(c.type,s.memoizedProps,c.pendingProps,s.memoizedState),null;case 27:return De(c),s===null&&Bt&&(g=c.stateNode=V5(c.type,c.pendingProps,fe.current),nr=c,Ia=!0,x=sn,ts(c.type)?(x1=x,sn=Da(g.firstChild)):sn=x),ar(s,c,c.pendingProps.children,p),hf(s,c),s===null&&(c.flags|=4194304),c.child;case 5:return s===null&&Bt&&((x=g=sn)&&(g=bG(g,c.type,c.pendingProps,Ia),g!==null?(c.stateNode=g,nr=c,sn=Da(g.firstChild),Ia=!1,x=!0):x=!1),x||Uo(c)),De(c),x=c.type,E=c.pendingProps,D=s!==null?s.memoizedProps:null,g=E.children,m1(x,E)?g=null:D!==null&&m1(x,D)&&(c.flags|=32),c.memoizedState!==null&&(x=fy(s,c,IH,null,null,p),_d._currentValue=x),hf(s,c),ar(s,c,g,p),c.child;case 6:return s===null&&Bt&&((s=p=sn)&&(p=yG(p,c.pendingProps,Ia),p!==null?(c.stateNode=p,nr=c,sn=null,s=!0):s=!1),s||Uo(c)),null;case 13:return B3(s,c,p);case 4:return Ae(c,c.stateNode.containerInfo),g=c.pendingProps,s===null?c.child=Xs(c,null,g,p):ar(s,c,g,p),c.child;case 11:return C3(s,c,c.type,c.pendingProps,p);case 7:return ar(s,c,c.pendingProps,p),c.child;case 8:return ar(s,c,c.pendingProps.children,p),c.child;case 12:return ar(s,c,c.pendingProps.children,p),c.child;case 10:return g=c.pendingProps,jo(c,c.type,g.value),ar(s,c,g.children,p),c.child;case 9:return x=c.type._context,g=c.pendingProps.children,qs(c),x=rr(x),g=g(x),c.flags|=1,ar(s,c,g,p),c.child;case 14:return A3(s,c,c.type,c.pendingProps,p);case 15:return R3(s,c,c.type,c.pendingProps,p);case 19:return z3(s,c,p);case 31:return PH(s,c,p);case 22:return N3(s,c,p,c.pendingProps);case 24:return qs(c),g=rr(Dn),s===null?(x=ay(),x===null&&(x=nn,E=ny(),x.pooledCache=E,E.refCount++,E!==null&&(x.pooledCacheLanes|=p),x=E),c.memoizedState={parent:g,cache:x},oy(c),jo(c,Dn,x)):((s.lanes&p)!==0&&(sy(s,c),od(c,null,null,p),id()),x=s.memoizedState,E=c.memoizedState,x.parent!==g?(x={parent:g,cache:g},c.memoizedState=x,c.lanes===0&&(c.memoizedState=c.updateQueue.baseState=x),jo(c,Dn,g)):(g=E.cache,jo(c,Dn,g),g!==x.cache&&ty(c,[Dn],p,!0))),ar(s,c,c.pendingProps.children,p),c.child;case 29:throw c.pendingProps}throw Error(r(156,c.tag))}function ro(s){s.flags|=4}function jy(s,c,p,g,x){if((c=(s.mode&32)!==0)&&(c=!1),c){if(s.flags|=16777216,(x&335544128)===x)if(s.stateNode.complete)s.flags|=8192;else if(h5())s.flags|=8192;else throw Ys=Kp,iy}else s.flags&=-16777217}function P3(s,c){if(c.type!=="stylesheet"||(c.state.loading&4)!==0)s.flags&=-16777217;else if(s.flags|=16777216,!t6(c))if(h5())s.flags|=8192;else throw Ys=Kp,iy}function ff(s,c){c!==null&&(s.flags|=4),s.flags&16384&&(c=s.tag!==22?qi():536870912,s.lanes|=c,dc|=c)}function hd(s,c){if(!Bt)switch(s.tailMode){case"hidden":c=s.tail;for(var p=null;c!==null;)c.alternate!==null&&(p=c),c=c.sibling;p===null?s.tail=null:p.sibling=null;break;case"collapsed":p=s.tail;for(var g=null;p!==null;)p.alternate!==null&&(g=p),p=p.sibling;g===null?c||s.tail===null?s.tail=null:s.tail.sibling=null:g.sibling=null}}function ln(s){var c=s.alternate!==null&&s.alternate.child===s.child,p=0,g=0;if(c)for(var x=s.child;x!==null;)p|=x.lanes|x.childLanes,g|=x.subtreeFlags&65011712,g|=x.flags&65011712,x.return=s,x=x.sibling;else for(x=s.child;x!==null;)p|=x.lanes|x.childLanes,g|=x.subtreeFlags,g|=x.flags,x.return=s,x=x.sibling;return s.subtreeFlags|=g,s.childLanes=p,c}function jH(s,c,p){var g=c.pendingProps;switch(Kb(c),c.tag){case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return ln(c),null;case 1:return ln(c),null;case 3:return p=c.stateNode,g=null,s!==null&&(g=s.memoizedState.cache),c.memoizedState.cache!==g&&(c.flags|=2048),Ji(Dn),ve(),p.pendingContext&&(p.context=p.pendingContext,p.pendingContext=null),(s===null||s.child===null)&&(Ql(c)?ro(c):s===null||s.memoizedState.isDehydrated&&(c.flags&256)===0||(c.flags|=1024,Qb())),ln(c),null;case 26:var x=c.type,E=c.memoizedState;return s===null?(ro(c),E!==null?(ln(c),P3(c,E)):(ln(c),jy(c,x,null,g,p))):E?E!==s.memoizedState?(ro(c),ln(c),P3(c,E)):(ln(c),c.flags&=-16777217):(s=s.memoizedProps,s!==g&&ro(c),ln(c),jy(c,x,s,g,p)),null;case 27:if(Le(c),p=fe.current,x=c.type,s!==null&&c.stateNode!=null)s.memoizedProps!==g&&ro(c);else{if(!g){if(c.stateNode===null)throw Error(r(166));return ln(c),null}s=be.current,Ql(c)?vA(c):(s=V5(x,g,p),c.stateNode=s,ro(c))}return ln(c),null;case 5:if(Le(c),x=c.type,s!==null&&c.stateNode!=null)s.memoizedProps!==g&&ro(c);else{if(!g){if(c.stateNode===null)throw Error(r(166));return ln(c),null}if(E=be.current,Ql(c))vA(c);else{var D=Rf(fe.current);switch(E){case 1:E=D.createElementNS("http://www.w3.org/2000/svg",x);break;case 2:E=D.createElementNS("http://www.w3.org/1998/Math/MathML",x);break;default:switch(x){case"svg":E=D.createElementNS("http://www.w3.org/2000/svg",x);break;case"math":E=D.createElementNS("http://www.w3.org/1998/Math/MathML",x);break;case"script":E=D.createElement("div"),E.innerHTML="<script><\/script>",E=E.removeChild(E.firstChild);break;case"select":E=typeof g.is=="string"?D.createElement("select",{is:g.is}):D.createElement("select"),g.multiple?E.multiple=!0:g.size&&(E.size=g.size);break;default:E=typeof g.is=="string"?D.createElement(x,{is:g.is}):D.createElement(x)}}E[Ln]=c,E[fn]=g;e:for(D=c.child;D!==null;){if(D.tag===5||D.tag===6)E.appendChild(D.stateNode);else if(D.tag!==4&&D.tag!==27&&D.child!==null){D.child.return=D,D=D.child;continue}if(D===c)break e;for(;D.sibling===null;){if(D.return===null||D.return===c)break e;D=D.return}D.sibling.return=D.return,D=D.sibling}c.stateNode=E;e:switch(ir(E,x,g),x){case"button":case"input":case"select":case"textarea":g=!!g.autoFocus;break e;case"img":g=!0;break e;default:g=!1}g&&ro(c)}}return ln(c),jy(c,c.type,s===null?null:s.memoizedProps,c.pendingProps,p),null;case 6:if(s&&c.stateNode!=null)s.memoizedProps!==g&&ro(c);else{if(typeof g!="string"&&c.stateNode===null)throw Error(r(166));if(s=fe.current,Ql(c)){if(s=c.stateNode,p=c.memoizedProps,g=null,x=nr,x!==null)switch(x.tag){case 27:case 5:g=x.memoizedProps}s[Ln]=c,s=!!(s.nodeValue===p||g!==null&&g.suppressHydrationWarning===!0||B5(s.nodeValue,p)),s||Uo(c,!0)}else s=Rf(s).createTextNode(g),s[Ln]=c,c.stateNode=s}return ln(c),null;case 31:if(p=c.memoizedState,s===null||s.memoizedState!==null){if(g=Ql(c),p!==null){if(s===null){if(!g)throw Error(r(318));if(s=c.memoizedState,s=s!==null?s.dehydrated:null,!s)throw Error(r(557));s[Ln]=c}else Hs(),(c.flags&128)===0&&(c.memoizedState=null),c.flags|=4;ln(c),s=!1}else p=Qb(),s!==null&&s.memoizedState!==null&&(s.memoizedState.hydrationErrors=p),s=!0;if(!s)return c.flags&256?(oa(c),c):(oa(c),null);if((c.flags&128)!==0)throw Error(r(558))}return ln(c),null;case 13:if(g=c.memoizedState,s===null||s.memoizedState!==null&&s.memoizedState.dehydrated!==null){if(x=Ql(c),g!==null&&g.dehydrated!==null){if(s===null){if(!x)throw Error(r(318));if(x=c.memoizedState,x=x!==null?x.dehydrated:null,!x)throw Error(r(317));x[Ln]=c}else Hs(),(c.flags&128)===0&&(c.memoizedState=null),c.flags|=4;ln(c),x=!1}else x=Qb(),s!==null&&s.memoizedState!==null&&(s.memoizedState.hydrationErrors=x),x=!0;if(!x)return c.flags&256?(oa(c),c):(oa(c),null)}return oa(c),(c.flags&128)!==0?(c.lanes=p,c):(p=g!==null,s=s!==null&&s.memoizedState!==null,p&&(g=c.child,x=null,g.alternate!==null&&g.alternate.memoizedState!==null&&g.alternate.memoizedState.cachePool!==null&&(x=g.alternate.memoizedState.cachePool.pool),E=null,g.memoizedState!==null&&g.memoizedState.cachePool!==null&&(E=g.memoizedState.cachePool.pool),E!==x&&(g.flags|=2048)),p!==s&&p&&(c.child.flags|=8192),ff(c,c.updateQueue),ln(c),null);case 4:return ve(),s===null&&u1(c.stateNode.containerInfo),ln(c),null;case 10:return Ji(c.type),ln(c),null;case 19:if(oe(Rn),g=c.memoizedState,g===null)return ln(c),null;if(x=(c.flags&128)!==0,E=g.rendering,E===null)if(x)hd(g,!1);else{if(Tn!==0||s!==null&&(s.flags&128)!==0)for(s=c.child;s!==null;){if(E=ef(s),E!==null){for(c.flags|=128,hd(g,!1),s=E.updateQueue,c.updateQueue=s,ff(c,s),c.subtreeFlags=0,s=p,p=c.child;p!==null;)fA(p,s),p=p.sibling;return U(Rn,Rn.current&1|2),Bt&&Zi(c,g.treeForkCount),c.child}s=s.sibling}g.tail!==null&&yt()>vf&&(c.flags|=128,x=!0,hd(g,!1),c.lanes=4194304)}else{if(!x)if(s=ef(E),s!==null){if(c.flags|=128,x=!0,s=s.updateQueue,c.updateQueue=s,ff(c,s),hd(g,!0),g.tail===null&&g.tailMode==="hidden"&&!E.alternate&&!Bt)return ln(c),null}else 2*yt()-g.renderingStartTime>vf&&p!==536870912&&(c.flags|=128,x=!0,hd(g,!1),c.lanes=4194304);g.isBackwards?(E.sibling=c.child,c.child=E):(s=g.last,s!==null?s.sibling=E:c.child=E,g.last=E)}return g.tail!==null?(s=g.tail,g.rendering=s,g.tail=s.sibling,g.renderingStartTime=yt(),s.sibling=null,p=Rn.current,U(Rn,x?p&1|2:p&1),Bt&&Zi(c,g.treeForkCount),s):(ln(c),null);case 22:case 23:return oa(c),dy(),g=c.memoizedState!==null,s!==null?s.memoizedState!==null!==g&&(c.flags|=8192):g&&(c.flags|=8192),g?(p&536870912)!==0&&(c.flags&128)===0&&(ln(c),c.subtreeFlags&6&&(c.flags|=8192)):ln(c),p=c.updateQueue,p!==null&&ff(c,p.retryQueue),p=null,s!==null&&s.memoizedState!==null&&s.memoizedState.cachePool!==null&&(p=s.memoizedState.cachePool.pool),g=null,c.memoizedState!==null&&c.memoizedState.cachePool!==null&&(g=c.memoizedState.cachePool.pool),g!==p&&(c.flags|=2048),s!==null&&oe(Ws),null;case 24:return p=null,s!==null&&(p=s.memoizedState.cache),c.memoizedState.cache!==p&&(c.flags|=2048),Ji(Dn),ln(c),null;case 25:return null;case 30:return null}throw Error(r(156,c.tag))}function HH(s,c){switch(Kb(c),c.tag){case 1:return s=c.flags,s&65536?(c.flags=s&-65537|128,c):null;case 3:return Ji(Dn),ve(),s=c.flags,(s&65536)!==0&&(s&128)===0?(c.flags=s&-65537|128,c):null;case 26:case 27:case 5:return Le(c),null;case 31:if(c.memoizedState!==null){if(oa(c),c.alternate===null)throw Error(r(340));Hs()}return s=c.flags,s&65536?(c.flags=s&-65537|128,c):null;case 13:if(oa(c),s=c.memoizedState,s!==null&&s.dehydrated!==null){if(c.alternate===null)throw Error(r(340));Hs()}return s=c.flags,s&65536?(c.flags=s&-65537|128,c):null;case 19:return oe(Rn),null;case 4:return ve(),null;case 10:return Ji(c.type),null;case 22:case 23:return oa(c),dy(),s!==null&&oe(Ws),s=c.flags,s&65536?(c.flags=s&-65537|128,c):null;case 24:return Ji(Dn),null;case 25:return null;default:return null}}function U3(s,c){switch(Kb(c),c.tag){case 3:Ji(Dn),ve();break;case 26:case 27:case 5:Le(c);break;case 4:ve();break;case 31:c.memoizedState!==null&&oa(c);break;case 13:oa(c);break;case 19:oe(Rn);break;case 10:Ji(c.type);break;case 22:case 23:oa(c),dy(),s!==null&&oe(Ws);break;case 24:Ji(Dn)}}function pd(s,c){try{var p=c.updateQueue,g=p!==null?p.lastEffect:null;if(g!==null){var x=g.next;p=x;do{if((p.tag&s)===s){g=void 0;var E=p.create,D=p.inst;g=E(),D.destroy=g}p=p.next}while(p!==x)}}catch(j){Zt(c,c.return,j)}}function Yo(s,c,p){try{var g=c.updateQueue,x=g!==null?g.lastEffect:null;if(x!==null){var E=x.next;g=E;do{if((g.tag&s)===s){var D=g.inst,j=D.destroy;if(j!==void 0){D.destroy=void 0,x=c;var ne=p,de=j;try{de()}catch(ye){Zt(x,ne,ye)}}}g=g.next}while(g!==E)}}catch(ye){Zt(c,c.return,ye)}}function j3(s){var c=s.updateQueue;if(c!==null){var p=s.stateNode;try{IA(c,p)}catch(g){Zt(s,s.return,g)}}}function H3(s,c,p){p.props=Zs(s.type,s.memoizedProps),p.state=s.memoizedState;try{p.componentWillUnmount()}catch(g){Zt(s,c,g)}}function fd(s,c){try{var p=s.ref;if(p!==null){switch(s.tag){case 26:case 27:case 5:var g=s.stateNode;break;case 30:g=s.stateNode;break;default:g=s.stateNode}typeof p=="function"?s.refCleanup=p(g):p.current=g}}catch(x){Zt(s,c,x)}}function mi(s,c){var p=s.ref,g=s.refCleanup;if(p!==null)if(typeof g=="function")try{g()}catch(x){Zt(s,c,x)}finally{s.refCleanup=null,s=s.alternate,s!=null&&(s.refCleanup=null)}else if(typeof p=="function")try{p(null)}catch(x){Zt(s,c,x)}else p.current=null}function G3(s){var c=s.type,p=s.memoizedProps,g=s.stateNode;try{e:switch(c){case"button":case"input":case"select":case"textarea":p.autoFocus&&g.focus();break e;case"img":p.src?g.src=p.src:p.srcSet&&(g.srcset=p.srcSet)}}catch(x){Zt(s,s.return,x)}}function Hy(s,c,p){try{var g=s.stateNode;dG(g,s.type,p,c),g[fn]=c}catch(x){Zt(s,s.return,x)}}function q3(s){return s.tag===5||s.tag===3||s.tag===26||s.tag===27&&ts(s.type)||s.tag===4}function Gy(s){e:for(;;){for(;s.sibling===null;){if(s.return===null||q3(s.return))return null;s=s.return}for(s.sibling.return=s.return,s=s.sibling;s.tag!==5&&s.tag!==6&&s.tag!==18;){if(s.tag===27&&ts(s.type)||s.flags&2||s.child===null||s.tag===4)continue e;s.child.return=s,s=s.child}if(!(s.flags&2))return s.stateNode}}function qy(s,c,p){var g=s.tag;if(g===5||g===6)s=s.stateNode,c?(p.nodeType===9?p.body:p.nodeName==="HTML"?p.ownerDocument.body:p).insertBefore(s,c):(c=p.nodeType===9?p.body:p.nodeName==="HTML"?p.ownerDocument.body:p,c.appendChild(s),p=p._reactRootContainer,p!=null||c.onclick!==null||(c.onclick=Yi));else if(g!==4&&(g===27&&ts(s.type)&&(p=s.stateNode,c=null),s=s.child,s!==null))for(qy(s,c,p),s=s.sibling;s!==null;)qy(s,c,p),s=s.sibling}function mf(s,c,p){var g=s.tag;if(g===5||g===6)s=s.stateNode,c?p.insertBefore(s,c):p.appendChild(s);else if(g!==4&&(g===27&&ts(s.type)&&(p=s.stateNode),s=s.child,s!==null))for(mf(s,c,p),s=s.sibling;s!==null;)mf(s,c,p),s=s.sibling}function W3(s){var c=s.stateNode,p=s.memoizedProps;try{for(var g=s.type,x=c.attributes;x.length;)c.removeAttributeNode(x[0]);ir(c,g,p),c[Ln]=s,c[fn]=p}catch(E){Zt(s,s.return,E)}}var ao=!1,Fn=!1,Wy=!1,V3=typeof WeakSet=="function"?WeakSet:Set,Qn=null;function GH(s,c){if(s=s.containerInfo,p1=Bf,s=iA(s),$b(s)){if("selectionStart"in s)var p={start:s.selectionStart,end:s.selectionEnd};else e:{p=(p=s.ownerDocument)&&p.defaultView||window;var g=p.getSelection&&p.getSelection();if(g&&g.rangeCount!==0){p=g.anchorNode;var x=g.anchorOffset,E=g.focusNode;g=g.focusOffset;try{p.nodeType,E.nodeType}catch{p=null;break e}var D=0,j=-1,ne=-1,de=0,ye=0,Se=s,he=null;t:for(;;){for(var pe;Se!==p||x!==0&&Se.nodeType!==3||(j=D+x),Se!==E||g!==0&&Se.nodeType!==3||(ne=D+g),Se.nodeType===3&&(D+=Se.nodeValue.length),(pe=Se.firstChild)!==null;)he=Se,Se=pe;for(;;){if(Se===s)break t;if(he===p&&++de===x&&(j=D),he===E&&++ye===g&&(ne=D),(pe=Se.nextSibling)!==null)break;Se=he,he=Se.parentNode}Se=pe}p=j===-1||ne===-1?null:{start:j,end:ne}}else p=null}p=p||{start:0,end:0}}else p=null;for(f1={focusedElem:s,selectionRange:p},Bf=!1,Qn=c;Qn!==null;)if(c=Qn,s=c.child,(c.subtreeFlags&1028)!==0&&s!==null)s.return=c,Qn=s;else for(;Qn!==null;){switch(c=Qn,E=c.alternate,s=c.flags,c.tag){case 0:if((s&4)!==0&&(s=c.updateQueue,s=s!==null?s.events:null,s!==null))for(p=0;p<s.length;p++)x=s[p],x.ref.impl=x.nextImpl;break;case 11:case 15:break;case 1:if((s&1024)!==0&&E!==null){s=void 0,p=c,x=E.memoizedProps,E=E.memoizedState,g=p.stateNode;try{var Pe=Zs(p.type,x);s=g.getSnapshotBeforeUpdate(Pe,E),g.__reactInternalSnapshotBeforeUpdate=s}catch(ot){Zt(p,p.return,ot)}}break;case 3:if((s&1024)!==0){if(s=c.stateNode.containerInfo,p=s.nodeType,p===9)b1(s);else if(p===1)switch(s.nodeName){case"HEAD":case"HTML":case"BODY":b1(s);break;default:s.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if((s&1024)!==0)throw Error(r(163))}if(s=c.sibling,s!==null){s.return=c.return,Qn=s;break}Qn=c.return}}function Y3(s,c,p){var g=p.flags;switch(p.tag){case 0:case 11:case 15:oo(s,p),g&4&&pd(5,p);break;case 1:if(oo(s,p),g&4)if(s=p.stateNode,c===null)try{s.componentDidMount()}catch(D){Zt(p,p.return,D)}else{var x=Zs(p.type,c.memoizedProps);c=c.memoizedState;try{s.componentDidUpdate(x,c,s.__reactInternalSnapshotBeforeUpdate)}catch(D){Zt(p,p.return,D)}}g&64&&j3(p),g&512&&fd(p,p.return);break;case 3:if(oo(s,p),g&64&&(s=p.updateQueue,s!==null)){if(c=null,p.child!==null)switch(p.child.tag){case 27:case 5:c=p.child.stateNode;break;case 1:c=p.child.stateNode}try{IA(s,c)}catch(D){Zt(p,p.return,D)}}break;case 27:c===null&&g&4&&W3(p);case 26:case 5:oo(s,p),c===null&&g&4&&G3(p),g&512&&fd(p,p.return);break;case 12:oo(s,p);break;case 31:oo(s,p),g&4&&Z3(s,p);break;case 13:oo(s,p),g&4&&Q3(s,p),g&64&&(s=p.memoizedState,s!==null&&(s=s.dehydrated,s!==null&&(p=JH.bind(null,p),vG(s,p))));break;case 22:if(g=p.memoizedState!==null||ao,!g){c=c!==null&&c.memoizedState!==null||Fn,x=ao;var E=Fn;ao=g,(Fn=c)&&!E?so(s,p,(p.subtreeFlags&8772)!==0):oo(s,p),ao=x,Fn=E}break;case 30:break;default:oo(s,p)}}function X3(s){var c=s.alternate;c!==null&&(s.alternate=null,X3(c)),s.child=null,s.deletions=null,s.sibling=null,s.tag===5&&(c=s.stateNode,c!==null&&re(c)),s.stateNode=null,s.return=null,s.dependencies=null,s.memoizedProps=null,s.memoizedState=null,s.pendingProps=null,s.stateNode=null,s.updateQueue=null}var mn=null,Gr=!1;function io(s,c,p){for(p=p.child;p!==null;)K3(s,c,p),p=p.sibling}function K3(s,c,p){if(hn&&typeof hn.onCommitFiberUnmount=="function")try{hn.onCommitFiberUnmount(In,p)}catch{}switch(p.tag){case 26:Fn||mi(p,c),io(s,c,p),p.memoizedState?p.memoizedState.count--:p.stateNode&&(p=p.stateNode,p.parentNode.removeChild(p));break;case 27:Fn||mi(p,c);var g=mn,x=Gr;ts(p.type)&&(mn=p.stateNode,Gr=!1),io(s,c,p),Ed(p.stateNode),mn=g,Gr=x;break;case 5:Fn||mi(p,c);case 6:if(g=mn,x=Gr,mn=null,io(s,c,p),mn=g,Gr=x,mn!==null)if(Gr)try{(mn.nodeType===9?mn.body:mn.nodeName==="HTML"?mn.ownerDocument.body:mn).removeChild(p.stateNode)}catch(E){Zt(p,c,E)}else try{mn.removeChild(p.stateNode)}catch(E){Zt(p,c,E)}break;case 18:mn!==null&&(Gr?(s=mn,j5(s.nodeType===9?s.body:s.nodeName==="HTML"?s.ownerDocument.body:s,p.stateNode),vc(s)):j5(mn,p.stateNode));break;case 4:g=mn,x=Gr,mn=p.stateNode.containerInfo,Gr=!0,io(s,c,p),mn=g,Gr=x;break;case 0:case 11:case 14:case 15:Yo(2,p,c),Fn||Yo(4,p,c),io(s,c,p);break;case 1:Fn||(mi(p,c),g=p.stateNode,typeof g.componentWillUnmount=="function"&&H3(p,c,g)),io(s,c,p);break;case 21:io(s,c,p);break;case 22:Fn=(g=Fn)||p.memoizedState!==null,io(s,c,p),Fn=g;break;default:io(s,c,p)}}function Z3(s,c){if(c.memoizedState===null&&(s=c.alternate,s!==null&&(s=s.memoizedState,s!==null))){s=s.dehydrated;try{vc(s)}catch(p){Zt(c,c.return,p)}}}function Q3(s,c){if(c.memoizedState===null&&(s=c.alternate,s!==null&&(s=s.memoizedState,s!==null&&(s=s.dehydrated,s!==null))))try{vc(s)}catch(p){Zt(c,c.return,p)}}function qH(s){switch(s.tag){case 31:case 13:case 19:var c=s.stateNode;return c===null&&(c=s.stateNode=new V3),c;case 22:return s=s.stateNode,c=s._retryCache,c===null&&(c=s._retryCache=new V3),c;default:throw Error(r(435,s.tag))}}function gf(s,c){var p=qH(s);c.forEach(function(g){if(!p.has(g)){p.add(g);var x=eG.bind(null,s,g);g.then(x,x)}})}function qr(s,c){var p=c.deletions;if(p!==null)for(var g=0;g<p.length;g++){var x=p[g],E=s,D=c,j=D;e:for(;j!==null;){switch(j.tag){case 27:if(ts(j.type)){mn=j.stateNode,Gr=!1;break e}break;case 5:mn=j.stateNode,Gr=!1;break e;case 3:case 4:mn=j.stateNode.containerInfo,Gr=!0;break e}j=j.return}if(mn===null)throw Error(r(160));K3(E,D,x),mn=null,Gr=!1,E=x.alternate,E!==null&&(E.return=null),x.return=null}if(c.subtreeFlags&13886)for(c=c.child;c!==null;)J3(c,s),c=c.sibling}var Ka=null;function J3(s,c){var p=s.alternate,g=s.flags;switch(s.tag){case 0:case 11:case 14:case 15:qr(c,s),Wr(s),g&4&&(Yo(3,s,s.return),pd(3,s),Yo(5,s,s.return));break;case 1:qr(c,s),Wr(s),g&512&&(Fn||p===null||mi(p,p.return)),g&64&&ao&&(s=s.updateQueue,s!==null&&(g=s.callbacks,g!==null&&(p=s.shared.hiddenCallbacks,s.shared.hiddenCallbacks=p===null?g:p.concat(g))));break;case 26:var x=Ka;if(qr(c,s),Wr(s),g&512&&(Fn||p===null||mi(p,p.return)),g&4){var E=p!==null?p.memoizedState:null;if(g=s.memoizedState,p===null)if(g===null)if(s.stateNode===null){e:{g=s.type,p=s.memoizedProps,x=x.ownerDocument||x;t:switch(g){case"title":E=x.getElementsByTagName("title")[0],(!E||E[Ke]||E[Ln]||E.namespaceURI==="http://www.w3.org/2000/svg"||E.hasAttribute("itemprop"))&&(E=x.createElement(g),x.head.insertBefore(E,x.querySelector("head > title"))),ir(E,g,p),E[Ln]=s,Tt(E),g=E;break e;case"link":var D=J5("link","href",x).get(g+(p.href||""));if(D){for(var j=0;j<D.length;j++)if(E=D[j],E.getAttribute("href")===(p.href==null||p.href===""?null:p.href)&&E.getAttribute("rel")===(p.rel==null?null:p.rel)&&E.getAttribute("title")===(p.title==null?null:p.title)&&E.getAttribute("crossorigin")===(p.crossOrigin==null?null:p.crossOrigin)){D.splice(j,1);break t}}E=x.createElement(g),ir(E,g,p),x.head.appendChild(E);break;case"meta":if(D=J5("meta","content",x).get(g+(p.content||""))){for(j=0;j<D.length;j++)if(E=D[j],E.getAttribute("content")===(p.content==null?null:""+p.content)&&E.getAttribute("name")===(p.name==null?null:p.name)&&E.getAttribute("property")===(p.property==null?null:p.property)&&E.getAttribute("http-equiv")===(p.httpEquiv==null?null:p.httpEquiv)&&E.getAttribute("charset")===(p.charSet==null?null:p.charSet)){D.splice(j,1);break t}}E=x.createElement(g),ir(E,g,p),x.head.appendChild(E);break;default:throw Error(r(468,g))}E[Ln]=s,Tt(E),g=E}s.stateNode=g}else e6(x,s.type,s.stateNode);else s.stateNode=Q5(x,g,s.memoizedProps);else E!==g?(E===null?p.stateNode!==null&&(p=p.stateNode,p.parentNode.removeChild(p)):E.count--,g===null?e6(x,s.type,s.stateNode):Q5(x,g,s.memoizedProps)):g===null&&s.stateNode!==null&&Hy(s,s.memoizedProps,p.memoizedProps)}break;case 27:qr(c,s),Wr(s),g&512&&(Fn||p===null||mi(p,p.return)),p!==null&&g&4&&Hy(s,s.memoizedProps,p.memoizedProps);break;case 5:if(qr(c,s),Wr(s),g&512&&(Fn||p===null||mi(p,p.return)),s.flags&32){x=s.stateNode;try{jl(x,"")}catch(Pe){Zt(s,s.return,Pe)}}g&4&&s.stateNode!=null&&(x=s.memoizedProps,Hy(s,x,p!==null?p.memoizedProps:x)),g&1024&&(Wy=!0);break;case 6:if(qr(c,s),Wr(s),g&4){if(s.stateNode===null)throw Error(r(162));g=s.memoizedProps,p=s.stateNode;try{p.nodeValue=g}catch(Pe){Zt(s,s.return,Pe)}}break;case 3:if(If=null,x=Ka,Ka=Nf(c.containerInfo),qr(c,s),Ka=x,Wr(s),g&4&&p!==null&&p.memoizedState.isDehydrated)try{vc(c.containerInfo)}catch(Pe){Zt(s,s.return,Pe)}Wy&&(Wy=!1,e5(s));break;case 4:g=Ka,Ka=Nf(s.stateNode.containerInfo),qr(c,s),Wr(s),Ka=g;break;case 12:qr(c,s),Wr(s);break;case 31:qr(c,s),Wr(s),g&4&&(g=s.updateQueue,g!==null&&(s.updateQueue=null,gf(s,g)));break;case 13:qr(c,s),Wr(s),s.child.flags&8192&&s.memoizedState!==null!=(p!==null&&p.memoizedState!==null)&&(yf=yt()),g&4&&(g=s.updateQueue,g!==null&&(s.updateQueue=null,gf(s,g)));break;case 22:x=s.memoizedState!==null;var ne=p!==null&&p.memoizedState!==null,de=ao,ye=Fn;if(ao=de||x,Fn=ye||ne,qr(c,s),Fn=ye,ao=de,Wr(s),g&8192)e:for(c=s.stateNode,c._visibility=x?c._visibility&-2:c._visibility|1,x&&(p===null||ne||ao||Fn||Qs(s)),p=null,c=s;;){if(c.tag===5||c.tag===26){if(p===null){ne=p=c;try{if(E=ne.stateNode,x)D=E.style,typeof D.setProperty=="function"?D.setProperty("display","none","important"):D.display="none";else{j=ne.stateNode;var Se=ne.memoizedProps.style,he=Se!=null&&Se.hasOwnProperty("display")?Se.display:null;j.style.display=he==null||typeof he=="boolean"?"":(""+he).trim()}}catch(Pe){Zt(ne,ne.return,Pe)}}}else if(c.tag===6){if(p===null){ne=c;try{ne.stateNode.nodeValue=x?"":ne.memoizedProps}catch(Pe){Zt(ne,ne.return,Pe)}}}else if(c.tag===18){if(p===null){ne=c;try{var pe=ne.stateNode;x?H5(pe,!0):H5(ne.stateNode,!1)}catch(Pe){Zt(ne,ne.return,Pe)}}}else if((c.tag!==22&&c.tag!==23||c.memoizedState===null||c===s)&&c.child!==null){c.child.return=c,c=c.child;continue}if(c===s)break e;for(;c.sibling===null;){if(c.return===null||c.return===s)break e;p===c&&(p=null),c=c.return}p===c&&(p=null),c.sibling.return=c.return,c=c.sibling}g&4&&(g=s.updateQueue,g!==null&&(p=g.retryQueue,p!==null&&(g.retryQueue=null,gf(s,p))));break;case 19:qr(c,s),Wr(s),g&4&&(g=s.updateQueue,g!==null&&(s.updateQueue=null,gf(s,g)));break;case 30:break;case 21:break;default:qr(c,s),Wr(s)}}function Wr(s){var c=s.flags;if(c&2){try{for(var p,g=s.return;g!==null;){if(q3(g)){p=g;break}g=g.return}if(p==null)throw Error(r(160));switch(p.tag){case 27:var x=p.stateNode,E=Gy(s);mf(s,E,x);break;case 5:var D=p.stateNode;p.flags&32&&(jl(D,""),p.flags&=-33);var j=Gy(s);mf(s,j,D);break;case 3:case 4:var ne=p.stateNode.containerInfo,de=Gy(s);qy(s,de,ne);break;default:throw Error(r(161))}}catch(ye){Zt(s,s.return,ye)}s.flags&=-3}c&4096&&(s.flags&=-4097)}function e5(s){if(s.subtreeFlags&1024)for(s=s.child;s!==null;){var c=s;e5(c),c.tag===5&&c.flags&1024&&c.stateNode.reset(),s=s.sibling}}function oo(s,c){if(c.subtreeFlags&8772)for(c=c.child;c!==null;)Y3(s,c.alternate,c),c=c.sibling}function Qs(s){for(s=s.child;s!==null;){var c=s;switch(c.tag){case 0:case 11:case 14:case 15:Yo(4,c,c.return),Qs(c);break;case 1:mi(c,c.return);var p=c.stateNode;typeof p.componentWillUnmount=="function"&&H3(c,c.return,p),Qs(c);break;case 27:Ed(c.stateNode);case 26:case 5:mi(c,c.return),Qs(c);break;case 22:c.memoizedState===null&&Qs(c);break;case 30:Qs(c);break;default:Qs(c)}s=s.sibling}}function so(s,c,p){for(p=p&&(c.subtreeFlags&8772)!==0,c=c.child;c!==null;){var g=c.alternate,x=s,E=c,D=E.flags;switch(E.tag){case 0:case 11:case 15:so(x,E,p),pd(4,E);break;case 1:if(so(x,E,p),g=E,x=g.stateNode,typeof x.componentDidMount=="function")try{x.componentDidMount()}catch(de){Zt(g,g.return,de)}if(g=E,x=g.updateQueue,x!==null){var j=g.stateNode;try{var ne=x.shared.hiddenCallbacks;if(ne!==null)for(x.shared.hiddenCallbacks=null,x=0;x<ne.length;x++)OA(ne[x],j)}catch(de){Zt(g,g.return,de)}}p&&D&64&&j3(E),fd(E,E.return);break;case 27:W3(E);case 26:case 5:so(x,E,p),p&&g===null&&D&4&&G3(E),fd(E,E.return);break;case 12:so(x,E,p);break;case 31:so(x,E,p),p&&D&4&&Z3(x,E);break;case 13:so(x,E,p),p&&D&4&&Q3(x,E);break;case 22:E.memoizedState===null&&so(x,E,p),fd(E,E.return);break;case 30:break;default:so(x,E,p)}c=c.sibling}}function Vy(s,c){var p=null;s!==null&&s.memoizedState!==null&&s.memoizedState.cachePool!==null&&(p=s.memoizedState.cachePool.pool),s=null,c.memoizedState!==null&&c.memoizedState.cachePool!==null&&(s=c.memoizedState.cachePool.pool),s!==p&&(s!=null&&s.refCount++,p!=null&&ed(p))}function Yy(s,c){s=null,c.alternate!==null&&(s=c.alternate.memoizedState.cache),c=c.memoizedState.cache,c!==s&&(c.refCount++,s!=null&&ed(s))}function Za(s,c,p,g){if(c.subtreeFlags&10256)for(c=c.child;c!==null;)t5(s,c,p,g),c=c.sibling}function t5(s,c,p,g){var x=c.flags;switch(c.tag){case 0:case 11:case 15:Za(s,c,p,g),x&2048&&pd(9,c);break;case 1:Za(s,c,p,g);break;case 3:Za(s,c,p,g),x&2048&&(s=null,c.alternate!==null&&(s=c.alternate.memoizedState.cache),c=c.memoizedState.cache,c!==s&&(c.refCount++,s!=null&&ed(s)));break;case 12:if(x&2048){Za(s,c,p,g),s=c.stateNode;try{var E=c.memoizedProps,D=E.id,j=E.onPostCommit;typeof j=="function"&&j(D,c.alternate===null?"mount":"update",s.passiveEffectDuration,-0)}catch(ne){Zt(c,c.return,ne)}}else Za(s,c,p,g);break;case 31:Za(s,c,p,g);break;case 13:Za(s,c,p,g);break;case 23:break;case 22:E=c.stateNode,D=c.alternate,c.memoizedState!==null?E._visibility&2?Za(s,c,p,g):md(s,c):E._visibility&2?Za(s,c,p,g):(E._visibility|=2,lc(s,c,p,g,(c.subtreeFlags&10256)!==0||!1)),x&2048&&Vy(D,c);break;case 24:Za(s,c,p,g),x&2048&&Yy(c.alternate,c);break;default:Za(s,c,p,g)}}function lc(s,c,p,g,x){for(x=x&&((c.subtreeFlags&10256)!==0||!1),c=c.child;c!==null;){var E=s,D=c,j=p,ne=g,de=D.flags;switch(D.tag){case 0:case 11:case 15:lc(E,D,j,ne,x),pd(8,D);break;case 23:break;case 22:var ye=D.stateNode;D.memoizedState!==null?ye._visibility&2?lc(E,D,j,ne,x):md(E,D):(ye._visibility|=2,lc(E,D,j,ne,x)),x&&de&2048&&Vy(D.alternate,D);break;case 24:lc(E,D,j,ne,x),x&&de&2048&&Yy(D.alternate,D);break;default:lc(E,D,j,ne,x)}c=c.sibling}}function md(s,c){if(c.subtreeFlags&10256)for(c=c.child;c!==null;){var p=s,g=c,x=g.flags;switch(g.tag){case 22:md(p,g),x&2048&&Vy(g.alternate,g);break;case 24:md(p,g),x&2048&&Yy(g.alternate,g);break;default:md(p,g)}c=c.sibling}}var gd=8192;function cc(s,c,p){if(s.subtreeFlags&gd)for(s=s.child;s!==null;)n5(s,c,p),s=s.sibling}function n5(s,c,p){switch(s.tag){case 26:cc(s,c,p),s.flags&gd&&s.memoizedState!==null&&OG(p,Ka,s.memoizedState,s.memoizedProps);break;case 5:cc(s,c,p);break;case 3:case 4:var g=Ka;Ka=Nf(s.stateNode.containerInfo),cc(s,c,p),Ka=g;break;case 22:s.memoizedState===null&&(g=s.alternate,g!==null&&g.memoizedState!==null?(g=gd,gd=16777216,cc(s,c,p),gd=g):cc(s,c,p));break;default:cc(s,c,p)}}function r5(s){var c=s.alternate;if(c!==null&&(s=c.child,s!==null)){c.child=null;do c=s.sibling,s.sibling=null,s=c;while(s!==null)}}function bd(s){var c=s.deletions;if((s.flags&16)!==0){if(c!==null)for(var p=0;p<c.length;p++){var g=c[p];Qn=g,i5(g,s)}r5(s)}if(s.subtreeFlags&10256)for(s=s.child;s!==null;)a5(s),s=s.sibling}function a5(s){switch(s.tag){case 0:case 11:case 15:bd(s),s.flags&2048&&Yo(9,s,s.return);break;case 3:bd(s);break;case 12:bd(s);break;case 22:var c=s.stateNode;s.memoizedState!==null&&c._visibility&2&&(s.return===null||s.return.tag!==13)?(c._visibility&=-3,bf(s)):bd(s);break;default:bd(s)}}function bf(s){var c=s.deletions;if((s.flags&16)!==0){if(c!==null)for(var p=0;p<c.length;p++){var g=c[p];Qn=g,i5(g,s)}r5(s)}for(s=s.child;s!==null;){switch(c=s,c.tag){case 0:case 11:case 15:Yo(8,c,c.return),bf(c);break;case 22:p=c.stateNode,p._visibility&2&&(p._visibility&=-3,bf(c));break;default:bf(c)}s=s.sibling}}function i5(s,c){for(;Qn!==null;){var p=Qn;switch(p.tag){case 0:case 11:case 15:Yo(8,p,c);break;case 23:case 22:if(p.memoizedState!==null&&p.memoizedState.cachePool!==null){var g=p.memoizedState.cachePool.pool;g!=null&&g.refCount++}break;case 24:ed(p.memoizedState.cache)}if(g=p.child,g!==null)g.return=p,Qn=g;else e:for(p=s;Qn!==null;){g=Qn;var x=g.sibling,E=g.return;if(X3(g),g===p){Qn=null;break e}if(x!==null){x.return=E,Qn=x;break e}Qn=E}}}var WH={getCacheForType:function(s){var c=rr(Dn),p=c.data.get(s);return p===void 0&&(p=s(),c.data.set(s,p)),p},cacheSignal:function(){return rr(Dn).controller.signal}},VH=typeof WeakMap=="function"?WeakMap:Map,Ht=0,nn=null,Rt=null,Lt=0,Kt=0,sa=null,Xo=!1,uc=!1,Xy=!1,lo=0,Tn=0,Ko=0,Js=0,Ky=0,la=0,dc=0,yd=null,Vr=null,Zy=!1,yf=0,o5=0,vf=1/0,xf=null,Zo=null,qn=0,Qo=null,hc=null,co=0,Qy=0,Jy=null,s5=null,vd=0,e1=null;function ca(){return(Ht&2)!==0&&Lt!==0?Lt&-Lt:$.T!==null?o1():$u()}function l5(){if(la===0)if((Lt&536870912)===0||Bt){var s=Gi;Gi<<=1,(Gi&3932160)===0&&(Gi=262144),la=s}else la=536870912;return s=ia.current,s!==null&&(s.flags|=32),la}function Yr(s,c,p){(s===nn&&(Kt===2||Kt===9)||s.cancelPendingCommit!==null)&&(pc(s,0),Jo(s,Lt,la,!1)),Fo(s,p),((Ht&2)===0||s!==nn)&&(s===nn&&((Ht&2)===0&&(Js|=p),Tn===4&&Jo(s,Lt,la,!1)),gi(s))}function c5(s,c,p){if((Ht&6)!==0)throw Error(r(327));var g=!p&&(c&127)===0&&(c&s.expiredLanes)===0||Fs(s,c),x=g?KH(s,c):n1(s,c,!0),E=g;do{if(x===0){uc&&!g&&Jo(s,c,0,!1);break}else{if(p=s.current.alternate,E&&!YH(p)){x=n1(s,c,!1),E=!1;continue}if(x===2){if(E=c,s.errorRecoveryDisabledLanes&E)var D=0;else D=s.pendingLanes&-536870913,D=D!==0?D:D&536870912?536870912:0;if(D!==0){c=D;e:{var j=s;x=yd;var ne=j.current.memoizedState.isDehydrated;if(ne&&(pc(j,D).flags|=256),D=n1(j,D,!1),D!==2){if(Xy&&!ne){j.errorRecoveryDisabledLanes|=E,Js|=E,x=4;break e}E=Vr,Vr=x,E!==null&&(Vr===null?Vr=E:Vr.push.apply(Vr,E))}x=D}if(E=!1,x!==2)continue}}if(x===1){pc(s,0),Jo(s,c,0,!0);break}e:{switch(g=s,E=x,E){case 0:case 1:throw Error(r(345));case 4:if((c&4194048)!==c)break;case 6:Jo(g,c,la,!Xo);break e;case 2:Vr=null;break;case 3:case 5:break;default:throw Error(r(329))}if((c&62914560)===c&&(x=yf+300-yt(),10<x)){if(Jo(g,c,la,!Xo),$l(g,0,!0)!==0)break e;co=c,g.timeoutHandle=P5(u5.bind(null,g,p,Vr,xf,Zy,c,la,Js,dc,Xo,E,"Throttled",-0,0),x);break e}u5(g,p,Vr,xf,Zy,c,la,Js,dc,Xo,E,null,-0,0)}}break}while(!0);gi(s)}function u5(s,c,p,g,x,E,D,j,ne,de,ye,Se,he,pe){if(s.timeoutHandle=-1,Se=c.subtreeFlags,Se&8192||(Se&16785408)===16785408){Se={stylesheets:null,count:0,imgCount:0,imgBytes:0,suspenseyImages:[],waitingForImages:!0,waitingForViewTransition:!1,unsuspend:Yi},n5(c,E,Se);var Pe=(E&62914560)===E?yf-yt():(E&4194048)===E?o5-yt():0;if(Pe=IG(Se,Pe),Pe!==null){co=E,s.cancelPendingCommit=Pe(y5.bind(null,s,c,E,p,g,x,D,j,ne,ye,Se,null,he,pe)),Jo(s,E,D,!de);return}}y5(s,c,E,p,g,x,D,j,ne)}function YH(s){for(var c=s;;){var p=c.tag;if((p===0||p===11||p===15)&&c.flags&16384&&(p=c.updateQueue,p!==null&&(p=p.stores,p!==null)))for(var g=0;g<p.length;g++){var x=p[g],E=x.getSnapshot;x=x.value;try{if(!ra(E(),x))return!1}catch{return!1}}if(p=c.child,c.subtreeFlags&16384&&p!==null)p.return=c,c=p;else{if(c===s)break;for(;c.sibling===null;){if(c.return===null||c.return===s)return!0;c=c.return}c.sibling.return=c.return,c=c.sibling}}return!0}function Jo(s,c,p,g){c&=~Ky,c&=~Js,s.suspendedLanes|=c,s.pingedLanes&=~c,g&&(s.warmLanes|=c),g=s.expirationTimes;for(var x=c;0<x;){var E=31-zt(x),D=1<<E;g[E]=-1,x&=~D}p!==0&&Fu(s,p,c)}function Sf(){return(Ht&6)===0?(xd(0),!1):!0}function t1(){if(Rt!==null){if(Kt===0)var s=Rt.return;else s=Rt,Qi=Gs=null,by(s),rc=null,nd=0,s=Rt;for(;s!==null;)U3(s.alternate,s),s=s.return;Rt=null}}function pc(s,c){var p=s.timeoutHandle;p!==-1&&(s.timeoutHandle=-1,fG(p)),p=s.cancelPendingCommit,p!==null&&(s.cancelPendingCommit=null,p()),co=0,t1(),nn=s,Rt=p=Ki(s.current,null),Lt=c,Kt=0,sa=null,Xo=!1,uc=Fs(s,c),Xy=!1,dc=la=Ky=Js=Ko=Tn=0,Vr=yd=null,Zy=!1,(c&8)!==0&&(c|=c&32);var g=s.entangledLanes;if(g!==0)for(s=s.entanglements,g&=c;0<g;){var x=31-zt(g),E=1<<x;c|=s[x],g&=~E}return lo=c,Up(),p}function d5(s,c){vt=null,$.H=ud,c===nc||c===Xp?(c=CA(),Kt=3):c===iy?(c=CA(),Kt=4):Kt=c===Ly?8:c!==null&&typeof c=="object"&&typeof c.then=="function"?6:1,sa=c,Rt===null&&(Tn=1,uf(s,Ra(c,s.current)))}function h5(){var s=ia.current;return s===null?!0:(Lt&4194048)===Lt?La===null:(Lt&62914560)===Lt||(Lt&536870912)!==0?s===La:!1}function p5(){var s=$.H;return $.H=ud,s===null?ud:s}function f5(){var s=$.A;return $.A=WH,s}function wf(){Tn=4,Xo||(Lt&4194048)!==Lt&&ia.current!==null||(uc=!0),(Ko&134217727)===0&&(Js&134217727)===0||nn===null||Jo(nn,Lt,la,!1)}function n1(s,c,p){var g=Ht;Ht|=2;var x=p5(),E=f5();(nn!==s||Lt!==c)&&(xf=null,pc(s,c)),c=!1;var D=Tn;e:do try{if(Kt!==0&&Rt!==null){var j=Rt,ne=sa;switch(Kt){case 8:t1(),D=6;break e;case 3:case 2:case 9:case 6:ia.current===null&&(c=!0);var de=Kt;if(Kt=0,sa=null,fc(s,j,ne,de),p&&uc){D=0;break e}break;default:de=Kt,Kt=0,sa=null,fc(s,j,ne,de)}}XH(),D=Tn;break}catch(ye){d5(s,ye)}while(!0);return c&&s.shellSuspendCounter++,Qi=Gs=null,Ht=g,$.H=x,$.A=E,Rt===null&&(nn=null,Lt=0,Up()),D}function XH(){for(;Rt!==null;)m5(Rt)}function KH(s,c){var p=Ht;Ht|=2;var g=p5(),x=f5();nn!==s||Lt!==c?(xf=null,vf=yt()+500,pc(s,c)):uc=Fs(s,c);e:do try{if(Kt!==0&&Rt!==null){c=Rt;var E=sa;t:switch(Kt){case 1:Kt=0,sa=null,fc(s,c,E,1);break;case 2:case 9:if(TA(E)){Kt=0,sa=null,g5(c);break}c=function(){Kt!==2&&Kt!==9||nn!==s||(Kt=7),gi(s)},E.then(c,c);break e;case 3:Kt=7;break e;case 4:Kt=5;break e;case 7:TA(E)?(Kt=0,sa=null,g5(c)):(Kt=0,sa=null,fc(s,c,E,7));break;case 5:var D=null;switch(Rt.tag){case 26:D=Rt.memoizedState;case 5:case 27:var j=Rt;if(D?t6(D):j.stateNode.complete){Kt=0,sa=null;var ne=j.sibling;if(ne!==null)Rt=ne;else{var de=j.return;de!==null?(Rt=de,Ef(de)):Rt=null}break t}}Kt=0,sa=null,fc(s,c,E,5);break;case 6:Kt=0,sa=null,fc(s,c,E,6);break;case 8:t1(),Tn=6;break e;default:throw Error(r(462))}}ZH();break}catch(ye){d5(s,ye)}while(!0);return Qi=Gs=null,$.H=g,$.A=x,Ht=p,Rt!==null?0:(nn=null,Lt=0,Up(),Tn)}function ZH(){for(;Rt!==null&&!di();)m5(Rt)}function m5(s){var c=$3(s.alternate,s,lo);s.memoizedProps=s.pendingProps,c===null?Ef(s):Rt=c}function g5(s){var c=s,p=c.alternate;switch(c.tag){case 15:case 0:c=L3(p,c,c.pendingProps,c.type,void 0,Lt);break;case 11:c=L3(p,c,c.pendingProps,c.type.render,c.ref,Lt);break;case 5:by(c);default:U3(p,c),c=Rt=fA(c,lo),c=$3(p,c,lo)}s.memoizedProps=s.pendingProps,c===null?Ef(s):Rt=c}function fc(s,c,p,g){Qi=Gs=null,by(c),rc=null,nd=0;var x=c.return;try{if($H(s,x,c,p,Lt)){Tn=1,uf(s,Ra(p,s.current)),Rt=null;return}}catch(E){if(x!==null)throw Rt=x,E;Tn=1,uf(s,Ra(p,s.current)),Rt=null;return}c.flags&32768?(Bt||g===1?s=!0:uc||(Lt&536870912)!==0?s=!1:(Xo=s=!0,(g===2||g===9||g===3||g===6)&&(g=ia.current,g!==null&&g.tag===13&&(g.flags|=16384))),b5(c,s)):Ef(c)}function Ef(s){var c=s;do{if((c.flags&32768)!==0){b5(c,Xo);return}s=c.return;var p=jH(c.alternate,c,lo);if(p!==null){Rt=p;return}if(c=c.sibling,c!==null){Rt=c;return}Rt=c=s}while(c!==null);Tn===0&&(Tn=5)}function b5(s,c){do{var p=HH(s.alternate,s);if(p!==null){p.flags&=32767,Rt=p;return}if(p=s.return,p!==null&&(p.flags|=32768,p.subtreeFlags=0,p.deletions=null),!c&&(s=s.sibling,s!==null)){Rt=s;return}Rt=s=p}while(s!==null);Tn=6,Rt=null}function y5(s,c,p,g,x,E,D,j,ne){s.cancelPendingCommit=null;do kf();while(qn!==0);if((Ht&6)!==0)throw Error(r(327));if(c!==null){if(c===s.current)throw Error(r(177));if(E=c.lanes|c.childLanes,E|=Gb,Bu(s,p,E,D,j,ne),s===nn&&(Rt=nn=null,Lt=0),hc=c,Qo=s,co=p,Qy=E,Jy=x,s5=g,(c.subtreeFlags&10256)!==0||(c.flags&10256)!==0?(s.callbackNode=null,s.callbackPriority=0,tG(We,function(){return E5(),null})):(s.callbackNode=null,s.callbackPriority=0),g=(c.flags&13878)!==0,(c.subtreeFlags&13878)!==0||g){g=$.T,$.T=null,x=Q.p,Q.p=2,D=Ht,Ht|=4;try{GH(s,c,p)}finally{Ht=D,Q.p=x,$.T=g}}qn=1,v5(),x5(),S5()}}function v5(){if(qn===1){qn=0;var s=Qo,c=hc,p=(c.flags&13878)!==0;if((c.subtreeFlags&13878)!==0||p){p=$.T,$.T=null;var g=Q.p;Q.p=2;var x=Ht;Ht|=4;try{J3(c,s);var E=f1,D=iA(s.containerInfo),j=E.focusedElem,ne=E.selectionRange;if(D!==j&&j&&j.ownerDocument&&aA(j.ownerDocument.documentElement,j)){if(ne!==null&&$b(j)){var de=ne.start,ye=ne.end;if(ye===void 0&&(ye=de),"selectionStart"in j)j.selectionStart=de,j.selectionEnd=Math.min(ye,j.value.length);else{var Se=j.ownerDocument||document,he=Se&&Se.defaultView||window;if(he.getSelection){var pe=he.getSelection(),Pe=j.textContent.length,ot=Math.min(ne.start,Pe),en=ne.end===void 0?ot:Math.min(ne.end,Pe);!pe.extend&&ot>en&&(D=en,en=ot,ot=D);var ce=rA(j,ot),ae=rA(j,en);if(ce&&ae&&(pe.rangeCount!==1||pe.anchorNode!==ce.node||pe.anchorOffset!==ce.offset||pe.focusNode!==ae.node||pe.focusOffset!==ae.offset)){var ue=Se.createRange();ue.setStart(ce.node,ce.offset),pe.removeAllRanges(),ot>en?(pe.addRange(ue),pe.extend(ae.node,ae.offset)):(ue.setEnd(ae.node,ae.offset),pe.addRange(ue))}}}}for(Se=[],pe=j;pe=pe.parentNode;)pe.nodeType===1&&Se.push({element:pe,left:pe.scrollLeft,top:pe.scrollTop});for(typeof j.focus=="function"&&j.focus(),j=0;j<Se.length;j++){var xe=Se[j];xe.element.scrollLeft=xe.left,xe.element.scrollTop=xe.top}}Bf=!!p1,f1=p1=null}finally{Ht=x,Q.p=g,$.T=p}}s.current=c,qn=2}}function x5(){if(qn===2){qn=0;var s=Qo,c=hc,p=(c.flags&8772)!==0;if((c.subtreeFlags&8772)!==0||p){p=$.T,$.T=null;var g=Q.p;Q.p=2;var x=Ht;Ht|=4;try{Y3(s,c.alternate,c)}finally{Ht=x,Q.p=g,$.T=p}}qn=3}}function S5(){if(qn===4||qn===3){qn=0,qe();var s=Qo,c=hc,p=co,g=s5;(c.subtreeFlags&10256)!==0||(c.flags&10256)!==0?qn=5:(qn=0,hc=Qo=null,w5(s,s.pendingLanes));var x=s.pendingLanes;if(x===0&&(Zo=null),Ya(p),c=c.stateNode,hn&&typeof hn.onCommitFiberRoot=="function")try{hn.onCommitFiberRoot(In,c,void 0,(c.current.flags&128)===128)}catch{}if(g!==null){c=$.T,x=Q.p,Q.p=2,$.T=null;try{for(var E=s.onRecoverableError,D=0;D<g.length;D++){var j=g[D];E(j.value,{componentStack:j.stack})}}finally{$.T=c,Q.p=x}}(co&3)!==0&&kf(),gi(s),x=s.pendingLanes,(p&261930)!==0&&(x&42)!==0?s===e1?vd++:(vd=0,e1=s):vd=0,xd(0)}}function w5(s,c){(s.pooledCacheLanes&=c)===0&&(c=s.pooledCache,c!=null&&(s.pooledCache=null,ed(c)))}function kf(){return v5(),x5(),S5(),E5()}function E5(){if(qn!==5)return!1;var s=Qo,c=Qy;Qy=0;var p=Ya(co),g=$.T,x=Q.p;try{Q.p=32>p?32:p,$.T=null,p=Jy,Jy=null;var E=Qo,D=co;if(qn=0,hc=Qo=null,co=0,(Ht&6)!==0)throw Error(r(331));var j=Ht;if(Ht|=4,a5(E.current),t5(E,E.current,D,p),Ht=j,xd(0,!1),hn&&typeof hn.onPostCommitFiberRoot=="function")try{hn.onPostCommitFiberRoot(In,E)}catch{}return!0}finally{Q.p=x,$.T=g,w5(s,c)}}function k5(s,c,p){c=Ra(p,c),c=Iy(s.stateNode,c,2),s=qo(s,c,2),s!==null&&(Fo(s,2),gi(s))}function Zt(s,c,p){if(s.tag===3)k5(s,s,p);else for(;c!==null;){if(c.tag===3){k5(c,s,p);break}else if(c.tag===1){var g=c.stateNode;if(typeof c.type.getDerivedStateFromError=="function"||typeof g.componentDidCatch=="function"&&(Zo===null||!Zo.has(g))){s=Ra(p,s),p=T3(2),g=qo(c,p,2),g!==null&&(_3(p,g,c,s),Fo(g,2),gi(g));break}}c=c.return}}function r1(s,c,p){var g=s.pingCache;if(g===null){g=s.pingCache=new VH;var x=new Set;g.set(c,x)}else x=g.get(c),x===void 0&&(x=new Set,g.set(c,x));x.has(p)||(Xy=!0,x.add(p),s=QH.bind(null,s,c,p),c.then(s,s))}function QH(s,c,p){var g=s.pingCache;g!==null&&g.delete(c),s.pingedLanes|=s.suspendedLanes&p,s.warmLanes&=~p,nn===s&&(Lt&p)===p&&(Tn===4||Tn===3&&(Lt&62914560)===Lt&&300>yt()-yf?(Ht&2)===0&&pc(s,0):Ky|=p,dc===Lt&&(dc=0)),gi(s)}function T5(s,c){c===0&&(c=qi()),s=Us(s,c),s!==null&&(Fo(s,c),gi(s))}function JH(s){var c=s.memoizedState,p=0;c!==null&&(p=c.retryLane),T5(s,p)}function eG(s,c){var p=0;switch(s.tag){case 31:case 13:var g=s.stateNode,x=s.memoizedState;x!==null&&(p=x.retryLane);break;case 19:g=s.stateNode;break;case 22:g=s.stateNode._retryCache;break;default:throw Error(r(314))}g!==null&&g.delete(c),T5(s,p)}function tG(s,c){return Zn(s,c)}var Tf=null,mc=null,a1=!1,_f=!1,i1=!1,es=0;function gi(s){s!==mc&&s.next===null&&(mc===null?Tf=mc=s:mc=mc.next=s),_f=!0,a1||(a1=!0,rG())}function xd(s,c){if(!i1&&_f){i1=!0;do for(var p=!1,g=Tf;g!==null;){if(s!==0){var x=g.pendingLanes;if(x===0)var E=0;else{var D=g.suspendedLanes,j=g.pingedLanes;E=(1<<31-zt(42|s)+1)-1,E&=x&~(D&~j),E=E&201326741?E&201326741|1:E?E|2:0}E!==0&&(p=!0,R5(g,E))}else E=Lt,E=$l(g,g===nn?E:0,g.cancelPendingCommit!==null||g.timeoutHandle!==-1),(E&3)===0||Fs(g,E)||(p=!0,R5(g,E));g=g.next}while(p);i1=!1}}function nG(){_5()}function _5(){_f=a1=!1;var s=0;es!==0&&pG()&&(s=es);for(var c=yt(),p=null,g=Tf;g!==null;){var x=g.next,E=C5(g,c);E===0?(g.next=null,p===null?Tf=x:p.next=x,x===null&&(mc=p)):(p=g,(s!==0||(E&3)!==0)&&(_f=!0)),g=x}qn!==0&&qn!==5||xd(s),es!==0&&(es=0)}function C5(s,c){for(var p=s.suspendedLanes,g=s.pingedLanes,x=s.expirationTimes,E=s.pendingLanes&-62914561;0<E;){var D=31-zt(E),j=1<<D,ne=x[D];ne===-1?((j&p)===0||(j&g)!==0)&&(x[D]=An(j,c)):ne<=c&&(s.expiredLanes|=j),E&=~j}if(c=nn,p=Lt,p=$l(s,s===c?p:0,s.cancelPendingCommit!==null||s.timeoutHandle!==-1),g=s.callbackNode,p===0||s===c&&(Kt===2||Kt===9)||s.cancelPendingCommit!==null)return g!==null&&g!==null&&wa(g),s.callbackNode=null,s.callbackPriority=0;if((p&3)===0||Fs(s,p)){if(c=p&-p,c===s.callbackPriority)return c;switch(g!==null&&wa(g),Ya(p)){case 2:case 8:p=Te;break;case 32:p=We;break;case 268435456:p=It;break;default:p=We}return g=A5.bind(null,s),p=Zn(p,g),s.callbackPriority=c,s.callbackNode=p,c}return g!==null&&g!==null&&wa(g),s.callbackPriority=2,s.callbackNode=null,2}function A5(s,c){if(qn!==0&&qn!==5)return s.callbackNode=null,s.callbackPriority=0,null;var p=s.callbackNode;if(kf()&&s.callbackNode!==p)return null;var g=Lt;return g=$l(s,s===nn?g:0,s.cancelPendingCommit!==null||s.timeoutHandle!==-1),g===0?null:(c5(s,g,c),C5(s,yt()),s.callbackNode!=null&&s.callbackNode===p?A5.bind(null,s):null)}function R5(s,c){if(kf())return null;c5(s,c,!0)}function rG(){mG(function(){(Ht&6)!==0?Zn(me,nG):_5()})}function o1(){if(es===0){var s=ec;s===0&&(s=Hi,Hi<<=1,(Hi&261888)===0&&(Hi=256)),es=s}return es}function N5(s){return s==null||typeof s=="symbol"||typeof s=="boolean"?null:typeof s=="function"?s:Lp(""+s)}function O5(s,c){var p=c.ownerDocument.createElement("input");return p.name=c.name,p.value=c.value,s.id&&p.setAttribute("form",s.id),c.parentNode.insertBefore(p,c),s=new FormData(s),p.parentNode.removeChild(p),s}function aG(s,c,p,g,x){if(c==="submit"&&p&&p.stateNode===x){var E=N5((x[fn]||null).action),D=g.submitter;D&&(c=(c=D[fn]||null)?N5(c.formAction):D.getAttribute("formAction"),c!==null&&(E=c,D=null));var j=new Fp("action","action",null,g,x);s.push({event:j,listeners:[{instance:null,listener:function(){if(g.defaultPrevented){if(es!==0){var ne=D?O5(x,D):new FormData(x);_y(p,{pending:!0,data:ne,method:x.method,action:E},null,ne)}}else typeof E=="function"&&(j.preventDefault(),ne=D?O5(x,D):new FormData(x),_y(p,{pending:!0,data:ne,method:x.method,action:E},E,ne))},currentTarget:x}]})}}for(var s1=0;s1<Hb.length;s1++){var l1=Hb[s1],iG=l1.toLowerCase(),oG=l1[0].toUpperCase()+l1.slice(1);Xa(iG,"on"+oG)}Xa(lA,"onAnimationEnd"),Xa(cA,"onAnimationIteration"),Xa(uA,"onAnimationStart"),Xa("dblclick","onDoubleClick"),Xa("focusin","onFocus"),Xa("focusout","onBlur"),Xa(wH,"onTransitionRun"),Xa(EH,"onTransitionStart"),Xa(kH,"onTransitionCancel"),Xa(dA,"onTransitionEnd"),hi("onMouseEnter",["mouseout","mouseover"]),hi("onMouseLeave",["mouseout","mouseover"]),hi("onPointerEnter",["pointerout","pointerover"]),hi("onPointerLeave",["pointerout","pointerover"]),jr("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),jr("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),jr("onBeforeInput",["compositionend","keypress","textInput","paste"]),jr("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),jr("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),jr("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var Sd="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),sG=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(Sd));function I5(s,c){c=(c&4)!==0;for(var p=0;p<s.length;p++){var g=s[p],x=g.event;g=g.listeners;e:{var E=void 0;if(c)for(var D=g.length-1;0<=D;D--){var j=g[D],ne=j.instance,de=j.currentTarget;if(j=j.listener,ne!==E&&x.isPropagationStopped())break e;E=j,x.currentTarget=de;try{E(x)}catch(ye){Pp(ye)}x.currentTarget=null,E=ne}else for(D=0;D<g.length;D++){if(j=g[D],ne=j.instance,de=j.currentTarget,j=j.listener,ne!==E&&x.isPropagationStopped())break e;E=j,x.currentTarget=de;try{E(x)}catch(ye){Pp(ye)}x.currentTarget=null,E=ne}}}}function Nt(s,c){var p=c[Pl];p===void 0&&(p=c[Pl]=new Set);var g=s+"__bubble";p.has(g)||(L5(c,s,2,!1),p.add(g))}function c1(s,c,p){var g=0;c&&(g|=4),L5(p,s,g,c)}var Cf="_reactListening"+Math.random().toString(36).slice(2);function u1(s){if(!s[Cf]){s[Cf]=!0,tr.forEach(function(p){p!=="selectionchange"&&(sG.has(p)||c1(p,!1,s),c1(p,!0,s))});var c=s.nodeType===9?s:s.ownerDocument;c===null||c[Cf]||(c[Cf]=!0,c1("selectionchange",!1,c))}}function L5(s,c,p,g){switch(l6(c)){case 2:var x=MG;break;case 8:x=BG;break;default:x=T1}p=x.bind(null,c,p,s),x=void 0,!Nb||c!=="touchstart"&&c!=="touchmove"&&c!=="wheel"||(x=!0),g?x!==void 0?s.addEventListener(c,p,{capture:!0,passive:x}):s.addEventListener(c,p,!0):x!==void 0?s.addEventListener(c,p,{passive:x}):s.addEventListener(c,p,!1)}function d1(s,c,p,g,x){var E=g;if((c&1)===0&&(c&2)===0&&g!==null)e:for(;;){if(g===null)return;var D=g.tag;if(D===3||D===4){var j=g.stateNode.containerInfo;if(j===x)break;if(D===4)for(D=g.return;D!==null;){var ne=D.tag;if((ne===3||ne===4)&&D.stateNode.containerInfo===x)return;D=D.return}for(;j!==null;){if(D=_e(j),D===null)return;if(ne=D.tag,ne===5||ne===6||ne===26||ne===27){g=E=D;continue e}j=j.parentNode}}g=g.return}zC(function(){var de=E,ye=Ab(p),Se=[];e:{var he=hA.get(s);if(he!==void 0){var pe=Fp,Pe=s;switch(s){case"keypress":if(Mp(p)===0)break e;case"keydown":case"keyup":pe=eH;break;case"focusin":Pe="focus",pe=Db;break;case"focusout":Pe="blur",pe=Db;break;case"beforeblur":case"afterblur":pe=Db;break;case"click":if(p.button===2)break e;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":pe=UC;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":pe=jj;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":pe=rH;break;case lA:case cA:case uA:pe=qj;break;case dA:pe=iH;break;case"scroll":case"scrollend":pe=Pj;break;case"wheel":pe=sH;break;case"copy":case"cut":case"paste":pe=Vj;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":pe=HC;break;case"toggle":case"beforetoggle":pe=cH}var ot=(c&4)!==0,en=!ot&&(s==="scroll"||s==="scrollend"),ce=ot?he!==null?he+"Capture":null:he;ot=[];for(var ae=de,ue;ae!==null;){var xe=ae;if(ue=xe.stateNode,xe=xe.tag,xe!==5&&xe!==26&&xe!==27||ue===null||ce===null||(xe=Hu(ae,ce),xe!=null&&ot.push(wd(ae,xe,ue))),en)break;ae=ae.return}0<ot.length&&(he=new pe(he,Pe,null,p,ye),Se.push({event:he,listeners:ot}))}}if((c&7)===0){e:{if(he=s==="mouseover"||s==="pointerover",pe=s==="mouseout"||s==="pointerout",he&&p!==Cb&&(Pe=p.relatedTarget||p.fromElement)&&(_e(Pe)||Pe[Wi]))break e;if((pe||he)&&(he=ye.window===ye?ye:(he=ye.ownerDocument)?he.defaultView||he.parentWindow:window,pe?(Pe=p.relatedTarget||p.toElement,pe=de,Pe=Pe?_e(Pe):null,Pe!==null&&(en=i(Pe),ot=Pe.tag,Pe!==en||ot!==5&&ot!==27&&ot!==6)&&(Pe=null)):(pe=null,Pe=de),pe!==Pe)){if(ot=UC,xe="onMouseLeave",ce="onMouseEnter",ae="mouse",(s==="pointerout"||s==="pointerover")&&(ot=HC,xe="onPointerLeave",ce="onPointerEnter",ae="pointer"),en=pe==null?he:Vt(pe),ue=Pe==null?he:Vt(Pe),he=new ot(xe,ae+"leave",pe,p,ye),he.target=en,he.relatedTarget=ue,xe=null,_e(ye)===de&&(ot=new ot(ce,ae+"enter",Pe,p,ye),ot.target=ue,ot.relatedTarget=en,xe=ot),en=xe,pe&&Pe)t:{for(ot=lG,ce=pe,ae=Pe,ue=0,xe=ce;xe;xe=ot(xe))ue++;xe=0;for(var tt=ae;tt;tt=ot(tt))xe++;for(;0<ue-xe;)ce=ot(ce),ue--;for(;0<xe-ue;)ae=ot(ae),xe--;for(;ue--;){if(ce===ae||ae!==null&&ce===ae.alternate){ot=ce;break t}ce=ot(ce),ae=ot(ae)}ot=null}else ot=null;pe!==null&&D5(Se,he,pe,ot,!1),Pe!==null&&en!==null&&D5(Se,en,Pe,ot,!0)}}e:{if(he=de?Vt(de):window,pe=he.nodeName&&he.nodeName.toLowerCase(),pe==="select"||pe==="input"&&he.type==="file")var $t=ZC;else if(XC(he))if(QC)$t=vH;else{$t=bH;var Ze=gH}else pe=he.nodeName,!pe||pe.toLowerCase()!=="input"||he.type!=="checkbox"&&he.type!=="radio"?de&&_b(de.elementType)&&($t=ZC):$t=yH;if($t&&($t=$t(s,de))){KC(Se,$t,p,ye);break e}Ze&&Ze(s,he,de),s==="focusout"&&de&&he.type==="number"&&de.memoizedProps.value!=null&&Tb(he,"number",he.value)}switch(Ze=de?Vt(de):window,s){case"focusin":(XC(Ze)||Ze.contentEditable==="true")&&(Wl=Ze,Pb=de,Zu=null);break;case"focusout":Zu=Pb=Wl=null;break;case"mousedown":Ub=!0;break;case"contextmenu":case"mouseup":case"dragend":Ub=!1,oA(Se,p,ye);break;case"selectionchange":if(SH)break;case"keydown":case"keyup":oA(Se,p,ye)}var xt;if(Bb)e:{switch(s){case"compositionstart":var Dt="onCompositionStart";break e;case"compositionend":Dt="onCompositionEnd";break e;case"compositionupdate":Dt="onCompositionUpdate";break e}Dt=void 0}else ql?VC(s,p)&&(Dt="onCompositionEnd"):s==="keydown"&&p.keyCode===229&&(Dt="onCompositionStart");Dt&&(GC&&p.locale!=="ko"&&(ql||Dt!=="onCompositionStart"?Dt==="onCompositionEnd"&&ql&&(xt=$C()):(zo=ye,Ob="value"in zo?zo.value:zo.textContent,ql=!0)),Ze=Af(de,Dt),0<Ze.length&&(Dt=new jC(Dt,s,null,p,ye),Se.push({event:Dt,listeners:Ze}),xt?Dt.data=xt:(xt=YC(p),xt!==null&&(Dt.data=xt)))),(xt=dH?hH(s,p):pH(s,p))&&(Dt=Af(de,"onBeforeInput"),0<Dt.length&&(Ze=new jC("onBeforeInput","beforeinput",null,p,ye),Se.push({event:Ze,listeners:Dt}),Ze.data=xt)),aG(Se,s,de,p,ye)}I5(Se,c)})}function wd(s,c,p){return{instance:s,listener:c,currentTarget:p}}function Af(s,c){for(var p=c+"Capture",g=[];s!==null;){var x=s,E=x.stateNode;if(x=x.tag,x!==5&&x!==26&&x!==27||E===null||(x=Hu(s,p),x!=null&&g.unshift(wd(s,x,E)),x=Hu(s,c),x!=null&&g.push(wd(s,x,E))),s.tag===3)return g;s=s.return}return[]}function lG(s){if(s===null)return null;do s=s.return;while(s&&s.tag!==5&&s.tag!==27);return s||null}function D5(s,c,p,g,x){for(var E=c._reactName,D=[];p!==null&&p!==g;){var j=p,ne=j.alternate,de=j.stateNode;if(j=j.tag,ne!==null&&ne===g)break;j!==5&&j!==26&&j!==27||de===null||(ne=de,x?(de=Hu(p,E),de!=null&&D.unshift(wd(p,de,ne))):x||(de=Hu(p,E),de!=null&&D.push(wd(p,de,ne)))),p=p.return}D.length!==0&&s.push({event:c,listeners:D})}var cG=/\r\n?/g,uG=/\u0000|\uFFFD/g;function M5(s){return(typeof s=="string"?s:""+s).replace(cG,`
`).replace(uG,"")}function B5(s,c){return c=M5(c),M5(s)===c}function Jt(s,c,p,g,x,E){switch(p){case"children":typeof g=="string"?c==="body"||c==="textarea"&&g===""||jl(s,g):(typeof g=="number"||typeof g=="bigint")&&c!=="body"&&jl(s,""+g);break;case"className":Op(s,"class",g);break;case"tabIndex":Op(s,"tabindex",g);break;case"dir":case"role":case"viewBox":case"width":case"height":Op(s,p,g);break;case"style":BC(s,g,E);break;case"data":if(c!=="object"){Op(s,"data",g);break}case"src":case"href":if(g===""&&(c!=="a"||p!=="href")){s.removeAttribute(p);break}if(g==null||typeof g=="function"||typeof g=="symbol"||typeof g=="boolean"){s.removeAttribute(p);break}g=Lp(""+g),s.setAttribute(p,g);break;case"action":case"formAction":if(typeof g=="function"){s.setAttribute(p,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof E=="function"&&(p==="formAction"?(c!=="input"&&Jt(s,c,"name",x.name,x,null),Jt(s,c,"formEncType",x.formEncType,x,null),Jt(s,c,"formMethod",x.formMethod,x,null),Jt(s,c,"formTarget",x.formTarget,x,null)):(Jt(s,c,"encType",x.encType,x,null),Jt(s,c,"method",x.method,x,null),Jt(s,c,"target",x.target,x,null)));if(g==null||typeof g=="symbol"||typeof g=="boolean"){s.removeAttribute(p);break}g=Lp(""+g),s.setAttribute(p,g);break;case"onClick":g!=null&&(s.onclick=Yi);break;case"onScroll":g!=null&&Nt("scroll",s);break;case"onScrollEnd":g!=null&&Nt("scrollend",s);break;case"dangerouslySetInnerHTML":if(g!=null){if(typeof g!="object"||!("__html"in g))throw Error(r(61));if(p=g.__html,p!=null){if(x.children!=null)throw Error(r(60));s.innerHTML=p}}break;case"multiple":s.multiple=g&&typeof g!="function"&&typeof g!="symbol";break;case"muted":s.muted=g&&typeof g!="function"&&typeof g!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(g==null||typeof g=="function"||typeof g=="boolean"||typeof g=="symbol"){s.removeAttribute("xlink:href");break}p=Lp(""+g),s.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",p);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":g!=null&&typeof g!="function"&&typeof g!="symbol"?s.setAttribute(p,""+g):s.removeAttribute(p);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":g&&typeof g!="function"&&typeof g!="symbol"?s.setAttribute(p,""):s.removeAttribute(p);break;case"capture":case"download":g===!0?s.setAttribute(p,""):g!==!1&&g!=null&&typeof g!="function"&&typeof g!="symbol"?s.setAttribute(p,g):s.removeAttribute(p);break;case"cols":case"rows":case"size":case"span":g!=null&&typeof g!="function"&&typeof g!="symbol"&&!isNaN(g)&&1<=g?s.setAttribute(p,g):s.removeAttribute(p);break;case"rowSpan":case"start":g==null||typeof g=="function"||typeof g=="symbol"||isNaN(g)?s.removeAttribute(p):s.setAttribute(p,g);break;case"popover":Nt("beforetoggle",s),Nt("toggle",s),Np(s,"popover",g);break;case"xlinkActuate":Vi(s,"http://www.w3.org/1999/xlink","xlink:actuate",g);break;case"xlinkArcrole":Vi(s,"http://www.w3.org/1999/xlink","xlink:arcrole",g);break;case"xlinkRole":Vi(s,"http://www.w3.org/1999/xlink","xlink:role",g);break;case"xlinkShow":Vi(s,"http://www.w3.org/1999/xlink","xlink:show",g);break;case"xlinkTitle":Vi(s,"http://www.w3.org/1999/xlink","xlink:title",g);break;case"xlinkType":Vi(s,"http://www.w3.org/1999/xlink","xlink:type",g);break;case"xmlBase":Vi(s,"http://www.w3.org/XML/1998/namespace","xml:base",g);break;case"xmlLang":Vi(s,"http://www.w3.org/XML/1998/namespace","xml:lang",g);break;case"xmlSpace":Vi(s,"http://www.w3.org/XML/1998/namespace","xml:space",g);break;case"is":Np(s,"is",g);break;case"innerText":case"textContent":break;default:(!(2<p.length)||p[0]!=="o"&&p[0]!=="O"||p[1]!=="n"&&p[1]!=="N")&&(p=zj.get(p)||p,Np(s,p,g))}}function h1(s,c,p,g,x,E){switch(p){case"style":BC(s,g,E);break;case"dangerouslySetInnerHTML":if(g!=null){if(typeof g!="object"||!("__html"in g))throw Error(r(61));if(p=g.__html,p!=null){if(x.children!=null)throw Error(r(60));s.innerHTML=p}}break;case"children":typeof g=="string"?jl(s,g):(typeof g=="number"||typeof g=="bigint")&&jl(s,""+g);break;case"onScroll":g!=null&&Nt("scroll",s);break;case"onScrollEnd":g!=null&&Nt("scrollend",s);break;case"onClick":g!=null&&(s.onclick=Yi);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!Ta.hasOwnProperty(p))e:{if(p[0]==="o"&&p[1]==="n"&&(x=p.endsWith("Capture"),c=p.slice(2,x?p.length-7:void 0),E=s[fn]||null,E=E!=null?E[p]:null,typeof E=="function"&&s.removeEventListener(c,E,x),typeof g=="function")){typeof E!="function"&&E!==null&&(p in s?s[p]=null:s.hasAttribute(p)&&s.removeAttribute(p)),s.addEventListener(c,g,x);break e}p in s?s[p]=g:g===!0?s.setAttribute(p,""):Np(s,p,g)}}}function ir(s,c,p){switch(c){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":Nt("error",s),Nt("load",s);var g=!1,x=!1,E;for(E in p)if(p.hasOwnProperty(E)){var D=p[E];if(D!=null)switch(E){case"src":g=!0;break;case"srcSet":x=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(r(137,c));default:Jt(s,c,E,D,p,null)}}x&&Jt(s,c,"srcSet",p.srcSet,p,null),g&&Jt(s,c,"src",p.src,p,null);return;case"input":Nt("invalid",s);var j=E=D=x=null,ne=null,de=null;for(g in p)if(p.hasOwnProperty(g)){var ye=p[g];if(ye!=null)switch(g){case"name":x=ye;break;case"type":D=ye;break;case"checked":ne=ye;break;case"defaultChecked":de=ye;break;case"value":E=ye;break;case"defaultValue":j=ye;break;case"children":case"dangerouslySetInnerHTML":if(ye!=null)throw Error(r(137,c));break;default:Jt(s,c,g,ye,p,null)}}IC(s,E,j,ne,de,D,x,!1);return;case"select":Nt("invalid",s),g=D=E=null;for(x in p)if(p.hasOwnProperty(x)&&(j=p[x],j!=null))switch(x){case"value":E=j;break;case"defaultValue":D=j;break;case"multiple":g=j;default:Jt(s,c,x,j,p,null)}c=E,p=D,s.multiple=!!g,c!=null?Ul(s,!!g,c,!1):p!=null&&Ul(s,!!g,p,!0);return;case"textarea":Nt("invalid",s),E=x=g=null;for(D in p)if(p.hasOwnProperty(D)&&(j=p[D],j!=null))switch(D){case"value":g=j;break;case"defaultValue":x=j;break;case"children":E=j;break;case"dangerouslySetInnerHTML":if(j!=null)throw Error(r(91));break;default:Jt(s,c,D,j,p,null)}DC(s,g,x,E);return;case"option":for(ne in p)if(p.hasOwnProperty(ne)&&(g=p[ne],g!=null))switch(ne){case"selected":s.selected=g&&typeof g!="function"&&typeof g!="symbol";break;default:Jt(s,c,ne,g,p,null)}return;case"dialog":Nt("beforetoggle",s),Nt("toggle",s),Nt("cancel",s),Nt("close",s);break;case"iframe":case"object":Nt("load",s);break;case"video":case"audio":for(g=0;g<Sd.length;g++)Nt(Sd[g],s);break;case"image":Nt("error",s),Nt("load",s);break;case"details":Nt("toggle",s);break;case"embed":case"source":case"link":Nt("error",s),Nt("load",s);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(de in p)if(p.hasOwnProperty(de)&&(g=p[de],g!=null))switch(de){case"children":case"dangerouslySetInnerHTML":throw Error(r(137,c));default:Jt(s,c,de,g,p,null)}return;default:if(_b(c)){for(ye in p)p.hasOwnProperty(ye)&&(g=p[ye],g!==void 0&&h1(s,c,ye,g,p,void 0));return}}for(j in p)p.hasOwnProperty(j)&&(g=p[j],g!=null&&Jt(s,c,j,g,p,null))}function dG(s,c,p,g){switch(c){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var x=null,E=null,D=null,j=null,ne=null,de=null,ye=null;for(pe in p){var Se=p[pe];if(p.hasOwnProperty(pe)&&Se!=null)switch(pe){case"checked":break;case"value":break;case"defaultValue":ne=Se;default:g.hasOwnProperty(pe)||Jt(s,c,pe,null,g,Se)}}for(var he in g){var pe=g[he];if(Se=p[he],g.hasOwnProperty(he)&&(pe!=null||Se!=null))switch(he){case"type":E=pe;break;case"name":x=pe;break;case"checked":de=pe;break;case"defaultChecked":ye=pe;break;case"value":D=pe;break;case"defaultValue":j=pe;break;case"children":case"dangerouslySetInnerHTML":if(pe!=null)throw Error(r(137,c));break;default:pe!==Se&&Jt(s,c,he,pe,g,Se)}}kb(s,D,j,ne,de,ye,E,x);return;case"select":pe=D=j=he=null;for(E in p)if(ne=p[E],p.hasOwnProperty(E)&&ne!=null)switch(E){case"value":break;case"multiple":pe=ne;default:g.hasOwnProperty(E)||Jt(s,c,E,null,g,ne)}for(x in g)if(E=g[x],ne=p[x],g.hasOwnProperty(x)&&(E!=null||ne!=null))switch(x){case"value":he=E;break;case"defaultValue":j=E;break;case"multiple":D=E;default:E!==ne&&Jt(s,c,x,E,g,ne)}c=j,p=D,g=pe,he!=null?Ul(s,!!p,he,!1):!!g!=!!p&&(c!=null?Ul(s,!!p,c,!0):Ul(s,!!p,p?[]:"",!1));return;case"textarea":pe=he=null;for(j in p)if(x=p[j],p.hasOwnProperty(j)&&x!=null&&!g.hasOwnProperty(j))switch(j){case"value":break;case"children":break;default:Jt(s,c,j,null,g,x)}for(D in g)if(x=g[D],E=p[D],g.hasOwnProperty(D)&&(x!=null||E!=null))switch(D){case"value":he=x;break;case"defaultValue":pe=x;break;case"children":break;case"dangerouslySetInnerHTML":if(x!=null)throw Error(r(91));break;default:x!==E&&Jt(s,c,D,x,g,E)}LC(s,he,pe);return;case"option":for(var Pe in p)if(he=p[Pe],p.hasOwnProperty(Pe)&&he!=null&&!g.hasOwnProperty(Pe))switch(Pe){case"selected":s.selected=!1;break;default:Jt(s,c,Pe,null,g,he)}for(ne in g)if(he=g[ne],pe=p[ne],g.hasOwnProperty(ne)&&he!==pe&&(he!=null||pe!=null))switch(ne){case"selected":s.selected=he&&typeof he!="function"&&typeof he!="symbol";break;default:Jt(s,c,ne,he,g,pe)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var ot in p)he=p[ot],p.hasOwnProperty(ot)&&he!=null&&!g.hasOwnProperty(ot)&&Jt(s,c,ot,null,g,he);for(de in g)if(he=g[de],pe=p[de],g.hasOwnProperty(de)&&he!==pe&&(he!=null||pe!=null))switch(de){case"children":case"dangerouslySetInnerHTML":if(he!=null)throw Error(r(137,c));break;default:Jt(s,c,de,he,g,pe)}return;default:if(_b(c)){for(var en in p)he=p[en],p.hasOwnProperty(en)&&he!==void 0&&!g.hasOwnProperty(en)&&h1(s,c,en,void 0,g,he);for(ye in g)he=g[ye],pe=p[ye],!g.hasOwnProperty(ye)||he===pe||he===void 0&&pe===void 0||h1(s,c,ye,he,g,pe);return}}for(var ce in p)he=p[ce],p.hasOwnProperty(ce)&&he!=null&&!g.hasOwnProperty(ce)&&Jt(s,c,ce,null,g,he);for(Se in g)he=g[Se],pe=p[Se],!g.hasOwnProperty(Se)||he===pe||he==null&&pe==null||Jt(s,c,Se,he,g,pe)}function F5(s){switch(s){case"css":case"script":case"font":case"img":case"image":case"input":case"link":return!0;default:return!1}}function hG(){if(typeof performance.getEntriesByType=="function"){for(var s=0,c=0,p=performance.getEntriesByType("resource"),g=0;g<p.length;g++){var x=p[g],E=x.transferSize,D=x.initiatorType,j=x.duration;if(E&&j&&F5(D)){for(D=0,j=x.responseEnd,g+=1;g<p.length;g++){var ne=p[g],de=ne.startTime;if(de>j)break;var ye=ne.transferSize,Se=ne.initiatorType;ye&&F5(Se)&&(ne=ne.responseEnd,D+=ye*(ne<j?1:(j-de)/(ne-de)))}if(--g,c+=8*(E+D)/(x.duration/1e3),s++,10<s)break}}if(0<s)return c/s/1e6}return navigator.connection&&(s=navigator.connection.downlink,typeof s=="number")?s:5}var p1=null,f1=null;function Rf(s){return s.nodeType===9?s:s.ownerDocument}function z5(s){switch(s){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function $5(s,c){if(s===0)switch(c){case"svg":return 1;case"math":return 2;default:return 0}return s===1&&c==="foreignObject"?0:s}function m1(s,c){return s==="textarea"||s==="noscript"||typeof c.children=="string"||typeof c.children=="number"||typeof c.children=="bigint"||typeof c.dangerouslySetInnerHTML=="object"&&c.dangerouslySetInnerHTML!==null&&c.dangerouslySetInnerHTML.__html!=null}var g1=null;function pG(){var s=window.event;return s&&s.type==="popstate"?s===g1?!1:(g1=s,!0):(g1=null,!1)}var P5=typeof setTimeout=="function"?setTimeout:void 0,fG=typeof clearTimeout=="function"?clearTimeout:void 0,U5=typeof Promise=="function"?Promise:void 0,mG=typeof queueMicrotask=="function"?queueMicrotask:typeof U5<"u"?function(s){return U5.resolve(null).then(s).catch(gG)}:P5;function gG(s){setTimeout(function(){throw s})}function ts(s){return s==="head"}function j5(s,c){var p=c,g=0;do{var x=p.nextSibling;if(s.removeChild(p),x&&x.nodeType===8)if(p=x.data,p==="/$"||p==="/&"){if(g===0){s.removeChild(x),vc(c);return}g--}else if(p==="$"||p==="$?"||p==="$~"||p==="$!"||p==="&")g++;else if(p==="html")Ed(s.ownerDocument.documentElement);else if(p==="head"){p=s.ownerDocument.head,Ed(p);for(var E=p.firstChild;E;){var D=E.nextSibling,j=E.nodeName;E[Ke]||j==="SCRIPT"||j==="STYLE"||j==="LINK"&&E.rel.toLowerCase()==="stylesheet"||p.removeChild(E),E=D}}else p==="body"&&Ed(s.ownerDocument.body);p=x}while(p);vc(c)}function H5(s,c){var p=s;s=0;do{var g=p.nextSibling;if(p.nodeType===1?c?(p._stashedDisplay=p.style.display,p.style.display="none"):(p.style.display=p._stashedDisplay||"",p.getAttribute("style")===""&&p.removeAttribute("style")):p.nodeType===3&&(c?(p._stashedText=p.nodeValue,p.nodeValue=""):p.nodeValue=p._stashedText||""),g&&g.nodeType===8)if(p=g.data,p==="/$"){if(s===0)break;s--}else p!=="$"&&p!=="$?"&&p!=="$~"&&p!=="$!"||s++;p=g}while(p)}function b1(s){var c=s.firstChild;for(c&&c.nodeType===10&&(c=c.nextSibling);c;){var p=c;switch(c=c.nextSibling,p.nodeName){case"HTML":case"HEAD":case"BODY":b1(p),re(p);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if(p.rel.toLowerCase()==="stylesheet")continue}s.removeChild(p)}}function bG(s,c,p,g){for(;s.nodeType===1;){var x=p;if(s.nodeName.toLowerCase()!==c.toLowerCase()){if(!g&&(s.nodeName!=="INPUT"||s.type!=="hidden"))break}else if(g){if(!s[Ke])switch(c){case"meta":if(!s.hasAttribute("itemprop"))break;return s;case"link":if(E=s.getAttribute("rel"),E==="stylesheet"&&s.hasAttribute("data-precedence"))break;if(E!==x.rel||s.getAttribute("href")!==(x.href==null||x.href===""?null:x.href)||s.getAttribute("crossorigin")!==(x.crossOrigin==null?null:x.crossOrigin)||s.getAttribute("title")!==(x.title==null?null:x.title))break;return s;case"style":if(s.hasAttribute("data-precedence"))break;return s;case"script":if(E=s.getAttribute("src"),(E!==(x.src==null?null:x.src)||s.getAttribute("type")!==(x.type==null?null:x.type)||s.getAttribute("crossorigin")!==(x.crossOrigin==null?null:x.crossOrigin))&&E&&s.hasAttribute("async")&&!s.hasAttribute("itemprop"))break;return s;default:return s}}else if(c==="input"&&s.type==="hidden"){var E=x.name==null?null:""+x.name;if(x.type==="hidden"&&s.getAttribute("name")===E)return s}else return s;if(s=Da(s.nextSibling),s===null)break}return null}function yG(s,c,p){if(c==="")return null;for(;s.nodeType!==3;)if((s.nodeType!==1||s.nodeName!=="INPUT"||s.type!=="hidden")&&!p||(s=Da(s.nextSibling),s===null))return null;return s}function G5(s,c){for(;s.nodeType!==8;)if((s.nodeType!==1||s.nodeName!=="INPUT"||s.type!=="hidden")&&!c||(s=Da(s.nextSibling),s===null))return null;return s}function y1(s){return s.data==="$?"||s.data==="$~"}function v1(s){return s.data==="$!"||s.data==="$?"&&s.ownerDocument.readyState!=="loading"}function vG(s,c){var p=s.ownerDocument;if(s.data==="$~")s._reactRetry=c;else if(s.data!=="$?"||p.readyState!=="loading")c();else{var g=function(){c(),p.removeEventListener("DOMContentLoaded",g)};p.addEventListener("DOMContentLoaded",g),s._reactRetry=g}}function Da(s){for(;s!=null;s=s.nextSibling){var c=s.nodeType;if(c===1||c===3)break;if(c===8){if(c=s.data,c==="$"||c==="$!"||c==="$?"||c==="$~"||c==="&"||c==="F!"||c==="F")break;if(c==="/$"||c==="/&")return null}}return s}var x1=null;function q5(s){s=s.nextSibling;for(var c=0;s;){if(s.nodeType===8){var p=s.data;if(p==="/$"||p==="/&"){if(c===0)return Da(s.nextSibling);c--}else p!=="$"&&p!=="$!"&&p!=="$?"&&p!=="$~"&&p!=="&"||c++}s=s.nextSibling}return null}function W5(s){s=s.previousSibling;for(var c=0;s;){if(s.nodeType===8){var p=s.data;if(p==="$"||p==="$!"||p==="$?"||p==="$~"||p==="&"){if(c===0)return s;c--}else p!=="/$"&&p!=="/&"||c++}s=s.previousSibling}return null}function V5(s,c,p){switch(c=Rf(p),s){case"html":if(s=c.documentElement,!s)throw Error(r(452));return s;case"head":if(s=c.head,!s)throw Error(r(453));return s;case"body":if(s=c.body,!s)throw Error(r(454));return s;default:throw Error(r(451))}}function Ed(s){for(var c=s.attributes;c.length;)s.removeAttributeNode(c[0]);re(s)}var Ma=new Map,Y5=new Set;function Nf(s){return typeof s.getRootNode=="function"?s.getRootNode():s.nodeType===9?s:s.ownerDocument}var uo=Q.d;Q.d={f:xG,r:SG,D:wG,C:EG,L:kG,m:TG,X:CG,S:_G,M:AG};function xG(){var s=uo.f(),c=Sf();return s||c}function SG(s){var c=$e(s);c!==null&&c.tag===5&&c.type==="form"?d3(c):uo.r(s)}var gc=typeof document>"u"?null:document;function X5(s,c,p){var g=gc;if(g&&typeof c=="string"&&c){var x=Ca(c);x='link[rel="'+s+'"][href="'+x+'"]',typeof p=="string"&&(x+='[crossorigin="'+p+'"]'),Y5.has(x)||(Y5.add(x),s={rel:s,crossOrigin:p,href:c},g.querySelector(x)===null&&(c=g.createElement("link"),ir(c,"link",s),Tt(c),g.head.appendChild(c)))}}function wG(s){uo.D(s),X5("dns-prefetch",s,null)}function EG(s,c){uo.C(s,c),X5("preconnect",s,c)}function kG(s,c,p){uo.L(s,c,p);var g=gc;if(g&&s&&c){var x='link[rel="preload"][as="'+Ca(c)+'"]';c==="image"&&p&&p.imageSrcSet?(x+='[imagesrcset="'+Ca(p.imageSrcSet)+'"]',typeof p.imageSizes=="string"&&(x+='[imagesizes="'+Ca(p.imageSizes)+'"]')):x+='[href="'+Ca(s)+'"]';var E=x;switch(c){case"style":E=bc(s);break;case"script":E=yc(s)}Ma.has(E)||(s=f({rel:"preload",href:c==="image"&&p&&p.imageSrcSet?void 0:s,as:c},p),Ma.set(E,s),g.querySelector(x)!==null||c==="style"&&g.querySelector(kd(E))||c==="script"&&g.querySelector(Td(E))||(c=g.createElement("link"),ir(c,"link",s),Tt(c),g.head.appendChild(c)))}}function TG(s,c){uo.m(s,c);var p=gc;if(p&&s){var g=c&&typeof c.as=="string"?c.as:"script",x='link[rel="modulepreload"][as="'+Ca(g)+'"][href="'+Ca(s)+'"]',E=x;switch(g){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":E=yc(s)}if(!Ma.has(E)&&(s=f({rel:"modulepreload",href:s},c),Ma.set(E,s),p.querySelector(x)===null)){switch(g){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if(p.querySelector(Td(E)))return}g=p.createElement("link"),ir(g,"link",s),Tt(g),p.head.appendChild(g)}}}function _G(s,c,p){uo.S(s,c,p);var g=gc;if(g&&s){var x=xn(g).hoistableStyles,E=bc(s);c=c||"default";var D=x.get(E);if(!D){var j={loading:0,preload:null};if(D=g.querySelector(kd(E)))j.loading=5;else{s=f({rel:"stylesheet",href:s,"data-precedence":c},p),(p=Ma.get(E))&&S1(s,p);var ne=D=g.createElement("link");Tt(ne),ir(ne,"link",s),ne._p=new Promise(function(de,ye){ne.onload=de,ne.onerror=ye}),ne.addEventListener("load",function(){j.loading|=1}),ne.addEventListener("error",function(){j.loading|=2}),j.loading|=4,Of(D,c,g)}D={type:"stylesheet",instance:D,count:1,state:j},x.set(E,D)}}}function CG(s,c){uo.X(s,c);var p=gc;if(p&&s){var g=xn(p).hoistableScripts,x=yc(s),E=g.get(x);E||(E=p.querySelector(Td(x)),E||(s=f({src:s,async:!0},c),(c=Ma.get(x))&&w1(s,c),E=p.createElement("script"),Tt(E),ir(E,"link",s),p.head.appendChild(E)),E={type:"script",instance:E,count:1,state:null},g.set(x,E))}}function AG(s,c){uo.M(s,c);var p=gc;if(p&&s){var g=xn(p).hoistableScripts,x=yc(s),E=g.get(x);E||(E=p.querySelector(Td(x)),E||(s=f({src:s,async:!0,type:"module"},c),(c=Ma.get(x))&&w1(s,c),E=p.createElement("script"),Tt(E),ir(E,"link",s),p.head.appendChild(E)),E={type:"script",instance:E,count:1,state:null},g.set(x,E))}}function K5(s,c,p,g){var x=(x=fe.current)?Nf(x):null;if(!x)throw Error(r(446));switch(s){case"meta":case"title":return null;case"style":return typeof p.precedence=="string"&&typeof p.href=="string"?(c=bc(p.href),p=xn(x).hoistableStyles,g=p.get(c),g||(g={type:"style",instance:null,count:0,state:null},p.set(c,g)),g):{type:"void",instance:null,count:0,state:null};case"link":if(p.rel==="stylesheet"&&typeof p.href=="string"&&typeof p.precedence=="string"){s=bc(p.href);var E=xn(x).hoistableStyles,D=E.get(s);if(D||(x=x.ownerDocument||x,D={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},E.set(s,D),(E=x.querySelector(kd(s)))&&!E._p&&(D.instance=E,D.state.loading=5),Ma.has(s)||(p={rel:"preload",as:"style",href:p.href,crossOrigin:p.crossOrigin,integrity:p.integrity,media:p.media,hrefLang:p.hrefLang,referrerPolicy:p.referrerPolicy},Ma.set(s,p),E||RG(x,s,p,D.state))),c&&g===null)throw Error(r(528,""));return D}if(c&&g!==null)throw Error(r(529,""));return null;case"script":return c=p.async,p=p.src,typeof p=="string"&&c&&typeof c!="function"&&typeof c!="symbol"?(c=yc(p),p=xn(x).hoistableScripts,g=p.get(c),g||(g={type:"script",instance:null,count:0,state:null},p.set(c,g)),g):{type:"void",instance:null,count:0,state:null};default:throw Error(r(444,s))}}function bc(s){return'href="'+Ca(s)+'"'}function kd(s){return'link[rel="stylesheet"]['+s+"]"}function Z5(s){return f({},s,{"data-precedence":s.precedence,precedence:null})}function RG(s,c,p,g){s.querySelector('link[rel="preload"][as="style"]['+c+"]")?g.loading=1:(c=s.createElement("link"),g.preload=c,c.addEventListener("load",function(){return g.loading|=1}),c.addEventListener("error",function(){return g.loading|=2}),ir(c,"link",p),Tt(c),s.head.appendChild(c))}function yc(s){return'[src="'+Ca(s)+'"]'}function Td(s){return"script[async]"+s}function Q5(s,c,p){if(c.count++,c.instance===null)switch(c.type){case"style":var g=s.querySelector('style[data-href~="'+Ca(p.href)+'"]');if(g)return c.instance=g,Tt(g),g;var x=f({},p,{"data-href":p.href,"data-precedence":p.precedence,href:null,precedence:null});return g=(s.ownerDocument||s).createElement("style"),Tt(g),ir(g,"style",x),Of(g,p.precedence,s),c.instance=g;case"stylesheet":x=bc(p.href);var E=s.querySelector(kd(x));if(E)return c.state.loading|=4,c.instance=E,Tt(E),E;g=Z5(p),(x=Ma.get(x))&&S1(g,x),E=(s.ownerDocument||s).createElement("link"),Tt(E);var D=E;return D._p=new Promise(function(j,ne){D.onload=j,D.onerror=ne}),ir(E,"link",g),c.state.loading|=4,Of(E,p.precedence,s),c.instance=E;case"script":return E=yc(p.src),(x=s.querySelector(Td(E)))?(c.instance=x,Tt(x),x):(g=p,(x=Ma.get(E))&&(g=f({},p),w1(g,x)),s=s.ownerDocument||s,x=s.createElement("script"),Tt(x),ir(x,"link",g),s.head.appendChild(x),c.instance=x);case"void":return null;default:throw Error(r(443,c.type))}else c.type==="stylesheet"&&(c.state.loading&4)===0&&(g=c.instance,c.state.loading|=4,Of(g,p.precedence,s));return c.instance}function Of(s,c,p){for(var g=p.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),x=g.length?g[g.length-1]:null,E=x,D=0;D<g.length;D++){var j=g[D];if(j.dataset.precedence===c)E=j;else if(E!==x)break}E?E.parentNode.insertBefore(s,E.nextSibling):(c=p.nodeType===9?p.head:p,c.insertBefore(s,c.firstChild))}function S1(s,c){s.crossOrigin==null&&(s.crossOrigin=c.crossOrigin),s.referrerPolicy==null&&(s.referrerPolicy=c.referrerPolicy),s.title==null&&(s.title=c.title)}function w1(s,c){s.crossOrigin==null&&(s.crossOrigin=c.crossOrigin),s.referrerPolicy==null&&(s.referrerPolicy=c.referrerPolicy),s.integrity==null&&(s.integrity=c.integrity)}var If=null;function J5(s,c,p){if(If===null){var g=new Map,x=If=new Map;x.set(p,g)}else x=If,g=x.get(p),g||(g=new Map,x.set(p,g));if(g.has(s))return g;for(g.set(s,null),p=p.getElementsByTagName(s),x=0;x<p.length;x++){var E=p[x];if(!(E[Ke]||E[Ln]||s==="link"&&E.getAttribute("rel")==="stylesheet")&&E.namespaceURI!=="http://www.w3.org/2000/svg"){var D=E.getAttribute(c)||"";D=s+D;var j=g.get(D);j?j.push(E):g.set(D,[E])}}return g}function e6(s,c,p){s=s.ownerDocument||s,s.head.insertBefore(p,c==="title"?s.querySelector("head > title"):null)}function NG(s,c,p){if(p===1||c.itemProp!=null)return!1;switch(s){case"meta":case"title":return!0;case"style":if(typeof c.precedence!="string"||typeof c.href!="string"||c.href==="")break;return!0;case"link":if(typeof c.rel!="string"||typeof c.href!="string"||c.href===""||c.onLoad||c.onError)break;switch(c.rel){case"stylesheet":return s=c.disabled,typeof c.precedence=="string"&&s==null;default:return!0}case"script":if(c.async&&typeof c.async!="function"&&typeof c.async!="symbol"&&!c.onLoad&&!c.onError&&c.src&&typeof c.src=="string")return!0}return!1}function t6(s){return!(s.type==="stylesheet"&&(s.state.loading&3)===0)}function OG(s,c,p,g){if(p.type==="stylesheet"&&(typeof g.media!="string"||matchMedia(g.media).matches!==!1)&&(p.state.loading&4)===0){if(p.instance===null){var x=bc(g.href),E=c.querySelector(kd(x));if(E){c=E._p,c!==null&&typeof c=="object"&&typeof c.then=="function"&&(s.count++,s=Lf.bind(s),c.then(s,s)),p.state.loading|=4,p.instance=E,Tt(E);return}E=c.ownerDocument||c,g=Z5(g),(x=Ma.get(x))&&S1(g,x),E=E.createElement("link"),Tt(E);var D=E;D._p=new Promise(function(j,ne){D.onload=j,D.onerror=ne}),ir(E,"link",g),p.instance=E}s.stylesheets===null&&(s.stylesheets=new Map),s.stylesheets.set(p,c),(c=p.state.preload)&&(p.state.loading&3)===0&&(s.count++,p=Lf.bind(s),c.addEventListener("load",p),c.addEventListener("error",p))}}var E1=0;function IG(s,c){return s.stylesheets&&s.count===0&&Mf(s,s.stylesheets),0<s.count||0<s.imgCount?function(p){var g=setTimeout(function(){if(s.stylesheets&&Mf(s,s.stylesheets),s.unsuspend){var E=s.unsuspend;s.unsuspend=null,E()}},6e4+c);0<s.imgBytes&&E1===0&&(E1=62500*hG());var x=setTimeout(function(){if(s.waitingForImages=!1,s.count===0&&(s.stylesheets&&Mf(s,s.stylesheets),s.unsuspend)){var E=s.unsuspend;s.unsuspend=null,E()}},(s.imgBytes>E1?50:800)+c);return s.unsuspend=p,function(){s.unsuspend=null,clearTimeout(g),clearTimeout(x)}}:null}function Lf(){if(this.count--,this.count===0&&(this.imgCount===0||!this.waitingForImages)){if(this.stylesheets)Mf(this,this.stylesheets);else if(this.unsuspend){var s=this.unsuspend;this.unsuspend=null,s()}}}var Df=null;function Mf(s,c){s.stylesheets=null,s.unsuspend!==null&&(s.count++,Df=new Map,c.forEach(LG,s),Df=null,Lf.call(s))}function LG(s,c){if(!(c.state.loading&4)){var p=Df.get(s);if(p)var g=p.get(null);else{p=new Map,Df.set(s,p);for(var x=s.querySelectorAll("link[data-precedence],style[data-precedence]"),E=0;E<x.length;E++){var D=x[E];(D.nodeName==="LINK"||D.getAttribute("media")!=="not all")&&(p.set(D.dataset.precedence,D),g=D)}g&&p.set(null,g)}x=c.instance,D=x.getAttribute("data-precedence"),E=p.get(D)||g,E===g&&p.set(null,x),p.set(D,x),this.count++,g=Lf.bind(this),x.addEventListener("load",g),x.addEventListener("error",g),E?E.parentNode.insertBefore(x,E.nextSibling):(s=s.nodeType===9?s.head:s,s.insertBefore(x,s.firstChild)),c.state.loading|=4}}var _d={$$typeof:R,Provider:null,Consumer:null,_currentValue:J,_currentValue2:J,_threadCount:0};function DG(s,c,p,g,x,E,D,j,ne){this.tag=1,this.containerInfo=s,this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=Mu(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=Mu(0),this.hiddenUpdates=Mu(null),this.identifierPrefix=g,this.onUncaughtError=x,this.onCaughtError=E,this.onRecoverableError=D,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=ne,this.incompleteTransitions=new Map}function n6(s,c,p,g,x,E,D,j,ne,de,ye,Se){return s=new DG(s,c,p,D,ne,de,ye,Se,j),c=1,E===!0&&(c|=24),E=aa(3,null,null,c),s.current=E,E.stateNode=s,c=ny(),c.refCount++,s.pooledCache=c,c.refCount++,E.memoizedState={element:g,isDehydrated:p,cache:c},oy(E),s}function r6(s){return s?(s=Xl,s):Xl}function a6(s,c,p,g,x,E){x=r6(x),g.context===null?g.context=x:g.pendingContext=x,g=Go(c),g.payload={element:p},E=E===void 0?null:E,E!==null&&(g.callback=E),p=qo(s,g,c),p!==null&&(Yr(p,s,c),ad(p,s,c))}function i6(s,c){if(s=s.memoizedState,s!==null&&s.dehydrated!==null){var p=s.retryLane;s.retryLane=p!==0&&p<c?p:c}}function k1(s,c){i6(s,c),(s=s.alternate)&&i6(s,c)}function o6(s){if(s.tag===13||s.tag===31){var c=Us(s,67108864);c!==null&&Yr(c,s,67108864),k1(s,67108864)}}function s6(s){if(s.tag===13||s.tag===31){var c=ca();c=Ur(c);var p=Us(s,c);p!==null&&Yr(p,s,c),k1(s,c)}}var Bf=!0;function MG(s,c,p,g){var x=$.T;$.T=null;var E=Q.p;try{Q.p=2,T1(s,c,p,g)}finally{Q.p=E,$.T=x}}function BG(s,c,p,g){var x=$.T;$.T=null;var E=Q.p;try{Q.p=8,T1(s,c,p,g)}finally{Q.p=E,$.T=x}}function T1(s,c,p,g){if(Bf){var x=_1(g);if(x===null)d1(s,c,g,Ff,p),c6(s,g);else if(zG(x,s,c,p,g))g.stopPropagation();else if(c6(s,g),c&4&&-1<FG.indexOf(s)){for(;x!==null;){var E=$e(x);if(E!==null)switch(E.tag){case 3:if(E=E.stateNode,E.current.memoizedState.isDehydrated){var D=na(E.pendingLanes);if(D!==0){var j=E;for(j.pendingLanes|=2,j.entangledLanes|=2;D;){var ne=1<<31-zt(D);j.entanglements[1]|=ne,D&=~ne}gi(E),(Ht&6)===0&&(vf=yt()+500,xd(0))}}break;case 31:case 13:j=Us(E,2),j!==null&&Yr(j,E,2),Sf(),k1(E,2)}if(E=_1(g),E===null&&d1(s,c,g,Ff,p),E===x)break;x=E}x!==null&&g.stopPropagation()}else d1(s,c,g,null,p)}}function _1(s){return s=Ab(s),C1(s)}var Ff=null;function C1(s){if(Ff=null,s=_e(s),s!==null){var c=i(s);if(c===null)s=null;else{var p=c.tag;if(p===13){if(s=o(c),s!==null)return s;s=null}else if(p===31){if(s=l(c),s!==null)return s;s=null}else if(p===3){if(c.stateNode.current.memoizedState.isDehydrated)return c.tag===3?c.stateNode.containerInfo:null;s=null}else c!==s&&(s=null)}}return Ff=s,null}function l6(s){switch(s){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch(ur()){case me:return 2;case Te:return 8;case We:case ut:return 32;case It:return 268435456;default:return 32}default:return 32}}var A1=!1,ns=null,rs=null,as=null,Cd=new Map,Ad=new Map,is=[],FG="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function c6(s,c){switch(s){case"focusin":case"focusout":ns=null;break;case"dragenter":case"dragleave":rs=null;break;case"mouseover":case"mouseout":as=null;break;case"pointerover":case"pointerout":Cd.delete(c.pointerId);break;case"gotpointercapture":case"lostpointercapture":Ad.delete(c.pointerId)}}function Rd(s,c,p,g,x,E){return s===null||s.nativeEvent!==E?(s={blockedOn:c,domEventName:p,eventSystemFlags:g,nativeEvent:E,targetContainers:[x]},c!==null&&(c=$e(c),c!==null&&o6(c)),s):(s.eventSystemFlags|=g,c=s.targetContainers,x!==null&&c.indexOf(x)===-1&&c.push(x),s)}function zG(s,c,p,g,x){switch(c){case"focusin":return ns=Rd(ns,s,c,p,g,x),!0;case"dragenter":return rs=Rd(rs,s,c,p,g,x),!0;case"mouseover":return as=Rd(as,s,c,p,g,x),!0;case"pointerover":var E=x.pointerId;return Cd.set(E,Rd(Cd.get(E)||null,s,c,p,g,x)),!0;case"gotpointercapture":return E=x.pointerId,Ad.set(E,Rd(Ad.get(E)||null,s,c,p,g,x)),!0}return!1}function u6(s){var c=_e(s.target);if(c!==null){var p=i(c);if(p!==null){if(c=p.tag,c===13){if(c=o(p),c!==null){s.blockedOn=c,Pu(s.priority,function(){s6(p)});return}}else if(c===31){if(c=l(p),c!==null){s.blockedOn=c,Pu(s.priority,function(){s6(p)});return}}else if(c===3&&p.stateNode.current.memoizedState.isDehydrated){s.blockedOn=p.tag===3?p.stateNode.containerInfo:null;return}}}s.blockedOn=null}function zf(s){if(s.blockedOn!==null)return!1;for(var c=s.targetContainers;0<c.length;){var p=_1(s.nativeEvent);if(p===null){p=s.nativeEvent;var g=new p.constructor(p.type,p);Cb=g,p.target.dispatchEvent(g),Cb=null}else return c=$e(p),c!==null&&o6(c),s.blockedOn=p,!1;c.shift()}return!0}function d6(s,c,p){zf(s)&&p.delete(c)}function $G(){A1=!1,ns!==null&&zf(ns)&&(ns=null),rs!==null&&zf(rs)&&(rs=null),as!==null&&zf(as)&&(as=null),Cd.forEach(d6),Ad.forEach(d6)}function $f(s,c){s.blockedOn===c&&(s.blockedOn=null,A1||(A1=!0,e.unstable_scheduleCallback(e.unstable_NormalPriority,$G)))}var Pf=null;function h6(s){Pf!==s&&(Pf=s,e.unstable_scheduleCallback(e.unstable_NormalPriority,function(){Pf===s&&(Pf=null);for(var c=0;c<s.length;c+=3){var p=s[c],g=s[c+1],x=s[c+2];if(typeof g!="function"){if(C1(g||p)===null)continue;break}var E=$e(p);E!==null&&(s.splice(c,3),c-=3,_y(E,{pending:!0,data:x,method:p.method,action:g},g,x))}}))}function vc(s){function c(ne){return $f(ne,s)}ns!==null&&$f(ns,s),rs!==null&&$f(rs,s),as!==null&&$f(as,s),Cd.forEach(c),Ad.forEach(c);for(var p=0;p<is.length;p++){var g=is[p];g.blockedOn===s&&(g.blockedOn=null)}for(;0<is.length&&(p=is[0],p.blockedOn===null);)u6(p),p.blockedOn===null&&is.shift();if(p=(s.ownerDocument||s).$$reactFormReplay,p!=null)for(g=0;g<p.length;g+=3){var x=p[g],E=p[g+1],D=x[fn]||null;if(typeof E=="function")D||h6(p);else if(D){var j=null;if(E&&E.hasAttribute("formAction")){if(x=E,D=E[fn]||null)j=D.formAction;else if(C1(x)!==null)continue}else j=D.action;typeof j=="function"?p[g+1]=j:(p.splice(g,3),g-=3),h6(p)}}}function p6(){function s(E){E.canIntercept&&E.info==="react-transition"&&E.intercept({handler:function(){return new Promise(function(D){return x=D})},focusReset:"manual",scroll:"manual"})}function c(){x!==null&&(x(),x=null),g||setTimeout(p,20)}function p(){if(!g&&!navigation.transition){var E=navigation.currentEntry;E&&E.url!=null&&navigation.navigate(E.url,{state:E.getState(),info:"react-transition",history:"replace"})}}if(typeof navigation=="object"){var g=!1,x=null;return navigation.addEventListener("navigate",s),navigation.addEventListener("navigatesuccess",c),navigation.addEventListener("navigateerror",c),setTimeout(p,100),function(){g=!0,navigation.removeEventListener("navigate",s),navigation.removeEventListener("navigatesuccess",c),navigation.removeEventListener("navigateerror",c),x!==null&&(x(),x=null)}}}function R1(s){this._internalRoot=s}Uf.prototype.render=R1.prototype.render=function(s){var c=this._internalRoot;if(c===null)throw Error(r(409));var p=c.current,g=ca();a6(p,g,s,c,null,null)},Uf.prototype.unmount=R1.prototype.unmount=function(){var s=this._internalRoot;if(s!==null){this._internalRoot=null;var c=s.containerInfo;a6(s.current,2,null,s,null,null),Sf(),c[Wi]=null}};function Uf(s){this._internalRoot=s}Uf.prototype.unstable_scheduleHydration=function(s){if(s){var c=$u();s={blockedOn:null,target:s,priority:c};for(var p=0;p<is.length&&c!==0&&c<is[p].priority;p++);is.splice(p,0,s),p===0&&u6(s)}};var f6=t.version;if(f6!=="19.2.4")throw Error(r(527,f6,"19.2.4"));Q.findDOMNode=function(s){var c=s._reactInternals;if(c===void 0)throw typeof s.render=="function"?Error(r(188)):(s=Object.keys(s).join(","),Error(r(268,s)));return s=d(c),s=s!==null?h(s):null,s=s===null?null:s.stateNode,s};var PG={bundleType:0,version:"19.2.4",rendererPackageName:"react-dom",currentDispatcherRef:$,reconcilerVersion:"19.2.4"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var jf=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!jf.isDisabled&&jf.supportsFiber)try{In=jf.inject(PG),hn=jf}catch{}}return Od.createRoot=function(s,c){if(!a(s))throw Error(r(299));var p=!1,g="",x=S3,E=w3,D=E3;return c!=null&&(c.unstable_strictMode===!0&&(p=!0),c.identifierPrefix!==void 0&&(g=c.identifierPrefix),c.onUncaughtError!==void 0&&(x=c.onUncaughtError),c.onCaughtError!==void 0&&(E=c.onCaughtError),c.onRecoverableError!==void 0&&(D=c.onRecoverableError)),c=n6(s,1,!1,null,null,p,g,null,x,E,D,p6),s[Wi]=c.current,u1(s),new R1(c)},Od.hydrateRoot=function(s,c,p){if(!a(s))throw Error(r(299));var g=!1,x="",E=S3,D=w3,j=E3,ne=null;return p!=null&&(p.unstable_strictMode===!0&&(g=!0),p.identifierPrefix!==void 0&&(x=p.identifierPrefix),p.onUncaughtError!==void 0&&(E=p.onUncaughtError),p.onCaughtError!==void 0&&(D=p.onCaughtError),p.onRecoverableError!==void 0&&(j=p.onRecoverableError),p.formState!==void 0&&(ne=p.formState)),c=n6(s,1,!0,c,p??null,g,x,ne,E,D,j,p6),c.context=r6(null),p=c.current,g=ca(),g=Ur(g),x=Go(g),x.callback=null,qo(p,x,g),p=g,c.current.lanes=p,Fo(c,p),gi(c),s[Wi]=c.current,u1(s),new Uf(c)},Od.version="19.2.4",Od}var k6;function QG(){if(k6)return I1.exports;k6=1;function e(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(e)}catch(t){console.error(t)}}return e(),I1.exports=ZG(),I1.exports}var JG=QG();/**
 * react-router v7.13.1
 *
 * Copyright (c) Remix Software Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE.md file in the root directory of this source tree.
 *
 * @license MIT
 */var T6="popstate";function _6(e){return typeof e=="object"&&e!=null&&"pathname"in e&&"search"in e&&"hash"in e&&"state"in e&&"key"in e}function eq(e={}){function t(r,a){var d;let i=(d=a.state)==null?void 0:d.masked,{pathname:o,search:l,hash:u}=i||r.location;return tx("",{pathname:o,search:l,hash:u},a.state&&a.state.usr||null,a.state&&a.state.key||"default",i?{pathname:r.location.pathname,search:r.location.search,hash:r.location.hash}:void 0)}function n(r,a){return typeof a=="string"?a:vh(a)}return nq(t,n,null,e)}function bn(e,t){if(e===!1||e===null||typeof e>"u")throw new Error(t)}function Ua(e,t){if(!e){typeof console<"u"&&console.warn(t);try{throw new Error(t)}catch{}}}function tq(){return Math.random().toString(36).substring(2,10)}function C6(e,t){return{usr:e.state,key:e.key,idx:t,masked:e.unstable_mask?{pathname:e.pathname,search:e.search,hash:e.hash}:void 0}}function tx(e,t,n=null,r,a){return{pathname:typeof e=="string"?e:e.pathname,search:"",hash:"",...typeof t=="string"?du(t):t,state:n,key:t&&t.key||r||tq(),unstable_mask:a}}function vh({pathname:e="/",search:t="",hash:n=""}){return t&&t!=="?"&&(e+=t.charAt(0)==="?"?t:"?"+t),n&&n!=="#"&&(e+=n.charAt(0)==="#"?n:"#"+n),e}function du(e){let t={};if(e){let n=e.indexOf("#");n>=0&&(t.hash=e.substring(n),e=e.substring(0,n));let r=e.indexOf("?");r>=0&&(t.search=e.substring(r),e=e.substring(0,r)),e&&(t.pathname=e)}return t}function nq(e,t,n,r={}){let{window:a=document.defaultView,v5Compat:i=!1}=r,o=a.history,l="POP",u=null,d=h();d==null&&(d=0,o.replaceState({...o.state,idx:d},""));function h(){return(o.state||{idx:null}).idx}function f(){l="POP";let w=h(),S=w==null?null:w-d;d=w,u&&u({action:l,location:v.location,delta:S})}function m(w,S){l="PUSH";let k=_6(w)?w:tx(v.location,w,S);d=h()+1;let R=C6(k,d),I=v.createHref(k.unstable_mask||k);try{o.pushState(R,"",I)}catch(L){if(L instanceof DOMException&&L.name==="DataCloneError")throw L;a.location.assign(I)}i&&u&&u({action:l,location:v.location,delta:1})}function b(w,S){l="REPLACE";let k=_6(w)?w:tx(v.location,w,S);d=h();let R=C6(k,d),I=v.createHref(k.unstable_mask||k);o.replaceState(R,"",I),i&&u&&u({action:l,location:v.location,delta:0})}function y(w){return rq(w)}let v={get action(){return l},get location(){return e(a,o)},listen(w){if(u)throw new Error("A history only accepts one active listener");return a.addEventListener(T6,f),u=w,()=>{a.removeEventListener(T6,f),u=null}},createHref(w){return t(a,w)},createURL:y,encodeLocation(w){let S=y(w);return{pathname:S.pathname,search:S.search,hash:S.hash}},push:m,replace:b,go(w){return o.go(w)}};return v}function rq(e,t=!1){let n="http://localhost";typeof window<"u"&&(n=window.location.origin!=="null"?window.location.origin:window.location.href),bn(n,"No window.location.(origin|href) available to create URL");let r=typeof e=="string"?e:vh(e);return r=r.replace(/ $/,"%20"),!t&&r.startsWith("//")&&(r=n+r),new URL(r,n)}function Z8(e,t,n="/"){return aq(e,t,n,!1)}function aq(e,t,n,r){let a=typeof t=="string"?du(t):t,i=wo(a.pathname||"/",n);if(i==null)return null;let o=Q8(e);iq(o);let l=null;for(let u=0;l==null&&u<o.length;++u){let d=gq(i);l=fq(o[u],d,r)}return l}function Q8(e,t=[],n=[],r="",a=!1){let i=(o,l,u=a,d)=>{let h={relativePath:d===void 0?o.path||"":d,caseSensitive:o.caseSensitive===!0,childrenIndex:l,route:o};if(h.relativePath.startsWith("/")){if(!h.relativePath.startsWith(r)&&u)return;bn(h.relativePath.startsWith(r),`Absolute route path "${h.relativePath}" nested under path "${r}" is not valid. An absolute child route path must start with the combined path of all its parent routes.`),h.relativePath=h.relativePath.slice(r.length)}let f=_i([r,h.relativePath]),m=n.concat(h);o.children&&o.children.length>0&&(bn(o.index!==!0,`Index routes must not have child routes. Please remove all child routes from route path "${f}".`),Q8(o.children,t,m,f,u)),!(o.path==null&&!o.index)&&t.push({path:f,score:hq(f,o.index),routesMeta:m})};return e.forEach((o,l)=>{var u;if(o.path===""||!((u=o.path)!=null&&u.includes("?")))i(o,l);else for(let d of J8(o.path))i(o,l,!0,d)}),t}function J8(e){let t=e.split("/");if(t.length===0)return[];let[n,...r]=t,a=n.endsWith("?"),i=n.replace(/\?$/,"");if(r.length===0)return a?[i,""]:[i];let o=J8(r.join("/")),l=[];return l.push(...o.map(u=>u===""?i:[i,u].join("/"))),a&&l.push(...o),l.map(u=>e.startsWith("/")&&u===""?"/":u)}function iq(e){e.sort((t,n)=>t.score!==n.score?n.score-t.score:pq(t.routesMeta.map(r=>r.childrenIndex),n.routesMeta.map(r=>r.childrenIndex)))}var oq=/^:[\w-]+$/,sq=3,lq=2,cq=1,uq=10,dq=-2,A6=e=>e==="*";function hq(e,t){let n=e.split("/"),r=n.length;return n.some(A6)&&(r+=dq),t&&(r+=lq),n.filter(a=>!A6(a)).reduce((a,i)=>a+(oq.test(i)?sq:i===""?cq:uq),r)}function pq(e,t){return e.length===t.length&&e.slice(0,-1).every((r,a)=>r===t[a])?e[e.length-1]-t[t.length-1]:0}function fq(e,t,n=!1){let{routesMeta:r}=e,a={},i="/",o=[];for(let l=0;l<r.length;++l){let u=r[l],d=l===r.length-1,h=i==="/"?t:t.slice(i.length)||"/",f=K0({path:u.relativePath,caseSensitive:u.caseSensitive,end:d},h),m=u.route;if(!f&&d&&n&&!r[r.length-1].route.index&&(f=K0({path:u.relativePath,caseSensitive:u.caseSensitive,end:!1},h)),!f)return null;Object.assign(a,f.params),o.push({params:a,pathname:_i([i,f.pathname]),pathnameBase:xq(_i([i,f.pathnameBase])),route:m}),f.pathnameBase!=="/"&&(i=_i([i,f.pathnameBase]))}return o}function K0(e,t){typeof e=="string"&&(e={path:e,caseSensitive:!1,end:!0});let[n,r]=mq(e.path,e.caseSensitive,e.end),a=t.match(n);if(!a)return null;let i=a[0],o=i.replace(/(.)\/+$/,"$1"),l=a.slice(1);return{params:r.reduce((d,{paramName:h,isOptional:f},m)=>{if(h==="*"){let y=l[m]||"";o=i.slice(0,i.length-y.length).replace(/(.)\/+$/,"$1")}const b=l[m];return f&&!b?d[h]=void 0:d[h]=(b||"").replace(/%2F/g,"/"),d},{}),pathname:i,pathnameBase:o,pattern:e}}function mq(e,t=!1,n=!0){Ua(e==="*"||!e.endsWith("*")||e.endsWith("/*"),`Route path "${e}" will be treated as if it were "${e.replace(/\*$/,"/*")}" because the \`*\` character must always follow a \`/\` in the pattern. To get rid of this warning, please change the route path to "${e.replace(/\*$/,"/*")}".`);let r=[],a="^"+e.replace(/\/*\*?$/,"").replace(/^\/*/,"/").replace(/[\\.*+^${}|()[\]]/g,"\\$&").replace(/\/:([\w-]+)(\?)?/g,(o,l,u,d,h)=>{if(r.push({paramName:l,isOptional:u!=null}),u){let f=h.charAt(d+o.length);return f&&f!=="/"?"/([^\\/]*)":"(?:/([^\\/]*))?"}return"/([^\\/]+)"}).replace(/\/([\w-]+)\?(\/|$)/g,"(/$1)?$2");return e.endsWith("*")?(r.push({paramName:"*"}),a+=e==="*"||e==="/*"?"(.*)$":"(?:\\/(.+)|\\/*)$"):n?a+="\\/*$":e!==""&&e!=="/"&&(a+="(?:(?=\\/|$))"),[new RegExp(a,t?void 0:"i"),r]}function gq(e){try{return e.split("/").map(t=>decodeURIComponent(t).replace(/\//g,"%2F")).join("/")}catch(t){return Ua(!1,`The URL path "${e}" could not be decoded because it is a malformed URL segment. This is probably due to a bad percent encoding (${t}).`),e}}function wo(e,t){if(t==="/")return e;if(!e.toLowerCase().startsWith(t.toLowerCase()))return null;let n=t.endsWith("/")?t.length-1:t.length,r=e.charAt(n);return r&&r!=="/"?null:e.slice(n)||"/"}var bq=/^(?:[a-z][a-z0-9+.-]*:|\/\/)/i;function yq(e,t="/"){let{pathname:n,search:r="",hash:a=""}=typeof e=="string"?du(e):e,i;return n?(n=n.replace(/\/\/+/g,"/"),n.startsWith("/")?i=R6(n.substring(1),"/"):i=R6(n,t)):i=t,{pathname:i,search:Sq(r),hash:wq(a)}}function R6(e,t){let n=t.replace(/\/+$/,"").split("/");return e.split("/").forEach(a=>{a===".."?n.length>1&&n.pop():a!=="."&&n.push(a)}),n.length>1?n.join("/"):"/"}function B1(e,t,n,r){return`Cannot include a '${e}' character in a manually specified \`to.${t}\` field [${JSON.stringify(r)}].  Please separate it out to the \`to.${n}\` field. Alternatively you may provide the full path as a string in <Link to="..."> and the router will parse it for you.`}function vq(e){return e.filter((t,n)=>n===0||t.route.path&&t.route.path.length>0)}function H2(e){let t=vq(e);return t.map((n,r)=>r===t.length-1?n.pathname:n.pathnameBase)}function eg(e,t,n,r=!1){let a;typeof e=="string"?a=du(e):(a={...e},bn(!a.pathname||!a.pathname.includes("?"),B1("?","pathname","search",a)),bn(!a.pathname||!a.pathname.includes("#"),B1("#","pathname","hash",a)),bn(!a.search||!a.search.includes("#"),B1("#","search","hash",a)));let i=e===""||a.pathname==="",o=i?"/":a.pathname,l;if(o==null)l=n;else{let f=t.length-1;if(!r&&o.startsWith("..")){let m=o.split("/");for(;m[0]==="..";)m.shift(),f-=1;a.pathname=m.join("/")}l=f>=0?t[f]:"/"}let u=yq(a,l),d=o&&o!=="/"&&o.endsWith("/"),h=(i||o===".")&&n.endsWith("/");return!u.pathname.endsWith("/")&&(d||h)&&(u.pathname+="/"),u}var _i=e=>e.join("/").replace(/\/\/+/g,"/"),xq=e=>e.replace(/\/+$/,"").replace(/^\/*/,"/"),Sq=e=>!e||e==="?"?"":e.startsWith("?")?e:"?"+e,wq=e=>!e||e==="#"?"":e.startsWith("#")?e:"#"+e,Eq=class{constructor(e,t,n,r=!1){this.status=e,this.statusText=t||"",this.internal=r,n instanceof Error?(this.data=n.toString(),this.error=n):this.data=n}};function kq(e){return e!=null&&typeof e.status=="number"&&typeof e.statusText=="string"&&typeof e.internal=="boolean"&&"data"in e}function Tq(e){return e.map(t=>t.route.path).filter(Boolean).join("/").replace(/\/\/*/g,"/")||"/"}var eO=typeof window<"u"&&typeof window.document<"u"&&typeof window.document.createElement<"u";function tO(e,t){let n=e;if(typeof n!="string"||!bq.test(n))return{absoluteURL:void 0,isExternal:!1,to:n};let r=n,a=!1;if(eO)try{let i=new URL(window.location.href),o=n.startsWith("//")?new URL(i.protocol+n):new URL(n),l=wo(o.pathname,t);o.origin===i.origin&&l!=null?n=l+o.search+o.hash:a=!0}catch{Ua(!1,`<Link to="${n}"> contains an invalid URL which will probably break when clicked - please update to a valid URL path.`)}return{absoluteURL:r,isExternal:a,to:n}}Object.getOwnPropertyNames(Object.prototype).sort().join("\0");var nO=["POST","PUT","PATCH","DELETE"];new Set(nO);var _q=["GET",...nO];new Set(_q);var hu=_.createContext(null);hu.displayName="DataRouter";var tg=_.createContext(null);tg.displayName="DataRouterState";var Cq=_.createContext(!1),rO=_.createContext({isTransitioning:!1});rO.displayName="ViewTransition";var Aq=_.createContext(new Map);Aq.displayName="Fetchers";var Rq=_.createContext(null);Rq.displayName="Await";var va=_.createContext(null);va.displayName="Navigation";var Wh=_.createContext(null);Wh.displayName="Location";var Ii=_.createContext({outlet:null,matches:[],isDataRoute:!1});Ii.displayName="Route";var G2=_.createContext(null);G2.displayName="RouteError";var aO="REACT_ROUTER_ERROR",Nq="REDIRECT",Oq="ROUTE_ERROR_RESPONSE";function Iq(e){if(e.startsWith(`${aO}:${Nq}:{`))try{let t=JSON.parse(e.slice(28));if(typeof t=="object"&&t&&typeof t.status=="number"&&typeof t.statusText=="string"&&typeof t.location=="string"&&typeof t.reloadDocument=="boolean"&&typeof t.replace=="boolean")return t}catch{}}function Lq(e){if(e.startsWith(`${aO}:${Oq}:{`))try{let t=JSON.parse(e.slice(40));if(typeof t=="object"&&t&&typeof t.status=="number"&&typeof t.statusText=="string")return new Eq(t.status,t.statusText,t.data)}catch{}}function Dq(e,{relative:t}={}){bn(pu(),"useHref() may be used only in the context of a <Router> component.");let{basename:n,navigator:r}=_.useContext(va),{hash:a,pathname:i,search:o}=Yh(e,{relative:t}),l=i;return n!=="/"&&(l=i==="/"?n:_i([n,i])),r.createHref({pathname:l,search:o,hash:a})}function pu(){return _.useContext(Wh)!=null}function Li(){return bn(pu(),"useLocation() may be used only in the context of a <Router> component."),_.useContext(Wh).location}var iO="You should call navigate() in a React.useEffect(), not when your component is first rendered.";function oO(e){_.useContext(va).static||_.useLayoutEffect(e)}function Vh(){let{isDataRoute:e}=_.useContext(Ii);return e?Vq():Mq()}function Mq(){bn(pu(),"useNavigate() may be used only in the context of a <Router> component.");let e=_.useContext(hu),{basename:t,navigator:n}=_.useContext(va),{matches:r}=_.useContext(Ii),{pathname:a}=Li(),i=JSON.stringify(H2(r)),o=_.useRef(!1);return oO(()=>{o.current=!0}),_.useCallback((u,d={})=>{if(Ua(o.current,iO),!o.current)return;if(typeof u=="number"){n.go(u);return}let h=eg(u,JSON.parse(i),a,d.relative==="path");e==null&&t!=="/"&&(h.pathname=h.pathname==="/"?t:_i([t,h.pathname])),(d.replace?n.replace:n.push)(h,d.state,d)},[t,n,i,a,e])}_.createContext(null);function Yh(e,{relative:t}={}){let{matches:n}=_.useContext(Ii),{pathname:r}=Li(),a=JSON.stringify(H2(n));return _.useMemo(()=>eg(e,JSON.parse(a),r,t==="path"),[e,a,r,t])}function Bq(e,t){return sO(e,t)}function sO(e,t,n){var w;bn(pu(),"useRoutes() may be used only in the context of a <Router> component.");let{navigator:r}=_.useContext(va),{matches:a}=_.useContext(Ii),i=a[a.length-1],o=i?i.params:{},l=i?i.pathname:"/",u=i?i.pathnameBase:"/",d=i&&i.route;{let S=d&&d.path||"";cO(l,!d||S.endsWith("*")||S.endsWith("*?"),`You rendered descendant <Routes> (or called \`useRoutes()\`) at "${l}" (under <Route path="${S}">) but the parent route path has no trailing "*". This means if you navigate deeper, the parent won't match anymore and therefore the child routes will never render.

Please change the parent <Route path="${S}"> to <Route path="${S==="/"?"*":`${S}/*`}">.`)}let h=Li(),f;if(t){let S=typeof t=="string"?du(t):t;bn(u==="/"||((w=S.pathname)==null?void 0:w.startsWith(u)),`When overriding the location using \`<Routes location>\` or \`useRoutes(routes, location)\`, the location pathname must begin with the portion of the URL pathname that was matched by all parent routes. The current pathname base is "${u}" but pathname "${S.pathname}" was given in the \`location\` prop.`),f=S}else f=h;let m=f.pathname||"/",b=m;if(u!=="/"){let S=u.replace(/^\//,"").split("/");b="/"+m.replace(/^\//,"").split("/").slice(S.length).join("/")}let y=Z8(e,{pathname:b});Ua(d||y!=null,`No routes matched location "${f.pathname}${f.search}${f.hash}" `),Ua(y==null||y[y.length-1].route.element!==void 0||y[y.length-1].route.Component!==void 0||y[y.length-1].route.lazy!==void 0,`Matched leaf route at location "${f.pathname}${f.search}${f.hash}" does not have an element or Component. This means it will render an <Outlet /> with a null value by default resulting in an "empty" page.`);let v=Uq(y&&y.map(S=>Object.assign({},S,{params:Object.assign({},o,S.params),pathname:_i([u,r.encodeLocation?r.encodeLocation(S.pathname.replace(/\?/g,"%3F").replace(/#/g,"%23")).pathname:S.pathname]),pathnameBase:S.pathnameBase==="/"?u:_i([u,r.encodeLocation?r.encodeLocation(S.pathnameBase.replace(/\?/g,"%3F").replace(/#/g,"%23")).pathname:S.pathnameBase])})),a,n);return t&&v?_.createElement(Wh.Provider,{value:{location:{pathname:"/",search:"",hash:"",state:null,key:"default",unstable_mask:void 0,...f},navigationType:"POP"}},v):v}function Fq(){let e=Wq(),t=kq(e)?`${e.status} ${e.statusText}`:e instanceof Error?e.message:JSON.stringify(e),n=e instanceof Error?e.stack:null,r="rgba(200,200,200, 0.5)",a={padding:"0.5rem",backgroundColor:r},i={padding:"2px 4px",backgroundColor:r},o=null;return console.error("Error handled by React Router default ErrorBoundary:",e),o=_.createElement(_.Fragment,null,_.createElement("p",null,"💿 Hey developer 👋"),_.createElement("p",null,"You can provide a way better UX than this when your app throws errors by providing your own ",_.createElement("code",{style:i},"ErrorBoundary")," or"," ",_.createElement("code",{style:i},"errorElement")," prop on your route.")),_.createElement(_.Fragment,null,_.createElement("h2",null,"Unexpected Application Error!"),_.createElement("h3",{style:{fontStyle:"italic"}},t),n?_.createElement("pre",{style:a},n):null,o)}var zq=_.createElement(Fq,null),lO=class extends _.Component{constructor(e){super(e),this.state={location:e.location,revalidation:e.revalidation,error:e.error}}static getDerivedStateFromError(e){return{error:e}}static getDerivedStateFromProps(e,t){return t.location!==e.location||t.revalidation!=="idle"&&e.revalidation==="idle"?{error:e.error,location:e.location,revalidation:e.revalidation}:{error:e.error!==void 0?e.error:t.error,location:t.location,revalidation:e.revalidation||t.revalidation}}componentDidCatch(e,t){this.props.onError?this.props.onError(e,t):console.error("React Router caught the following error during render",e)}render(){let e=this.state.error;if(this.context&&typeof e=="object"&&e&&"digest"in e&&typeof e.digest=="string"){const n=Lq(e.digest);n&&(e=n)}let t=e!==void 0?_.createElement(Ii.Provider,{value:this.props.routeContext},_.createElement(G2.Provider,{value:e,children:this.props.component})):this.props.children;return this.context?_.createElement($q,{error:e},t):t}};lO.contextType=Cq;var F1=new WeakMap;function $q({children:e,error:t}){let{basename:n}=_.useContext(va);if(typeof t=="object"&&t&&"digest"in t&&typeof t.digest=="string"){let r=Iq(t.digest);if(r){let a=F1.get(t);if(a)throw a;let i=tO(r.location,n);if(eO&&!F1.get(t))if(i.isExternal||r.reloadDocument)window.location.href=i.absoluteURL||i.to;else{const o=Promise.resolve().then(()=>window.__reactRouterDataRouter.navigate(i.to,{replace:r.replace}));throw F1.set(t,o),o}return _.createElement("meta",{httpEquiv:"refresh",content:`0;url=${i.absoluteURL||i.to}`})}}return e}function Pq({routeContext:e,match:t,children:n}){let r=_.useContext(hu);return r&&r.static&&r.staticContext&&(t.route.errorElement||t.route.ErrorBoundary)&&(r.staticContext._deepestRenderedBoundaryId=t.route.id),_.createElement(Ii.Provider,{value:e},n)}function Uq(e,t=[],n){let r=n==null?void 0:n.state;if(e==null){if(!r)return null;if(r.errors)e=r.matches;else if(t.length===0&&!r.initialized&&r.matches.length>0)e=r.matches;else return null}let a=e,i=r==null?void 0:r.errors;if(i!=null){let h=a.findIndex(f=>f.route.id&&(i==null?void 0:i[f.route.id])!==void 0);bn(h>=0,`Could not find a matching route for errors on route IDs: ${Object.keys(i).join(",")}`),a=a.slice(0,Math.min(a.length,h+1))}let o=!1,l=-1;if(n&&r){o=r.renderFallback;for(let h=0;h<a.length;h++){let f=a[h];if((f.route.HydrateFallback||f.route.hydrateFallbackElement)&&(l=h),f.route.id){let{loaderData:m,errors:b}=r,y=f.route.loader&&!m.hasOwnProperty(f.route.id)&&(!b||b[f.route.id]===void 0);if(f.route.lazy||y){n.isStatic&&(o=!0),l>=0?a=a.slice(0,l+1):a=[a[0]];break}}}}let u=n==null?void 0:n.onError,d=r&&u?(h,f)=>{var m,b;u(h,{location:r.location,params:((b=(m=r.matches)==null?void 0:m[0])==null?void 0:b.params)??{},unstable_pattern:Tq(r.matches),errorInfo:f})}:void 0;return a.reduceRight((h,f,m)=>{let b,y=!1,v=null,w=null;r&&(b=i&&f.route.id?i[f.route.id]:void 0,v=f.route.errorElement||zq,o&&(l<0&&m===0?(cO("route-fallback",!1,"No `HydrateFallback` element provided to render during initial hydration"),y=!0,w=null):l===m&&(y=!0,w=f.route.hydrateFallbackElement||null)));let S=t.concat(a.slice(0,m+1)),k=()=>{let R;return b?R=v:y?R=w:f.route.Component?R=_.createElement(f.route.Component,null):f.route.element?R=f.route.element:R=h,_.createElement(Pq,{match:f,routeContext:{outlet:h,matches:S,isDataRoute:r!=null},children:R})};return r&&(f.route.ErrorBoundary||f.route.errorElement||m===0)?_.createElement(lO,{location:r.location,revalidation:r.revalidation,component:v,error:b,children:k(),routeContext:{outlet:null,matches:S,isDataRoute:!0},onError:d}):k()},null)}function q2(e){return`${e} must be used within a data router.  See https://reactrouter.com/en/main/routers/picking-a-router.`}function jq(e){let t=_.useContext(hu);return bn(t,q2(e)),t}function Hq(e){let t=_.useContext(tg);return bn(t,q2(e)),t}function Gq(e){let t=_.useContext(Ii);return bn(t,q2(e)),t}function W2(e){let t=Gq(e),n=t.matches[t.matches.length-1];return bn(n.route.id,`${e} can only be used on routes that contain a unique "id"`),n.route.id}function qq(){return W2("useRouteId")}function Wq(){var r;let e=_.useContext(G2),t=Hq("useRouteError"),n=W2("useRouteError");return e!==void 0?e:(r=t.errors)==null?void 0:r[n]}function Vq(){let{router:e}=jq("useNavigate"),t=W2("useNavigate"),n=_.useRef(!1);return oO(()=>{n.current=!0}),_.useCallback(async(a,i={})=>{Ua(n.current,iO),n.current&&(typeof a=="number"?await e.navigate(a):await e.navigate(a,{fromRouteId:t,...i}))},[e,t])}var N6={};function cO(e,t,n){!t&&!N6[e]&&(N6[e]=!0,Ua(!1,n))}_.memo(Yq);function Yq({routes:e,future:t,state:n,isStatic:r,onError:a}){return sO(e,void 0,{state:n,isStatic:r,onError:a})}function Xq({to:e,replace:t,state:n,relative:r}){bn(pu(),"<Navigate> may be used only in the context of a <Router> component.");let{static:a}=_.useContext(va);Ua(!a,"<Navigate> must not be used on the initial render in a <StaticRouter>. This is a no-op, but you should modify your code so the <Navigate> is only ever rendered in response to some user interaction or state change.");let{matches:i}=_.useContext(Ii),{pathname:o}=Li(),l=Vh(),u=eg(e,H2(i),o,r==="path"),d=JSON.stringify(u);return _.useEffect(()=>{l(JSON.parse(d),{replace:t,state:n,relative:r})},[l,d,r,t,n]),null}function Ac(e){bn(!1,"A <Route> is only ever to be used as the child of <Routes> element, never rendered directly. Please wrap your <Route> in a <Routes>.")}function Kq({basename:e="/",children:t=null,location:n,navigationType:r="POP",navigator:a,static:i=!1,unstable_useTransitions:o}){bn(!pu(),"You cannot render a <Router> inside another <Router>. You should never have more than one in your app.");let l=e.replace(/^\/*/,"/"),u=_.useMemo(()=>({basename:l,navigator:a,static:i,unstable_useTransitions:o,future:{}}),[l,a,i,o]);typeof n=="string"&&(n=du(n));let{pathname:d="/",search:h="",hash:f="",state:m=null,key:b="default",unstable_mask:y}=n,v=_.useMemo(()=>{let w=wo(d,l);return w==null?null:{location:{pathname:w,search:h,hash:f,state:m,key:b,unstable_mask:y},navigationType:r}},[l,d,h,f,m,b,r,y]);return Ua(v!=null,`<Router basename="${l}"> is not able to match the URL "${d}${h}${f}" because it does not start with the basename, so the <Router> won't render anything.`),v==null?null:_.createElement(va.Provider,{value:u},_.createElement(Wh.Provider,{children:t,value:v}))}function Zq({children:e,location:t}){return Bq(nx(e),t)}function nx(e,t=[]){let n=[];return _.Children.forEach(e,(r,a)=>{if(!_.isValidElement(r))return;let i=[...t,a];if(r.type===_.Fragment){n.push.apply(n,nx(r.props.children,i));return}bn(r.type===Ac,`[${typeof r.type=="string"?r.type:r.type.name}] is not a <Route> component. All component children of <Routes> must be a <Route> or <React.Fragment>`),bn(!r.props.index||!r.props.children,"An index route cannot have child routes.");let o={id:r.props.id||i.join("-"),caseSensitive:r.props.caseSensitive,element:r.props.element,Component:r.props.Component,index:r.props.index,path:r.props.path,middleware:r.props.middleware,loader:r.props.loader,action:r.props.action,hydrateFallbackElement:r.props.hydrateFallbackElement,HydrateFallback:r.props.HydrateFallback,errorElement:r.props.errorElement,ErrorBoundary:r.props.ErrorBoundary,hasErrorBoundary:r.props.hasErrorBoundary===!0||r.props.ErrorBoundary!=null||r.props.errorElement!=null,shouldRevalidate:r.props.shouldRevalidate,handle:r.props.handle,lazy:r.props.lazy};r.props.children&&(o.children=nx(r.props.children,i)),n.push(o)}),n}var T0="get",_0="application/x-www-form-urlencoded";function ng(e){return typeof HTMLElement<"u"&&e instanceof HTMLElement}function Qq(e){return ng(e)&&e.tagName.toLowerCase()==="button"}function Jq(e){return ng(e)&&e.tagName.toLowerCase()==="form"}function eW(e){return ng(e)&&e.tagName.toLowerCase()==="input"}function tW(e){return!!(e.metaKey||e.altKey||e.ctrlKey||e.shiftKey)}function nW(e,t){return e.button===0&&(!t||t==="_self")&&!tW(e)}function rx(e=""){return new URLSearchParams(typeof e=="string"||Array.isArray(e)||e instanceof URLSearchParams?e:Object.keys(e).reduce((t,n)=>{let r=e[n];return t.concat(Array.isArray(r)?r.map(a=>[n,a]):[[n,r]])},[]))}function rW(e,t){let n=rx(e);return t&&t.forEach((r,a)=>{n.has(a)||t.getAll(a).forEach(i=>{n.append(a,i)})}),n}var Hf=null;function aW(){if(Hf===null)try{new FormData(document.createElement("form"),0),Hf=!1}catch{Hf=!0}return Hf}var iW=new Set(["application/x-www-form-urlencoded","multipart/form-data","text/plain"]);function z1(e){return e!=null&&!iW.has(e)?(Ua(!1,`"${e}" is not a valid \`encType\` for \`<Form>\`/\`<fetcher.Form>\` and will default to "${_0}"`),null):e}function oW(e,t){let n,r,a,i,o;if(Jq(e)){let l=e.getAttribute("action");r=l?wo(l,t):null,n=e.getAttribute("method")||T0,a=z1(e.getAttribute("enctype"))||_0,i=new FormData(e)}else if(Qq(e)||eW(e)&&(e.type==="submit"||e.type==="image")){let l=e.form;if(l==null)throw new Error('Cannot submit a <button> or <input type="submit"> without a <form>');let u=e.getAttribute("formaction")||l.getAttribute("action");if(r=u?wo(u,t):null,n=e.getAttribute("formmethod")||l.getAttribute("method")||T0,a=z1(e.getAttribute("formenctype"))||z1(l.getAttribute("enctype"))||_0,i=new FormData(l,e),!aW()){let{name:d,type:h,value:f}=e;if(h==="image"){let m=d?`${d}.`:"";i.append(`${m}x`,"0"),i.append(`${m}y`,"0")}else d&&i.append(d,f)}}else{if(ng(e))throw new Error('Cannot submit element that is not <form>, <button>, or <input type="submit|image">');n=T0,r=null,a=_0,o=e}return i&&a==="text/plain"&&(o=i,i=void 0),{action:r,method:n.toLowerCase(),encType:a,formData:i,body:o}}Object.getOwnPropertyNames(Object.prototype).sort().join("\0");function V2(e,t){if(e===!1||e===null||typeof e>"u")throw new Error(t)}function sW(e,t,n,r){let a=typeof e=="string"?new URL(e,typeof window>"u"?"server://singlefetch/":window.location.origin):e;return n?a.pathname.endsWith("/")?a.pathname=`${a.pathname}_.${r}`:a.pathname=`${a.pathname}.${r}`:a.pathname==="/"?a.pathname=`_root.${r}`:t&&wo(a.pathname,t)==="/"?a.pathname=`${t.replace(/\/$/,"")}/_root.${r}`:a.pathname=`${a.pathname.replace(/\/$/,"")}.${r}`,a}async function lW(e,t){if(e.id in t)return t[e.id];try{let n=await import(e.module);return t[e.id]=n,n}catch(n){return console.error(`Error loading route module \`${e.module}\`, reloading page...`),console.error(n),window.__reactRouterContext&&window.__reactRouterContext.isSpaMode,window.location.reload(),new Promise(()=>{})}}function cW(e){return e==null?!1:e.href==null?e.rel==="preload"&&typeof e.imageSrcSet=="string"&&typeof e.imageSizes=="string":typeof e.rel=="string"&&typeof e.href=="string"}async function uW(e,t,n){let r=await Promise.all(e.map(async a=>{let i=t.routes[a.route.id];if(i){let o=await lW(i,n);return o.links?o.links():[]}return[]}));return fW(r.flat(1).filter(cW).filter(a=>a.rel==="stylesheet"||a.rel==="preload").map(a=>a.rel==="stylesheet"?{...a,rel:"prefetch",as:"style"}:{...a,rel:"prefetch"}))}function O6(e,t,n,r,a,i){let o=(u,d)=>n[d]?u.route.id!==n[d].route.id:!0,l=(u,d)=>{var h;return n[d].pathname!==u.pathname||((h=n[d].route.path)==null?void 0:h.endsWith("*"))&&n[d].params["*"]!==u.params["*"]};return i==="assets"?t.filter((u,d)=>o(u,d)||l(u,d)):i==="data"?t.filter((u,d)=>{var f;let h=r.routes[u.route.id];if(!h||!h.hasLoader)return!1;if(o(u,d)||l(u,d))return!0;if(u.route.shouldRevalidate){let m=u.route.shouldRevalidate({currentUrl:new URL(a.pathname+a.search+a.hash,window.origin),currentParams:((f=n[0])==null?void 0:f.params)||{},nextUrl:new URL(e,window.origin),nextParams:u.params,defaultShouldRevalidate:!0});if(typeof m=="boolean")return m}return!0}):[]}function dW(e,t,{includeHydrateFallback:n}={}){return hW(e.map(r=>{let a=t.routes[r.route.id];if(!a)return[];let i=[a.module];return a.clientActionModule&&(i=i.concat(a.clientActionModule)),a.clientLoaderModule&&(i=i.concat(a.clientLoaderModule)),n&&a.hydrateFallbackModule&&(i=i.concat(a.hydrateFallbackModule)),a.imports&&(i=i.concat(a.imports)),i}).flat(1))}function hW(e){return[...new Set(e)]}function pW(e){let t={},n=Object.keys(e).sort();for(let r of n)t[r]=e[r];return t}function fW(e,t){let n=new Set;return new Set(t),e.reduce((r,a)=>{let i=JSON.stringify(pW(a));return n.has(i)||(n.add(i),r.push({key:i,link:a})),r},[])}function uO(){let e=_.useContext(hu);return V2(e,"You must render this element inside a <DataRouterContext.Provider> element"),e}function mW(){let e=_.useContext(tg);return V2(e,"You must render this element inside a <DataRouterStateContext.Provider> element"),e}var Y2=_.createContext(void 0);Y2.displayName="FrameworkContext";function dO(){let e=_.useContext(Y2);return V2(e,"You must render this element inside a <HydratedRouter> element"),e}function gW(e,t){let n=_.useContext(Y2),[r,a]=_.useState(!1),[i,o]=_.useState(!1),{onFocus:l,onBlur:u,onMouseEnter:d,onMouseLeave:h,onTouchStart:f}=t,m=_.useRef(null);_.useEffect(()=>{if(e==="render"&&o(!0),e==="viewport"){let v=S=>{S.forEach(k=>{o(k.isIntersecting)})},w=new IntersectionObserver(v,{threshold:.5});return m.current&&w.observe(m.current),()=>{w.disconnect()}}},[e]),_.useEffect(()=>{if(r){let v=setTimeout(()=>{o(!0)},100);return()=>{clearTimeout(v)}}},[r]);let b=()=>{a(!0)},y=()=>{a(!1),o(!1)};return n?e!=="intent"?[i,m,{}]:[i,m,{onFocus:Id(l,b),onBlur:Id(u,y),onMouseEnter:Id(d,b),onMouseLeave:Id(h,y),onTouchStart:Id(f,b)}]:[!1,m,{}]}function Id(e,t){return n=>{e&&e(n),n.defaultPrevented||t(n)}}function bW({page:e,...t}){let{router:n}=uO(),r=_.useMemo(()=>Z8(n.routes,e,n.basename),[n.routes,e,n.basename]);return r?_.createElement(vW,{page:e,matches:r,...t}):null}function yW(e){let{manifest:t,routeModules:n}=dO(),[r,a]=_.useState([]);return _.useEffect(()=>{let i=!1;return uW(e,t,n).then(o=>{i||a(o)}),()=>{i=!0}},[e,t,n]),r}function vW({page:e,matches:t,...n}){let r=Li(),{future:a,manifest:i,routeModules:o}=dO(),{basename:l}=uO(),{loaderData:u,matches:d}=mW(),h=_.useMemo(()=>O6(e,t,d,i,r,"data"),[e,t,d,i,r]),f=_.useMemo(()=>O6(e,t,d,i,r,"assets"),[e,t,d,i,r]),m=_.useMemo(()=>{if(e===r.pathname+r.search+r.hash)return[];let v=new Set,w=!1;if(t.forEach(k=>{var I;let R=i.routes[k.route.id];!R||!R.hasLoader||(!h.some(L=>L.route.id===k.route.id)&&k.route.id in u&&((I=o[k.route.id])!=null&&I.shouldRevalidate)||R.hasClientLoader?w=!0:v.add(k.route.id))}),v.size===0)return[];let S=sW(e,l,a.unstable_trailingSlashAwareDataRequests,"data");return w&&v.size>0&&S.searchParams.set("_routes",t.filter(k=>v.has(k.route.id)).map(k=>k.route.id).join(",")),[S.pathname+S.search]},[l,a.unstable_trailingSlashAwareDataRequests,u,r,i,h,t,e,o]),b=_.useMemo(()=>dW(f,i),[f,i]),y=yW(f);return _.createElement(_.Fragment,null,m.map(v=>_.createElement("link",{key:v,rel:"prefetch",as:"fetch",href:v,...n})),b.map(v=>_.createElement("link",{key:v,rel:"modulepreload",href:v,...n})),y.map(({key:v,link:w})=>_.createElement("link",{key:v,nonce:n.nonce,...w,crossOrigin:w.crossOrigin??n.crossOrigin})))}function xW(...e){return t=>{e.forEach(n=>{typeof n=="function"?n(t):n!=null&&(n.current=t)})}}var SW=typeof window<"u"&&typeof window.document<"u"&&typeof window.document.createElement<"u";try{SW&&(window.__reactRouterVersion="7.13.1")}catch{}function wW({basename:e,children:t,unstable_useTransitions:n,window:r}){let a=_.useRef();a.current==null&&(a.current=eq({window:r,v5Compat:!0}));let i=a.current,[o,l]=_.useState({action:i.action,location:i.location}),u=_.useCallback(d=>{n===!1?l(d):_.startTransition(()=>l(d))},[n]);return _.useLayoutEffect(()=>i.listen(u),[i,u]),_.createElement(Kq,{basename:e,children:t,location:o.location,navigationType:o.action,navigator:i,unstable_useTransitions:n})}var hO=/^(?:[a-z][a-z0-9+.-]*:|\/\/)/i,X2=_.forwardRef(function({onClick:t,discover:n="render",prefetch:r="none",relative:a,reloadDocument:i,replace:o,unstable_mask:l,state:u,target:d,to:h,preventScrollReset:f,viewTransition:m,unstable_defaultShouldRevalidate:b,...y},v){let{basename:w,navigator:S,unstable_useTransitions:k}=_.useContext(va),R=typeof h=="string"&&hO.test(h),I=tO(h,w);h=I.to;let L=Dq(h,{relative:a}),A=Li(),M=null;if(l){let X=eg(l,[],A.unstable_mask?A.unstable_mask.pathname:"/",!0);w!=="/"&&(X.pathname=X.pathname==="/"?w:_i([w,X.pathname])),M=S.createHref(X)}let[P,G,B]=gW(r,y),H=_W(h,{replace:o,unstable_mask:l,state:u,target:d,preventScrollReset:f,relative:a,viewTransition:m,unstable_defaultShouldRevalidate:b,unstable_useTransitions:k});function Z(X){t&&t(X),X.defaultPrevented||H(X)}let V=!(I.isExternal||i),q=_.createElement("a",{...y,...B,href:(V?M:void 0)||I.absoluteURL||L,onClick:V?Z:t,ref:xW(v,G),target:d,"data-discover":!R&&n==="render"?"true":void 0});return P&&!R?_.createElement(_.Fragment,null,q,_.createElement(bW,{page:L})):q});X2.displayName="Link";var EW=_.forwardRef(function({"aria-current":t="page",caseSensitive:n=!1,className:r="",end:a=!1,style:i,to:o,viewTransition:l,children:u,...d},h){let f=Yh(o,{relative:d.relative}),m=Li(),b=_.useContext(tg),{navigator:y,basename:v}=_.useContext(va),w=b!=null&&IW(f)&&l===!0,S=y.encodeLocation?y.encodeLocation(f).pathname:f.pathname,k=m.pathname,R=b&&b.navigation&&b.navigation.location?b.navigation.location.pathname:null;n||(k=k.toLowerCase(),R=R?R.toLowerCase():null,S=S.toLowerCase()),R&&v&&(R=wo(R,v)||R);const I=S!=="/"&&S.endsWith("/")?S.length-1:S.length;let L=k===S||!a&&k.startsWith(S)&&k.charAt(I)==="/",A=R!=null&&(R===S||!a&&R.startsWith(S)&&R.charAt(S.length)==="/"),M={isActive:L,isPending:A,isTransitioning:w},P=L?t:void 0,G;typeof r=="function"?G=r(M):G=[r,L?"active":null,A?"pending":null,w?"transitioning":null].filter(Boolean).join(" ");let B=typeof i=="function"?i(M):i;return _.createElement(X2,{...d,"aria-current":P,className:G,ref:h,style:B,to:o,viewTransition:l},typeof u=="function"?u(M):u)});EW.displayName="NavLink";var kW=_.forwardRef(({discover:e="render",fetcherKey:t,navigate:n,reloadDocument:r,replace:a,state:i,method:o=T0,action:l,onSubmit:u,relative:d,preventScrollReset:h,viewTransition:f,unstable_defaultShouldRevalidate:m,...b},y)=>{let{unstable_useTransitions:v}=_.useContext(va),w=NW(),S=OW(l,{relative:d}),k=o.toLowerCase()==="get"?"get":"post",R=typeof l=="string"&&hO.test(l),I=L=>{if(u&&u(L),L.defaultPrevented)return;L.preventDefault();let A=L.nativeEvent.submitter,M=(A==null?void 0:A.getAttribute("formmethod"))||o,P=()=>w(A||L.currentTarget,{fetcherKey:t,method:M,navigate:n,replace:a,state:i,relative:d,preventScrollReset:h,viewTransition:f,unstable_defaultShouldRevalidate:m});v&&n!==!1?_.startTransition(()=>P()):P()};return _.createElement("form",{ref:y,method:k,action:S,onSubmit:r?u:I,...b,"data-discover":!R&&e==="render"?"true":void 0})});kW.displayName="Form";function TW(e){return`${e} must be used within a data router.  See https://reactrouter.com/en/main/routers/picking-a-router.`}function pO(e){let t=_.useContext(hu);return bn(t,TW(e)),t}function _W(e,{target:t,replace:n,unstable_mask:r,state:a,preventScrollReset:i,relative:o,viewTransition:l,unstable_defaultShouldRevalidate:u,unstable_useTransitions:d}={}){let h=Vh(),f=Li(),m=Yh(e,{relative:o});return _.useCallback(b=>{if(nW(b,t)){b.preventDefault();let y=n!==void 0?n:vh(f)===vh(m),v=()=>h(e,{replace:y,unstable_mask:r,state:a,preventScrollReset:i,relative:o,viewTransition:l,unstable_defaultShouldRevalidate:u});d?_.startTransition(()=>v()):v()}},[f,h,m,n,r,a,t,e,i,o,l,u,d])}function CW(e){Ua(typeof URLSearchParams<"u","You cannot use the `useSearchParams` hook in a browser that does not support the URLSearchParams API. If you need to support Internet Explorer 11, we recommend you load a polyfill such as https://github.com/ungap/url-search-params.");let t=_.useRef(rx(e)),n=_.useRef(!1),r=Li(),a=_.useMemo(()=>rW(r.search,n.current?null:t.current),[r.search]),i=Vh(),o=_.useCallback((l,u)=>{const d=rx(typeof l=="function"?l(new URLSearchParams(a)):l);n.current=!0,i("?"+d,u)},[i,a]);return[a,o]}var AW=0,RW=()=>`__${String(++AW)}__`;function NW(){let{router:e}=pO("useSubmit"),{basename:t}=_.useContext(va),n=qq(),r=e.fetch,a=e.navigate;return _.useCallback(async(i,o={})=>{let{action:l,method:u,encType:d,formData:h,body:f}=oW(i,t);if(o.navigate===!1){let m=o.fetcherKey||RW();await r(m,n,o.action||l,{unstable_defaultShouldRevalidate:o.unstable_defaultShouldRevalidate,preventScrollReset:o.preventScrollReset,formData:h,body:f,formMethod:o.method||u,formEncType:o.encType||d,flushSync:o.flushSync})}else await a(o.action||l,{unstable_defaultShouldRevalidate:o.unstable_defaultShouldRevalidate,preventScrollReset:o.preventScrollReset,formData:h,body:f,formMethod:o.method||u,formEncType:o.encType||d,replace:o.replace,state:o.state,fromRouteId:n,flushSync:o.flushSync,viewTransition:o.viewTransition})},[r,a,t,n])}function OW(e,{relative:t}={}){let{basename:n}=_.useContext(va),r=_.useContext(Ii);bn(r,"useFormAction must be used inside a RouteContext");let[a]=r.matches.slice(-1),i={...Yh(e||".",{relative:t})},o=Li();if(e==null){i.search=o.search;let l=new URLSearchParams(i.search),u=l.getAll("index");if(u.some(h=>h==="")){l.delete("index"),u.filter(f=>f).forEach(f=>l.append("index",f));let h=l.toString();i.search=h?`?${h}`:""}}return(!e||e===".")&&a.route.index&&(i.search=i.search?i.search.replace(/^\?/,"?index&"):"?index"),n!=="/"&&(i.pathname=i.pathname==="/"?n:_i([n,i.pathname])),vh(i)}function IW(e,{relative:t}={}){let n=_.useContext(rO);bn(n!=null,"`useViewTransitionState` must be used within `react-router-dom`'s `RouterProvider`.  Did you accidentally import `RouterProvider` from `react-router`?");let{basename:r}=pO("useViewTransitionState"),a=Yh(e,{relative:t});if(!n.isTransitioning)return!1;let i=wo(n.currentLocation.pathname,r)||n.currentLocation.pathname,o=wo(n.nextLocation.pathname,r)||n.nextLocation.pathname;return K0(a.pathname,o)!=null||K0(a.pathname,i)!=null}var K2=K8();const LW=qh(K2);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const DW=e=>e.replace(/([a-z0-9])([A-Z])/g,"$1-$2").toLowerCase(),MW=e=>e.replace(/^([A-Z])|[\s-_]+(\w)/g,(t,n,r)=>r?r.toUpperCase():n.toLowerCase()),I6=e=>{const t=MW(e);return t.charAt(0).toUpperCase()+t.slice(1)},fO=(...e)=>e.filter((t,n,r)=>!!t&&t.trim()!==""&&r.indexOf(t)===n).join(" ").trim(),BW=e=>{for(const t in e)if(t.startsWith("aria-")||t==="role"||t==="title")return!0};/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */var FW={xmlns:"http://www.w3.org/2000/svg",width:24,height:24,viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:2,strokeLinecap:"round",strokeLinejoin:"round"};/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const zW=_.forwardRef(({color:e="currentColor",size:t=24,strokeWidth:n=2,absoluteStrokeWidth:r,className:a="",children:i,iconNode:o,...l},u)=>_.createElement("svg",{ref:u,...FW,width:t,height:t,stroke:e,strokeWidth:r?Number(n)*24/Number(t):n,className:fO("lucide",a),...!i&&!BW(l)&&{"aria-hidden":"true"},...l},[...o.map(([d,h])=>_.createElement(d,h)),...Array.isArray(i)?i:[i]]));/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const ht=(e,t)=>{const n=_.forwardRef(({className:r,...a},i)=>_.createElement(zW,{ref:i,iconNode:t,className:fO(`lucide-${DW(I6(e))}`,`lucide-${e}`,r),...a}));return n.displayName=I6(e),n};/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const $W=[["rect",{width:"20",height:"5",x:"2",y:"3",rx:"1",key:"1wp1u1"}],["path",{d:"M4 8v11a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V8",key:"1s80jp"}],["path",{d:"M10 12h4",key:"a56b0p"}]],PW=ht("archive",$W);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const UW=[["path",{d:"M12 8V4H8",key:"hb8ula"}],["rect",{width:"16",height:"12",x:"4",y:"8",rx:"2",key:"enze0r"}],["path",{d:"M2 14h2",key:"vft8re"}],["path",{d:"M20 14h2",key:"4cs60a"}],["path",{d:"M15 13v2",key:"1xurst"}],["path",{d:"M9 13v2",key:"rq6x2g"}]],jW=ht("bot",UW);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const HW=[["path",{d:"M12 5a3 3 0 1 0-5.997.125 4 4 0 0 0-2.526 5.77 4 4 0 0 0 .556 6.588A4 4 0 1 0 12 18Z",key:"l5xja"}],["path",{d:"M12 5a3 3 0 1 1 5.997.125 4 4 0 0 1 2.526 5.77 4 4 0 0 1-.556 6.588A4 4 0 1 1 12 18Z",key:"ep3f8r"}],["path",{d:"M15 13a4.5 4.5 0 0 1-3-4 4.5 4.5 0 0 1-3 4",key:"1p4c4q"}],["path",{d:"M17.599 6.5a3 3 0 0 0 .399-1.375",key:"tmeiqw"}],["path",{d:"M6.003 5.125A3 3 0 0 0 6.401 6.5",key:"105sqy"}],["path",{d:"M3.477 10.896a4 4 0 0 1 .585-.396",key:"ql3yin"}],["path",{d:"M19.938 10.5a4 4 0 0 1 .585.396",key:"1qfode"}],["path",{d:"M6 18a4 4 0 0 1-1.967-.516",key:"2e4loj"}],["path",{d:"M19.967 17.484A4 4 0 0 1 18 18",key:"159ez6"}]],GW=ht("brain",HW);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const qW=[["path",{d:"M8 2v4",key:"1cmpym"}],["path",{d:"M16 2v4",key:"4m81vk"}],["rect",{width:"18",height:"18",x:"3",y:"4",rx:"2",key:"1hopcy"}],["path",{d:"M3 10h18",key:"8toen8"}]],mO=ht("calendar",qW);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const WW=[["path",{d:"M20 6 9 17l-5-5",key:"1gmf2c"}]],rg=ht("check",WW);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const VW=[["path",{d:"m9 18 6-6-6-6",key:"mthhwq"}]],Z2=ht("chevron-right",VW);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const YW=[["circle",{cx:"12",cy:"12",r:"10",key:"1mglay"}]],XW=ht("circle",YW);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const KW=[["path",{d:"M17.5 19H9a7 7 0 1 1 6.71-9h1.79a4.5 4.5 0 1 1 0 9Z",key:"p7xjir"}]],gO=ht("cloud",KW);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const ZW=[["path",{d:"m16 18 6-6-6-6",key:"eg8j8"}],["path",{d:"m8 6-6 6 6 6",key:"ppft3o"}]],QW=ht("code",ZW);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const JW=[["rect",{width:"14",height:"14",x:"8",y:"8",rx:"2",ry:"2",key:"17jyea"}],["path",{d:"M4 16c-1.1 0-2-.9-2-2V4c0-1.1.9-2 2-2h10c1.1 0 2 .9 2 2",key:"zix9uf"}]],Q2=ht("copy",JW);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const eV=[["path",{d:"M12 15V3",key:"m9g1x1"}],["path",{d:"M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4",key:"ih7n3h"}],["path",{d:"m7 10 5 5 5-5",key:"brsn70"}]],bO=ht("download",eV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const tV=[["path",{d:"M7 16.3c2.2 0 4-1.83 4-4.05 0-1.16-.57-2.26-1.71-3.19S7.29 6.75 7 5.3c-.29 1.45-1.14 2.84-2.29 3.76S3 11.1 3 12.25c0 2.22 1.8 4.05 4 4.05z",key:"1ptgy4"}],["path",{d:"M12.56 6.6A10.97 10.97 0 0 0 14 3.02c.5 2.5 2 4.9 4 6.5s3 3.5 3 5.5a6.98 6.98 0 0 1-11.91 4.97",key:"1sl1rz"}]],yO=ht("droplets",tV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const nV=[["circle",{cx:"12",cy:"12",r:"1",key:"41hilf"}],["circle",{cx:"19",cy:"12",r:"1",key:"1wjl8i"}],["circle",{cx:"5",cy:"12",r:"1",key:"1pcz8c"}]],rV=ht("ellipsis",nV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const aV=[["path",{d:"M21 21H8a2 2 0 0 1-1.42-.587l-3.994-3.999a2 2 0 0 1 0-2.828l10-10a2 2 0 0 1 2.829 0l5.999 6a2 2 0 0 1 0 2.828L12.834 21",key:"g5wo59"}],["path",{d:"m5.082 11.09 8.828 8.828",key:"1wx5vj"}]],iV=ht("eraser",aV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const oV=[["path",{d:"M12.5 22H18a2 2 0 0 0 2-2V7l-5-5H6a2 2 0 0 0-2 2v9.5",key:"1couwa"}],["path",{d:"M14 2v4a2 2 0 0 0 2 2h4",key:"tnqrlb"}],["path",{d:"M13.378 15.626a1 1 0 1 0-3.004-3.004l-5.01 5.012a2 2 0 0 0-.506.854l-.837 2.87a.5.5 0 0 0 .62.62l2.87-.837a2 2 0 0 0 .854-.506z",key:"1y4qbx"}]],sV=ht("file-pen",oV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const lV=[["path",{d:"M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z",key:"1rqfz7"}],["path",{d:"M14 2v4a2 2 0 0 0 2 2h4",key:"tnqrlb"}],["path",{d:"M10 9H8",key:"b1mrlr"}],["path",{d:"M16 13H8",key:"t4e002"}],["path",{d:"M16 17H8",key:"z1uh3a"}]],vO=ht("file-text",lV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const cV=[["path",{d:"M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z",key:"1rqfz7"}],["path",{d:"M14 2v4a2 2 0 0 0 2 2h4",key:"tnqrlb"}]],uV=ht("file",cV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const dV=[["path",{d:"M10.7 20H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h3.9a2 2 0 0 1 1.69.9l.81 1.2a2 2 0 0 0 1.67.9H20a2 2 0 0 1 2 2v4.1",key:"1bw5m7"}],["path",{d:"m21 21-1.9-1.9",key:"1g2n9r"}],["circle",{cx:"17",cy:"17",r:"3",key:"18b49y"}]],hV=ht("folder-search",dV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const pV=[["line",{x1:"6",x2:"6",y1:"3",y2:"15",key:"17qcm7"}],["circle",{cx:"18",cy:"6",r:"3",key:"1h7g24"}],["circle",{cx:"6",cy:"18",r:"3",key:"fqmcym"}],["path",{d:"M18 9a9 9 0 0 1-9 9",key:"n2h4wq"}]],fV=ht("git-branch",pV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const mV=[["circle",{cx:"12",cy:"12",r:"10",key:"1mglay"}],["path",{d:"M12 2a14.5 14.5 0 0 0 0 20 14.5 14.5 0 0 0 0-20",key:"13o1zl"}],["path",{d:"M2 12h20",key:"9i4pu4"}]],L6=ht("globe",mV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const gV=[["path",{d:"M16 5h6",key:"1vod17"}],["path",{d:"M19 2v6",key:"4bpg5p"}],["path",{d:"M21 11.5V19a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h7.5",key:"1ue2ih"}],["path",{d:"m21 15-3.086-3.086a2 2 0 0 0-2.828 0L6 21",key:"1xmnt7"}],["circle",{cx:"9",cy:"9",r:"2",key:"af1f0g"}]],bV=ht("image-plus",gV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const yV=[["rect",{width:"18",height:"18",x:"3",y:"3",rx:"2",ry:"2",key:"1m3agn"}],["circle",{cx:"9",cy:"9",r:"2",key:"af1f0g"}],["path",{d:"m21 15-3.086-3.086a2 2 0 0 0-2.828 0L6 21",key:"1xmnt7"}]],xO=ht("image",yV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const vV=[["path",{d:"M21 12a9 9 0 1 1-6.219-8.56",key:"13zald"}]],fu=ht("loader-circle",vV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const xV=[["path",{d:"M20 10c0 4.993-5.539 10.193-7.399 11.799a1 1 0 0 1-1.202 0C9.539 20.193 4 14.993 4 10a8 8 0 0 1 16 0",key:"1r0f0z"}],["circle",{cx:"12",cy:"10",r:"3",key:"ilqhr7"}]],J2=ht("map-pin",xV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const SV=[["path",{d:"M4 12h16",key:"1lakjw"}],["path",{d:"M4 18h16",key:"19g7jn"}],["path",{d:"M4 6h16",key:"1o0s65"}]],wV=ht("menu",SV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const EV=[["path",{d:"M7.9 20A9 9 0 1 0 4 16.1L2 22Z",key:"vv11sd"}]],SO=ht("message-circle",EV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const kV=[["path",{d:"M12 2a3 3 0 0 0-3 3v7a3 3 0 0 0 6 0V5a3 3 0 0 0-3-3Z",key:"131961"}],["path",{d:"M19 10v2a7 7 0 0 1-14 0v-2",key:"1vc78b"}],["line",{x1:"12",x2:"12",y1:"19",y2:"22",key:"x3vr5v"}]],TV=ht("mic",kV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const _V=[["path",{d:"m14.622 17.897-10.68-2.913",key:"vj2p1u"}],["path",{d:"M18.376 2.622a1 1 0 1 1 3.002 3.002L17.36 9.643a.5.5 0 0 0 0 .707l.944.944a2.41 2.41 0 0 1 0 3.408l-.944.944a.5.5 0 0 1-.707 0L8.354 7.348a.5.5 0 0 1 0-.707l.944-.944a2.41 2.41 0 0 1 3.408 0l.944.944a.5.5 0 0 0 .707 0z",key:"18tc5c"}],["path",{d:"M9 8c-1.804 2.71-3.97 3.46-6.583 3.948a.507.507 0 0 0-.302.819l7.32 8.883a1 1 0 0 0 1.185.204C12.735 20.405 16 16.792 16 15",key:"ytzfxy"}]],wO=ht("paintbrush",_V);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const CV=[["path",{d:"m16 6-8.414 8.586a2 2 0 0 0 2.829 2.829l8.414-8.586a4 4 0 1 0-5.657-5.657l-8.379 8.551a6 6 0 1 0 8.485 8.485l8.379-8.551",key:"1miecu"}]],AV=ht("paperclip",CV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const RV=[["path",{d:"M21.174 6.812a1 1 0 0 0-3.986-3.987L3.842 16.174a2 2 0 0 0-.5.83l-1.321 4.352a.5.5 0 0 0 .623.622l4.353-1.32a2 2 0 0 0 .83-.497z",key:"1a8usu"}],["path",{d:"m15 5 4 4",key:"1mk7zo"}]],eS=ht("pencil",RV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const NV=[["path",{d:"M12 17v5",key:"bb1du9"}],["path",{d:"M15 9.34V7a1 1 0 0 1 1-1 2 2 0 0 0 0-4H7.89",key:"znwnzq"}],["path",{d:"m2 2 20 20",key:"1ooewy"}],["path",{d:"M9 9v1.76a2 2 0 0 1-1.11 1.79l-1.78.9A2 2 0 0 0 5 15.24V16a1 1 0 0 0 1 1h11",key:"c9qhm2"}]],OV=ht("pin-off",NV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const IV=[["path",{d:"M12 17v5",key:"bb1du9"}],["path",{d:"M9 10.76a2 2 0 0 1-1.11 1.79l-1.78.9A2 2 0 0 0 5 15.24V16a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-.76a2 2 0 0 0-1.11-1.79l-1.78-.9A2 2 0 0 1 15 10.76V7a1 1 0 0 1 1-1 2 2 0 0 0 0-4H8a2 2 0 0 0 0 4 1 1 0 0 1 1 1z",key:"1nkz8b"}]],D6=ht("pin",IV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const LV=[["path",{d:"M5 12h14",key:"1ays0h"}],["path",{d:"M12 5v14",key:"s699le"}]],tS=ht("plus",LV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const DV=[["path",{d:"m15 14 5-5-5-5",key:"12vg1m"}],["path",{d:"M20 9H9.5A5.5 5.5 0 0 0 4 14.5A5.5 5.5 0 0 0 9.5 20H13",key:"6uklza"}]],MV=ht("redo-2",DV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const BV=[["path",{d:"M3 12a9 9 0 0 1 9-9 9.75 9.75 0 0 1 6.74 2.74L21 8",key:"v9h5vc"}],["path",{d:"M21 3v5h-5",key:"1q7to0"}],["path",{d:"M21 12a9 9 0 0 1-9 9 9.75 9.75 0 0 1-6.74-2.74L3 16",key:"3uifl3"}],["path",{d:"M8 16H3v5",key:"1cv678"}]],FV=ht("refresh-cw",BV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const zV=[["path",{d:"m21 21-4.34-4.34",key:"14j7rj"}],["circle",{cx:"11",cy:"11",r:"8",key:"4ej97u"}]],nS=ht("search",zV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const $V=[["path",{d:"M3.714 3.048a.498.498 0 0 0-.683.627l2.843 7.627a2 2 0 0 1 0 1.396l-2.842 7.627a.498.498 0 0 0 .682.627l18-8.5a.5.5 0 0 0 0-.904z",key:"117uat"}],["path",{d:"M6 12h16",key:"s4cdu5"}]],PV=ht("send-horizontal",$V);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const UV=[["rect",{width:"18",height:"18",x:"3",y:"3",rx:"2",key:"afitv7"}]],rS=ht("square",UV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const jV=[["path",{d:"M12 19h8",key:"baeox8"}],["path",{d:"m4 17 6-6-6-6",key:"1yngyt"}]],HV=ht("terminal",jV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const GV=[["path",{d:"M14 4v10.54a4 4 0 1 1-4 0V4a2 2 0 0 1 4 0Z",key:"17jzev"}]],qV=ht("thermometer",GV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const WV=[["path",{d:"M3 6h18",key:"d0wm0j"}],["path",{d:"M19 6v14c0 1-1 2-2 2H7c-1 0-2-1-2-2V6",key:"4alrt4"}],["path",{d:"M8 6V4c0-1 1-2 2-2h4c1 0 2 1 2 2v2",key:"v07s0e"}],["line",{x1:"10",x2:"10",y1:"11",y2:"17",key:"1uufr5"}],["line",{x1:"14",x2:"14",y1:"11",y2:"17",key:"xtxkd"}]],aS=ht("trash-2",WV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const VV=[["path",{d:"M9 14 4 9l5-5",key:"102s5s"}],["path",{d:"M4 9h10.5a5.5 5.5 0 0 1 5.5 5.5a5.5 5.5 0 0 1-5.5 5.5H11",key:"f3b9sd"}]],YV=ht("undo-2",VV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const XV=[["path",{d:"M19 21v-2a4 4 0 0 0-4-4H9a4 4 0 0 0-4 4v2",key:"975kel"}],["circle",{cx:"12",cy:"7",r:"4",key:"17ys0d"}]],KV=ht("user",XV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const ZV=[["path",{d:"M11 4.702a.705.705 0 0 0-1.203-.498L6.413 7.587A1.4 1.4 0 0 1 5.416 8H3a1 1 0 0 0-1 1v6a1 1 0 0 0 1 1h2.416a1.4 1.4 0 0 1 .997.413l3.383 3.384A.705.705 0 0 0 11 19.298z",key:"uqj9uw"}],["path",{d:"M16 9a5 5 0 0 1 0 6",key:"1q6k2b"}],["path",{d:"M19.364 18.364a9 9 0 0 0 0-12.728",key:"ijwkga"}]],QV=ht("volume-2",ZV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const JV=[["path",{d:"M12.8 19.6A2 2 0 1 0 14 16H2",key:"148xed"}],["path",{d:"M17.5 8a2.5 2.5 0 1 1 2 4H2",key:"1u4tom"}],["path",{d:"M9.8 4.4A2 2 0 1 1 11 8H2",key:"75valh"}]],eY=ht("wind",JV);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const tY=[["path",{d:"M14.7 6.3a1 1 0 0 0 0 1.4l1.6 1.6a1 1 0 0 0 1.4 0l3.77-3.77a6 6 0 0 1-7.94 7.94l-6.91 6.91a2.12 2.12 0 0 1-3-3l6.91-6.91a6 6 0 0 1 7.94-7.94l-3.76 3.76z",key:"cbrjhi"}]],nY=ht("wrench",tY);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const rY=[["path",{d:"M18 6 6 18",key:"1bl5f8"}],["path",{d:"m6 6 12 12",key:"d8bk6v"}]],gl=ht("x",rY);/**
 * @license lucide-react v0.513.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const aY=[["path",{d:"M4 14a1 1 0 0 1-.78-1.63l9.9-10.2a.5.5 0 0 1 .86.46l-1.92 6.02A1 1 0 0 0 13 10h7a1 1 0 0 1 .78 1.63l-9.9 10.2a.5.5 0 0 1-.86-.46l1.92-6.02A1 1 0 0 0 11 14z",key:"1xq2db"}]],iY=ht("zap",aY);function EO(e){var t,n,r="";if(typeof e=="string"||typeof e=="number")r+=e;else if(typeof e=="object")if(Array.isArray(e)){var a=e.length;for(t=0;t<a;t++)e[t]&&(n=EO(e[t]))&&(r&&(r+=" "),r+=n)}else for(n in e)e[n]&&(r&&(r+=" "),r+=n);return r}function kO(){for(var e,t,n=0,r="",a=arguments.length;n<a;n++)(e=arguments[n])&&(t=EO(e))&&(r&&(r+=" "),r+=t);return r}const oY=(e,t)=>{const n=new Array(e.length+t.length);for(let r=0;r<e.length;r++)n[r]=e[r];for(let r=0;r<t.length;r++)n[e.length+r]=t[r];return n},sY=(e,t)=>({classGroupId:e,validator:t}),TO=(e=new Map,t=null,n)=>({nextPart:e,validators:t,classGroupId:n}),Z0="-",M6=[],lY="arbitrary..",cY=e=>{const t=dY(e),{conflictingClassGroups:n,conflictingClassGroupModifiers:r}=e;return{getClassGroupId:o=>{if(o.startsWith("[")&&o.endsWith("]"))return uY(o);const l=o.split(Z0),u=l[0]===""&&l.length>1?1:0;return _O(l,u,t)},getConflictingClassGroupIds:(o,l)=>{if(l){const u=r[o],d=n[o];return u?d?oY(d,u):u:d||M6}return n[o]||M6}}},_O=(e,t,n)=>{if(e.length-t===0)return n.classGroupId;const a=e[t],i=n.nextPart.get(a);if(i){const d=_O(e,t+1,i);if(d)return d}const o=n.validators;if(o===null)return;const l=t===0?e.join(Z0):e.slice(t).join(Z0),u=o.length;for(let d=0;d<u;d++){const h=o[d];if(h.validator(l))return h.classGroupId}},uY=e=>e.slice(1,-1).indexOf(":")===-1?void 0:(()=>{const t=e.slice(1,-1),n=t.indexOf(":"),r=t.slice(0,n);return r?lY+r:void 0})(),dY=e=>{const{theme:t,classGroups:n}=e;return hY(n,t)},hY=(e,t)=>{const n=TO();for(const r in e){const a=e[r];iS(a,n,r,t)}return n},iS=(e,t,n,r)=>{const a=e.length;for(let i=0;i<a;i++){const o=e[i];pY(o,t,n,r)}},pY=(e,t,n,r)=>{if(typeof e=="string"){fY(e,t,n);return}if(typeof e=="function"){mY(e,t,n,r);return}gY(e,t,n,r)},fY=(e,t,n)=>{const r=e===""?t:CO(t,e);r.classGroupId=n},mY=(e,t,n,r)=>{if(bY(e)){iS(e(r),t,n,r);return}t.validators===null&&(t.validators=[]),t.validators.push(sY(n,e))},gY=(e,t,n,r)=>{const a=Object.entries(e),i=a.length;for(let o=0;o<i;o++){const[l,u]=a[o];iS(u,CO(t,l),n,r)}},CO=(e,t)=>{let n=e;const r=t.split(Z0),a=r.length;for(let i=0;i<a;i++){const o=r[i];let l=n.nextPart.get(o);l||(l=TO(),n.nextPart.set(o,l)),n=l}return n},bY=e=>"isThemeGetter"in e&&e.isThemeGetter===!0,yY=e=>{if(e<1)return{get:()=>{},set:()=>{}};let t=0,n=Object.create(null),r=Object.create(null);const a=(i,o)=>{n[i]=o,t++,t>e&&(t=0,r=n,n=Object.create(null))};return{get(i){let o=n[i];if(o!==void 0)return o;if((o=r[i])!==void 0)return a(i,o),o},set(i,o){i in n?n[i]=o:a(i,o)}}},ax="!",B6=":",vY=[],F6=(e,t,n,r,a)=>({modifiers:e,hasImportantModifier:t,baseClassName:n,maybePostfixModifierPosition:r,isExternal:a}),xY=e=>{const{prefix:t,experimentalParseClassName:n}=e;let r=a=>{const i=[];let o=0,l=0,u=0,d;const h=a.length;for(let v=0;v<h;v++){const w=a[v];if(o===0&&l===0){if(w===B6){i.push(a.slice(u,v)),u=v+1;continue}if(w==="/"){d=v;continue}}w==="["?o++:w==="]"?o--:w==="("?l++:w===")"&&l--}const f=i.length===0?a:a.slice(u);let m=f,b=!1;f.endsWith(ax)?(m=f.slice(0,-1),b=!0):f.startsWith(ax)&&(m=f.slice(1),b=!0);const y=d&&d>u?d-u:void 0;return F6(i,b,m,y)};if(t){const a=t+B6,i=r;r=o=>o.startsWith(a)?i(o.slice(a.length)):F6(vY,!1,o,void 0,!0)}if(n){const a=r;r=i=>n({className:i,parseClassName:a})}return r},SY=e=>{const t=new Map;return e.orderSensitiveModifiers.forEach((n,r)=>{t.set(n,1e6+r)}),n=>{const r=[];let a=[];for(let i=0;i<n.length;i++){const o=n[i],l=o[0]==="[",u=t.has(o);l||u?(a.length>0&&(a.sort(),r.push(...a),a=[]),r.push(o)):a.push(o)}return a.length>0&&(a.sort(),r.push(...a)),r}},wY=e=>({cache:yY(e.cacheSize),parseClassName:xY(e),sortModifiers:SY(e),...cY(e)}),EY=/\s+/,kY=(e,t)=>{const{parseClassName:n,getClassGroupId:r,getConflictingClassGroupIds:a,sortModifiers:i}=t,o=[],l=e.trim().split(EY);let u="";for(let d=l.length-1;d>=0;d-=1){const h=l[d],{isExternal:f,modifiers:m,hasImportantModifier:b,baseClassName:y,maybePostfixModifierPosition:v}=n(h);if(f){u=h+(u.length>0?" "+u:u);continue}let w=!!v,S=r(w?y.substring(0,v):y);if(!S){if(!w){u=h+(u.length>0?" "+u:u);continue}if(S=r(y),!S){u=h+(u.length>0?" "+u:u);continue}w=!1}const k=m.length===0?"":m.length===1?m[0]:i(m).join(":"),R=b?k+ax:k,I=R+S;if(o.indexOf(I)>-1)continue;o.push(I);const L=a(S,w);for(let A=0;A<L.length;++A){const M=L[A];o.push(R+M)}u=h+(u.length>0?" "+u:u)}return u},TY=(...e)=>{let t=0,n,r,a="";for(;t<e.length;)(n=e[t++])&&(r=AO(n))&&(a&&(a+=" "),a+=r);return a},AO=e=>{if(typeof e=="string")return e;let t,n="";for(let r=0;r<e.length;r++)e[r]&&(t=AO(e[r]))&&(n&&(n+=" "),n+=t);return n},_Y=(e,...t)=>{let n,r,a,i;const o=u=>{const d=t.reduce((h,f)=>f(h),e());return n=wY(d),r=n.cache.get,a=n.cache.set,i=l,l(u)},l=u=>{const d=r(u);if(d)return d;const h=kY(u,n);return a(u,h),h};return i=o,(...u)=>i(TY(...u))},CY=[],Wn=e=>{const t=n=>n[e]||CY;return t.isThemeGetter=!0,t},RO=/^\[(?:(\w[\w-]*):)?(.+)\]$/i,NO=/^\((?:(\w[\w-]*):)?(.+)\)$/i,AY=/^\d+(?:\.\d+)?\/\d+(?:\.\d+)?$/,RY=/^(\d+(\.\d+)?)?(xs|sm|md|lg|xl)$/,NY=/\d+(%|px|r?em|[sdl]?v([hwib]|min|max)|pt|pc|in|cm|mm|cap|ch|ex|r?lh|cq(w|h|i|b|min|max))|\b(calc|min|max|clamp)\(.+\)|^0$/,OY=/^(rgba?|hsla?|hwb|(ok)?(lab|lch)|color-mix)\(.+\)$/,IY=/^(inset_)?-?((\d+)?\.?(\d+)[a-z]+|0)_-?((\d+)?\.?(\d+)[a-z]+|0)/,LY=/^(url|image|image-set|cross-fade|element|(repeating-)?(linear|radial|conic)-gradient)\(.+\)$/,ss=e=>AY.test(e),_t=e=>!!e&&!Number.isNaN(Number(e)),ls=e=>!!e&&Number.isInteger(Number(e)),$1=e=>e.endsWith("%")&&_t(e.slice(0,-1)),ho=e=>RY.test(e),OO=()=>!0,DY=e=>NY.test(e)&&!OY.test(e),oS=()=>!1,MY=e=>IY.test(e),BY=e=>LY.test(e),FY=e=>!je(e)&&!He(e),zY=e=>Ns(e,DO,oS),je=e=>RO.test(e),el=e=>Ns(e,MO,DY),z6=e=>Ns(e,WY,_t),$Y=e=>Ns(e,FO,OO),PY=e=>Ns(e,BO,oS),$6=e=>Ns(e,IO,oS),UY=e=>Ns(e,LO,BY),Gf=e=>Ns(e,zO,MY),He=e=>NO.test(e),Ld=e=>Cl(e,MO),jY=e=>Cl(e,BO),P6=e=>Cl(e,IO),HY=e=>Cl(e,DO),GY=e=>Cl(e,LO),qf=e=>Cl(e,zO,!0),qY=e=>Cl(e,FO,!0),Ns=(e,t,n)=>{const r=RO.exec(e);return r?r[1]?t(r[1]):n(r[2]):!1},Cl=(e,t,n=!1)=>{const r=NO.exec(e);return r?r[1]?t(r[1]):n:!1},IO=e=>e==="position"||e==="percentage",LO=e=>e==="image"||e==="url",DO=e=>e==="length"||e==="size"||e==="bg-size",MO=e=>e==="length",WY=e=>e==="number",BO=e=>e==="family-name",FO=e=>e==="number"||e==="weight",zO=e=>e==="shadow",VY=()=>{const e=Wn("color"),t=Wn("font"),n=Wn("text"),r=Wn("font-weight"),a=Wn("tracking"),i=Wn("leading"),o=Wn("breakpoint"),l=Wn("container"),u=Wn("spacing"),d=Wn("radius"),h=Wn("shadow"),f=Wn("inset-shadow"),m=Wn("text-shadow"),b=Wn("drop-shadow"),y=Wn("blur"),v=Wn("perspective"),w=Wn("aspect"),S=Wn("ease"),k=Wn("animate"),R=()=>["auto","avoid","all","avoid-page","page","left","right","column"],I=()=>["center","top","bottom","left","right","top-left","left-top","top-right","right-top","bottom-right","right-bottom","bottom-left","left-bottom"],L=()=>[...I(),He,je],A=()=>["auto","hidden","clip","visible","scroll"],M=()=>["auto","contain","none"],P=()=>[He,je,u],G=()=>[ss,"full","auto",...P()],B=()=>[ls,"none","subgrid",He,je],H=()=>["auto",{span:["full",ls,He,je]},ls,He,je],Z=()=>[ls,"auto",He,je],V=()=>["auto","min","max","fr",He,je],q=()=>["start","end","center","between","around","evenly","stretch","baseline","center-safe","end-safe"],X=()=>["start","end","center","stretch","center-safe","end-safe"],$=()=>["auto",...P()],Q=()=>[ss,"auto","full","dvw","dvh","lvw","lvh","svw","svh","min","max","fit",...P()],J=()=>[ss,"screen","full","dvw","lvw","svw","min","max","fit",...P()],ie=()=>[ss,"screen","full","lh","dvh","lvh","svh","min","max","fit",...P()],F=()=>[e,He,je],Y=()=>[...I(),P6,$6,{position:[He,je]}],oe=()=>["no-repeat",{repeat:["","x","y","space","round"]}],U=()=>["auto","cover","contain",HY,zY,{size:[He,je]}],be=()=>[$1,Ld,el],ge=()=>["","none","full",d,He,je],fe=()=>["",_t,Ld,el],Ee=()=>["solid","dashed","dotted","double"],Ae=()=>["normal","multiply","screen","overlay","darken","lighten","color-dodge","color-burn","hard-light","soft-light","difference","exclusion","hue","saturation","color","luminosity"],ve=()=>[_t,$1,P6,$6],De=()=>["","none",y,He,je],Le=()=>["none",_t,He,je],rt=()=>["none",_t,He,je],Xe=()=>[_t,He,je],gt=()=>[ss,"full",...P()];return{cacheSize:500,theme:{animate:["spin","ping","pulse","bounce"],aspect:["video"],blur:[ho],breakpoint:[ho],color:[OO],container:[ho],"drop-shadow":[ho],ease:["in","out","in-out"],font:[FY],"font-weight":["thin","extralight","light","normal","medium","semibold","bold","extrabold","black"],"inset-shadow":[ho],leading:["none","tight","snug","normal","relaxed","loose"],perspective:["dramatic","near","normal","midrange","distant","none"],radius:[ho],shadow:[ho],spacing:["px",_t],text:[ho],"text-shadow":[ho],tracking:["tighter","tight","normal","wide","wider","widest"]},classGroups:{aspect:[{aspect:["auto","square",ss,je,He,w]}],container:["container"],columns:[{columns:[_t,je,He,l]}],"break-after":[{"break-after":R()}],"break-before":[{"break-before":R()}],"break-inside":[{"break-inside":["auto","avoid","avoid-page","avoid-column"]}],"box-decoration":[{"box-decoration":["slice","clone"]}],box:[{box:["border","content"]}],display:["block","inline-block","inline","flex","inline-flex","table","inline-table","table-caption","table-cell","table-column","table-column-group","table-footer-group","table-header-group","table-row-group","table-row","flow-root","grid","inline-grid","contents","list-item","hidden"],sr:["sr-only","not-sr-only"],float:[{float:["right","left","none","start","end"]}],clear:[{clear:["left","right","both","none","start","end"]}],isolation:["isolate","isolation-auto"],"object-fit":[{object:["contain","cover","fill","none","scale-down"]}],"object-position":[{object:L()}],overflow:[{overflow:A()}],"overflow-x":[{"overflow-x":A()}],"overflow-y":[{"overflow-y":A()}],overscroll:[{overscroll:M()}],"overscroll-x":[{"overscroll-x":M()}],"overscroll-y":[{"overscroll-y":M()}],position:["static","fixed","absolute","relative","sticky"],inset:[{inset:G()}],"inset-x":[{"inset-x":G()}],"inset-y":[{"inset-y":G()}],start:[{"inset-s":G(),start:G()}],end:[{"inset-e":G(),end:G()}],"inset-bs":[{"inset-bs":G()}],"inset-be":[{"inset-be":G()}],top:[{top:G()}],right:[{right:G()}],bottom:[{bottom:G()}],left:[{left:G()}],visibility:["visible","invisible","collapse"],z:[{z:[ls,"auto",He,je]}],basis:[{basis:[ss,"full","auto",l,...P()]}],"flex-direction":[{flex:["row","row-reverse","col","col-reverse"]}],"flex-wrap":[{flex:["nowrap","wrap","wrap-reverse"]}],flex:[{flex:[_t,ss,"auto","initial","none",je]}],grow:[{grow:["",_t,He,je]}],shrink:[{shrink:["",_t,He,je]}],order:[{order:[ls,"first","last","none",He,je]}],"grid-cols":[{"grid-cols":B()}],"col-start-end":[{col:H()}],"col-start":[{"col-start":Z()}],"col-end":[{"col-end":Z()}],"grid-rows":[{"grid-rows":B()}],"row-start-end":[{row:H()}],"row-start":[{"row-start":Z()}],"row-end":[{"row-end":Z()}],"grid-flow":[{"grid-flow":["row","col","dense","row-dense","col-dense"]}],"auto-cols":[{"auto-cols":V()}],"auto-rows":[{"auto-rows":V()}],gap:[{gap:P()}],"gap-x":[{"gap-x":P()}],"gap-y":[{"gap-y":P()}],"justify-content":[{justify:[...q(),"normal"]}],"justify-items":[{"justify-items":[...X(),"normal"]}],"justify-self":[{"justify-self":["auto",...X()]}],"align-content":[{content:["normal",...q()]}],"align-items":[{items:[...X(),{baseline:["","last"]}]}],"align-self":[{self:["auto",...X(),{baseline:["","last"]}]}],"place-content":[{"place-content":q()}],"place-items":[{"place-items":[...X(),"baseline"]}],"place-self":[{"place-self":["auto",...X()]}],p:[{p:P()}],px:[{px:P()}],py:[{py:P()}],ps:[{ps:P()}],pe:[{pe:P()}],pbs:[{pbs:P()}],pbe:[{pbe:P()}],pt:[{pt:P()}],pr:[{pr:P()}],pb:[{pb:P()}],pl:[{pl:P()}],m:[{m:$()}],mx:[{mx:$()}],my:[{my:$()}],ms:[{ms:$()}],me:[{me:$()}],mbs:[{mbs:$()}],mbe:[{mbe:$()}],mt:[{mt:$()}],mr:[{mr:$()}],mb:[{mb:$()}],ml:[{ml:$()}],"space-x":[{"space-x":P()}],"space-x-reverse":["space-x-reverse"],"space-y":[{"space-y":P()}],"space-y-reverse":["space-y-reverse"],size:[{size:Q()}],"inline-size":[{inline:["auto",...J()]}],"min-inline-size":[{"min-inline":["auto",...J()]}],"max-inline-size":[{"max-inline":["none",...J()]}],"block-size":[{block:["auto",...ie()]}],"min-block-size":[{"min-block":["auto",...ie()]}],"max-block-size":[{"max-block":["none",...ie()]}],w:[{w:[l,"screen",...Q()]}],"min-w":[{"min-w":[l,"screen","none",...Q()]}],"max-w":[{"max-w":[l,"screen","none","prose",{screen:[o]},...Q()]}],h:[{h:["screen","lh",...Q()]}],"min-h":[{"min-h":["screen","lh","none",...Q()]}],"max-h":[{"max-h":["screen","lh",...Q()]}],"font-size":[{text:["base",n,Ld,el]}],"font-smoothing":["antialiased","subpixel-antialiased"],"font-style":["italic","not-italic"],"font-weight":[{font:[r,qY,$Y]}],"font-stretch":[{"font-stretch":["ultra-condensed","extra-condensed","condensed","semi-condensed","normal","semi-expanded","expanded","extra-expanded","ultra-expanded",$1,je]}],"font-family":[{font:[jY,PY,t]}],"font-features":[{"font-features":[je]}],"fvn-normal":["normal-nums"],"fvn-ordinal":["ordinal"],"fvn-slashed-zero":["slashed-zero"],"fvn-figure":["lining-nums","oldstyle-nums"],"fvn-spacing":["proportional-nums","tabular-nums"],"fvn-fraction":["diagonal-fractions","stacked-fractions"],tracking:[{tracking:[a,He,je]}],"line-clamp":[{"line-clamp":[_t,"none",He,z6]}],leading:[{leading:[i,...P()]}],"list-image":[{"list-image":["none",He,je]}],"list-style-position":[{list:["inside","outside"]}],"list-style-type":[{list:["disc","decimal","none",He,je]}],"text-alignment":[{text:["left","center","right","justify","start","end"]}],"placeholder-color":[{placeholder:F()}],"text-color":[{text:F()}],"text-decoration":["underline","overline","line-through","no-underline"],"text-decoration-style":[{decoration:[...Ee(),"wavy"]}],"text-decoration-thickness":[{decoration:[_t,"from-font","auto",He,el]}],"text-decoration-color":[{decoration:F()}],"underline-offset":[{"underline-offset":[_t,"auto",He,je]}],"text-transform":["uppercase","lowercase","capitalize","normal-case"],"text-overflow":["truncate","text-ellipsis","text-clip"],"text-wrap":[{text:["wrap","nowrap","balance","pretty"]}],indent:[{indent:P()}],"vertical-align":[{align:["baseline","top","middle","bottom","text-top","text-bottom","sub","super",He,je]}],whitespace:[{whitespace:["normal","nowrap","pre","pre-line","pre-wrap","break-spaces"]}],break:[{break:["normal","words","all","keep"]}],wrap:[{wrap:["break-word","anywhere","normal"]}],hyphens:[{hyphens:["none","manual","auto"]}],content:[{content:["none",He,je]}],"bg-attachment":[{bg:["fixed","local","scroll"]}],"bg-clip":[{"bg-clip":["border","padding","content","text"]}],"bg-origin":[{"bg-origin":["border","padding","content"]}],"bg-position":[{bg:Y()}],"bg-repeat":[{bg:oe()}],"bg-size":[{bg:U()}],"bg-image":[{bg:["none",{linear:[{to:["t","tr","r","br","b","bl","l","tl"]},ls,He,je],radial:["",He,je],conic:[ls,He,je]},GY,UY]}],"bg-color":[{bg:F()}],"gradient-from-pos":[{from:be()}],"gradient-via-pos":[{via:be()}],"gradient-to-pos":[{to:be()}],"gradient-from":[{from:F()}],"gradient-via":[{via:F()}],"gradient-to":[{to:F()}],rounded:[{rounded:ge()}],"rounded-s":[{"rounded-s":ge()}],"rounded-e":[{"rounded-e":ge()}],"rounded-t":[{"rounded-t":ge()}],"rounded-r":[{"rounded-r":ge()}],"rounded-b":[{"rounded-b":ge()}],"rounded-l":[{"rounded-l":ge()}],"rounded-ss":[{"rounded-ss":ge()}],"rounded-se":[{"rounded-se":ge()}],"rounded-ee":[{"rounded-ee":ge()}],"rounded-es":[{"rounded-es":ge()}],"rounded-tl":[{"rounded-tl":ge()}],"rounded-tr":[{"rounded-tr":ge()}],"rounded-br":[{"rounded-br":ge()}],"rounded-bl":[{"rounded-bl":ge()}],"border-w":[{border:fe()}],"border-w-x":[{"border-x":fe()}],"border-w-y":[{"border-y":fe()}],"border-w-s":[{"border-s":fe()}],"border-w-e":[{"border-e":fe()}],"border-w-bs":[{"border-bs":fe()}],"border-w-be":[{"border-be":fe()}],"border-w-t":[{"border-t":fe()}],"border-w-r":[{"border-r":fe()}],"border-w-b":[{"border-b":fe()}],"border-w-l":[{"border-l":fe()}],"divide-x":[{"divide-x":fe()}],"divide-x-reverse":["divide-x-reverse"],"divide-y":[{"divide-y":fe()}],"divide-y-reverse":["divide-y-reverse"],"border-style":[{border:[...Ee(),"hidden","none"]}],"divide-style":[{divide:[...Ee(),"hidden","none"]}],"border-color":[{border:F()}],"border-color-x":[{"border-x":F()}],"border-color-y":[{"border-y":F()}],"border-color-s":[{"border-s":F()}],"border-color-e":[{"border-e":F()}],"border-color-bs":[{"border-bs":F()}],"border-color-be":[{"border-be":F()}],"border-color-t":[{"border-t":F()}],"border-color-r":[{"border-r":F()}],"border-color-b":[{"border-b":F()}],"border-color-l":[{"border-l":F()}],"divide-color":[{divide:F()}],"outline-style":[{outline:[...Ee(),"none","hidden"]}],"outline-offset":[{"outline-offset":[_t,He,je]}],"outline-w":[{outline:["",_t,Ld,el]}],"outline-color":[{outline:F()}],shadow:[{shadow:["","none",h,qf,Gf]}],"shadow-color":[{shadow:F()}],"inset-shadow":[{"inset-shadow":["none",f,qf,Gf]}],"inset-shadow-color":[{"inset-shadow":F()}],"ring-w":[{ring:fe()}],"ring-w-inset":["ring-inset"],"ring-color":[{ring:F()}],"ring-offset-w":[{"ring-offset":[_t,el]}],"ring-offset-color":[{"ring-offset":F()}],"inset-ring-w":[{"inset-ring":fe()}],"inset-ring-color":[{"inset-ring":F()}],"text-shadow":[{"text-shadow":["none",m,qf,Gf]}],"text-shadow-color":[{"text-shadow":F()}],opacity:[{opacity:[_t,He,je]}],"mix-blend":[{"mix-blend":[...Ae(),"plus-darker","plus-lighter"]}],"bg-blend":[{"bg-blend":Ae()}],"mask-clip":[{"mask-clip":["border","padding","content","fill","stroke","view"]},"mask-no-clip"],"mask-composite":[{mask:["add","subtract","intersect","exclude"]}],"mask-image-linear-pos":[{"mask-linear":[_t]}],"mask-image-linear-from-pos":[{"mask-linear-from":ve()}],"mask-image-linear-to-pos":[{"mask-linear-to":ve()}],"mask-image-linear-from-color":[{"mask-linear-from":F()}],"mask-image-linear-to-color":[{"mask-linear-to":F()}],"mask-image-t-from-pos":[{"mask-t-from":ve()}],"mask-image-t-to-pos":[{"mask-t-to":ve()}],"mask-image-t-from-color":[{"mask-t-from":F()}],"mask-image-t-to-color":[{"mask-t-to":F()}],"mask-image-r-from-pos":[{"mask-r-from":ve()}],"mask-image-r-to-pos":[{"mask-r-to":ve()}],"mask-image-r-from-color":[{"mask-r-from":F()}],"mask-image-r-to-color":[{"mask-r-to":F()}],"mask-image-b-from-pos":[{"mask-b-from":ve()}],"mask-image-b-to-pos":[{"mask-b-to":ve()}],"mask-image-b-from-color":[{"mask-b-from":F()}],"mask-image-b-to-color":[{"mask-b-to":F()}],"mask-image-l-from-pos":[{"mask-l-from":ve()}],"mask-image-l-to-pos":[{"mask-l-to":ve()}],"mask-image-l-from-color":[{"mask-l-from":F()}],"mask-image-l-to-color":[{"mask-l-to":F()}],"mask-image-x-from-pos":[{"mask-x-from":ve()}],"mask-image-x-to-pos":[{"mask-x-to":ve()}],"mask-image-x-from-color":[{"mask-x-from":F()}],"mask-image-x-to-color":[{"mask-x-to":F()}],"mask-image-y-from-pos":[{"mask-y-from":ve()}],"mask-image-y-to-pos":[{"mask-y-to":ve()}],"mask-image-y-from-color":[{"mask-y-from":F()}],"mask-image-y-to-color":[{"mask-y-to":F()}],"mask-image-radial":[{"mask-radial":[He,je]}],"mask-image-radial-from-pos":[{"mask-radial-from":ve()}],"mask-image-radial-to-pos":[{"mask-radial-to":ve()}],"mask-image-radial-from-color":[{"mask-radial-from":F()}],"mask-image-radial-to-color":[{"mask-radial-to":F()}],"mask-image-radial-shape":[{"mask-radial":["circle","ellipse"]}],"mask-image-radial-size":[{"mask-radial":[{closest:["side","corner"],farthest:["side","corner"]}]}],"mask-image-radial-pos":[{"mask-radial-at":I()}],"mask-image-conic-pos":[{"mask-conic":[_t]}],"mask-image-conic-from-pos":[{"mask-conic-from":ve()}],"mask-image-conic-to-pos":[{"mask-conic-to":ve()}],"mask-image-conic-from-color":[{"mask-conic-from":F()}],"mask-image-conic-to-color":[{"mask-conic-to":F()}],"mask-mode":[{mask:["alpha","luminance","match"]}],"mask-origin":[{"mask-origin":["border","padding","content","fill","stroke","view"]}],"mask-position":[{mask:Y()}],"mask-repeat":[{mask:oe()}],"mask-size":[{mask:U()}],"mask-type":[{"mask-type":["alpha","luminance"]}],"mask-image":[{mask:["none",He,je]}],filter:[{filter:["","none",He,je]}],blur:[{blur:De()}],brightness:[{brightness:[_t,He,je]}],contrast:[{contrast:[_t,He,je]}],"drop-shadow":[{"drop-shadow":["","none",b,qf,Gf]}],"drop-shadow-color":[{"drop-shadow":F()}],grayscale:[{grayscale:["",_t,He,je]}],"hue-rotate":[{"hue-rotate":[_t,He,je]}],invert:[{invert:["",_t,He,je]}],saturate:[{saturate:[_t,He,je]}],sepia:[{sepia:["",_t,He,je]}],"backdrop-filter":[{"backdrop-filter":["","none",He,je]}],"backdrop-blur":[{"backdrop-blur":De()}],"backdrop-brightness":[{"backdrop-brightness":[_t,He,je]}],"backdrop-contrast":[{"backdrop-contrast":[_t,He,je]}],"backdrop-grayscale":[{"backdrop-grayscale":["",_t,He,je]}],"backdrop-hue-rotate":[{"backdrop-hue-rotate":[_t,He,je]}],"backdrop-invert":[{"backdrop-invert":["",_t,He,je]}],"backdrop-opacity":[{"backdrop-opacity":[_t,He,je]}],"backdrop-saturate":[{"backdrop-saturate":[_t,He,je]}],"backdrop-sepia":[{"backdrop-sepia":["",_t,He,je]}],"border-collapse":[{border:["collapse","separate"]}],"border-spacing":[{"border-spacing":P()}],"border-spacing-x":[{"border-spacing-x":P()}],"border-spacing-y":[{"border-spacing-y":P()}],"table-layout":[{table:["auto","fixed"]}],caption:[{caption:["top","bottom"]}],transition:[{transition:["","all","colors","opacity","shadow","transform","none",He,je]}],"transition-behavior":[{transition:["normal","discrete"]}],duration:[{duration:[_t,"initial",He,je]}],ease:[{ease:["linear","initial",S,He,je]}],delay:[{delay:[_t,He,je]}],animate:[{animate:["none",k,He,je]}],backface:[{backface:["hidden","visible"]}],perspective:[{perspective:[v,He,je]}],"perspective-origin":[{"perspective-origin":L()}],rotate:[{rotate:Le()}],"rotate-x":[{"rotate-x":Le()}],"rotate-y":[{"rotate-y":Le()}],"rotate-z":[{"rotate-z":Le()}],scale:[{scale:rt()}],"scale-x":[{"scale-x":rt()}],"scale-y":[{"scale-y":rt()}],"scale-z":[{"scale-z":rt()}],"scale-3d":["scale-3d"],skew:[{skew:Xe()}],"skew-x":[{"skew-x":Xe()}],"skew-y":[{"skew-y":Xe()}],transform:[{transform:[He,je,"","none","gpu","cpu"]}],"transform-origin":[{origin:L()}],"transform-style":[{transform:["3d","flat"]}],translate:[{translate:gt()}],"translate-x":[{"translate-x":gt()}],"translate-y":[{"translate-y":gt()}],"translate-z":[{"translate-z":gt()}],"translate-none":["translate-none"],accent:[{accent:F()}],appearance:[{appearance:["none","auto"]}],"caret-color":[{caret:F()}],"color-scheme":[{scheme:["normal","dark","light","light-dark","only-dark","only-light"]}],cursor:[{cursor:["auto","default","pointer","wait","text","move","help","not-allowed","none","context-menu","progress","cell","crosshair","vertical-text","alias","copy","no-drop","grab","grabbing","all-scroll","col-resize","row-resize","n-resize","e-resize","s-resize","w-resize","ne-resize","nw-resize","se-resize","sw-resize","ew-resize","ns-resize","nesw-resize","nwse-resize","zoom-in","zoom-out",He,je]}],"field-sizing":[{"field-sizing":["fixed","content"]}],"pointer-events":[{"pointer-events":["auto","none"]}],resize:[{resize:["none","","y","x"]}],"scroll-behavior":[{scroll:["auto","smooth"]}],"scroll-m":[{"scroll-m":P()}],"scroll-mx":[{"scroll-mx":P()}],"scroll-my":[{"scroll-my":P()}],"scroll-ms":[{"scroll-ms":P()}],"scroll-me":[{"scroll-me":P()}],"scroll-mbs":[{"scroll-mbs":P()}],"scroll-mbe":[{"scroll-mbe":P()}],"scroll-mt":[{"scroll-mt":P()}],"scroll-mr":[{"scroll-mr":P()}],"scroll-mb":[{"scroll-mb":P()}],"scroll-ml":[{"scroll-ml":P()}],"scroll-p":[{"scroll-p":P()}],"scroll-px":[{"scroll-px":P()}],"scroll-py":[{"scroll-py":P()}],"scroll-ps":[{"scroll-ps":P()}],"scroll-pe":[{"scroll-pe":P()}],"scroll-pbs":[{"scroll-pbs":P()}],"scroll-pbe":[{"scroll-pbe":P()}],"scroll-pt":[{"scroll-pt":P()}],"scroll-pr":[{"scroll-pr":P()}],"scroll-pb":[{"scroll-pb":P()}],"scroll-pl":[{"scroll-pl":P()}],"snap-align":[{snap:["start","end","center","align-none"]}],"snap-stop":[{snap:["normal","always"]}],"snap-type":[{snap:["none","x","y","both"]}],"snap-strictness":[{snap:["mandatory","proximity"]}],touch:[{touch:["auto","none","manipulation"]}],"touch-x":[{"touch-pan":["x","left","right"]}],"touch-y":[{"touch-pan":["y","up","down"]}],"touch-pz":["touch-pinch-zoom"],select:[{select:["none","text","all","auto"]}],"will-change":[{"will-change":["auto","scroll","contents","transform",He,je]}],fill:[{fill:["none",...F()]}],"stroke-w":[{stroke:[_t,Ld,el,z6]}],stroke:[{stroke:["none",...F()]}],"forced-color-adjust":[{"forced-color-adjust":["auto","none"]}]},conflictingClassGroups:{overflow:["overflow-x","overflow-y"],overscroll:["overscroll-x","overscroll-y"],inset:["inset-x","inset-y","inset-bs","inset-be","start","end","top","right","bottom","left"],"inset-x":["right","left"],"inset-y":["top","bottom"],flex:["basis","grow","shrink"],gap:["gap-x","gap-y"],p:["px","py","ps","pe","pbs","pbe","pt","pr","pb","pl"],px:["pr","pl"],py:["pt","pb"],m:["mx","my","ms","me","mbs","mbe","mt","mr","mb","ml"],mx:["mr","ml"],my:["mt","mb"],size:["w","h"],"font-size":["leading"],"fvn-normal":["fvn-ordinal","fvn-slashed-zero","fvn-figure","fvn-spacing","fvn-fraction"],"fvn-ordinal":["fvn-normal"],"fvn-slashed-zero":["fvn-normal"],"fvn-figure":["fvn-normal"],"fvn-spacing":["fvn-normal"],"fvn-fraction":["fvn-normal"],"line-clamp":["display","overflow"],rounded:["rounded-s","rounded-e","rounded-t","rounded-r","rounded-b","rounded-l","rounded-ss","rounded-se","rounded-ee","rounded-es","rounded-tl","rounded-tr","rounded-br","rounded-bl"],"rounded-s":["rounded-ss","rounded-es"],"rounded-e":["rounded-se","rounded-ee"],"rounded-t":["rounded-tl","rounded-tr"],"rounded-r":["rounded-tr","rounded-br"],"rounded-b":["rounded-br","rounded-bl"],"rounded-l":["rounded-tl","rounded-bl"],"border-spacing":["border-spacing-x","border-spacing-y"],"border-w":["border-w-x","border-w-y","border-w-s","border-w-e","border-w-bs","border-w-be","border-w-t","border-w-r","border-w-b","border-w-l"],"border-w-x":["border-w-r","border-w-l"],"border-w-y":["border-w-t","border-w-b"],"border-color":["border-color-x","border-color-y","border-color-s","border-color-e","border-color-bs","border-color-be","border-color-t","border-color-r","border-color-b","border-color-l"],"border-color-x":["border-color-r","border-color-l"],"border-color-y":["border-color-t","border-color-b"],translate:["translate-x","translate-y","translate-none"],"translate-none":["translate","translate-x","translate-y","translate-z"],"scroll-m":["scroll-mx","scroll-my","scroll-ms","scroll-me","scroll-mbs","scroll-mbe","scroll-mt","scroll-mr","scroll-mb","scroll-ml"],"scroll-mx":["scroll-mr","scroll-ml"],"scroll-my":["scroll-mt","scroll-mb"],"scroll-p":["scroll-px","scroll-py","scroll-ps","scroll-pe","scroll-pbs","scroll-pbe","scroll-pt","scroll-pr","scroll-pb","scroll-pl"],"scroll-px":["scroll-pr","scroll-pl"],"scroll-py":["scroll-pt","scroll-pb"],touch:["touch-x","touch-y","touch-pz"],"touch-x":["touch"],"touch-y":["touch"],"touch-pz":["touch"]},conflictingClassGroupModifiers:{"font-size":["leading"]},orderSensitiveModifiers:["*","**","after","backdrop","before","details-content","file","first-letter","first-line","marker","placeholder","selection"]}},YY=_Y(VY);function st(...e){return YY(kO(e))}function U6({enabled:e,onToggle:t}){return T.jsxs("button",{type:"button",onClick:()=>t(!e),className:st("flex items-center gap-1 rounded-md px-1.5 h-6 text-xs transition-colors",e?"bg-blue-500/10 text-blue-500 hover:bg-blue-500/20":"text-muted-foreground/60 hover:text-muted-foreground"),title:e?"Background Responses: ON":"Background Responses: OFF","aria-label":e?"Disable background responses":"Enable background responses",children:[T.jsx(iY,{className:"h-3 w-3"}),T.jsx("span",{children:"BG"})]})}function XY({attachments:e,onRemove:t}){return e.length===0?null:T.jsx("div",{className:"flex gap-2 overflow-x-auto px-3 pt-2 pb-1",children:e.map(n=>T.jsxs("div",{className:"group/thumb relative shrink-0",children:[T.jsxs("div",{className:st("h-16 w-16 overflow-hidden rounded-lg border",n.status==="error"&&"border-destructive"),children:[T.jsx("img",{src:n.previewUrl,alt:n.file.name,className:"h-full w-full object-cover"}),n.status==="uploading"&&T.jsx("div",{className:"absolute inset-0 flex items-center justify-center bg-background/60",children:T.jsx(fu,{className:"h-4 w-4 animate-spin"})})]}),T.jsx("button",{type:"button",onClick:()=>t(n.id),className:st("absolute -right-1.5 -top-1.5 flex h-5 w-5 items-center justify-center","rounded-full bg-foreground text-background","opacity-0 transition-opacity group-hover/thumb:opacity-100"),"aria-label":`Remove ${n.file.name}`,children:T.jsx(gl,{className:"h-3 w-3"})})]},n.id))})}function j6(e,t){if(typeof e=="function")return e(t);e!=null&&(e.current=t)}function Xh(...e){return t=>{let n=!1;const r=e.map(a=>{const i=j6(a,t);return!n&&typeof i=="function"&&(n=!0),i});if(n)return()=>{for(let a=0;a<r.length;a++){const i=r[a];typeof i=="function"?i():j6(e[a],null)}}}}function un(...e){return _.useCallback(Xh(...e),e)}var KY=Symbol.for("react.lazy"),Q0=j2[" use ".trim().toString()];function ZY(e){return typeof e=="object"&&e!==null&&"then"in e}function $O(e){return e!=null&&typeof e=="object"&&"$$typeof"in e&&e.$$typeof===KY&&"_payload"in e&&ZY(e._payload)}function PO(e){const t=JY(e),n=_.forwardRef((r,a)=>{let{children:i,...o}=r;$O(i)&&typeof Q0=="function"&&(i=Q0(i._payload));const l=_.Children.toArray(i),u=l.find(tX);if(u){const d=u.props.children,h=l.map(f=>f===u?_.Children.count(d)>1?_.Children.only(null):_.isValidElement(d)?d.props.children:null:f);return T.jsx(t,{...o,ref:a,children:_.isValidElement(d)?_.cloneElement(d,void 0,h):null})}return T.jsx(t,{...o,ref:a,children:i})});return n.displayName=`${e}.Slot`,n}var QY=PO("Slot");function JY(e){const t=_.forwardRef((n,r)=>{let{children:a,...i}=n;if($O(a)&&typeof Q0=="function"&&(a=Q0(a._payload)),_.isValidElement(a)){const o=rX(a),l=nX(i,a.props);return a.type!==_.Fragment&&(l.ref=r?Xh(r,o):o),_.cloneElement(a,l)}return _.Children.count(a)>1?_.Children.only(null):null});return t.displayName=`${e}.SlotClone`,t}var eX=Symbol("radix.slottable");function tX(e){return _.isValidElement(e)&&typeof e.type=="function"&&"__radixId"in e.type&&e.type.__radixId===eX}function nX(e,t){const n={...t};for(const r in t){const a=e[r],i=t[r];/^on[A-Z]/.test(r)?a&&i?n[r]=(...l)=>{const u=i(...l);return a(...l),u}:a&&(n[r]=a):r==="style"?n[r]={...a,...i}:r==="className"&&(n[r]=[a,i].filter(Boolean).join(" "))}return{...e,...n}}function rX(e){var r,a;let t=(r=Object.getOwnPropertyDescriptor(e.props,"ref"))==null?void 0:r.get,n=t&&"isReactWarning"in t&&t.isReactWarning;return n?e.ref:(t=(a=Object.getOwnPropertyDescriptor(e,"ref"))==null?void 0:a.get,n=t&&"isReactWarning"in t&&t.isReactWarning,n?e.props.ref:e.props.ref||e.ref)}const H6=e=>typeof e=="boolean"?`${e}`:e===0?"0":e,G6=kO,aX=(e,t)=>n=>{var r;if((t==null?void 0:t.variants)==null)return G6(e,n==null?void 0:n.class,n==null?void 0:n.className);const{variants:a,defaultVariants:i}=t,o=Object.keys(a).map(d=>{const h=n==null?void 0:n[d],f=i==null?void 0:i[d];if(h===null)return null;const m=H6(h)||H6(f);return a[d][m]}),l=n&&Object.entries(n).reduce((d,h)=>{let[f,m]=h;return m===void 0||(d[f]=m),d},{}),u=t==null||(r=t.compoundVariants)===null||r===void 0?void 0:r.reduce((d,h)=>{let{class:f,className:m,...b}=h;return Object.entries(b).every(y=>{let[v,w]=y;return Array.isArray(w)?w.includes({...i,...l}[v]):{...i,...l}[v]===w})?[...d,f,m]:d},[]);return G6(e,o,u,n==null?void 0:n.class,n==null?void 0:n.className)},sS=aX("inline-flex items-center justify-center whitespace-nowrap rounded-md text-sm font-medium ring-offset-background transition-colors focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring focus-visible:ring-offset-2 disabled:pointer-events-none disabled:opacity-50",{variants:{variant:{default:"bg-primary text-primary-foreground hover:bg-primary/90",destructive:"bg-destructive text-destructive-foreground hover:bg-destructive/90",outline:"border border-input bg-background hover:bg-accent hover:text-accent-foreground",secondary:"bg-secondary text-secondary-foreground hover:bg-secondary/80",ghost:"hover:bg-accent hover:text-accent-foreground",link:"text-primary underline-offset-4 hover:underline"},size:{default:"h-10 px-4 py-2",sm:"h-9 rounded-md px-3",lg:"h-11 rounded-md px-8",icon:"h-10 w-10"}},defaultVariants:{variant:"default",size:"default"}});function kt({className:e,variant:t,size:n,asChild:r=!1,...a}){const i=r?QY:"button";return T.jsx(i,{className:st(sS({variant:t,size:n,className:e})),...a})}function ft(e,t,{checkForDefaultPrevented:n=!0}={}){return function(a){if(e==null||e(a),n===!1||!a.defaultPrevented)return t==null?void 0:t(a)}}function iX(e,t){const n=_.createContext(t),r=i=>{const{children:o,...l}=i,u=_.useMemo(()=>l,Object.values(l));return T.jsx(n.Provider,{value:u,children:o})};r.displayName=e+"Provider";function a(i){const o=_.useContext(n);if(o)return o;if(t!==void 0)return t;throw new Error(`\`${i}\` must be used within \`${e}\``)}return[r,a]}function Os(e,t=[]){let n=[];function r(i,o){const l=_.createContext(o),u=n.length;n=[...n,o];const d=f=>{var S;const{scope:m,children:b,...y}=f,v=((S=m==null?void 0:m[e])==null?void 0:S[u])||l,w=_.useMemo(()=>y,Object.values(y));return T.jsx(v.Provider,{value:w,children:b})};d.displayName=i+"Provider";function h(f,m){var v;const b=((v=m==null?void 0:m[e])==null?void 0:v[u])||l,y=_.useContext(b);if(y)return y;if(o!==void 0)return o;throw new Error(`\`${f}\` must be used within \`${i}\``)}return[d,h]}const a=()=>{const i=n.map(o=>_.createContext(o));return function(l){const u=(l==null?void 0:l[e])||i;return _.useMemo(()=>({[`__scope${e}`]:{...l,[e]:u}}),[l,u])}};return a.scopeName=e,[r,oX(a,...t)]}function oX(...e){const t=e[0];if(e.length===1)return t;const n=()=>{const r=e.map(a=>({useScope:a(),scopeName:a.scopeName}));return function(i){const o=r.reduce((l,{useScope:u,scopeName:d})=>{const f=u(i)[`__scope${d}`];return{...l,...f}},{});return _.useMemo(()=>({[`__scope${t.scopeName}`]:o}),[o])}};return n.scopeName=t.scopeName,n}var ja=globalThis!=null&&globalThis.document?_.useLayoutEffect:()=>{},sX=j2[" useInsertionEffect ".trim().toString()]||ja;function lS({prop:e,defaultProp:t,onChange:n=()=>{},caller:r}){const[a,i,o]=lX({defaultProp:t,onChange:n}),l=e!==void 0,u=l?e:a;{const h=_.useRef(e!==void 0);_.useEffect(()=>{const f=h.current;f!==l&&console.warn(`${r} is changing from ${f?"controlled":"uncontrolled"} to ${l?"controlled":"uncontrolled"}. Components should not switch from controlled to uncontrolled (or vice versa). Decide between using a controlled or uncontrolled value for the lifetime of the component.`),h.current=l},[l,r])}const d=_.useCallback(h=>{var f;if(l){const m=cX(h)?h(e):h;m!==e&&((f=o.current)==null||f.call(o,m))}else i(h)},[l,e,i,o]);return[u,d]}function lX({defaultProp:e,onChange:t}){const[n,r]=_.useState(e),a=_.useRef(n),i=_.useRef(t);return sX(()=>{i.current=t},[t]),_.useEffect(()=>{var o;a.current!==n&&((o=i.current)==null||o.call(i,n),a.current=n)},[n,a]),[n,r,i]}function cX(e){return typeof e=="function"}function xh(e){const t=uX(e),n=_.forwardRef((r,a)=>{const{children:i,...o}=r,l=_.Children.toArray(i),u=l.find(hX);if(u){const d=u.props.children,h=l.map(f=>f===u?_.Children.count(d)>1?_.Children.only(null):_.isValidElement(d)?d.props.children:null:f);return T.jsx(t,{...o,ref:a,children:_.isValidElement(d)?_.cloneElement(d,void 0,h):null})}return T.jsx(t,{...o,ref:a,children:i})});return n.displayName=`${e}.Slot`,n}function uX(e){const t=_.forwardRef((n,r)=>{const{children:a,...i}=n;if(_.isValidElement(a)){const o=fX(a),l=pX(i,a.props);return a.type!==_.Fragment&&(l.ref=r?Xh(r,o):o),_.cloneElement(a,l)}return _.Children.count(a)>1?_.Children.only(null):null});return t.displayName=`${e}.SlotClone`,t}var UO=Symbol("radix.slottable");function dX(e){const t=({children:n})=>T.jsx(T.Fragment,{children:n});return t.displayName=`${e}.Slottable`,t.__radixId=UO,t}function hX(e){return _.isValidElement(e)&&typeof e.type=="function"&&"__radixId"in e.type&&e.type.__radixId===UO}function pX(e,t){const n={...t};for(const r in t){const a=e[r],i=t[r];/^on[A-Z]/.test(r)?a&&i?n[r]=(...l)=>{const u=i(...l);return a(...l),u}:a&&(n[r]=a):r==="style"?n[r]={...a,...i}:r==="className"&&(n[r]=[a,i].filter(Boolean).join(" "))}return{...e,...n}}function fX(e){var r,a;let t=(r=Object.getOwnPropertyDescriptor(e.props,"ref"))==null?void 0:r.get,n=t&&"isReactWarning"in t&&t.isReactWarning;return n?e.ref:(t=(a=Object.getOwnPropertyDescriptor(e,"ref"))==null?void 0:a.get,n=t&&"isReactWarning"in t&&t.isReactWarning,n?e.props.ref:e.props.ref||e.ref)}var mX=["a","button","div","form","h2","h3","img","input","label","li","nav","ol","p","select","span","svg","ul"],dn=mX.reduce((e,t)=>{const n=xh(`Primitive.${t}`),r=_.forwardRef((a,i)=>{const{asChild:o,...l}=a,u=o?n:t;return typeof window<"u"&&(window[Symbol.for("radix-ui")]=!0),T.jsx(u,{...l,ref:i})});return r.displayName=`Primitive.${t}`,{...e,[t]:r}},{});function jO(e,t){e&&K2.flushSync(()=>e.dispatchEvent(t))}function HO(e){const t=e+"CollectionProvider",[n,r]=Os(t),[a,i]=n(t,{collectionRef:{current:null},itemMap:new Map}),o=v=>{const{scope:w,children:S}=v,k=fr.useRef(null),R=fr.useRef(new Map).current;return T.jsx(a,{scope:w,itemMap:R,collectionRef:k,children:S})};o.displayName=t;const l=e+"CollectionSlot",u=xh(l),d=fr.forwardRef((v,w)=>{const{scope:S,children:k}=v,R=i(l,S),I=un(w,R.collectionRef);return T.jsx(u,{ref:I,children:k})});d.displayName=l;const h=e+"CollectionItemSlot",f="data-radix-collection-item",m=xh(h),b=fr.forwardRef((v,w)=>{const{scope:S,children:k,...R}=v,I=fr.useRef(null),L=un(w,I),A=i(h,S);return fr.useEffect(()=>(A.itemMap.set(I,{ref:I,...R}),()=>void A.itemMap.delete(I))),T.jsx(m,{[f]:"",ref:L,children:k})});b.displayName=h;function y(v){const w=i(e+"CollectionConsumer",v);return fr.useCallback(()=>{const k=w.collectionRef.current;if(!k)return[];const R=Array.from(k.querySelectorAll(`[${f}]`));return Array.from(w.itemMap.values()).sort((A,M)=>R.indexOf(A.ref.current)-R.indexOf(M.ref.current))},[w.collectionRef,w.itemMap])}return[{Provider:o,Slot:d,ItemSlot:b},y,r]}var gX=_.createContext(void 0);function cS(e){const t=_.useContext(gX);return e||t||"ltr"}function lr(e){const t=_.useRef(e);return _.useEffect(()=>{t.current=e}),_.useMemo(()=>(...n)=>{var r;return(r=t.current)==null?void 0:r.call(t,...n)},[])}function bX(e,t=globalThis==null?void 0:globalThis.document){const n=lr(e);_.useEffect(()=>{const r=a=>{a.key==="Escape"&&n(a)};return t.addEventListener("keydown",r,{capture:!0}),()=>t.removeEventListener("keydown",r,{capture:!0})},[n,t])}var yX="DismissableLayer",ix="dismissableLayer.update",vX="dismissableLayer.pointerDownOutside",xX="dismissableLayer.focusOutside",q6,GO=_.createContext({layers:new Set,layersWithOutsidePointerEventsDisabled:new Set,branches:new Set}),uS=_.forwardRef((e,t)=>{const{disableOutsidePointerEvents:n=!1,onEscapeKeyDown:r,onPointerDownOutside:a,onFocusOutside:i,onInteractOutside:o,onDismiss:l,...u}=e,d=_.useContext(GO),[h,f]=_.useState(null),m=(h==null?void 0:h.ownerDocument)??(globalThis==null?void 0:globalThis.document),[,b]=_.useState({}),y=un(t,M=>f(M)),v=Array.from(d.layers),[w]=[...d.layersWithOutsidePointerEventsDisabled].slice(-1),S=v.indexOf(w),k=h?v.indexOf(h):-1,R=d.layersWithOutsidePointerEventsDisabled.size>0,I=k>=S,L=EX(M=>{const P=M.target,G=[...d.branches].some(B=>B.contains(P));!I||G||(a==null||a(M),o==null||o(M),M.defaultPrevented||l==null||l())},m),A=kX(M=>{const P=M.target;[...d.branches].some(B=>B.contains(P))||(i==null||i(M),o==null||o(M),M.defaultPrevented||l==null||l())},m);return bX(M=>{k===d.layers.size-1&&(r==null||r(M),!M.defaultPrevented&&l&&(M.preventDefault(),l()))},m),_.useEffect(()=>{if(h)return n&&(d.layersWithOutsidePointerEventsDisabled.size===0&&(q6=m.body.style.pointerEvents,m.body.style.pointerEvents="none"),d.layersWithOutsidePointerEventsDisabled.add(h)),d.layers.add(h),W6(),()=>{n&&d.layersWithOutsidePointerEventsDisabled.size===1&&(m.body.style.pointerEvents=q6)}},[h,m,n,d]),_.useEffect(()=>()=>{h&&(d.layers.delete(h),d.layersWithOutsidePointerEventsDisabled.delete(h),W6())},[h,d]),_.useEffect(()=>{const M=()=>b({});return document.addEventListener(ix,M),()=>document.removeEventListener(ix,M)},[]),T.jsx(dn.div,{...u,ref:y,style:{pointerEvents:R?I?"auto":"none":void 0,...e.style},onFocusCapture:ft(e.onFocusCapture,A.onFocusCapture),onBlurCapture:ft(e.onBlurCapture,A.onBlurCapture),onPointerDownCapture:ft(e.onPointerDownCapture,L.onPointerDownCapture)})});uS.displayName=yX;var SX="DismissableLayerBranch",wX=_.forwardRef((e,t)=>{const n=_.useContext(GO),r=_.useRef(null),a=un(t,r);return _.useEffect(()=>{const i=r.current;if(i)return n.branches.add(i),()=>{n.branches.delete(i)}},[n.branches]),T.jsx(dn.div,{...e,ref:a})});wX.displayName=SX;function EX(e,t=globalThis==null?void 0:globalThis.document){const n=lr(e),r=_.useRef(!1),a=_.useRef(()=>{});return _.useEffect(()=>{const i=l=>{if(l.target&&!r.current){let u=function(){qO(vX,n,d,{discrete:!0})};const d={originalEvent:l};l.pointerType==="touch"?(t.removeEventListener("click",a.current),a.current=u,t.addEventListener("click",a.current,{once:!0})):u()}else t.removeEventListener("click",a.current);r.current=!1},o=window.setTimeout(()=>{t.addEventListener("pointerdown",i)},0);return()=>{window.clearTimeout(o),t.removeEventListener("pointerdown",i),t.removeEventListener("click",a.current)}},[t,n]),{onPointerDownCapture:()=>r.current=!0}}function kX(e,t=globalThis==null?void 0:globalThis.document){const n=lr(e),r=_.useRef(!1);return _.useEffect(()=>{const a=i=>{i.target&&!r.current&&qO(xX,n,{originalEvent:i},{discrete:!1})};return t.addEventListener("focusin",a),()=>t.removeEventListener("focusin",a)},[t,n]),{onFocusCapture:()=>r.current=!0,onBlurCapture:()=>r.current=!1}}function W6(){const e=new CustomEvent(ix);document.dispatchEvent(e)}function qO(e,t,n,{discrete:r}){const a=n.originalEvent.target,i=new CustomEvent(e,{bubbles:!1,cancelable:!0,detail:n});t&&a.addEventListener(e,t,{once:!0}),r?jO(a,i):a.dispatchEvent(i)}var P1=0;function WO(){_.useEffect(()=>{const e=document.querySelectorAll("[data-radix-focus-guard]");return document.body.insertAdjacentElement("afterbegin",e[0]??V6()),document.body.insertAdjacentElement("beforeend",e[1]??V6()),P1++,()=>{P1===1&&document.querySelectorAll("[data-radix-focus-guard]").forEach(t=>t.remove()),P1--}},[])}function V6(){const e=document.createElement("span");return e.setAttribute("data-radix-focus-guard",""),e.tabIndex=0,e.style.outline="none",e.style.opacity="0",e.style.position="fixed",e.style.pointerEvents="none",e}var U1="focusScope.autoFocusOnMount",j1="focusScope.autoFocusOnUnmount",Y6={bubbles:!1,cancelable:!0},TX="FocusScope",dS=_.forwardRef((e,t)=>{const{loop:n=!1,trapped:r=!1,onMountAutoFocus:a,onUnmountAutoFocus:i,...o}=e,[l,u]=_.useState(null),d=lr(a),h=lr(i),f=_.useRef(null),m=un(t,v=>u(v)),b=_.useRef({paused:!1,pause(){this.paused=!0},resume(){this.paused=!1}}).current;_.useEffect(()=>{if(r){let v=function(R){if(b.paused||!l)return;const I=R.target;l.contains(I)?f.current=I:hs(f.current,{select:!0})},w=function(R){if(b.paused||!l)return;const I=R.relatedTarget;I!==null&&(l.contains(I)||hs(f.current,{select:!0}))},S=function(R){if(document.activeElement===document.body)for(const L of R)L.removedNodes.length>0&&hs(l)};document.addEventListener("focusin",v),document.addEventListener("focusout",w);const k=new MutationObserver(S);return l&&k.observe(l,{childList:!0,subtree:!0}),()=>{document.removeEventListener("focusin",v),document.removeEventListener("focusout",w),k.disconnect()}}},[r,l,b.paused]),_.useEffect(()=>{if(l){K6.add(b);const v=document.activeElement;if(!l.contains(v)){const S=new CustomEvent(U1,Y6);l.addEventListener(U1,d),l.dispatchEvent(S),S.defaultPrevented||(_X(OX(VO(l)),{select:!0}),document.activeElement===v&&hs(l))}return()=>{l.removeEventListener(U1,d),setTimeout(()=>{const S=new CustomEvent(j1,Y6);l.addEventListener(j1,h),l.dispatchEvent(S),S.defaultPrevented||hs(v??document.body,{select:!0}),l.removeEventListener(j1,h),K6.remove(b)},0)}}},[l,d,h,b]);const y=_.useCallback(v=>{if(!n&&!r||b.paused)return;const w=v.key==="Tab"&&!v.altKey&&!v.ctrlKey&&!v.metaKey,S=document.activeElement;if(w&&S){const k=v.currentTarget,[R,I]=CX(k);R&&I?!v.shiftKey&&S===I?(v.preventDefault(),n&&hs(R,{select:!0})):v.shiftKey&&S===R&&(v.preventDefault(),n&&hs(I,{select:!0})):S===k&&v.preventDefault()}},[n,r,b.paused]);return T.jsx(dn.div,{tabIndex:-1,...o,ref:m,onKeyDown:y})});dS.displayName=TX;function _X(e,{select:t=!1}={}){const n=document.activeElement;for(const r of e)if(hs(r,{select:t}),document.activeElement!==n)return}function CX(e){const t=VO(e),n=X6(t,e),r=X6(t.reverse(),e);return[n,r]}function VO(e){const t=[],n=document.createTreeWalker(e,NodeFilter.SHOW_ELEMENT,{acceptNode:r=>{const a=r.tagName==="INPUT"&&r.type==="hidden";return r.disabled||r.hidden||a?NodeFilter.FILTER_SKIP:r.tabIndex>=0?NodeFilter.FILTER_ACCEPT:NodeFilter.FILTER_SKIP}});for(;n.nextNode();)t.push(n.currentNode);return t}function X6(e,t){for(const n of e)if(!AX(n,{upTo:t}))return n}function AX(e,{upTo:t}){if(getComputedStyle(e).visibility==="hidden")return!0;for(;e;){if(t!==void 0&&e===t)return!1;if(getComputedStyle(e).display==="none")return!0;e=e.parentElement}return!1}function RX(e){return e instanceof HTMLInputElement&&"select"in e}function hs(e,{select:t=!1}={}){if(e&&e.focus){const n=document.activeElement;e.focus({preventScroll:!0}),e!==n&&RX(e)&&t&&e.select()}}var K6=NX();function NX(){let e=[];return{add(t){const n=e[0];t!==n&&(n==null||n.pause()),e=Z6(e,t),e.unshift(t)},remove(t){var n;e=Z6(e,t),(n=e[0])==null||n.resume()}}}function Z6(e,t){const n=[...e],r=n.indexOf(t);return r!==-1&&n.splice(r,1),n}function OX(e){return e.filter(t=>t.tagName!=="A")}var IX=j2[" useId ".trim().toString()]||(()=>{}),LX=0;function Dc(e){const[t,n]=_.useState(IX());return ja(()=>{n(r=>r??String(LX++))},[e]),t?`radix-${t}`:""}const DX=["top","right","bottom","left"],xs=Math.min,pa=Math.max,J0=Math.round,Wf=Math.floor,Ci=e=>({x:e,y:e}),MX={left:"right",right:"left",bottom:"top",top:"bottom"};function ox(e,t,n){return pa(e,xs(t,n))}function Eo(e,t){return typeof e=="function"?e(t):e}function ko(e){return e.split("-")[0]}function mu(e){return e.split("-")[1]}function hS(e){return e==="x"?"y":"x"}function pS(e){return e==="y"?"height":"width"}function ki(e){const t=e[0];return t==="t"||t==="b"?"y":"x"}function fS(e){return hS(ki(e))}function BX(e,t,n){n===void 0&&(n=!1);const r=mu(e),a=fS(e),i=pS(a);let o=a==="x"?r===(n?"end":"start")?"right":"left":r==="start"?"bottom":"top";return t.reference[i]>t.floating[i]&&(o=em(o)),[o,em(o)]}function FX(e){const t=em(e);return[sx(e),t,sx(t)]}function sx(e){return e.includes("start")?e.replace("start","end"):e.replace("end","start")}const Q6=["left","right"],J6=["right","left"],zX=["top","bottom"],$X=["bottom","top"];function PX(e,t,n){switch(e){case"top":case"bottom":return n?t?J6:Q6:t?Q6:J6;case"left":case"right":return t?zX:$X;default:return[]}}function UX(e,t,n,r){const a=mu(e);let i=PX(ko(e),n==="start",r);return a&&(i=i.map(o=>o+"-"+a),t&&(i=i.concat(i.map(sx)))),i}function em(e){const t=ko(e);return MX[t]+e.slice(t.length)}function jX(e){return{top:0,right:0,bottom:0,left:0,...e}}function YO(e){return typeof e!="number"?jX(e):{top:e,right:e,bottom:e,left:e}}function tm(e){const{x:t,y:n,width:r,height:a}=e;return{width:r,height:a,top:n,left:t,right:t+r,bottom:n+a,x:t,y:n}}function eR(e,t,n){let{reference:r,floating:a}=e;const i=ki(t),o=fS(t),l=pS(o),u=ko(t),d=i==="y",h=r.x+r.width/2-a.width/2,f=r.y+r.height/2-a.height/2,m=r[l]/2-a[l]/2;let b;switch(u){case"top":b={x:h,y:r.y-a.height};break;case"bottom":b={x:h,y:r.y+r.height};break;case"right":b={x:r.x+r.width,y:f};break;case"left":b={x:r.x-a.width,y:f};break;default:b={x:r.x,y:r.y}}switch(mu(t)){case"start":b[o]-=m*(n&&d?-1:1);break;case"end":b[o]+=m*(n&&d?-1:1);break}return b}async function HX(e,t){var n;t===void 0&&(t={});const{x:r,y:a,platform:i,rects:o,elements:l,strategy:u}=e,{boundary:d="clippingAncestors",rootBoundary:h="viewport",elementContext:f="floating",altBoundary:m=!1,padding:b=0}=Eo(t,e),y=YO(b),w=l[m?f==="floating"?"reference":"floating":f],S=tm(await i.getClippingRect({element:(n=await(i.isElement==null?void 0:i.isElement(w)))==null||n?w:w.contextElement||await(i.getDocumentElement==null?void 0:i.getDocumentElement(l.floating)),boundary:d,rootBoundary:h,strategy:u})),k=f==="floating"?{x:r,y:a,width:o.floating.width,height:o.floating.height}:o.reference,R=await(i.getOffsetParent==null?void 0:i.getOffsetParent(l.floating)),I=await(i.isElement==null?void 0:i.isElement(R))?await(i.getScale==null?void 0:i.getScale(R))||{x:1,y:1}:{x:1,y:1},L=tm(i.convertOffsetParentRelativeRectToViewportRelativeRect?await i.convertOffsetParentRelativeRectToViewportRelativeRect({elements:l,rect:k,offsetParent:R,strategy:u}):k);return{top:(S.top-L.top+y.top)/I.y,bottom:(L.bottom-S.bottom+y.bottom)/I.y,left:(S.left-L.left+y.left)/I.x,right:(L.right-S.right+y.right)/I.x}}const GX=50,qX=async(e,t,n)=>{const{placement:r="bottom",strategy:a="absolute",middleware:i=[],platform:o}=n,l=o.detectOverflow?o:{...o,detectOverflow:HX},u=await(o.isRTL==null?void 0:o.isRTL(t));let d=await o.getElementRects({reference:e,floating:t,strategy:a}),{x:h,y:f}=eR(d,r,u),m=r,b=0;const y={};for(let v=0;v<i.length;v++){const w=i[v];if(!w)continue;const{name:S,fn:k}=w,{x:R,y:I,data:L,reset:A}=await k({x:h,y:f,initialPlacement:r,placement:m,strategy:a,middlewareData:y,rects:d,platform:l,elements:{reference:e,floating:t}});h=R??h,f=I??f,y[S]={...y[S],...L},A&&b<GX&&(b++,typeof A=="object"&&(A.placement&&(m=A.placement),A.rects&&(d=A.rects===!0?await o.getElementRects({reference:e,floating:t,strategy:a}):A.rects),{x:h,y:f}=eR(d,m,u)),v=-1)}return{x:h,y:f,placement:m,strategy:a,middlewareData:y}},WX=e=>({name:"arrow",options:e,async fn(t){const{x:n,y:r,placement:a,rects:i,platform:o,elements:l,middlewareData:u}=t,{element:d,padding:h=0}=Eo(e,t)||{};if(d==null)return{};const f=YO(h),m={x:n,y:r},b=fS(a),y=pS(b),v=await o.getDimensions(d),w=b==="y",S=w?"top":"left",k=w?"bottom":"right",R=w?"clientHeight":"clientWidth",I=i.reference[y]+i.reference[b]-m[b]-i.floating[y],L=m[b]-i.reference[b],A=await(o.getOffsetParent==null?void 0:o.getOffsetParent(d));let M=A?A[R]:0;(!M||!await(o.isElement==null?void 0:o.isElement(A)))&&(M=l.floating[R]||i.floating[y]);const P=I/2-L/2,G=M/2-v[y]/2-1,B=xs(f[S],G),H=xs(f[k],G),Z=B,V=M-v[y]-H,q=M/2-v[y]/2+P,X=ox(Z,q,V),$=!u.arrow&&mu(a)!=null&&q!==X&&i.reference[y]/2-(q<Z?B:H)-v[y]/2<0,Q=$?q<Z?q-Z:q-V:0;return{[b]:m[b]+Q,data:{[b]:X,centerOffset:q-X-Q,...$&&{alignmentOffset:Q}},reset:$}}}),VX=function(e){return e===void 0&&(e={}),{name:"flip",options:e,async fn(t){var n,r;const{placement:a,middlewareData:i,rects:o,initialPlacement:l,platform:u,elements:d}=t,{mainAxis:h=!0,crossAxis:f=!0,fallbackPlacements:m,fallbackStrategy:b="bestFit",fallbackAxisSideDirection:y="none",flipAlignment:v=!0,...w}=Eo(e,t);if((n=i.arrow)!=null&&n.alignmentOffset)return{};const S=ko(a),k=ki(l),R=ko(l)===l,I=await(u.isRTL==null?void 0:u.isRTL(d.floating)),L=m||(R||!v?[em(l)]:FX(l)),A=y!=="none";!m&&A&&L.push(...UX(l,v,y,I));const M=[l,...L],P=await u.detectOverflow(t,w),G=[];let B=((r=i.flip)==null?void 0:r.overflows)||[];if(h&&G.push(P[S]),f){const q=BX(a,o,I);G.push(P[q[0]],P[q[1]])}if(B=[...B,{placement:a,overflows:G}],!G.every(q=>q<=0)){var H,Z;const q=(((H=i.flip)==null?void 0:H.index)||0)+1,X=M[q];if(X&&(!(f==="alignment"?k!==ki(X):!1)||B.every(J=>ki(J.placement)===k?J.overflows[0]>0:!0)))return{data:{index:q,overflows:B},reset:{placement:X}};let $=(Z=B.filter(Q=>Q.overflows[0]<=0).sort((Q,J)=>Q.overflows[1]-J.overflows[1])[0])==null?void 0:Z.placement;if(!$)switch(b){case"bestFit":{var V;const Q=(V=B.filter(J=>{if(A){const ie=ki(J.placement);return ie===k||ie==="y"}return!0}).map(J=>[J.placement,J.overflows.filter(ie=>ie>0).reduce((ie,F)=>ie+F,0)]).sort((J,ie)=>J[1]-ie[1])[0])==null?void 0:V[0];Q&&($=Q);break}case"initialPlacement":$=l;break}if(a!==$)return{reset:{placement:$}}}return{}}}};function tR(e,t){return{top:e.top-t.height,right:e.right-t.width,bottom:e.bottom-t.height,left:e.left-t.width}}function nR(e){return DX.some(t=>e[t]>=0)}const YX=function(e){return e===void 0&&(e={}),{name:"hide",options:e,async fn(t){const{rects:n,platform:r}=t,{strategy:a="referenceHidden",...i}=Eo(e,t);switch(a){case"referenceHidden":{const o=await r.detectOverflow(t,{...i,elementContext:"reference"}),l=tR(o,n.reference);return{data:{referenceHiddenOffsets:l,referenceHidden:nR(l)}}}case"escaped":{const o=await r.detectOverflow(t,{...i,altBoundary:!0}),l=tR(o,n.floating);return{data:{escapedOffsets:l,escaped:nR(l)}}}default:return{}}}}},XO=new Set(["left","top"]);async function XX(e,t){const{placement:n,platform:r,elements:a}=e,i=await(r.isRTL==null?void 0:r.isRTL(a.floating)),o=ko(n),l=mu(n),u=ki(n)==="y",d=XO.has(o)?-1:1,h=i&&u?-1:1,f=Eo(t,e);let{mainAxis:m,crossAxis:b,alignmentAxis:y}=typeof f=="number"?{mainAxis:f,crossAxis:0,alignmentAxis:null}:{mainAxis:f.mainAxis||0,crossAxis:f.crossAxis||0,alignmentAxis:f.alignmentAxis};return l&&typeof y=="number"&&(b=l==="end"?y*-1:y),u?{x:b*h,y:m*d}:{x:m*d,y:b*h}}const KX=function(e){return e===void 0&&(e=0),{name:"offset",options:e,async fn(t){var n,r;const{x:a,y:i,placement:o,middlewareData:l}=t,u=await XX(t,e);return o===((n=l.offset)==null?void 0:n.placement)&&(r=l.arrow)!=null&&r.alignmentOffset?{}:{x:a+u.x,y:i+u.y,data:{...u,placement:o}}}}},ZX=function(e){return e===void 0&&(e={}),{name:"shift",options:e,async fn(t){const{x:n,y:r,placement:a,platform:i}=t,{mainAxis:o=!0,crossAxis:l=!1,limiter:u={fn:S=>{let{x:k,y:R}=S;return{x:k,y:R}}},...d}=Eo(e,t),h={x:n,y:r},f=await i.detectOverflow(t,d),m=ki(ko(a)),b=hS(m);let y=h[b],v=h[m];if(o){const S=b==="y"?"top":"left",k=b==="y"?"bottom":"right",R=y+f[S],I=y-f[k];y=ox(R,y,I)}if(l){const S=m==="y"?"top":"left",k=m==="y"?"bottom":"right",R=v+f[S],I=v-f[k];v=ox(R,v,I)}const w=u.fn({...t,[b]:y,[m]:v});return{...w,data:{x:w.x-n,y:w.y-r,enabled:{[b]:o,[m]:l}}}}}},QX=function(e){return e===void 0&&(e={}),{options:e,fn(t){const{x:n,y:r,placement:a,rects:i,middlewareData:o}=t,{offset:l=0,mainAxis:u=!0,crossAxis:d=!0}=Eo(e,t),h={x:n,y:r},f=ki(a),m=hS(f);let b=h[m],y=h[f];const v=Eo(l,t),w=typeof v=="number"?{mainAxis:v,crossAxis:0}:{mainAxis:0,crossAxis:0,...v};if(u){const R=m==="y"?"height":"width",I=i.reference[m]-i.floating[R]+w.mainAxis,L=i.reference[m]+i.reference[R]-w.mainAxis;b<I?b=I:b>L&&(b=L)}if(d){var S,k;const R=m==="y"?"width":"height",I=XO.has(ko(a)),L=i.reference[f]-i.floating[R]+(I&&((S=o.offset)==null?void 0:S[f])||0)+(I?0:w.crossAxis),A=i.reference[f]+i.reference[R]+(I?0:((k=o.offset)==null?void 0:k[f])||0)-(I?w.crossAxis:0);y<L?y=L:y>A&&(y=A)}return{[m]:b,[f]:y}}}},JX=function(e){return e===void 0&&(e={}),{name:"size",options:e,async fn(t){var n,r;const{placement:a,rects:i,platform:o,elements:l}=t,{apply:u=()=>{},...d}=Eo(e,t),h=await o.detectOverflow(t,d),f=ko(a),m=mu(a),b=ki(a)==="y",{width:y,height:v}=i.floating;let w,S;f==="top"||f==="bottom"?(w=f,S=m===(await(o.isRTL==null?void 0:o.isRTL(l.floating))?"start":"end")?"left":"right"):(S=f,w=m==="end"?"top":"bottom");const k=v-h.top-h.bottom,R=y-h.left-h.right,I=xs(v-h[w],k),L=xs(y-h[S],R),A=!t.middlewareData.shift;let M=I,P=L;if((n=t.middlewareData.shift)!=null&&n.enabled.x&&(P=R),(r=t.middlewareData.shift)!=null&&r.enabled.y&&(M=k),A&&!m){const B=pa(h.left,0),H=pa(h.right,0),Z=pa(h.top,0),V=pa(h.bottom,0);b?P=y-2*(B!==0||H!==0?B+H:pa(h.left,h.right)):M=v-2*(Z!==0||V!==0?Z+V:pa(h.top,h.bottom))}await u({...t,availableWidth:P,availableHeight:M});const G=await o.getDimensions(l.floating);return y!==G.width||v!==G.height?{reset:{rects:!0}}:{}}}};function ag(){return typeof window<"u"}function gu(e){return KO(e)?(e.nodeName||"").toLowerCase():"#document"}function fa(e){var t;return(e==null||(t=e.ownerDocument)==null?void 0:t.defaultView)||window}function Di(e){var t;return(t=(KO(e)?e.ownerDocument:e.document)||window.document)==null?void 0:t.documentElement}function KO(e){return ag()?e instanceof Node||e instanceof fa(e).Node:!1}function oi(e){return ag()?e instanceof Element||e instanceof fa(e).Element:!1}function Ao(e){return ag()?e instanceof HTMLElement||e instanceof fa(e).HTMLElement:!1}function rR(e){return!ag()||typeof ShadowRoot>"u"?!1:e instanceof ShadowRoot||e instanceof fa(e).ShadowRoot}function Kh(e){const{overflow:t,overflowX:n,overflowY:r,display:a}=si(e);return/auto|scroll|overlay|hidden|clip/.test(t+r+n)&&a!=="inline"&&a!=="contents"}function eK(e){return/^(table|td|th)$/.test(gu(e))}function ig(e){try{if(e.matches(":popover-open"))return!0}catch{}try{return e.matches(":modal")}catch{return!1}}const tK=/transform|translate|scale|rotate|perspective|filter/,nK=/paint|layout|strict|content/,tl=e=>!!e&&e!=="none";let H1;function mS(e){const t=oi(e)?si(e):e;return tl(t.transform)||tl(t.translate)||tl(t.scale)||tl(t.rotate)||tl(t.perspective)||!gS()&&(tl(t.backdropFilter)||tl(t.filter))||tK.test(t.willChange||"")||nK.test(t.contain||"")}function rK(e){let t=Ss(e);for(;Ao(t)&&!Zc(t);){if(mS(t))return t;if(ig(t))return null;t=Ss(t)}return null}function gS(){return H1==null&&(H1=typeof CSS<"u"&&CSS.supports&&CSS.supports("-webkit-backdrop-filter","none")),H1}function Zc(e){return/^(html|body|#document)$/.test(gu(e))}function si(e){return fa(e).getComputedStyle(e)}function og(e){return oi(e)?{scrollLeft:e.scrollLeft,scrollTop:e.scrollTop}:{scrollLeft:e.scrollX,scrollTop:e.scrollY}}function Ss(e){if(gu(e)==="html")return e;const t=e.assignedSlot||e.parentNode||rR(e)&&e.host||Di(e);return rR(t)?t.host:t}function ZO(e){const t=Ss(e);return Zc(t)?e.ownerDocument?e.ownerDocument.body:e.body:Ao(t)&&Kh(t)?t:ZO(t)}function Sh(e,t,n){var r;t===void 0&&(t=[]),n===void 0&&(n=!0);const a=ZO(e),i=a===((r=e.ownerDocument)==null?void 0:r.body),o=fa(a);if(i){const l=lx(o);return t.concat(o,o.visualViewport||[],Kh(a)?a:[],l&&n?Sh(l):[])}else return t.concat(a,Sh(a,[],n))}function lx(e){return e.parent&&Object.getPrototypeOf(e.parent)?e.frameElement:null}function QO(e){const t=si(e);let n=parseFloat(t.width)||0,r=parseFloat(t.height)||0;const a=Ao(e),i=a?e.offsetWidth:n,o=a?e.offsetHeight:r,l=J0(n)!==i||J0(r)!==o;return l&&(n=i,r=o),{width:n,height:r,$:l}}function bS(e){return oi(e)?e:e.contextElement}function Mc(e){const t=bS(e);if(!Ao(t))return Ci(1);const n=t.getBoundingClientRect(),{width:r,height:a,$:i}=QO(t);let o=(i?J0(n.width):n.width)/r,l=(i?J0(n.height):n.height)/a;return(!o||!Number.isFinite(o))&&(o=1),(!l||!Number.isFinite(l))&&(l=1),{x:o,y:l}}const aK=Ci(0);function JO(e){const t=fa(e);return!gS()||!t.visualViewport?aK:{x:t.visualViewport.offsetLeft,y:t.visualViewport.offsetTop}}function iK(e,t,n){return t===void 0&&(t=!1),!n||t&&n!==fa(e)?!1:t}function bl(e,t,n,r){t===void 0&&(t=!1),n===void 0&&(n=!1);const a=e.getBoundingClientRect(),i=bS(e);let o=Ci(1);t&&(r?oi(r)&&(o=Mc(r)):o=Mc(e));const l=iK(i,n,r)?JO(i):Ci(0);let u=(a.left+l.x)/o.x,d=(a.top+l.y)/o.y,h=a.width/o.x,f=a.height/o.y;if(i){const m=fa(i),b=r&&oi(r)?fa(r):r;let y=m,v=lx(y);for(;v&&r&&b!==y;){const w=Mc(v),S=v.getBoundingClientRect(),k=si(v),R=S.left+(v.clientLeft+parseFloat(k.paddingLeft))*w.x,I=S.top+(v.clientTop+parseFloat(k.paddingTop))*w.y;u*=w.x,d*=w.y,h*=w.x,f*=w.y,u+=R,d+=I,y=fa(v),v=lx(y)}}return tm({width:h,height:f,x:u,y:d})}function sg(e,t){const n=og(e).scrollLeft;return t?t.left+n:bl(Di(e)).left+n}function eI(e,t){const n=e.getBoundingClientRect(),r=n.left+t.scrollLeft-sg(e,n),a=n.top+t.scrollTop;return{x:r,y:a}}function oK(e){let{elements:t,rect:n,offsetParent:r,strategy:a}=e;const i=a==="fixed",o=Di(r),l=t?ig(t.floating):!1;if(r===o||l&&i)return n;let u={scrollLeft:0,scrollTop:0},d=Ci(1);const h=Ci(0),f=Ao(r);if((f||!f&&!i)&&((gu(r)!=="body"||Kh(o))&&(u=og(r)),f)){const b=bl(r);d=Mc(r),h.x=b.x+r.clientLeft,h.y=b.y+r.clientTop}const m=o&&!f&&!i?eI(o,u):Ci(0);return{width:n.width*d.x,height:n.height*d.y,x:n.x*d.x-u.scrollLeft*d.x+h.x+m.x,y:n.y*d.y-u.scrollTop*d.y+h.y+m.y}}function sK(e){return Array.from(e.getClientRects())}function lK(e){const t=Di(e),n=og(e),r=e.ownerDocument.body,a=pa(t.scrollWidth,t.clientWidth,r.scrollWidth,r.clientWidth),i=pa(t.scrollHeight,t.clientHeight,r.scrollHeight,r.clientHeight);let o=-n.scrollLeft+sg(e);const l=-n.scrollTop;return si(r).direction==="rtl"&&(o+=pa(t.clientWidth,r.clientWidth)-a),{width:a,height:i,x:o,y:l}}const aR=25;function cK(e,t){const n=fa(e),r=Di(e),a=n.visualViewport;let i=r.clientWidth,o=r.clientHeight,l=0,u=0;if(a){i=a.width,o=a.height;const h=gS();(!h||h&&t==="fixed")&&(l=a.offsetLeft,u=a.offsetTop)}const d=sg(r);if(d<=0){const h=r.ownerDocument,f=h.body,m=getComputedStyle(f),b=h.compatMode==="CSS1Compat"&&parseFloat(m.marginLeft)+parseFloat(m.marginRight)||0,y=Math.abs(r.clientWidth-f.clientWidth-b);y<=aR&&(i-=y)}else d<=aR&&(i+=d);return{width:i,height:o,x:l,y:u}}function uK(e,t){const n=bl(e,!0,t==="fixed"),r=n.top+e.clientTop,a=n.left+e.clientLeft,i=Ao(e)?Mc(e):Ci(1),o=e.clientWidth*i.x,l=e.clientHeight*i.y,u=a*i.x,d=r*i.y;return{width:o,height:l,x:u,y:d}}function iR(e,t,n){let r;if(t==="viewport")r=cK(e,n);else if(t==="document")r=lK(Di(e));else if(oi(t))r=uK(t,n);else{const a=JO(e);r={x:t.x-a.x,y:t.y-a.y,width:t.width,height:t.height}}return tm(r)}function tI(e,t){const n=Ss(e);return n===t||!oi(n)||Zc(n)?!1:si(n).position==="fixed"||tI(n,t)}function dK(e,t){const n=t.get(e);if(n)return n;let r=Sh(e,[],!1).filter(l=>oi(l)&&gu(l)!=="body"),a=null;const i=si(e).position==="fixed";let o=i?Ss(e):e;for(;oi(o)&&!Zc(o);){const l=si(o),u=mS(o);!u&&l.position==="fixed"&&(a=null),(i?!u&&!a:!u&&l.position==="static"&&!!a&&(a.position==="absolute"||a.position==="fixed")||Kh(o)&&!u&&tI(e,o))?r=r.filter(h=>h!==o):a=l,o=Ss(o)}return t.set(e,r),r}function hK(e){let{element:t,boundary:n,rootBoundary:r,strategy:a}=e;const o=[...n==="clippingAncestors"?ig(t)?[]:dK(t,this._c):[].concat(n),r],l=iR(t,o[0],a);let u=l.top,d=l.right,h=l.bottom,f=l.left;for(let m=1;m<o.length;m++){const b=iR(t,o[m],a);u=pa(b.top,u),d=xs(b.right,d),h=xs(b.bottom,h),f=pa(b.left,f)}return{width:d-f,height:h-u,x:f,y:u}}function pK(e){const{width:t,height:n}=QO(e);return{width:t,height:n}}function fK(e,t,n){const r=Ao(t),a=Di(t),i=n==="fixed",o=bl(e,!0,i,t);let l={scrollLeft:0,scrollTop:0};const u=Ci(0);function d(){u.x=sg(a)}if(r||!r&&!i)if((gu(t)!=="body"||Kh(a))&&(l=og(t)),r){const b=bl(t,!0,i,t);u.x=b.x+t.clientLeft,u.y=b.y+t.clientTop}else a&&d();i&&!r&&a&&d();const h=a&&!r&&!i?eI(a,l):Ci(0),f=o.left+l.scrollLeft-u.x-h.x,m=o.top+l.scrollTop-u.y-h.y;return{x:f,y:m,width:o.width,height:o.height}}function G1(e){return si(e).position==="static"}function oR(e,t){if(!Ao(e)||si(e).position==="fixed")return null;if(t)return t(e);let n=e.offsetParent;return Di(e)===n&&(n=n.ownerDocument.body),n}function nI(e,t){const n=fa(e);if(ig(e))return n;if(!Ao(e)){let a=Ss(e);for(;a&&!Zc(a);){if(oi(a)&&!G1(a))return a;a=Ss(a)}return n}let r=oR(e,t);for(;r&&eK(r)&&G1(r);)r=oR(r,t);return r&&Zc(r)&&G1(r)&&!mS(r)?n:r||rK(e)||n}const mK=async function(e){const t=this.getOffsetParent||nI,n=this.getDimensions,r=await n(e.floating);return{reference:fK(e.reference,await t(e.floating),e.strategy),floating:{x:0,y:0,width:r.width,height:r.height}}};function gK(e){return si(e).direction==="rtl"}const bK={convertOffsetParentRelativeRectToViewportRelativeRect:oK,getDocumentElement:Di,getClippingRect:hK,getOffsetParent:nI,getElementRects:mK,getClientRects:sK,getDimensions:pK,getScale:Mc,isElement:oi,isRTL:gK};function rI(e,t){return e.x===t.x&&e.y===t.y&&e.width===t.width&&e.height===t.height}function yK(e,t){let n=null,r;const a=Di(e);function i(){var l;clearTimeout(r),(l=n)==null||l.disconnect(),n=null}function o(l,u){l===void 0&&(l=!1),u===void 0&&(u=1),i();const d=e.getBoundingClientRect(),{left:h,top:f,width:m,height:b}=d;if(l||t(),!m||!b)return;const y=Wf(f),v=Wf(a.clientWidth-(h+m)),w=Wf(a.clientHeight-(f+b)),S=Wf(h),R={rootMargin:-y+"px "+-v+"px "+-w+"px "+-S+"px",threshold:pa(0,xs(1,u))||1};let I=!0;function L(A){const M=A[0].intersectionRatio;if(M!==u){if(!I)return o();M?o(!1,M):r=setTimeout(()=>{o(!1,1e-7)},1e3)}M===1&&!rI(d,e.getBoundingClientRect())&&o(),I=!1}try{n=new IntersectionObserver(L,{...R,root:a.ownerDocument})}catch{n=new IntersectionObserver(L,R)}n.observe(e)}return o(!0),i}function vK(e,t,n,r){r===void 0&&(r={});const{ancestorScroll:a=!0,ancestorResize:i=!0,elementResize:o=typeof ResizeObserver=="function",layoutShift:l=typeof IntersectionObserver=="function",animationFrame:u=!1}=r,d=bS(e),h=a||i?[...d?Sh(d):[],...t?Sh(t):[]]:[];h.forEach(S=>{a&&S.addEventListener("scroll",n,{passive:!0}),i&&S.addEventListener("resize",n)});const f=d&&l?yK(d,n):null;let m=-1,b=null;o&&(b=new ResizeObserver(S=>{let[k]=S;k&&k.target===d&&b&&t&&(b.unobserve(t),cancelAnimationFrame(m),m=requestAnimationFrame(()=>{var R;(R=b)==null||R.observe(t)})),n()}),d&&!u&&b.observe(d),t&&b.observe(t));let y,v=u?bl(e):null;u&&w();function w(){const S=bl(e);v&&!rI(v,S)&&n(),v=S,y=requestAnimationFrame(w)}return n(),()=>{var S;h.forEach(k=>{a&&k.removeEventListener("scroll",n),i&&k.removeEventListener("resize",n)}),f==null||f(),(S=b)==null||S.disconnect(),b=null,u&&cancelAnimationFrame(y)}}const xK=KX,SK=ZX,wK=VX,EK=JX,kK=YX,sR=WX,TK=QX,_K=(e,t,n)=>{const r=new Map,a={platform:bK,...n},i={...a.platform,_c:r};return qX(e,t,{...a,platform:i})};var CK=typeof document<"u",AK=function(){},C0=CK?_.useLayoutEffect:AK;function nm(e,t){if(e===t)return!0;if(typeof e!=typeof t)return!1;if(typeof e=="function"&&e.toString()===t.toString())return!0;let n,r,a;if(e&&t&&typeof e=="object"){if(Array.isArray(e)){if(n=e.length,n!==t.length)return!1;for(r=n;r--!==0;)if(!nm(e[r],t[r]))return!1;return!0}if(a=Object.keys(e),n=a.length,n!==Object.keys(t).length)return!1;for(r=n;r--!==0;)if(!{}.hasOwnProperty.call(t,a[r]))return!1;for(r=n;r--!==0;){const i=a[r];if(!(i==="_owner"&&e.$$typeof)&&!nm(e[i],t[i]))return!1}return!0}return e!==e&&t!==t}function aI(e){return typeof window>"u"?1:(e.ownerDocument.defaultView||window).devicePixelRatio||1}function lR(e,t){const n=aI(e);return Math.round(t*n)/n}function q1(e){const t=_.useRef(e);return C0(()=>{t.current=e}),t}function RK(e){e===void 0&&(e={});const{placement:t="bottom",strategy:n="absolute",middleware:r=[],platform:a,elements:{reference:i,floating:o}={},transform:l=!0,whileElementsMounted:u,open:d}=e,[h,f]=_.useState({x:0,y:0,strategy:n,placement:t,middlewareData:{},isPositioned:!1}),[m,b]=_.useState(r);nm(m,r)||b(r);const[y,v]=_.useState(null),[w,S]=_.useState(null),k=_.useCallback(J=>{J!==A.current&&(A.current=J,v(J))},[]),R=_.useCallback(J=>{J!==M.current&&(M.current=J,S(J))},[]),I=i||y,L=o||w,A=_.useRef(null),M=_.useRef(null),P=_.useRef(h),G=u!=null,B=q1(u),H=q1(a),Z=q1(d),V=_.useCallback(()=>{if(!A.current||!M.current)return;const J={placement:t,strategy:n,middleware:m};H.current&&(J.platform=H.current),_K(A.current,M.current,J).then(ie=>{const F={...ie,isPositioned:Z.current!==!1};q.current&&!nm(P.current,F)&&(P.current=F,K2.flushSync(()=>{f(F)}))})},[m,t,n,H,Z]);C0(()=>{d===!1&&P.current.isPositioned&&(P.current.isPositioned=!1,f(J=>({...J,isPositioned:!1})))},[d]);const q=_.useRef(!1);C0(()=>(q.current=!0,()=>{q.current=!1}),[]),C0(()=>{if(I&&(A.current=I),L&&(M.current=L),I&&L){if(B.current)return B.current(I,L,V);V()}},[I,L,V,B,G]);const X=_.useMemo(()=>({reference:A,floating:M,setReference:k,setFloating:R}),[k,R]),$=_.useMemo(()=>({reference:I,floating:L}),[I,L]),Q=_.useMemo(()=>{const J={position:n,left:0,top:0};if(!$.floating)return J;const ie=lR($.floating,h.x),F=lR($.floating,h.y);return l?{...J,transform:"translate("+ie+"px, "+F+"px)",...aI($.floating)>=1.5&&{willChange:"transform"}}:{position:n,left:ie,top:F}},[n,l,$.floating,h.x,h.y]);return _.useMemo(()=>({...h,update:V,refs:X,elements:$,floatingStyles:Q}),[h,V,X,$,Q])}const NK=e=>{function t(n){return{}.hasOwnProperty.call(n,"current")}return{name:"arrow",options:e,fn(n){const{element:r,padding:a}=typeof e=="function"?e(n):e;return r&&t(r)?r.current!=null?sR({element:r.current,padding:a}).fn(n):{}:r?sR({element:r,padding:a}).fn(n):{}}}},OK=(e,t)=>{const n=xK(e);return{name:n.name,fn:n.fn,options:[e,t]}},IK=(e,t)=>{const n=SK(e);return{name:n.name,fn:n.fn,options:[e,t]}},LK=(e,t)=>({fn:TK(e).fn,options:[e,t]}),DK=(e,t)=>{const n=wK(e);return{name:n.name,fn:n.fn,options:[e,t]}},MK=(e,t)=>{const n=EK(e);return{name:n.name,fn:n.fn,options:[e,t]}},BK=(e,t)=>{const n=kK(e);return{name:n.name,fn:n.fn,options:[e,t]}},FK=(e,t)=>{const n=NK(e);return{name:n.name,fn:n.fn,options:[e,t]}};var zK="Arrow",iI=_.forwardRef((e,t)=>{const{children:n,width:r=10,height:a=5,...i}=e;return T.jsx(dn.svg,{...i,ref:t,width:r,height:a,viewBox:"0 0 30 10",preserveAspectRatio:"none",children:e.asChild?n:T.jsx("polygon",{points:"0,0 30,0 15,10"})})});iI.displayName=zK;var $K=iI;function PK(e){const[t,n]=_.useState(void 0);return ja(()=>{if(e){n({width:e.offsetWidth,height:e.offsetHeight});const r=new ResizeObserver(a=>{if(!Array.isArray(a)||!a.length)return;const i=a[0];let o,l;if("borderBoxSize"in i){const u=i.borderBoxSize,d=Array.isArray(u)?u[0]:u;o=d.inlineSize,l=d.blockSize}else o=e.offsetWidth,l=e.offsetHeight;n({width:o,height:l})});return r.observe(e,{box:"border-box"}),()=>r.unobserve(e)}else n(void 0)},[e]),t}var yS="Popper",[oI,sI]=Os(yS),[UK,lI]=oI(yS),cI=e=>{const{__scopePopper:t,children:n}=e,[r,a]=_.useState(null);return T.jsx(UK,{scope:t,anchor:r,onAnchorChange:a,children:n})};cI.displayName=yS;var uI="PopperAnchor",dI=_.forwardRef((e,t)=>{const{__scopePopper:n,virtualRef:r,...a}=e,i=lI(uI,n),o=_.useRef(null),l=un(t,o),u=_.useRef(null);return _.useEffect(()=>{const d=u.current;u.current=(r==null?void 0:r.current)||o.current,d!==u.current&&i.onAnchorChange(u.current)}),r?null:T.jsx(dn.div,{...a,ref:l})});dI.displayName=uI;var vS="PopperContent",[jK,HK]=oI(vS),hI=_.forwardRef((e,t)=>{var Ee,Ae,ve,De,Le,rt;const{__scopePopper:n,side:r="bottom",sideOffset:a=0,align:i="center",alignOffset:o=0,arrowPadding:l=0,avoidCollisions:u=!0,collisionBoundary:d=[],collisionPadding:h=0,sticky:f="partial",hideWhenDetached:m=!1,updatePositionStrategy:b="optimized",onPlaced:y,...v}=e,w=lI(vS,n),[S,k]=_.useState(null),R=un(t,Xe=>k(Xe)),[I,L]=_.useState(null),A=PK(I),M=(A==null?void 0:A.width)??0,P=(A==null?void 0:A.height)??0,G=r+(i!=="center"?"-"+i:""),B=typeof h=="number"?h:{top:0,right:0,bottom:0,left:0,...h},H=Array.isArray(d)?d:[d],Z=H.length>0,V={padding:B,boundary:H.filter(qK),altBoundary:Z},{refs:q,floatingStyles:X,placement:$,isPositioned:Q,middlewareData:J}=RK({strategy:"fixed",placement:G,whileElementsMounted:(...Xe)=>vK(...Xe,{animationFrame:b==="always"}),elements:{reference:w.anchor},middleware:[OK({mainAxis:a+P,alignmentAxis:o}),u&&IK({mainAxis:!0,crossAxis:!1,limiter:f==="partial"?LK():void 0,...V}),u&&DK({...V}),MK({...V,apply:({elements:Xe,rects:gt,availableWidth:Xt,availableHeight:er})=>{const{width:Tr,height:Hn}=gt.reference,Cn=Xe.floating.style;Cn.setProperty("--radix-popper-available-width",`${Xt}px`),Cn.setProperty("--radix-popper-available-height",`${er}px`),Cn.setProperty("--radix-popper-anchor-width",`${Tr}px`),Cn.setProperty("--radix-popper-anchor-height",`${Hn}px`)}}),I&&FK({element:I,padding:l}),WK({arrowWidth:M,arrowHeight:P}),m&&BK({strategy:"referenceHidden",...V})]}),[ie,F]=mI($),Y=lr(y);ja(()=>{Q&&(Y==null||Y())},[Q,Y]);const oe=(Ee=J.arrow)==null?void 0:Ee.x,U=(Ae=J.arrow)==null?void 0:Ae.y,be=((ve=J.arrow)==null?void 0:ve.centerOffset)!==0,[ge,fe]=_.useState();return ja(()=>{S&&fe(window.getComputedStyle(S).zIndex)},[S]),T.jsx("div",{ref:q.setFloating,"data-radix-popper-content-wrapper":"",style:{...X,transform:Q?X.transform:"translate(0, -200%)",minWidth:"max-content",zIndex:ge,"--radix-popper-transform-origin":[(De=J.transformOrigin)==null?void 0:De.x,(Le=J.transformOrigin)==null?void 0:Le.y].join(" "),...((rt=J.hide)==null?void 0:rt.referenceHidden)&&{visibility:"hidden",pointerEvents:"none"}},dir:e.dir,children:T.jsx(jK,{scope:n,placedSide:ie,onArrowChange:L,arrowX:oe,arrowY:U,shouldHideArrow:be,children:T.jsx(dn.div,{"data-side":ie,"data-align":F,...v,ref:R,style:{...v.style,animation:Q?void 0:"none"}})})})});hI.displayName=vS;var pI="PopperArrow",GK={top:"bottom",right:"left",bottom:"top",left:"right"},fI=_.forwardRef(function(t,n){const{__scopePopper:r,...a}=t,i=HK(pI,r),o=GK[i.placedSide];return T.jsx("span",{ref:i.onArrowChange,style:{position:"absolute",left:i.arrowX,top:i.arrowY,[o]:0,transformOrigin:{top:"",right:"0 0",bottom:"center 0",left:"100% 0"}[i.placedSide],transform:{top:"translateY(100%)",right:"translateY(50%) rotate(90deg) translateX(-50%)",bottom:"rotate(180deg)",left:"translateY(50%) rotate(-90deg) translateX(50%)"}[i.placedSide],visibility:i.shouldHideArrow?"hidden":void 0},children:T.jsx($K,{...a,ref:n,style:{...a.style,display:"block"}})})});fI.displayName=pI;function qK(e){return e!==null}var WK=e=>({name:"transformOrigin",options:e,fn(t){var w,S,k;const{placement:n,rects:r,middlewareData:a}=t,o=((w=a.arrow)==null?void 0:w.centerOffset)!==0,l=o?0:e.arrowWidth,u=o?0:e.arrowHeight,[d,h]=mI(n),f={start:"0%",center:"50%",end:"100%"}[h],m=(((S=a.arrow)==null?void 0:S.x)??0)+l/2,b=(((k=a.arrow)==null?void 0:k.y)??0)+u/2;let y="",v="";return d==="bottom"?(y=o?f:`${m}px`,v=`${-u}px`):d==="top"?(y=o?f:`${m}px`,v=`${r.floating.height+u}px`):d==="right"?(y=`${-u}px`,v=o?f:`${b}px`):d==="left"&&(y=`${r.floating.width+u}px`,v=o?f:`${b}px`),{data:{x:y,y:v}}}});function mI(e){const[t,n="center"]=e.split("-");return[t,n]}var VK=cI,YK=dI,XK=hI,KK=fI,ZK="Portal",xS=_.forwardRef((e,t)=>{var l;const{container:n,...r}=e,[a,i]=_.useState(!1);ja(()=>i(!0),[]);const o=n||a&&((l=globalThis==null?void 0:globalThis.document)==null?void 0:l.body);return o?LW.createPortal(T.jsx(dn.div,{...r,ref:t}),o):null});xS.displayName=ZK;function QK(e,t){return _.useReducer((n,r)=>t[n][r]??n,e)}var Wa=e=>{const{present:t,children:n}=e,r=JK(t),a=typeof n=="function"?n({present:r.isPresent}):_.Children.only(n),i=un(r.ref,eZ(a));return typeof n=="function"||r.isPresent?_.cloneElement(a,{ref:i}):null};Wa.displayName="Presence";function JK(e){const[t,n]=_.useState(),r=_.useRef(null),a=_.useRef(e),i=_.useRef("none"),o=e?"mounted":"unmounted",[l,u]=QK(o,{mounted:{UNMOUNT:"unmounted",ANIMATION_OUT:"unmountSuspended"},unmountSuspended:{MOUNT:"mounted",ANIMATION_END:"unmounted"},unmounted:{MOUNT:"mounted"}});return _.useEffect(()=>{const d=Vf(r.current);i.current=l==="mounted"?d:"none"},[l]),ja(()=>{const d=r.current,h=a.current;if(h!==e){const m=i.current,b=Vf(d);e?u("MOUNT"):b==="none"||(d==null?void 0:d.display)==="none"?u("UNMOUNT"):u(h&&m!==b?"ANIMATION_OUT":"UNMOUNT"),a.current=e}},[e,u]),ja(()=>{if(t){let d;const h=t.ownerDocument.defaultView??window,f=b=>{const v=Vf(r.current).includes(CSS.escape(b.animationName));if(b.target===t&&v&&(u("ANIMATION_END"),!a.current)){const w=t.style.animationFillMode;t.style.animationFillMode="forwards",d=h.setTimeout(()=>{t.style.animationFillMode==="forwards"&&(t.style.animationFillMode=w)})}},m=b=>{b.target===t&&(i.current=Vf(r.current))};return t.addEventListener("animationstart",m),t.addEventListener("animationcancel",f),t.addEventListener("animationend",f),()=>{h.clearTimeout(d),t.removeEventListener("animationstart",m),t.removeEventListener("animationcancel",f),t.removeEventListener("animationend",f)}}else u("ANIMATION_END")},[t,u]),{isPresent:["mounted","unmountSuspended"].includes(l),ref:_.useCallback(d=>{r.current=d?getComputedStyle(d):null,n(d)},[])}}function Vf(e){return(e==null?void 0:e.animationName)||"none"}function eZ(e){var r,a;let t=(r=Object.getOwnPropertyDescriptor(e.props,"ref"))==null?void 0:r.get,n=t&&"isReactWarning"in t&&t.isReactWarning;return n?e.ref:(t=(a=Object.getOwnPropertyDescriptor(e,"ref"))==null?void 0:a.get,n=t&&"isReactWarning"in t&&t.isReactWarning,n?e.props.ref:e.props.ref||e.ref)}var W1="rovingFocusGroup.onEntryFocus",tZ={bubbles:!1,cancelable:!0},Zh="RovingFocusGroup",[cx,gI,nZ]=HO(Zh),[rZ,bI]=Os(Zh,[nZ]),[aZ,iZ]=rZ(Zh),yI=_.forwardRef((e,t)=>T.jsx(cx.Provider,{scope:e.__scopeRovingFocusGroup,children:T.jsx(cx.Slot,{scope:e.__scopeRovingFocusGroup,children:T.jsx(oZ,{...e,ref:t})})}));yI.displayName=Zh;var oZ=_.forwardRef((e,t)=>{const{__scopeRovingFocusGroup:n,orientation:r,loop:a=!1,dir:i,currentTabStopId:o,defaultCurrentTabStopId:l,onCurrentTabStopIdChange:u,onEntryFocus:d,preventScrollOnEntryFocus:h=!1,...f}=e,m=_.useRef(null),b=un(t,m),y=cS(i),[v,w]=lS({prop:o,defaultProp:l??null,onChange:u,caller:Zh}),[S,k]=_.useState(!1),R=lr(d),I=gI(n),L=_.useRef(!1),[A,M]=_.useState(0);return _.useEffect(()=>{const P=m.current;if(P)return P.addEventListener(W1,R),()=>P.removeEventListener(W1,R)},[R]),T.jsx(aZ,{scope:n,orientation:r,dir:y,loop:a,currentTabStopId:v,onItemFocus:_.useCallback(P=>w(P),[w]),onItemShiftTab:_.useCallback(()=>k(!0),[]),onFocusableItemAdd:_.useCallback(()=>M(P=>P+1),[]),onFocusableItemRemove:_.useCallback(()=>M(P=>P-1),[]),children:T.jsx(dn.div,{tabIndex:S||A===0?-1:0,"data-orientation":r,...f,ref:b,style:{outline:"none",...e.style},onMouseDown:ft(e.onMouseDown,()=>{L.current=!0}),onFocus:ft(e.onFocus,P=>{const G=!L.current;if(P.target===P.currentTarget&&G&&!S){const B=new CustomEvent(W1,tZ);if(P.currentTarget.dispatchEvent(B),!B.defaultPrevented){const H=I().filter($=>$.focusable),Z=H.find($=>$.active),V=H.find($=>$.id===v),X=[Z,V,...H].filter(Boolean).map($=>$.ref.current);SI(X,h)}}L.current=!1}),onBlur:ft(e.onBlur,()=>k(!1))})})}),vI="RovingFocusGroupItem",xI=_.forwardRef((e,t)=>{const{__scopeRovingFocusGroup:n,focusable:r=!0,active:a=!1,tabStopId:i,children:o,...l}=e,u=Dc(),d=i||u,h=iZ(vI,n),f=h.currentTabStopId===d,m=gI(n),{onFocusableItemAdd:b,onFocusableItemRemove:y,currentTabStopId:v}=h;return _.useEffect(()=>{if(r)return b(),()=>y()},[r,b,y]),T.jsx(cx.ItemSlot,{scope:n,id:d,focusable:r,active:a,children:T.jsx(dn.span,{tabIndex:f?0:-1,"data-orientation":h.orientation,...l,ref:t,onMouseDown:ft(e.onMouseDown,w=>{r?h.onItemFocus(d):w.preventDefault()}),onFocus:ft(e.onFocus,()=>h.onItemFocus(d)),onKeyDown:ft(e.onKeyDown,w=>{if(w.key==="Tab"&&w.shiftKey){h.onItemShiftTab();return}if(w.target!==w.currentTarget)return;const S=cZ(w,h.orientation,h.dir);if(S!==void 0){if(w.metaKey||w.ctrlKey||w.altKey||w.shiftKey)return;w.preventDefault();let R=m().filter(I=>I.focusable).map(I=>I.ref.current);if(S==="last")R.reverse();else if(S==="prev"||S==="next"){S==="prev"&&R.reverse();const I=R.indexOf(w.currentTarget);R=h.loop?uZ(R,I+1):R.slice(I+1)}setTimeout(()=>SI(R))}}),children:typeof o=="function"?o({isCurrentTabStop:f,hasTabStop:v!=null}):o})})});xI.displayName=vI;var sZ={ArrowLeft:"prev",ArrowUp:"prev",ArrowRight:"next",ArrowDown:"next",PageUp:"first",Home:"first",PageDown:"last",End:"last"};function lZ(e,t){return t!=="rtl"?e:e==="ArrowLeft"?"ArrowRight":e==="ArrowRight"?"ArrowLeft":e}function cZ(e,t,n){const r=lZ(e.key,n);if(!(t==="vertical"&&["ArrowLeft","ArrowRight"].includes(r))&&!(t==="horizontal"&&["ArrowUp","ArrowDown"].includes(r)))return sZ[r]}function SI(e,t=!1){const n=document.activeElement;for(const r of e)if(r===n||(r.focus({preventScroll:t}),document.activeElement!==n))return}function uZ(e,t){return e.map((n,r)=>e[(t+r)%e.length])}var dZ=yI,hZ=xI,pZ=function(e){if(typeof document>"u")return null;var t=Array.isArray(e)?e[0]:e;return t.ownerDocument.body},xc=new WeakMap,Yf=new WeakMap,Xf={},V1=0,wI=function(e){return e&&(e.host||wI(e.parentNode))},fZ=function(e,t){return t.map(function(n){if(e.contains(n))return n;var r=wI(n);return r&&e.contains(r)?r:(console.error("aria-hidden",n,"in not contained inside",e,". Doing nothing"),null)}).filter(function(n){return!!n})},mZ=function(e,t,n,r){var a=fZ(t,Array.isArray(e)?e:[e]);Xf[n]||(Xf[n]=new WeakMap);var i=Xf[n],o=[],l=new Set,u=new Set(a),d=function(f){!f||l.has(f)||(l.add(f),d(f.parentNode))};a.forEach(d);var h=function(f){!f||u.has(f)||Array.prototype.forEach.call(f.children,function(m){if(l.has(m))h(m);else try{var b=m.getAttribute(r),y=b!==null&&b!=="false",v=(xc.get(m)||0)+1,w=(i.get(m)||0)+1;xc.set(m,v),i.set(m,w),o.push(m),v===1&&y&&Yf.set(m,!0),w===1&&m.setAttribute(n,"true"),y||m.setAttribute(r,"true")}catch(S){console.error("aria-hidden: cannot operate on ",m,S)}})};return h(t),l.clear(),V1++,function(){o.forEach(function(f){var m=xc.get(f)-1,b=i.get(f)-1;xc.set(f,m),i.set(f,b),m||(Yf.has(f)||f.removeAttribute(r),Yf.delete(f)),b||f.removeAttribute(n)}),V1--,V1||(xc=new WeakMap,xc=new WeakMap,Yf=new WeakMap,Xf={})}},EI=function(e,t,n){n===void 0&&(n="data-aria-hidden");var r=Array.from(Array.isArray(e)?e:[e]),a=pZ(e);return a?(r.push.apply(r,Array.from(a.querySelectorAll("[aria-live], script"))),mZ(r,a,n,"aria-hidden")):function(){return null}},Ei=function(){return Ei=Object.assign||function(t){for(var n,r=1,a=arguments.length;r<a;r++){n=arguments[r];for(var i in n)Object.prototype.hasOwnProperty.call(n,i)&&(t[i]=n[i])}return t},Ei.apply(this,arguments)};function kI(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var a=0,r=Object.getOwnPropertySymbols(e);a<r.length;a++)t.indexOf(r[a])<0&&Object.prototype.propertyIsEnumerable.call(e,r[a])&&(n[r[a]]=e[r[a]]);return n}function gZ(e,t,n){if(n||arguments.length===2)for(var r=0,a=t.length,i;r<a;r++)(i||!(r in t))&&(i||(i=Array.prototype.slice.call(t,0,r)),i[r]=t[r]);return e.concat(i||Array.prototype.slice.call(t))}var A0="right-scroll-bar-position",R0="width-before-scroll-bar",bZ="with-scroll-bars-hidden",yZ="--removed-body-scroll-bar-size";function Y1(e,t){return typeof e=="function"?e(t):e&&(e.current=t),e}function vZ(e,t){var n=_.useState(function(){return{value:e,callback:t,facade:{get current(){return n.value},set current(r){var a=n.value;a!==r&&(n.value=r,n.callback(r,a))}}}})[0];return n.callback=t,n.facade}var xZ=typeof window<"u"?_.useLayoutEffect:_.useEffect,cR=new WeakMap;function SZ(e,t){var n=vZ(null,function(r){return e.forEach(function(a){return Y1(a,r)})});return xZ(function(){var r=cR.get(n);if(r){var a=new Set(r),i=new Set(e),o=n.current;a.forEach(function(l){i.has(l)||Y1(l,null)}),i.forEach(function(l){a.has(l)||Y1(l,o)})}cR.set(n,e)},[e]),n}function wZ(e){return e}function EZ(e,t){t===void 0&&(t=wZ);var n=[],r=!1,a={read:function(){if(r)throw new Error("Sidecar: could not `read` from an `assigned` medium. `read` could be used only with `useMedium`.");return n.length?n[n.length-1]:e},useMedium:function(i){var o=t(i,r);return n.push(o),function(){n=n.filter(function(l){return l!==o})}},assignSyncMedium:function(i){for(r=!0;n.length;){var o=n;n=[],o.forEach(i)}n={push:function(l){return i(l)},filter:function(){return n}}},assignMedium:function(i){r=!0;var o=[];if(n.length){var l=n;n=[],l.forEach(i),o=n}var u=function(){var h=o;o=[],h.forEach(i)},d=function(){return Promise.resolve().then(u)};d(),n={push:function(h){o.push(h),d()},filter:function(h){return o=o.filter(h),n}}}};return a}function kZ(e){e===void 0&&(e={});var t=EZ(null);return t.options=Ei({async:!0,ssr:!1},e),t}var TI=function(e){var t=e.sideCar,n=kI(e,["sideCar"]);if(!t)throw new Error("Sidecar: please provide `sideCar` property to import the right car");var r=t.read();if(!r)throw new Error("Sidecar medium not found");return _.createElement(r,Ei({},n))};TI.isSideCarExport=!0;function TZ(e,t){return e.useMedium(t),TI}var _I=kZ(),X1=function(){},lg=_.forwardRef(function(e,t){var n=_.useRef(null),r=_.useState({onScrollCapture:X1,onWheelCapture:X1,onTouchMoveCapture:X1}),a=r[0],i=r[1],o=e.forwardProps,l=e.children,u=e.className,d=e.removeScrollBar,h=e.enabled,f=e.shards,m=e.sideCar,b=e.noRelative,y=e.noIsolation,v=e.inert,w=e.allowPinchZoom,S=e.as,k=S===void 0?"div":S,R=e.gapMode,I=kI(e,["forwardProps","children","className","removeScrollBar","enabled","shards","sideCar","noRelative","noIsolation","inert","allowPinchZoom","as","gapMode"]),L=m,A=SZ([n,t]),M=Ei(Ei({},I),a);return _.createElement(_.Fragment,null,h&&_.createElement(L,{sideCar:_I,removeScrollBar:d,shards:f,noRelative:b,noIsolation:y,inert:v,setCallbacks:i,allowPinchZoom:!!w,lockRef:n,gapMode:R}),o?_.cloneElement(_.Children.only(l),Ei(Ei({},M),{ref:A})):_.createElement(k,Ei({},M,{className:u,ref:A}),l))});lg.defaultProps={enabled:!0,removeScrollBar:!0,inert:!1};lg.classNames={fullWidth:R0,zeroRight:A0};var _Z=function(){if(typeof __webpack_nonce__<"u")return __webpack_nonce__};function CZ(){if(!document)return null;var e=document.createElement("style");e.type="text/css";var t=_Z();return t&&e.setAttribute("nonce",t),e}function AZ(e,t){e.styleSheet?e.styleSheet.cssText=t:e.appendChild(document.createTextNode(t))}function RZ(e){var t=document.head||document.getElementsByTagName("head")[0];t.appendChild(e)}var NZ=function(){var e=0,t=null;return{add:function(n){e==0&&(t=CZ())&&(AZ(t,n),RZ(t)),e++},remove:function(){e--,!e&&t&&(t.parentNode&&t.parentNode.removeChild(t),t=null)}}},OZ=function(){var e=NZ();return function(t,n){_.useEffect(function(){return e.add(t),function(){e.remove()}},[t&&n])}},CI=function(){var e=OZ(),t=function(n){var r=n.styles,a=n.dynamic;return e(r,a),null};return t},IZ={left:0,top:0,right:0,gap:0},K1=function(e){return parseInt(e||"",10)||0},LZ=function(e){var t=window.getComputedStyle(document.body),n=t[e==="padding"?"paddingLeft":"marginLeft"],r=t[e==="padding"?"paddingTop":"marginTop"],a=t[e==="padding"?"paddingRight":"marginRight"];return[K1(n),K1(r),K1(a)]},DZ=function(e){if(e===void 0&&(e="margin"),typeof window>"u")return IZ;var t=LZ(e),n=document.documentElement.clientWidth,r=window.innerWidth;return{left:t[0],top:t[1],right:t[2],gap:Math.max(0,r-n+t[2]-t[0])}},MZ=CI(),Bc="data-scroll-locked",BZ=function(e,t,n,r){var a=e.left,i=e.top,o=e.right,l=e.gap;return n===void 0&&(n="margin"),`
  .`.concat(bZ,` {
   overflow: hidden `).concat(r,`;
   padding-right: `).concat(l,"px ").concat(r,`;
  }
  body[`).concat(Bc,`] {
    overflow: hidden `).concat(r,`;
    overscroll-behavior: contain;
    `).concat([t&&"position: relative ".concat(r,";"),n==="margin"&&`
    padding-left: `.concat(a,`px;
    padding-top: `).concat(i,`px;
    padding-right: `).concat(o,`px;
    margin-left:0;
    margin-top:0;
    margin-right: `).concat(l,"px ").concat(r,`;
    `),n==="padding"&&"padding-right: ".concat(l,"px ").concat(r,";")].filter(Boolean).join(""),`
  }
  
  .`).concat(A0,` {
    right: `).concat(l,"px ").concat(r,`;
  }
  
  .`).concat(R0,` {
    margin-right: `).concat(l,"px ").concat(r,`;
  }
  
  .`).concat(A0," .").concat(A0,` {
    right: 0 `).concat(r,`;
  }
  
  .`).concat(R0," .").concat(R0,` {
    margin-right: 0 `).concat(r,`;
  }
  
  body[`).concat(Bc,`] {
    `).concat(yZ,": ").concat(l,`px;
  }
`)},uR=function(){var e=parseInt(document.body.getAttribute(Bc)||"0",10);return isFinite(e)?e:0},FZ=function(){_.useEffect(function(){return document.body.setAttribute(Bc,(uR()+1).toString()),function(){var e=uR()-1;e<=0?document.body.removeAttribute(Bc):document.body.setAttribute(Bc,e.toString())}},[])},zZ=function(e){var t=e.noRelative,n=e.noImportant,r=e.gapMode,a=r===void 0?"margin":r;FZ();var i=_.useMemo(function(){return DZ(a)},[a]);return _.createElement(MZ,{styles:BZ(i,!t,a,n?"":"!important")})},ux=!1;if(typeof window<"u")try{var Kf=Object.defineProperty({},"passive",{get:function(){return ux=!0,!0}});window.addEventListener("test",Kf,Kf),window.removeEventListener("test",Kf,Kf)}catch{ux=!1}var Sc=ux?{passive:!1}:!1,$Z=function(e){return e.tagName==="TEXTAREA"},AI=function(e,t){if(!(e instanceof Element))return!1;var n=window.getComputedStyle(e);return n[t]!=="hidden"&&!(n.overflowY===n.overflowX&&!$Z(e)&&n[t]==="visible")},PZ=function(e){return AI(e,"overflowY")},UZ=function(e){return AI(e,"overflowX")},dR=function(e,t){var n=t.ownerDocument,r=t;do{typeof ShadowRoot<"u"&&r instanceof ShadowRoot&&(r=r.host);var a=RI(e,r);if(a){var i=NI(e,r),o=i[1],l=i[2];if(o>l)return!0}r=r.parentNode}while(r&&r!==n.body);return!1},jZ=function(e){var t=e.scrollTop,n=e.scrollHeight,r=e.clientHeight;return[t,n,r]},HZ=function(e){var t=e.scrollLeft,n=e.scrollWidth,r=e.clientWidth;return[t,n,r]},RI=function(e,t){return e==="v"?PZ(t):UZ(t)},NI=function(e,t){return e==="v"?jZ(t):HZ(t)},GZ=function(e,t){return e==="h"&&t==="rtl"?-1:1},qZ=function(e,t,n,r,a){var i=GZ(e,window.getComputedStyle(t).direction),o=i*r,l=n.target,u=t.contains(l),d=!1,h=o>0,f=0,m=0;do{if(!l)break;var b=NI(e,l),y=b[0],v=b[1],w=b[2],S=v-w-i*y;(y||S)&&RI(e,l)&&(f+=S,m+=y);var k=l.parentNode;l=k&&k.nodeType===Node.DOCUMENT_FRAGMENT_NODE?k.host:k}while(!u&&l!==document.body||u&&(t.contains(l)||t===l));return(h&&Math.abs(f)<1||!h&&Math.abs(m)<1)&&(d=!0),d},Zf=function(e){return"changedTouches"in e?[e.changedTouches[0].clientX,e.changedTouches[0].clientY]:[0,0]},hR=function(e){return[e.deltaX,e.deltaY]},pR=function(e){return e&&"current"in e?e.current:e},WZ=function(e,t){return e[0]===t[0]&&e[1]===t[1]},VZ=function(e){return`
  .block-interactivity-`.concat(e,` {pointer-events: none;}
  .allow-interactivity-`).concat(e,` {pointer-events: all;}
`)},YZ=0,wc=[];function XZ(e){var t=_.useRef([]),n=_.useRef([0,0]),r=_.useRef(),a=_.useState(YZ++)[0],i=_.useState(CI)[0],o=_.useRef(e);_.useEffect(function(){o.current=e},[e]),_.useEffect(function(){if(e.inert){document.body.classList.add("block-interactivity-".concat(a));var v=gZ([e.lockRef.current],(e.shards||[]).map(pR),!0).filter(Boolean);return v.forEach(function(w){return w.classList.add("allow-interactivity-".concat(a))}),function(){document.body.classList.remove("block-interactivity-".concat(a)),v.forEach(function(w){return w.classList.remove("allow-interactivity-".concat(a))})}}},[e.inert,e.lockRef.current,e.shards]);var l=_.useCallback(function(v,w){if("touches"in v&&v.touches.length===2||v.type==="wheel"&&v.ctrlKey)return!o.current.allowPinchZoom;var S=Zf(v),k=n.current,R="deltaX"in v?v.deltaX:k[0]-S[0],I="deltaY"in v?v.deltaY:k[1]-S[1],L,A=v.target,M=Math.abs(R)>Math.abs(I)?"h":"v";if("touches"in v&&M==="h"&&A.type==="range")return!1;var P=window.getSelection(),G=P&&P.anchorNode,B=G?G===A||G.contains(A):!1;if(B)return!1;var H=dR(M,A);if(!H)return!0;if(H?L=M:(L=M==="v"?"h":"v",H=dR(M,A)),!H)return!1;if(!r.current&&"changedTouches"in v&&(R||I)&&(r.current=L),!L)return!0;var Z=r.current||L;return qZ(Z,w,v,Z==="h"?R:I)},[]),u=_.useCallback(function(v){var w=v;if(!(!wc.length||wc[wc.length-1]!==i)){var S="deltaY"in w?hR(w):Zf(w),k=t.current.filter(function(L){return L.name===w.type&&(L.target===w.target||w.target===L.shadowParent)&&WZ(L.delta,S)})[0];if(k&&k.should){w.cancelable&&w.preventDefault();return}if(!k){var R=(o.current.shards||[]).map(pR).filter(Boolean).filter(function(L){return L.contains(w.target)}),I=R.length>0?l(w,R[0]):!o.current.noIsolation;I&&w.cancelable&&w.preventDefault()}}},[]),d=_.useCallback(function(v,w,S,k){var R={name:v,delta:w,target:S,should:k,shadowParent:KZ(S)};t.current.push(R),setTimeout(function(){t.current=t.current.filter(function(I){return I!==R})},1)},[]),h=_.useCallback(function(v){n.current=Zf(v),r.current=void 0},[]),f=_.useCallback(function(v){d(v.type,hR(v),v.target,l(v,e.lockRef.current))},[]),m=_.useCallback(function(v){d(v.type,Zf(v),v.target,l(v,e.lockRef.current))},[]);_.useEffect(function(){return wc.push(i),e.setCallbacks({onScrollCapture:f,onWheelCapture:f,onTouchMoveCapture:m}),document.addEventListener("wheel",u,Sc),document.addEventListener("touchmove",u,Sc),document.addEventListener("touchstart",h,Sc),function(){wc=wc.filter(function(v){return v!==i}),document.removeEventListener("wheel",u,Sc),document.removeEventListener("touchmove",u,Sc),document.removeEventListener("touchstart",h,Sc)}},[]);var b=e.removeScrollBar,y=e.inert;return _.createElement(_.Fragment,null,y?_.createElement(i,{styles:VZ(a)}):null,b?_.createElement(zZ,{noRelative:e.noRelative,gapMode:e.gapMode}):null)}function KZ(e){for(var t=null;e!==null;)e instanceof ShadowRoot&&(t=e.host,e=e.host),e=e.parentNode;return t}const ZZ=TZ(_I,XZ);var SS=_.forwardRef(function(e,t){return _.createElement(lg,Ei({},e,{ref:t,sideCar:ZZ}))});SS.classNames=lg.classNames;var dx=["Enter"," "],QZ=["ArrowDown","PageUp","Home"],OI=["ArrowUp","PageDown","End"],JZ=[...QZ,...OI],eQ={ltr:[...dx,"ArrowRight"],rtl:[...dx,"ArrowLeft"]},tQ={ltr:["ArrowLeft"],rtl:["ArrowRight"]},Qh="Menu",[wh,nQ,rQ]=HO(Qh),[Al,II]=Os(Qh,[rQ,sI,bI]),cg=sI(),LI=bI(),[aQ,Rl]=Al(Qh),[iQ,Jh]=Al(Qh),DI=e=>{const{__scopeMenu:t,open:n=!1,children:r,dir:a,onOpenChange:i,modal:o=!0}=e,l=cg(t),[u,d]=_.useState(null),h=_.useRef(!1),f=lr(i),m=cS(a);return _.useEffect(()=>{const b=()=>{h.current=!0,document.addEventListener("pointerdown",y,{capture:!0,once:!0}),document.addEventListener("pointermove",y,{capture:!0,once:!0})},y=()=>h.current=!1;return document.addEventListener("keydown",b,{capture:!0}),()=>{document.removeEventListener("keydown",b,{capture:!0}),document.removeEventListener("pointerdown",y,{capture:!0}),document.removeEventListener("pointermove",y,{capture:!0})}},[]),T.jsx(VK,{...l,children:T.jsx(aQ,{scope:t,open:n,onOpenChange:f,content:u,onContentChange:d,children:T.jsx(iQ,{scope:t,onClose:_.useCallback(()=>f(!1),[f]),isUsingKeyboardRef:h,dir:m,modal:o,children:r})})})};DI.displayName=Qh;var oQ="MenuAnchor",wS=_.forwardRef((e,t)=>{const{__scopeMenu:n,...r}=e,a=cg(n);return T.jsx(YK,{...a,...r,ref:t})});wS.displayName=oQ;var ES="MenuPortal",[sQ,MI]=Al(ES,{forceMount:void 0}),BI=e=>{const{__scopeMenu:t,forceMount:n,children:r,container:a}=e,i=Rl(ES,t);return T.jsx(sQ,{scope:t,forceMount:n,children:T.jsx(Wa,{present:n||i.open,children:T.jsx(xS,{asChild:!0,container:a,children:r})})})};BI.displayName=ES;var Pa="MenuContent",[lQ,kS]=Al(Pa),FI=_.forwardRef((e,t)=>{const n=MI(Pa,e.__scopeMenu),{forceMount:r=n.forceMount,...a}=e,i=Rl(Pa,e.__scopeMenu),o=Jh(Pa,e.__scopeMenu);return T.jsx(wh.Provider,{scope:e.__scopeMenu,children:T.jsx(Wa,{present:r||i.open,children:T.jsx(wh.Slot,{scope:e.__scopeMenu,children:o.modal?T.jsx(cQ,{...a,ref:t}):T.jsx(uQ,{...a,ref:t})})})})}),cQ=_.forwardRef((e,t)=>{const n=Rl(Pa,e.__scopeMenu),r=_.useRef(null),a=un(t,r);return _.useEffect(()=>{const i=r.current;if(i)return EI(i)},[]),T.jsx(TS,{...e,ref:a,trapFocus:n.open,disableOutsidePointerEvents:n.open,disableOutsideScroll:!0,onFocusOutside:ft(e.onFocusOutside,i=>i.preventDefault(),{checkForDefaultPrevented:!1}),onDismiss:()=>n.onOpenChange(!1)})}),uQ=_.forwardRef((e,t)=>{const n=Rl(Pa,e.__scopeMenu);return T.jsx(TS,{...e,ref:t,trapFocus:!1,disableOutsidePointerEvents:!1,disableOutsideScroll:!1,onDismiss:()=>n.onOpenChange(!1)})}),dQ=xh("MenuContent.ScrollLock"),TS=_.forwardRef((e,t)=>{const{__scopeMenu:n,loop:r=!1,trapFocus:a,onOpenAutoFocus:i,onCloseAutoFocus:o,disableOutsidePointerEvents:l,onEntryFocus:u,onEscapeKeyDown:d,onPointerDownOutside:h,onFocusOutside:f,onInteractOutside:m,onDismiss:b,disableOutsideScroll:y,...v}=e,w=Rl(Pa,n),S=Jh(Pa,n),k=cg(n),R=LI(n),I=nQ(n),[L,A]=_.useState(null),M=_.useRef(null),P=un(t,M,w.onContentChange),G=_.useRef(0),B=_.useRef(""),H=_.useRef(0),Z=_.useRef(null),V=_.useRef("right"),q=_.useRef(0),X=y?SS:_.Fragment,$=y?{as:dQ,allowPinchZoom:!0}:void 0,Q=ie=>{var Ee,Ae;const F=B.current+ie,Y=I().filter(ve=>!ve.disabled),oe=document.activeElement,U=(Ee=Y.find(ve=>ve.ref.current===oe))==null?void 0:Ee.textValue,be=Y.map(ve=>ve.textValue),ge=EQ(be,F,U),fe=(Ae=Y.find(ve=>ve.textValue===ge))==null?void 0:Ae.ref.current;(function ve(De){B.current=De,window.clearTimeout(G.current),De!==""&&(G.current=window.setTimeout(()=>ve(""),1e3))})(F),fe&&setTimeout(()=>fe.focus())};_.useEffect(()=>()=>window.clearTimeout(G.current),[]),WO();const J=_.useCallback(ie=>{var Y,oe;return V.current===((Y=Z.current)==null?void 0:Y.side)&&TQ(ie,(oe=Z.current)==null?void 0:oe.area)},[]);return T.jsx(lQ,{scope:n,searchRef:B,onItemEnter:_.useCallback(ie=>{J(ie)&&ie.preventDefault()},[J]),onItemLeave:_.useCallback(ie=>{var F;J(ie)||((F=M.current)==null||F.focus(),A(null))},[J]),onTriggerLeave:_.useCallback(ie=>{J(ie)&&ie.preventDefault()},[J]),pointerGraceTimerRef:H,onPointerGraceIntentChange:_.useCallback(ie=>{Z.current=ie},[]),children:T.jsx(X,{...$,children:T.jsx(dS,{asChild:!0,trapped:a,onMountAutoFocus:ft(i,ie=>{var F;ie.preventDefault(),(F=M.current)==null||F.focus({preventScroll:!0})}),onUnmountAutoFocus:o,children:T.jsx(uS,{asChild:!0,disableOutsidePointerEvents:l,onEscapeKeyDown:d,onPointerDownOutside:h,onFocusOutside:f,onInteractOutside:m,onDismiss:b,children:T.jsx(dZ,{asChild:!0,...R,dir:S.dir,orientation:"vertical",loop:r,currentTabStopId:L,onCurrentTabStopIdChange:A,onEntryFocus:ft(u,ie=>{S.isUsingKeyboardRef.current||ie.preventDefault()}),preventScrollOnEntryFocus:!0,children:T.jsx(XK,{role:"menu","aria-orientation":"vertical","data-state":JI(w.open),"data-radix-menu-content":"",dir:S.dir,...k,...v,ref:P,style:{outline:"none",...v.style},onKeyDown:ft(v.onKeyDown,ie=>{const Y=ie.target.closest("[data-radix-menu-content]")===ie.currentTarget,oe=ie.ctrlKey||ie.altKey||ie.metaKey,U=ie.key.length===1;Y&&(ie.key==="Tab"&&ie.preventDefault(),!oe&&U&&Q(ie.key));const be=M.current;if(ie.target!==be||!JZ.includes(ie.key))return;ie.preventDefault();const fe=I().filter(Ee=>!Ee.disabled).map(Ee=>Ee.ref.current);OI.includes(ie.key)&&fe.reverse(),SQ(fe)}),onBlur:ft(e.onBlur,ie=>{ie.currentTarget.contains(ie.target)||(window.clearTimeout(G.current),B.current="")}),onPointerMove:ft(e.onPointerMove,Eh(ie=>{const F=ie.target,Y=q.current!==ie.clientX;if(ie.currentTarget.contains(F)&&Y){const oe=ie.clientX>q.current?"right":"left";V.current=oe,q.current=ie.clientX}}))})})})})})})});FI.displayName=Pa;var hQ="MenuGroup",_S=_.forwardRef((e,t)=>{const{__scopeMenu:n,...r}=e;return T.jsx(dn.div,{role:"group",...r,ref:t})});_S.displayName=hQ;var pQ="MenuLabel",zI=_.forwardRef((e,t)=>{const{__scopeMenu:n,...r}=e;return T.jsx(dn.div,{...r,ref:t})});zI.displayName=pQ;var rm="MenuItem",fR="menu.itemSelect",ug=_.forwardRef((e,t)=>{const{disabled:n=!1,onSelect:r,...a}=e,i=_.useRef(null),o=Jh(rm,e.__scopeMenu),l=kS(rm,e.__scopeMenu),u=un(t,i),d=_.useRef(!1),h=()=>{const f=i.current;if(!n&&f){const m=new CustomEvent(fR,{bubbles:!0,cancelable:!0});f.addEventListener(fR,b=>r==null?void 0:r(b),{once:!0}),jO(f,m),m.defaultPrevented?d.current=!1:o.onClose()}};return T.jsx($I,{...a,ref:u,disabled:n,onClick:ft(e.onClick,h),onPointerDown:f=>{var m;(m=e.onPointerDown)==null||m.call(e,f),d.current=!0},onPointerUp:ft(e.onPointerUp,f=>{var m;d.current||(m=f.currentTarget)==null||m.click()}),onKeyDown:ft(e.onKeyDown,f=>{const m=l.searchRef.current!=="";n||m&&f.key===" "||dx.includes(f.key)&&(f.currentTarget.click(),f.preventDefault())})})});ug.displayName=rm;var $I=_.forwardRef((e,t)=>{const{__scopeMenu:n,disabled:r=!1,textValue:a,...i}=e,o=kS(rm,n),l=LI(n),u=_.useRef(null),d=un(t,u),[h,f]=_.useState(!1),[m,b]=_.useState("");return _.useEffect(()=>{const y=u.current;y&&b((y.textContent??"").trim())},[i.children]),T.jsx(wh.ItemSlot,{scope:n,disabled:r,textValue:a??m,children:T.jsx(hZ,{asChild:!0,...l,focusable:!r,children:T.jsx(dn.div,{role:"menuitem","data-highlighted":h?"":void 0,"aria-disabled":r||void 0,"data-disabled":r?"":void 0,...i,ref:d,onPointerMove:ft(e.onPointerMove,Eh(y=>{r?o.onItemLeave(y):(o.onItemEnter(y),y.defaultPrevented||y.currentTarget.focus({preventScroll:!0}))})),onPointerLeave:ft(e.onPointerLeave,Eh(y=>o.onItemLeave(y))),onFocus:ft(e.onFocus,()=>f(!0)),onBlur:ft(e.onBlur,()=>f(!1))})})})}),fQ="MenuCheckboxItem",PI=_.forwardRef((e,t)=>{const{checked:n=!1,onCheckedChange:r,...a}=e;return T.jsx(qI,{scope:e.__scopeMenu,checked:n,children:T.jsx(ug,{role:"menuitemcheckbox","aria-checked":am(n)?"mixed":n,...a,ref:t,"data-state":AS(n),onSelect:ft(a.onSelect,()=>r==null?void 0:r(am(n)?!0:!n),{checkForDefaultPrevented:!1})})})});PI.displayName=fQ;var UI="MenuRadioGroup",[mQ,gQ]=Al(UI,{value:void 0,onValueChange:()=>{}}),jI=_.forwardRef((e,t)=>{const{value:n,onValueChange:r,...a}=e,i=lr(r);return T.jsx(mQ,{scope:e.__scopeMenu,value:n,onValueChange:i,children:T.jsx(_S,{...a,ref:t})})});jI.displayName=UI;var HI="MenuRadioItem",GI=_.forwardRef((e,t)=>{const{value:n,...r}=e,a=gQ(HI,e.__scopeMenu),i=n===a.value;return T.jsx(qI,{scope:e.__scopeMenu,checked:i,children:T.jsx(ug,{role:"menuitemradio","aria-checked":i,...r,ref:t,"data-state":AS(i),onSelect:ft(r.onSelect,()=>{var o;return(o=a.onValueChange)==null?void 0:o.call(a,n)},{checkForDefaultPrevented:!1})})})});GI.displayName=HI;var CS="MenuItemIndicator",[qI,bQ]=Al(CS,{checked:!1}),WI=_.forwardRef((e,t)=>{const{__scopeMenu:n,forceMount:r,...a}=e,i=bQ(CS,n);return T.jsx(Wa,{present:r||am(i.checked)||i.checked===!0,children:T.jsx(dn.span,{...a,ref:t,"data-state":AS(i.checked)})})});WI.displayName=CS;var yQ="MenuSeparator",VI=_.forwardRef((e,t)=>{const{__scopeMenu:n,...r}=e;return T.jsx(dn.div,{role:"separator","aria-orientation":"horizontal",...r,ref:t})});VI.displayName=yQ;var vQ="MenuArrow",YI=_.forwardRef((e,t)=>{const{__scopeMenu:n,...r}=e,a=cg(n);return T.jsx(KK,{...a,...r,ref:t})});YI.displayName=vQ;var xQ="MenuSub",[lEe,XI]=Al(xQ),Zd="MenuSubTrigger",KI=_.forwardRef((e,t)=>{const n=Rl(Zd,e.__scopeMenu),r=Jh(Zd,e.__scopeMenu),a=XI(Zd,e.__scopeMenu),i=kS(Zd,e.__scopeMenu),o=_.useRef(null),{pointerGraceTimerRef:l,onPointerGraceIntentChange:u}=i,d={__scopeMenu:e.__scopeMenu},h=_.useCallback(()=>{o.current&&window.clearTimeout(o.current),o.current=null},[]);return _.useEffect(()=>h,[h]),_.useEffect(()=>{const f=l.current;return()=>{window.clearTimeout(f),u(null)}},[l,u]),T.jsx(wS,{asChild:!0,...d,children:T.jsx($I,{id:a.triggerId,"aria-haspopup":"menu","aria-expanded":n.open,"aria-controls":a.contentId,"data-state":JI(n.open),...e,ref:Xh(t,a.onTriggerChange),onClick:f=>{var m;(m=e.onClick)==null||m.call(e,f),!(e.disabled||f.defaultPrevented)&&(f.currentTarget.focus(),n.open||n.onOpenChange(!0))},onPointerMove:ft(e.onPointerMove,Eh(f=>{i.onItemEnter(f),!f.defaultPrevented&&!e.disabled&&!n.open&&!o.current&&(i.onPointerGraceIntentChange(null),o.current=window.setTimeout(()=>{n.onOpenChange(!0),h()},100))})),onPointerLeave:ft(e.onPointerLeave,Eh(f=>{var b,y;h();const m=(b=n.content)==null?void 0:b.getBoundingClientRect();if(m){const v=(y=n.content)==null?void 0:y.dataset.side,w=v==="right",S=w?-5:5,k=m[w?"left":"right"],R=m[w?"right":"left"];i.onPointerGraceIntentChange({area:[{x:f.clientX+S,y:f.clientY},{x:k,y:m.top},{x:R,y:m.top},{x:R,y:m.bottom},{x:k,y:m.bottom}],side:v}),window.clearTimeout(l.current),l.current=window.setTimeout(()=>i.onPointerGraceIntentChange(null),300)}else{if(i.onTriggerLeave(f),f.defaultPrevented)return;i.onPointerGraceIntentChange(null)}})),onKeyDown:ft(e.onKeyDown,f=>{var b;const m=i.searchRef.current!=="";e.disabled||m&&f.key===" "||eQ[r.dir].includes(f.key)&&(n.onOpenChange(!0),(b=n.content)==null||b.focus(),f.preventDefault())})})})});KI.displayName=Zd;var ZI="MenuSubContent",QI=_.forwardRef((e,t)=>{const n=MI(Pa,e.__scopeMenu),{forceMount:r=n.forceMount,...a}=e,i=Rl(Pa,e.__scopeMenu),o=Jh(Pa,e.__scopeMenu),l=XI(ZI,e.__scopeMenu),u=_.useRef(null),d=un(t,u);return T.jsx(wh.Provider,{scope:e.__scopeMenu,children:T.jsx(Wa,{present:r||i.open,children:T.jsx(wh.Slot,{scope:e.__scopeMenu,children:T.jsx(TS,{id:l.contentId,"aria-labelledby":l.triggerId,...a,ref:d,align:"start",side:o.dir==="rtl"?"left":"right",disableOutsidePointerEvents:!1,disableOutsideScroll:!1,trapFocus:!1,onOpenAutoFocus:h=>{var f;o.isUsingKeyboardRef.current&&((f=u.current)==null||f.focus()),h.preventDefault()},onCloseAutoFocus:h=>h.preventDefault(),onFocusOutside:ft(e.onFocusOutside,h=>{h.target!==l.trigger&&i.onOpenChange(!1)}),onEscapeKeyDown:ft(e.onEscapeKeyDown,h=>{o.onClose(),h.preventDefault()}),onKeyDown:ft(e.onKeyDown,h=>{var b;const f=h.currentTarget.contains(h.target),m=tQ[o.dir].includes(h.key);f&&m&&(i.onOpenChange(!1),(b=l.trigger)==null||b.focus(),h.preventDefault())})})})})})});QI.displayName=ZI;function JI(e){return e?"open":"closed"}function am(e){return e==="indeterminate"}function AS(e){return am(e)?"indeterminate":e?"checked":"unchecked"}function SQ(e){const t=document.activeElement;for(const n of e)if(n===t||(n.focus(),document.activeElement!==t))return}function wQ(e,t){return e.map((n,r)=>e[(t+r)%e.length])}function EQ(e,t,n){const a=t.length>1&&Array.from(t).every(d=>d===t[0])?t[0]:t,i=n?e.indexOf(n):-1;let o=wQ(e,Math.max(i,0));a.length===1&&(o=o.filter(d=>d!==n));const u=o.find(d=>d.toLowerCase().startsWith(a.toLowerCase()));return u!==n?u:void 0}function kQ(e,t){const{x:n,y:r}=e;let a=!1;for(let i=0,o=t.length-1;i<t.length;o=i++){const l=t[i],u=t[o],d=l.x,h=l.y,f=u.x,m=u.y;h>r!=m>r&&n<(f-d)*(r-h)/(m-h)+d&&(a=!a)}return a}function TQ(e,t){if(!t)return!1;const n={x:e.clientX,y:e.clientY};return kQ(n,t)}function Eh(e){return t=>t.pointerType==="mouse"?e(t):void 0}var _Q=DI,CQ=wS,AQ=BI,RQ=FI,NQ=_S,OQ=zI,IQ=ug,LQ=PI,DQ=jI,MQ=GI,BQ=WI,FQ=VI,zQ=YI,$Q=KI,PQ=QI,dg="DropdownMenu",[UQ]=Os(dg,[II]),$r=II(),[jQ,eL]=UQ(dg),tL=e=>{const{__scopeDropdownMenu:t,children:n,dir:r,open:a,defaultOpen:i,onOpenChange:o,modal:l=!0}=e,u=$r(t),d=_.useRef(null),[h,f]=lS({prop:a,defaultProp:i??!1,onChange:o,caller:dg});return T.jsx(jQ,{scope:t,triggerId:Dc(),triggerRef:d,contentId:Dc(),open:h,onOpenChange:f,onOpenToggle:_.useCallback(()=>f(m=>!m),[f]),modal:l,children:T.jsx(_Q,{...u,open:h,onOpenChange:f,dir:r,modal:l,children:n})})};tL.displayName=dg;var nL="DropdownMenuTrigger",rL=_.forwardRef((e,t)=>{const{__scopeDropdownMenu:n,disabled:r=!1,...a}=e,i=eL(nL,n),o=$r(n);return T.jsx(CQ,{asChild:!0,...o,children:T.jsx(dn.button,{type:"button",id:i.triggerId,"aria-haspopup":"menu","aria-expanded":i.open,"aria-controls":i.open?i.contentId:void 0,"data-state":i.open?"open":"closed","data-disabled":r?"":void 0,disabled:r,...a,ref:Xh(t,i.triggerRef),onPointerDown:ft(e.onPointerDown,l=>{!r&&l.button===0&&l.ctrlKey===!1&&(i.onOpenToggle(),i.open||l.preventDefault())}),onKeyDown:ft(e.onKeyDown,l=>{r||(["Enter"," "].includes(l.key)&&i.onOpenToggle(),l.key==="ArrowDown"&&i.onOpenChange(!0),["Enter"," ","ArrowDown"].includes(l.key)&&l.preventDefault())})})})});rL.displayName=nL;var HQ="DropdownMenuPortal",aL=e=>{const{__scopeDropdownMenu:t,...n}=e,r=$r(t);return T.jsx(AQ,{...r,...n})};aL.displayName=HQ;var iL="DropdownMenuContent",oL=_.forwardRef((e,t)=>{const{__scopeDropdownMenu:n,...r}=e,a=eL(iL,n),i=$r(n),o=_.useRef(!1);return T.jsx(RQ,{id:a.contentId,"aria-labelledby":a.triggerId,...i,...r,ref:t,onCloseAutoFocus:ft(e.onCloseAutoFocus,l=>{var u;o.current||(u=a.triggerRef.current)==null||u.focus(),o.current=!1,l.preventDefault()}),onInteractOutside:ft(e.onInteractOutside,l=>{const u=l.detail.originalEvent,d=u.button===0&&u.ctrlKey===!0,h=u.button===2||d;(!a.modal||h)&&(o.current=!0)}),style:{...e.style,"--radix-dropdown-menu-content-transform-origin":"var(--radix-popper-transform-origin)","--radix-dropdown-menu-content-available-width":"var(--radix-popper-available-width)","--radix-dropdown-menu-content-available-height":"var(--radix-popper-available-height)","--radix-dropdown-menu-trigger-width":"var(--radix-popper-anchor-width)","--radix-dropdown-menu-trigger-height":"var(--radix-popper-anchor-height)"}})});oL.displayName=iL;var GQ="DropdownMenuGroup",qQ=_.forwardRef((e,t)=>{const{__scopeDropdownMenu:n,...r}=e,a=$r(n);return T.jsx(NQ,{...a,...r,ref:t})});qQ.displayName=GQ;var WQ="DropdownMenuLabel",sL=_.forwardRef((e,t)=>{const{__scopeDropdownMenu:n,...r}=e,a=$r(n);return T.jsx(OQ,{...a,...r,ref:t})});sL.displayName=WQ;var VQ="DropdownMenuItem",lL=_.forwardRef((e,t)=>{const{__scopeDropdownMenu:n,...r}=e,a=$r(n);return T.jsx(IQ,{...a,...r,ref:t})});lL.displayName=VQ;var YQ="DropdownMenuCheckboxItem",cL=_.forwardRef((e,t)=>{const{__scopeDropdownMenu:n,...r}=e,a=$r(n);return T.jsx(LQ,{...a,...r,ref:t})});cL.displayName=YQ;var XQ="DropdownMenuRadioGroup",KQ=_.forwardRef((e,t)=>{const{__scopeDropdownMenu:n,...r}=e,a=$r(n);return T.jsx(DQ,{...a,...r,ref:t})});KQ.displayName=XQ;var ZQ="DropdownMenuRadioItem",uL=_.forwardRef((e,t)=>{const{__scopeDropdownMenu:n,...r}=e,a=$r(n);return T.jsx(MQ,{...a,...r,ref:t})});uL.displayName=ZQ;var QQ="DropdownMenuItemIndicator",dL=_.forwardRef((e,t)=>{const{__scopeDropdownMenu:n,...r}=e,a=$r(n);return T.jsx(BQ,{...a,...r,ref:t})});dL.displayName=QQ;var JQ="DropdownMenuSeparator",hL=_.forwardRef((e,t)=>{const{__scopeDropdownMenu:n,...r}=e,a=$r(n);return T.jsx(FQ,{...a,...r,ref:t})});hL.displayName=JQ;var eJ="DropdownMenuArrow",tJ=_.forwardRef((e,t)=>{const{__scopeDropdownMenu:n,...r}=e,a=$r(n);return T.jsx(zQ,{...a,...r,ref:t})});tJ.displayName=eJ;var nJ="DropdownMenuSubTrigger",pL=_.forwardRef((e,t)=>{const{__scopeDropdownMenu:n,...r}=e,a=$r(n);return T.jsx($Q,{...a,...r,ref:t})});pL.displayName=nJ;var rJ="DropdownMenuSubContent",fL=_.forwardRef((e,t)=>{const{__scopeDropdownMenu:n,...r}=e,a=$r(n);return T.jsx(PQ,{...a,...r,ref:t,style:{...e.style,"--radix-dropdown-menu-content-transform-origin":"var(--radix-popper-transform-origin)","--radix-dropdown-menu-content-available-width":"var(--radix-popper-available-width)","--radix-dropdown-menu-content-available-height":"var(--radix-popper-available-height)","--radix-dropdown-menu-trigger-width":"var(--radix-popper-anchor-width)","--radix-dropdown-menu-trigger-height":"var(--radix-popper-anchor-height)"}})});fL.displayName=rJ;var aJ=tL,iJ=rL,oJ=aL,mL=oL,gL=sL,bL=lL,yL=cL,vL=uL,xL=dL,SL=hL,wL=pL,EL=fL;const kL=aJ,TL=iJ,sJ=_.forwardRef(({className:e,inset:t,children:n,...r},a)=>T.jsxs(wL,{ref:a,className:st("flex cursor-default select-none items-center rounded-sm px-2 py-1.5 text-sm outline-none focus:bg-accent data-[state=open]:bg-accent",t&&"pl-8",e),...r,children:[n,T.jsx(Z2,{className:"ml-auto h-4 w-4"})]}));sJ.displayName=wL.displayName;const lJ=_.forwardRef(({className:e,...t},n)=>T.jsx(EL,{ref:n,className:st("z-50 min-w-[8rem] overflow-hidden rounded-md border bg-popover p-1 text-popover-foreground shadow-lg data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 data-[side=bottom]:slide-in-from-top-2 data-[side=left]:slide-in-from-right-2 data-[side=right]:slide-in-from-left-2 data-[side=top]:slide-in-from-bottom-2",e),...t}));lJ.displayName=EL.displayName;const RS=_.forwardRef(({className:e,sideOffset:t=4,...n},r)=>T.jsx(oJ,{children:T.jsx(mL,{ref:r,sideOffset:t,className:st("z-50 min-w-[8rem] overflow-hidden rounded-md border bg-popover p-1 text-popover-foreground shadow-md data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 data-[side=bottom]:slide-in-from-top-2 data-[side=left]:slide-in-from-right-2 data-[side=right]:slide-in-from-left-2 data-[side=top]:slide-in-from-bottom-2",e),...n})}));RS.displayName=mL.displayName;const cl=_.forwardRef(({className:e,inset:t,...n},r)=>T.jsx(bL,{ref:r,className:st("relative flex cursor-default select-none items-center rounded-sm px-2 py-1.5 text-sm outline-none transition-colors focus:bg-accent focus:text-accent-foreground data-[disabled]:pointer-events-none data-[disabled]:opacity-50",t&&"pl-8",e),...n}));cl.displayName=bL.displayName;const cJ=_.forwardRef(({className:e,children:t,checked:n,...r},a)=>T.jsxs(yL,{ref:a,className:st("relative flex cursor-default select-none items-center rounded-sm py-1.5 pl-8 pr-2 text-sm outline-none transition-colors focus:bg-accent focus:text-accent-foreground data-[disabled]:pointer-events-none data-[disabled]:opacity-50",e),checked:n,...r,children:[T.jsx("span",{className:"absolute left-2 flex h-3.5 w-3.5 items-center justify-center",children:T.jsx(xL,{children:T.jsx(rg,{className:"h-4 w-4"})})}),t]}));cJ.displayName=yL.displayName;const uJ=_.forwardRef(({className:e,children:t,...n},r)=>T.jsxs(vL,{ref:r,className:st("relative flex cursor-default select-none items-center rounded-sm py-1.5 pl-8 pr-2 text-sm outline-none transition-colors focus:bg-accent focus:text-accent-foreground data-[disabled]:pointer-events-none data-[disabled]:opacity-50",e),...n,children:[T.jsx("span",{className:"absolute left-2 flex h-3.5 w-3.5 items-center justify-center",children:T.jsx(xL,{children:T.jsx(XW,{className:"h-2 w-2 fill-current"})})}),t]}));uJ.displayName=vL.displayName;const dJ=_.forwardRef(({className:e,inset:t,...n},r)=>T.jsx(gL,{ref:r,className:st("px-2 py-1.5 text-sm font-semibold",t&&"pl-8",e),...n}));dJ.displayName=gL.displayName;const hJ=_.forwardRef(({className:e,...t},n)=>T.jsx(SL,{ref:n,className:st("-mx-1 my-1 h-px bg-muted",e),...t}));hJ.displayName=SL.displayName;function pJ({data:e,onStop:t,className:n}){return T.jsxs("div",{className:st("flex items-center gap-3 rounded-lg border bg-background px-3 py-1",n),children:[T.jsx("div",{className:"flex flex-1 items-center justify-center gap-[2px]",style:{height:20},children:Array.from(e,(r,a)=>{const i=`b${a}`;return T.jsx("div",{className:"w-[3px] rounded-full bg-red-500 transition-all duration-75",style:{height:`${Math.max(3,r*32)}px`}},i)})}),T.jsx(kt,{variant:"destructive",size:"icon",className:"h-8 w-8 shrink-0",onClick:t,"aria-label":"Stop recording",children:T.jsx(rS,{className:"h-3.5 w-3.5"})})]})}const _L=64,mR=_L/2;function fJ(e){const[t,n]=_.useState("idle"),[r,a]=_.useState(()=>Array.from({length:mR},()=>0)),[i,o]=_.useState(null),l=_.useRef(null),u=_.useRef(null),d=_.useRef(null),h=_.useRef(null),f=_.useRef([]),m=_.useRef(null),b=_.useCallback(()=>{if(h.current!==null&&(cancelAnimationFrame(h.current),h.current=null),u.current&&(u.current.close(),u.current=null),m.current){for(const S of m.current.getTracks())S.stop();m.current=null}d.current=null,l.current=null,f.current=[],a(Array.from({length:mR},()=>0))},[]),y=_.useCallback(()=>{const S=d.current;if(!S)return;const k=new Uint8Array(S.frequencyBinCount);S.getByteFrequencyData(k);const R=Array.from(k,I=>I/255);a(R),h.current=requestAnimationFrame(y)},[]),v=_.useCallback(async()=>{o(null);try{const S=await navigator.mediaDevices.getUserMedia({audio:!0});m.current=S;const k=new AudioContext;u.current=k;const R=k.createMediaStreamSource(S),I=k.createAnalyser();I.fftSize=_L,R.connect(I),d.current=I;const L=MediaRecorder.isTypeSupported("audio/webm;codecs=opus")?"audio/webm;codecs=opus":MediaRecorder.isTypeSupported("audio/webm")?"audio/webm":"",A=new MediaRecorder(S,L?{mimeType:L}:void 0);l.current=A,f.current=[],A.ondataavailable=M=>{M.data.size>0&&f.current.push(M.data)},A.onstop=async()=>{const M=f.current;if(M.length===0){b(),n("idle");return}const P=new Blob(M,{type:A.mimeType||"audio/webm"});b(),n("transcribing");try{const G=new FormData;G.append("file",P,"recording.webm");const B=await fetch("/api/transcribe",{method:"POST",body:G});if(!B.ok){const Z=await B.text();throw new Error(`Transcription failed: ${Z}`)}const H=await B.json();H.text&&e(H.text)}catch(G){o(G instanceof Error?G.message:"Transcription failed")}finally{n("idle")}},A.start(250),n("recording"),y()}catch(S){b(),n("idle"),S instanceof DOMException&&S.name==="NotAllowedError"?o("Microphone access denied"):o(S instanceof Error?S.message:"Failed to start recording")}},[e,b,y]),w=_.useCallback(()=>{const S=l.current;S&&S.state==="recording"&&S.stop()},[]);return{voiceState:t,waveformData:r,startRecording:v,stopRecording:w,error:i}}const gR=_.forwardRef(function({onSend:t,onStop:n,isLoading:r,attachments:a=[],onAddFiles:i,onRemoveAttachment:o,getImageRefs:l,isUploading:u,bgEnabled:d,onOpenTemplates:h},f){const[m,b]=_.useState(""),y=_.useRef(null),v=_.useRef(null);_.useImperativeHandle(f,()=>({insertText:V=>{b(V),requestAnimationFrame(()=>{const q=y.current;q&&(q.style.height="auto",q.style.height=`${Math.min(q.scrollHeight,200)}px`,q.focus())})}}));const w=_.useCallback(V=>{b(q=>{const X=q&&!q.endsWith(" ")?" ":"";return q+X+V}),requestAnimationFrame(()=>{const q=y.current;q&&(q.style.height="auto",q.style.height=`${Math.min(q.scrollHeight,200)}px`,q.focus())})},[]),{voiceState:S,waveformData:k,startRecording:R,stopRecording:I,error:L}=fJ(w),A=()=>{if(!m.trim()&&a.length===0||r||u)return;const V=l==null?void 0:l();t(m,V&&V.length>0?V:void 0),b(""),y.current&&(y.current.style.height="auto")},M=V=>{V.key==="Enter"&&!V.shiftKey&&(V.preventDefault(),A())},P=()=>{const V=y.current;V&&(V.style.height="auto",V.style.height=`${Math.min(V.scrollHeight,200)}px`)},G=()=>{var V;(V=v.current)==null||V.click()},B=V=>{const q=V.target.files;q&&q.length>0&&i&&i(q),V.target.value=""},H=S==="recording",Z=S==="transcribing";return T.jsx("div",{className:"p-4 pb-5",children:T.jsxs("div",{className:"mx-auto max-w-3xl",children:[H?T.jsx(pJ,{data:k,onStop:I}):T.jsxs("div",{className:st("flex flex-col rounded-lg border bg-background",d?"ring-2 ring-blue-500 ring-offset-2 ring-offset-background":"ring-offset-background focus-within:ring-2 focus-within:ring-ring focus-within:ring-offset-2"),children:[o&&T.jsx(XY,{attachments:a,onRemove:o}),T.jsxs("div",{className:"flex items-end",children:[i&&T.jsxs(T.Fragment,{children:[T.jsx("input",{ref:v,type:"file",accept:"image/jpeg,image/png,image/gif,image/webp",multiple:!0,onChange:B,className:"hidden"}),T.jsx("div",{className:"flex shrink-0 items-center p-1",children:T.jsxs(kL,{children:[T.jsx(TL,{asChild:!0,children:T.jsx("button",{type:"button",className:st("inline-flex h-8 w-8 items-center justify-center rounded-md","text-muted-foreground hover:text-foreground","transition-colors"),"aria-label":"Attach file",children:T.jsx(tS,{className:"h-4 w-4"})})}),T.jsxs(RS,{align:"start",children:[T.jsxs(cl,{onClick:G,children:[T.jsx(AV,{className:"mr-2 h-4 w-4"}),"Attach image"]}),h&&T.jsxs(cl,{onClick:h,children:[T.jsx(vO,{className:"mr-2 h-4 w-4"}),"Use template"]})]})]})})]}),T.jsx("textarea",{ref:y,value:m,onChange:V=>b(V.target.value),onKeyDown:M,onInput:P,placeholder:Z?"Transcribing...":"Type a message...",rows:1,className:st("flex-1 resize-none bg-transparent px-3 py-2 text-sm","placeholder:text-muted-foreground","focus-visible:outline-none","disabled:cursor-not-allowed disabled:opacity-50",!i&&"pl-3"),disabled:r||Z}),T.jsx("div",{className:"flex shrink-0 items-center gap-0.5 p-1",children:r?T.jsx(kt,{variant:"destructive",size:"icon",className:"h-8 w-8",onClick:n,"aria-label":"Stop generation",children:T.jsx(rS,{className:"h-4 w-4"})}):T.jsxs(T.Fragment,{children:[T.jsx("button",{type:"button",onClick:R,disabled:Z,className:st("inline-flex h-8 w-8 items-center justify-center rounded-md","text-muted-foreground hover:text-foreground","disabled:pointer-events-none disabled:opacity-50","transition-colors"),"aria-label":Z?"Transcribing":"Voice input",children:Z?T.jsx(fu,{className:"h-4 w-4 animate-spin"}):T.jsx(TV,{className:"h-4 w-4"})}),T.jsx(kt,{size:"icon",className:"h-8 w-8",onClick:A,disabled:!m.trim()&&a.length===0||Z||u,"aria-label":"Send message",children:T.jsx(PV,{className:"h-4 w-4"})})]})})]})]}),L&&T.jsx("p",{className:"mt-1 text-xs text-destructive",children:L})]})})}),mJ=new Set(["generate_image","edit_image"]);function gJ({toolCall:e,onMaskEdit:t}){var a,i;const n=_.useMemo(()=>{try{return JSON.parse(e.result??"")}catch{return null}},[e.result]);if(!n||n.error||!((a=n.images)!=null&&a.length))return null;const r=n.images.length===1;return T.jsxs("div",{className:"my-2 flex flex-col gap-2",children:[T.jsx("div",{className:r?"":"grid grid-cols-2 gap-2",children:n.images.map(o=>T.jsxs("div",{className:"group/img relative",children:[T.jsx("a",{href:o.url,target:"_blank",rel:"noopener noreferrer",className:"block",children:T.jsx("img",{src:o.url,alt:o.revised_prompt??"Generated image",className:"max-w-full rounded-lg border border-border/50 shadow-sm transition-shadow hover:shadow-md"})}),t&&T.jsxs(kt,{variant:"secondary",size:"sm",className:"absolute bottom-2 right-2 h-7 gap-1 px-2 text-xs opacity-0 shadow-md transition-opacity group-hover/img:opacity-100",onClick:l=>{l.preventDefault(),l.stopPropagation(),t(o.url)},"aria-label":"Edit with mask",children:[T.jsx(wO,{className:"h-3 w-3"}),"Edit"]})]},o.filename))}),((i=n.images[0])==null?void 0:i.revised_prompt)&&T.jsx("p",{className:"text-xs text-muted-foreground/70 italic",children:n.images[0].revised_prompt})]})}function bJ({toolCalls:e,onMaskEdit:t}){const n=_.useMemo(()=>e.filter(r=>mJ.has(r.name)&&r.status==="completed"&&r.result),[e]);return n.length===0?null:T.jsx("div",{className:"flex flex-col gap-1",children:n.map(r=>T.jsx(gJ,{toolCall:r,onMaskEdit:t},r.id))})}function bR(e){const t=[],n=String(e||"");let r=n.indexOf(","),a=0,i=!1;for(;!i;){r===-1&&(r=n.length,i=!0);const o=n.slice(a,r).trim();(o||!i)&&t.push(o),a=r+1,r=n.indexOf(",",a)}return t}function yJ(e,t){const n={};return(e[e.length-1]===""?[...e,""]:e).join((n.padRight?" ":"")+","+(n.padLeft===!1?"":" ")).trim()}const vJ=/^[$_\p{ID_Start}][$_\u{200C}\u{200D}\p{ID_Continue}]*$/u,xJ=/^[$_\p{ID_Start}][-$_\u{200C}\u{200D}\p{ID_Continue}]*$/u,SJ={};function yR(e,t){return(SJ.jsx?xJ:vJ).test(e)}const wJ=/[ \t\n\f\r]/g;function EJ(e){return typeof e=="object"?e.type==="text"?vR(e.value):!1:vR(e)}function vR(e){return e.replace(wJ,"")===""}class ep{constructor(t,n,r){this.normal=n,this.property=t,r&&(this.space=r)}}ep.prototype.normal={};ep.prototype.property={};ep.prototype.space=void 0;function CL(e,t){const n={},r={};for(const a of e)Object.assign(n,a.property),Object.assign(r,a.normal);return new ep(n,r,t)}function kh(e){return e.toLowerCase()}class ta{constructor(t,n){this.attribute=n,this.property=t}}ta.prototype.attribute="";ta.prototype.booleanish=!1;ta.prototype.boolean=!1;ta.prototype.commaOrSpaceSeparated=!1;ta.prototype.commaSeparated=!1;ta.prototype.defined=!1;ta.prototype.mustUseProperty=!1;ta.prototype.number=!1;ta.prototype.overloadedBoolean=!1;ta.prototype.property="";ta.prototype.spaceSeparated=!1;ta.prototype.space=void 0;let kJ=0;const St=Nl(),zn=Nl(),hx=Nl(),Ne=Nl(),on=Nl(),Fc=Nl(),da=Nl();function Nl(){return 2**++kJ}const px=Object.freeze(Object.defineProperty({__proto__:null,boolean:St,booleanish:zn,commaOrSpaceSeparated:da,commaSeparated:Fc,number:Ne,overloadedBoolean:hx,spaceSeparated:on},Symbol.toStringTag,{value:"Module"})),Z1=Object.keys(px);class NS extends ta{constructor(t,n,r,a){let i=-1;if(super(t,n),xR(this,"space",a),typeof r=="number")for(;++i<Z1.length;){const o=Z1[i];xR(this,Z1[i],(r&px[o])===px[o])}}}NS.prototype.defined=!0;function xR(e,t,n){n&&(e[t]=n)}function bu(e){const t={},n={};for(const[r,a]of Object.entries(e.properties)){const i=new NS(r,e.transform(e.attributes||{},r),a,e.space);e.mustUseProperty&&e.mustUseProperty.includes(r)&&(i.mustUseProperty=!0),t[r]=i,n[kh(r)]=r,n[kh(i.attribute)]=r}return new ep(t,n,e.space)}const AL=bu({properties:{ariaActiveDescendant:null,ariaAtomic:zn,ariaAutoComplete:null,ariaBusy:zn,ariaChecked:zn,ariaColCount:Ne,ariaColIndex:Ne,ariaColSpan:Ne,ariaControls:on,ariaCurrent:null,ariaDescribedBy:on,ariaDetails:null,ariaDisabled:zn,ariaDropEffect:on,ariaErrorMessage:null,ariaExpanded:zn,ariaFlowTo:on,ariaGrabbed:zn,ariaHasPopup:null,ariaHidden:zn,ariaInvalid:null,ariaKeyShortcuts:null,ariaLabel:null,ariaLabelledBy:on,ariaLevel:Ne,ariaLive:null,ariaModal:zn,ariaMultiLine:zn,ariaMultiSelectable:zn,ariaOrientation:null,ariaOwns:on,ariaPlaceholder:null,ariaPosInSet:Ne,ariaPressed:zn,ariaReadOnly:zn,ariaRelevant:null,ariaRequired:zn,ariaRoleDescription:on,ariaRowCount:Ne,ariaRowIndex:Ne,ariaRowSpan:Ne,ariaSelected:zn,ariaSetSize:Ne,ariaSort:null,ariaValueMax:Ne,ariaValueMin:Ne,ariaValueNow:Ne,ariaValueText:null,role:null},transform(e,t){return t==="role"?t:"aria-"+t.slice(4).toLowerCase()}});function RL(e,t){return t in e?e[t]:t}function NL(e,t){return RL(e,t.toLowerCase())}const TJ=bu({attributes:{acceptcharset:"accept-charset",classname:"class",htmlfor:"for",httpequiv:"http-equiv"},mustUseProperty:["checked","multiple","muted","selected"],properties:{abbr:null,accept:Fc,acceptCharset:on,accessKey:on,action:null,allow:null,allowFullScreen:St,allowPaymentRequest:St,allowUserMedia:St,alt:null,as:null,async:St,autoCapitalize:null,autoComplete:on,autoFocus:St,autoPlay:St,blocking:on,capture:null,charSet:null,checked:St,cite:null,className:on,cols:Ne,colSpan:null,content:null,contentEditable:zn,controls:St,controlsList:on,coords:Ne|Fc,crossOrigin:null,data:null,dateTime:null,decoding:null,default:St,defer:St,dir:null,dirName:null,disabled:St,download:hx,draggable:zn,encType:null,enterKeyHint:null,fetchPriority:null,form:null,formAction:null,formEncType:null,formMethod:null,formNoValidate:St,formTarget:null,headers:on,height:Ne,hidden:hx,high:Ne,href:null,hrefLang:null,htmlFor:on,httpEquiv:on,id:null,imageSizes:null,imageSrcSet:null,inert:St,inputMode:null,integrity:null,is:null,isMap:St,itemId:null,itemProp:on,itemRef:on,itemScope:St,itemType:on,kind:null,label:null,lang:null,language:null,list:null,loading:null,loop:St,low:Ne,manifest:null,max:null,maxLength:Ne,media:null,method:null,min:null,minLength:Ne,multiple:St,muted:St,name:null,nonce:null,noModule:St,noValidate:St,onAbort:null,onAfterPrint:null,onAuxClick:null,onBeforeMatch:null,onBeforePrint:null,onBeforeToggle:null,onBeforeUnload:null,onBlur:null,onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,onContextLost:null,onContextMenu:null,onContextRestored:null,onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,onEmptied:null,onEnded:null,onError:null,onFocus:null,onFormData:null,onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,onKeyUp:null,onLanguageChange:null,onLoad:null,onLoadedData:null,onLoadedMetadata:null,onLoadEnd:null,onLoadStart:null,onMessage:null,onMessageError:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onOffline:null,onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,onRejectionHandled:null,onReset:null,onResize:null,onScroll:null,onScrollEnd:null,onSecurityPolicyViolation:null,onSeeked:null,onSeeking:null,onSelect:null,onSlotChange:null,onStalled:null,onStorage:null,onSubmit:null,onSuspend:null,onTimeUpdate:null,onToggle:null,onUnhandledRejection:null,onUnload:null,onVolumeChange:null,onWaiting:null,onWheel:null,open:St,optimum:Ne,pattern:null,ping:on,placeholder:null,playsInline:St,popover:null,popoverTarget:null,popoverTargetAction:null,poster:null,preload:null,readOnly:St,referrerPolicy:null,rel:on,required:St,reversed:St,rows:Ne,rowSpan:Ne,sandbox:on,scope:null,scoped:St,seamless:St,selected:St,shadowRootClonable:St,shadowRootDelegatesFocus:St,shadowRootMode:null,shape:null,size:Ne,sizes:null,slot:null,span:Ne,spellCheck:zn,src:null,srcDoc:null,srcLang:null,srcSet:null,start:Ne,step:null,style:null,tabIndex:Ne,target:null,title:null,translate:null,type:null,typeMustMatch:St,useMap:null,value:zn,width:Ne,wrap:null,writingSuggestions:null,align:null,aLink:null,archive:on,axis:null,background:null,bgColor:null,border:Ne,borderColor:null,bottomMargin:Ne,cellPadding:null,cellSpacing:null,char:null,charOff:null,classId:null,clear:null,code:null,codeBase:null,codeType:null,color:null,compact:St,declare:St,event:null,face:null,frame:null,frameBorder:null,hSpace:Ne,leftMargin:Ne,link:null,longDesc:null,lowSrc:null,marginHeight:Ne,marginWidth:Ne,noResize:St,noHref:St,noShade:St,noWrap:St,object:null,profile:null,prompt:null,rev:null,rightMargin:Ne,rules:null,scheme:null,scrolling:zn,standby:null,summary:null,text:null,topMargin:Ne,valueType:null,version:null,vAlign:null,vLink:null,vSpace:Ne,allowTransparency:null,autoCorrect:null,autoSave:null,disablePictureInPicture:St,disableRemotePlayback:St,prefix:null,property:null,results:Ne,security:null,unselectable:null},space:"html",transform:NL}),_J=bu({attributes:{accentHeight:"accent-height",alignmentBaseline:"alignment-baseline",arabicForm:"arabic-form",baselineShift:"baseline-shift",capHeight:"cap-height",className:"class",clipPath:"clip-path",clipRule:"clip-rule",colorInterpolation:"color-interpolation",colorInterpolationFilters:"color-interpolation-filters",colorProfile:"color-profile",colorRendering:"color-rendering",crossOrigin:"crossorigin",dataType:"datatype",dominantBaseline:"dominant-baseline",enableBackground:"enable-background",fillOpacity:"fill-opacity",fillRule:"fill-rule",floodColor:"flood-color",floodOpacity:"flood-opacity",fontFamily:"font-family",fontSize:"font-size",fontSizeAdjust:"font-size-adjust",fontStretch:"font-stretch",fontStyle:"font-style",fontVariant:"font-variant",fontWeight:"font-weight",glyphName:"glyph-name",glyphOrientationHorizontal:"glyph-orientation-horizontal",glyphOrientationVertical:"glyph-orientation-vertical",hrefLang:"hreflang",horizAdvX:"horiz-adv-x",horizOriginX:"horiz-origin-x",horizOriginY:"horiz-origin-y",imageRendering:"image-rendering",letterSpacing:"letter-spacing",lightingColor:"lighting-color",markerEnd:"marker-end",markerMid:"marker-mid",markerStart:"marker-start",navDown:"nav-down",navDownLeft:"nav-down-left",navDownRight:"nav-down-right",navLeft:"nav-left",navNext:"nav-next",navPrev:"nav-prev",navRight:"nav-right",navUp:"nav-up",navUpLeft:"nav-up-left",navUpRight:"nav-up-right",onAbort:"onabort",onActivate:"onactivate",onAfterPrint:"onafterprint",onBeforePrint:"onbeforeprint",onBegin:"onbegin",onCancel:"oncancel",onCanPlay:"oncanplay",onCanPlayThrough:"oncanplaythrough",onChange:"onchange",onClick:"onclick",onClose:"onclose",onCopy:"oncopy",onCueChange:"oncuechange",onCut:"oncut",onDblClick:"ondblclick",onDrag:"ondrag",onDragEnd:"ondragend",onDragEnter:"ondragenter",onDragExit:"ondragexit",onDragLeave:"ondragleave",onDragOver:"ondragover",onDragStart:"ondragstart",onDrop:"ondrop",onDurationChange:"ondurationchange",onEmptied:"onemptied",onEnd:"onend",onEnded:"onended",onError:"onerror",onFocus:"onfocus",onFocusIn:"onfocusin",onFocusOut:"onfocusout",onHashChange:"onhashchange",onInput:"oninput",onInvalid:"oninvalid",onKeyDown:"onkeydown",onKeyPress:"onkeypress",onKeyUp:"onkeyup",onLoad:"onload",onLoadedData:"onloadeddata",onLoadedMetadata:"onloadedmetadata",onLoadStart:"onloadstart",onMessage:"onmessage",onMouseDown:"onmousedown",onMouseEnter:"onmouseenter",onMouseLeave:"onmouseleave",onMouseMove:"onmousemove",onMouseOut:"onmouseout",onMouseOver:"onmouseover",onMouseUp:"onmouseup",onMouseWheel:"onmousewheel",onOffline:"onoffline",onOnline:"ononline",onPageHide:"onpagehide",onPageShow:"onpageshow",onPaste:"onpaste",onPause:"onpause",onPlay:"onplay",onPlaying:"onplaying",onPopState:"onpopstate",onProgress:"onprogress",onRateChange:"onratechange",onRepeat:"onrepeat",onReset:"onreset",onResize:"onresize",onScroll:"onscroll",onSeeked:"onseeked",onSeeking:"onseeking",onSelect:"onselect",onShow:"onshow",onStalled:"onstalled",onStorage:"onstorage",onSubmit:"onsubmit",onSuspend:"onsuspend",onTimeUpdate:"ontimeupdate",onToggle:"ontoggle",onUnload:"onunload",onVolumeChange:"onvolumechange",onWaiting:"onwaiting",onZoom:"onzoom",overlinePosition:"overline-position",overlineThickness:"overline-thickness",paintOrder:"paint-order",panose1:"panose-1",pointerEvents:"pointer-events",referrerPolicy:"referrerpolicy",renderingIntent:"rendering-intent",shapeRendering:"shape-rendering",stopColor:"stop-color",stopOpacity:"stop-opacity",strikethroughPosition:"strikethrough-position",strikethroughThickness:"strikethrough-thickness",strokeDashArray:"stroke-dasharray",strokeDashOffset:"stroke-dashoffset",strokeLineCap:"stroke-linecap",strokeLineJoin:"stroke-linejoin",strokeMiterLimit:"stroke-miterlimit",strokeOpacity:"stroke-opacity",strokeWidth:"stroke-width",tabIndex:"tabindex",textAnchor:"text-anchor",textDecoration:"text-decoration",textRendering:"text-rendering",transformOrigin:"transform-origin",typeOf:"typeof",underlinePosition:"underline-position",underlineThickness:"underline-thickness",unicodeBidi:"unicode-bidi",unicodeRange:"unicode-range",unitsPerEm:"units-per-em",vAlphabetic:"v-alphabetic",vHanging:"v-hanging",vIdeographic:"v-ideographic",vMathematical:"v-mathematical",vectorEffect:"vector-effect",vertAdvY:"vert-adv-y",vertOriginX:"vert-origin-x",vertOriginY:"vert-origin-y",wordSpacing:"word-spacing",writingMode:"writing-mode",xHeight:"x-height",playbackOrder:"playbackorder",timelineBegin:"timelinebegin"},properties:{about:da,accentHeight:Ne,accumulate:null,additive:null,alignmentBaseline:null,alphabetic:Ne,amplitude:Ne,arabicForm:null,ascent:Ne,attributeName:null,attributeType:null,azimuth:Ne,bandwidth:null,baselineShift:null,baseFrequency:null,baseProfile:null,bbox:null,begin:null,bias:Ne,by:null,calcMode:null,capHeight:Ne,className:on,clip:null,clipPath:null,clipPathUnits:null,clipRule:null,color:null,colorInterpolation:null,colorInterpolationFilters:null,colorProfile:null,colorRendering:null,content:null,contentScriptType:null,contentStyleType:null,crossOrigin:null,cursor:null,cx:null,cy:null,d:null,dataType:null,defaultAction:null,descent:Ne,diffuseConstant:Ne,direction:null,display:null,dur:null,divisor:Ne,dominantBaseline:null,download:St,dx:null,dy:null,edgeMode:null,editable:null,elevation:Ne,enableBackground:null,end:null,event:null,exponent:Ne,externalResourcesRequired:null,fill:null,fillOpacity:Ne,fillRule:null,filter:null,filterRes:null,filterUnits:null,floodColor:null,floodOpacity:null,focusable:null,focusHighlight:null,fontFamily:null,fontSize:null,fontSizeAdjust:null,fontStretch:null,fontStyle:null,fontVariant:null,fontWeight:null,format:null,fr:null,from:null,fx:null,fy:null,g1:Fc,g2:Fc,glyphName:Fc,glyphOrientationHorizontal:null,glyphOrientationVertical:null,glyphRef:null,gradientTransform:null,gradientUnits:null,handler:null,hanging:Ne,hatchContentUnits:null,hatchUnits:null,height:null,href:null,hrefLang:null,horizAdvX:Ne,horizOriginX:Ne,horizOriginY:Ne,id:null,ideographic:Ne,imageRendering:null,initialVisibility:null,in:null,in2:null,intercept:Ne,k:Ne,k1:Ne,k2:Ne,k3:Ne,k4:Ne,kernelMatrix:da,kernelUnitLength:null,keyPoints:null,keySplines:null,keyTimes:null,kerning:null,lang:null,lengthAdjust:null,letterSpacing:null,lightingColor:null,limitingConeAngle:Ne,local:null,markerEnd:null,markerMid:null,markerStart:null,markerHeight:null,markerUnits:null,markerWidth:null,mask:null,maskContentUnits:null,maskUnits:null,mathematical:null,max:null,media:null,mediaCharacterEncoding:null,mediaContentEncodings:null,mediaSize:Ne,mediaTime:null,method:null,min:null,mode:null,name:null,navDown:null,navDownLeft:null,navDownRight:null,navLeft:null,navNext:null,navPrev:null,navRight:null,navUp:null,navUpLeft:null,navUpRight:null,numOctaves:null,observer:null,offset:null,onAbort:null,onActivate:null,onAfterPrint:null,onBeforePrint:null,onBegin:null,onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,onEmptied:null,onEnd:null,onEnded:null,onError:null,onFocus:null,onFocusIn:null,onFocusOut:null,onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,onKeyUp:null,onLoad:null,onLoadedData:null,onLoadedMetadata:null,onLoadStart:null,onMessage:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onMouseWheel:null,onOffline:null,onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,onRepeat:null,onReset:null,onResize:null,onScroll:null,onSeeked:null,onSeeking:null,onSelect:null,onShow:null,onStalled:null,onStorage:null,onSubmit:null,onSuspend:null,onTimeUpdate:null,onToggle:null,onUnload:null,onVolumeChange:null,onWaiting:null,onZoom:null,opacity:null,operator:null,order:null,orient:null,orientation:null,origin:null,overflow:null,overlay:null,overlinePosition:Ne,overlineThickness:Ne,paintOrder:null,panose1:null,path:null,pathLength:Ne,patternContentUnits:null,patternTransform:null,patternUnits:null,phase:null,ping:on,pitch:null,playbackOrder:null,pointerEvents:null,points:null,pointsAtX:Ne,pointsAtY:Ne,pointsAtZ:Ne,preserveAlpha:null,preserveAspectRatio:null,primitiveUnits:null,propagate:null,property:da,r:null,radius:null,referrerPolicy:null,refX:null,refY:null,rel:da,rev:da,renderingIntent:null,repeatCount:null,repeatDur:null,requiredExtensions:da,requiredFeatures:da,requiredFonts:da,requiredFormats:da,resource:null,restart:null,result:null,rotate:null,rx:null,ry:null,scale:null,seed:null,shapeRendering:null,side:null,slope:null,snapshotTime:null,specularConstant:Ne,specularExponent:Ne,spreadMethod:null,spacing:null,startOffset:null,stdDeviation:null,stemh:null,stemv:null,stitchTiles:null,stopColor:null,stopOpacity:null,strikethroughPosition:Ne,strikethroughThickness:Ne,string:null,stroke:null,strokeDashArray:da,strokeDashOffset:null,strokeLineCap:null,strokeLineJoin:null,strokeMiterLimit:Ne,strokeOpacity:Ne,strokeWidth:null,style:null,surfaceScale:Ne,syncBehavior:null,syncBehaviorDefault:null,syncMaster:null,syncTolerance:null,syncToleranceDefault:null,systemLanguage:da,tabIndex:Ne,tableValues:null,target:null,targetX:Ne,targetY:Ne,textAnchor:null,textDecoration:null,textRendering:null,textLength:null,timelineBegin:null,title:null,transformBehavior:null,type:null,typeOf:da,to:null,transform:null,transformOrigin:null,u1:null,u2:null,underlinePosition:Ne,underlineThickness:Ne,unicode:null,unicodeBidi:null,unicodeRange:null,unitsPerEm:Ne,values:null,vAlphabetic:Ne,vMathematical:Ne,vectorEffect:null,vHanging:Ne,vIdeographic:Ne,version:null,vertAdvY:Ne,vertOriginX:Ne,vertOriginY:Ne,viewBox:null,viewTarget:null,visibility:null,width:null,widths:null,wordSpacing:null,writingMode:null,x:null,x1:null,x2:null,xChannelSelector:null,xHeight:Ne,y:null,y1:null,y2:null,yChannelSelector:null,z:null,zoomAndPan:null},space:"svg",transform:RL}),OL=bu({properties:{xLinkActuate:null,xLinkArcRole:null,xLinkHref:null,xLinkRole:null,xLinkShow:null,xLinkTitle:null,xLinkType:null},space:"xlink",transform(e,t){return"xlink:"+t.slice(5).toLowerCase()}}),IL=bu({attributes:{xmlnsxlink:"xmlns:xlink"},properties:{xmlnsXLink:null,xmlns:null},space:"xmlns",transform:NL}),LL=bu({properties:{xmlBase:null,xmlLang:null,xmlSpace:null},space:"xml",transform(e,t){return"xml:"+t.slice(3).toLowerCase()}}),CJ={classId:"classID",dataType:"datatype",itemId:"itemID",strokeDashArray:"strokeDasharray",strokeDashOffset:"strokeDashoffset",strokeLineCap:"strokeLinecap",strokeLineJoin:"strokeLinejoin",strokeMiterLimit:"strokeMiterlimit",typeOf:"typeof",xLinkActuate:"xlinkActuate",xLinkArcRole:"xlinkArcrole",xLinkHref:"xlinkHref",xLinkRole:"xlinkRole",xLinkShow:"xlinkShow",xLinkTitle:"xlinkTitle",xLinkType:"xlinkType",xmlnsXLink:"xmlnsXlink"},AJ=/[A-Z]/g,SR=/-[a-z]/g,RJ=/^data[-\w.:]+$/i;function DL(e,t){const n=kh(t);let r=t,a=ta;if(n in e.normal)return e.property[e.normal[n]];if(n.length>4&&n.slice(0,4)==="data"&&RJ.test(t)){if(t.charAt(4)==="-"){const i=t.slice(5).replace(SR,OJ);r="data"+i.charAt(0).toUpperCase()+i.slice(1)}else{const i=t.slice(4);if(!SR.test(i)){let o=i.replace(AJ,NJ);o.charAt(0)!=="-"&&(o="-"+o),t="data"+o}}a=NS}return new a(r,t)}function NJ(e){return"-"+e.toLowerCase()}function OJ(e){return e.charAt(1).toUpperCase()}const ML=CL([AL,TJ,OL,IL,LL],"html"),hg=CL([AL,_J,OL,IL,LL],"svg");function wR(e){const t=String(e||"").trim();return t?t.split(/[ \t\n\r\f]+/g):[]}function IJ(e){return e.join(" ").trim()}var Ec={},Q1,ER;function LJ(){if(ER)return Q1;ER=1;var e=/\/\*[^*]*\*+([^/*][^*]*\*+)*\//g,t=/\n/g,n=/^\s*/,r=/^(\*?[-#/*\\\w]+(\[[0-9a-z_-]+\])?)\s*/,a=/^:\s*/,i=/^((?:'(?:\\'|.)*?'|"(?:\\"|.)*?"|\([^)]*?\)|[^};])+)/,o=/^[;\s]*/,l=/^\s+|\s+$/g,u=`
`,d="/",h="*",f="",m="comment",b="declaration";function y(w,S){if(typeof w!="string")throw new TypeError("First argument must be a string");if(!w)return[];S=S||{};var k=1,R=1;function I(q){var X=q.match(t);X&&(k+=X.length);var $=q.lastIndexOf(u);R=~$?q.length-$:R+q.length}function L(){var q={line:k,column:R};return function(X){return X.position=new A(q),G(),X}}function A(q){this.start=q,this.end={line:k,column:R},this.source=S.source}A.prototype.content=w;function M(q){var X=new Error(S.source+":"+k+":"+R+": "+q);if(X.reason=q,X.filename=S.source,X.line=k,X.column=R,X.source=w,!S.silent)throw X}function P(q){var X=q.exec(w);if(X){var $=X[0];return I($),w=w.slice($.length),X}}function G(){P(n)}function B(q){var X;for(q=q||[];X=H();)X!==!1&&q.push(X);return q}function H(){var q=L();if(!(d!=w.charAt(0)||h!=w.charAt(1))){for(var X=2;f!=w.charAt(X)&&(h!=w.charAt(X)||d!=w.charAt(X+1));)++X;if(X+=2,f===w.charAt(X-1))return M("End of comment missing");var $=w.slice(2,X-2);return R+=2,I($),w=w.slice(X),R+=2,q({type:m,comment:$})}}function Z(){var q=L(),X=P(r);if(X){if(H(),!P(a))return M("property missing ':'");var $=P(i),Q=q({type:b,property:v(X[0].replace(e,f)),value:$?v($[0].replace(e,f)):f});return P(o),Q}}function V(){var q=[];B(q);for(var X;X=Z();)X!==!1&&(q.push(X),B(q));return q}return G(),V()}function v(w){return w?w.replace(l,f):f}return Q1=y,Q1}var kR;function DJ(){if(kR)return Ec;kR=1;var e=Ec&&Ec.__importDefault||function(r){return r&&r.__esModule?r:{default:r}};Object.defineProperty(Ec,"__esModule",{value:!0}),Ec.default=n;const t=e(LJ());function n(r,a){let i=null;if(!r||typeof r!="string")return i;const o=(0,t.default)(r),l=typeof a=="function";return o.forEach(u=>{if(u.type!=="declaration")return;const{property:d,value:h}=u;l?a(d,h,u):h&&(i=i||{},i[d]=h)}),i}return Ec}var Dd={},TR;function MJ(){if(TR)return Dd;TR=1,Object.defineProperty(Dd,"__esModule",{value:!0}),Dd.camelCase=void 0;var e=/^--[a-zA-Z0-9_-]+$/,t=/-([a-z])/g,n=/^[^-]+$/,r=/^-(webkit|moz|ms|o|khtml)-/,a=/^-(ms)-/,i=function(d){return!d||n.test(d)||e.test(d)},o=function(d,h){return h.toUpperCase()},l=function(d,h){return"".concat(h,"-")},u=function(d,h){return h===void 0&&(h={}),i(d)?d:(d=d.toLowerCase(),h.reactCompat?d=d.replace(a,l):d=d.replace(r,l),d.replace(t,o))};return Dd.camelCase=u,Dd}var Md,_R;function BJ(){if(_R)return Md;_R=1;var e=Md&&Md.__importDefault||function(a){return a&&a.__esModule?a:{default:a}},t=e(DJ()),n=MJ();function r(a,i){var o={};return!a||typeof a!="string"||(0,t.default)(a,function(l,u){l&&u&&(o[(0,n.camelCase)(l,i)]=u)}),o}return r.default=r,Md=r,Md}var FJ=BJ();const zJ=qh(FJ),BL=FL("end"),OS=FL("start");function FL(e){return t;function t(n){const r=n&&n.position&&n.position[e]||{};if(typeof r.line=="number"&&r.line>0&&typeof r.column=="number"&&r.column>0)return{line:r.line,column:r.column,offset:typeof r.offset=="number"&&r.offset>-1?r.offset:void 0}}}function $J(e){const t=OS(e),n=BL(e);if(t&&n)return{start:t,end:n}}function sh(e){return!e||typeof e!="object"?"":"position"in e||"type"in e?CR(e.position):"start"in e||"end"in e?CR(e):"line"in e||"column"in e?fx(e):""}function fx(e){return AR(e&&e.line)+":"+AR(e&&e.column)}function CR(e){return fx(e&&e.start)+"-"+fx(e&&e.end)}function AR(e){return e&&typeof e=="number"?e:1}class Sr extends Error{constructor(t,n,r){super(),typeof n=="string"&&(r=n,n=void 0);let a="",i={},o=!1;if(n&&("line"in n&&"column"in n?i={place:n}:"start"in n&&"end"in n?i={place:n}:"type"in n?i={ancestors:[n],place:n.position}:i={...n}),typeof t=="string"?a=t:!i.cause&&t&&(o=!0,a=t.message,i.cause=t),!i.ruleId&&!i.source&&typeof r=="string"){const u=r.indexOf(":");u===-1?i.ruleId=r:(i.source=r.slice(0,u),i.ruleId=r.slice(u+1))}if(!i.place&&i.ancestors&&i.ancestors){const u=i.ancestors[i.ancestors.length-1];u&&(i.place=u.position)}const l=i.place&&"start"in i.place?i.place.start:i.place;this.ancestors=i.ancestors||void 0,this.cause=i.cause||void 0,this.column=l?l.column:void 0,this.fatal=void 0,this.file="",this.message=a,this.line=l?l.line:void 0,this.name=sh(i.place)||"1:1",this.place=i.place||void 0,this.reason=this.message,this.ruleId=i.ruleId||void 0,this.source=i.source||void 0,this.stack=o&&i.cause&&typeof i.cause.stack=="string"?i.cause.stack:"",this.actual=void 0,this.expected=void 0,this.note=void 0,this.url=void 0}}Sr.prototype.file="";Sr.prototype.name="";Sr.prototype.reason="";Sr.prototype.message="";Sr.prototype.stack="";Sr.prototype.column=void 0;Sr.prototype.line=void 0;Sr.prototype.ancestors=void 0;Sr.prototype.cause=void 0;Sr.prototype.fatal=void 0;Sr.prototype.place=void 0;Sr.prototype.ruleId=void 0;Sr.prototype.source=void 0;const IS={}.hasOwnProperty,PJ=new Map,UJ=/[A-Z]/g,jJ=new Set(["table","tbody","thead","tfoot","tr"]),HJ=new Set(["td","th"]),zL="https://github.com/syntax-tree/hast-util-to-jsx-runtime";function GJ(e,t){if(!t||t.Fragment===void 0)throw new TypeError("Expected `Fragment` in options");const n=t.filePath||void 0;let r;if(t.development){if(typeof t.jsxDEV!="function")throw new TypeError("Expected `jsxDEV` in options when `development: true`");r=QJ(n,t.jsxDEV)}else{if(typeof t.jsx!="function")throw new TypeError("Expected `jsx` in production options");if(typeof t.jsxs!="function")throw new TypeError("Expected `jsxs` in production options");r=ZJ(n,t.jsx,t.jsxs)}const a={Fragment:t.Fragment,ancestors:[],components:t.components||{},create:r,elementAttributeNameCase:t.elementAttributeNameCase||"react",evaluater:t.createEvaluater?t.createEvaluater():void 0,filePath:n,ignoreInvalidStyle:t.ignoreInvalidStyle||!1,passKeys:t.passKeys!==!1,passNode:t.passNode||!1,schema:t.space==="svg"?hg:ML,stylePropertyNameCase:t.stylePropertyNameCase||"dom",tableCellAlignToStyle:t.tableCellAlignToStyle!==!1},i=$L(a,e,void 0);return i&&typeof i!="string"?i:a.create(e,a.Fragment,{children:i||void 0},void 0)}function $L(e,t,n){if(t.type==="element")return qJ(e,t,n);if(t.type==="mdxFlowExpression"||t.type==="mdxTextExpression")return WJ(e,t);if(t.type==="mdxJsxFlowElement"||t.type==="mdxJsxTextElement")return YJ(e,t,n);if(t.type==="mdxjsEsm")return VJ(e,t);if(t.type==="root")return XJ(e,t,n);if(t.type==="text")return KJ(e,t)}function qJ(e,t,n){const r=e.schema;let a=r;t.tagName.toLowerCase()==="svg"&&r.space==="html"&&(a=hg,e.schema=a),e.ancestors.push(t);const i=UL(e,t.tagName,!1),o=JJ(e,t);let l=DS(e,t);return jJ.has(t.tagName)&&(l=l.filter(function(u){return typeof u=="string"?!EJ(u):!0})),PL(e,o,i,t),LS(o,l),e.ancestors.pop(),e.schema=r,e.create(t,i,o,n)}function WJ(e,t){if(t.data&&t.data.estree&&e.evaluater){const r=t.data.estree.body[0];return r.type,e.evaluater.evaluateExpression(r.expression)}Th(e,t.position)}function VJ(e,t){if(t.data&&t.data.estree&&e.evaluater)return e.evaluater.evaluateProgram(t.data.estree);Th(e,t.position)}function YJ(e,t,n){const r=e.schema;let a=r;t.name==="svg"&&r.space==="html"&&(a=hg,e.schema=a),e.ancestors.push(t);const i=t.name===null?e.Fragment:UL(e,t.name,!0),o=eee(e,t),l=DS(e,t);return PL(e,o,i,t),LS(o,l),e.ancestors.pop(),e.schema=r,e.create(t,i,o,n)}function XJ(e,t,n){const r={};return LS(r,DS(e,t)),e.create(t,e.Fragment,r,n)}function KJ(e,t){return t.value}function PL(e,t,n,r){typeof n!="string"&&n!==e.Fragment&&e.passNode&&(t.node=r)}function LS(e,t){if(t.length>0){const n=t.length>1?t:t[0];n&&(e.children=n)}}function ZJ(e,t,n){return r;function r(a,i,o,l){const d=Array.isArray(o.children)?n:t;return l?d(i,o,l):d(i,o)}}function QJ(e,t){return n;function n(r,a,i,o){const l=Array.isArray(i.children),u=OS(r);return t(a,i,o,l,{columnNumber:u?u.column-1:void 0,fileName:e,lineNumber:u?u.line:void 0},void 0)}}function JJ(e,t){const n={};let r,a;for(a in t.properties)if(a!=="children"&&IS.call(t.properties,a)){const i=tee(e,a,t.properties[a]);if(i){const[o,l]=i;e.tableCellAlignToStyle&&o==="align"&&typeof l=="string"&&HJ.has(t.tagName)?r=l:n[o]=l}}if(r){const i=n.style||(n.style={});i[e.stylePropertyNameCase==="css"?"text-align":"textAlign"]=r}return n}function eee(e,t){const n={};for(const r of t.attributes)if(r.type==="mdxJsxExpressionAttribute")if(r.data&&r.data.estree&&e.evaluater){const i=r.data.estree.body[0];i.type;const o=i.expression;o.type;const l=o.properties[0];l.type,Object.assign(n,e.evaluater.evaluateExpression(l.argument))}else Th(e,t.position);else{const a=r.name;let i;if(r.value&&typeof r.value=="object")if(r.value.data&&r.value.data.estree&&e.evaluater){const l=r.value.data.estree.body[0];l.type,i=e.evaluater.evaluateExpression(l.expression)}else Th(e,t.position);else i=r.value===null?!0:r.value;n[a]=i}return n}function DS(e,t){const n=[];let r=-1;const a=e.passKeys?new Map:PJ;for(;++r<t.children.length;){const i=t.children[r];let o;if(e.passKeys){const u=i.type==="element"?i.tagName:i.type==="mdxJsxFlowElement"||i.type==="mdxJsxTextElement"?i.name:void 0;if(u){const d=a.get(u)||0;o=u+"-"+d,a.set(u,d+1)}}const l=$L(e,i,o);l!==void 0&&n.push(l)}return n}function tee(e,t,n){const r=DL(e.schema,t);if(!(n==null||typeof n=="number"&&Number.isNaN(n))){if(Array.isArray(n)&&(n=r.commaSeparated?yJ(n):IJ(n)),r.property==="style"){let a=typeof n=="object"?n:nee(e,String(n));return e.stylePropertyNameCase==="css"&&(a=ree(a)),["style",a]}return[e.elementAttributeNameCase==="react"&&r.space?CJ[r.property]||r.property:r.attribute,n]}}function nee(e,t){try{return zJ(t,{reactCompat:!0})}catch(n){if(e.ignoreInvalidStyle)return{};const r=n,a=new Sr("Cannot parse `style` attribute",{ancestors:e.ancestors,cause:r,ruleId:"style",source:"hast-util-to-jsx-runtime"});throw a.file=e.filePath||void 0,a.url=zL+"#cannot-parse-style-attribute",a}}function UL(e,t,n){let r;if(!n)r={type:"Literal",value:t};else if(t.includes(".")){const a=t.split(".");let i=-1,o;for(;++i<a.length;){const l=yR(a[i])?{type:"Identifier",name:a[i]}:{type:"Literal",value:a[i]};o=o?{type:"MemberExpression",object:o,property:l,computed:!!(i&&l.type==="Literal"),optional:!1}:l}r=o}else r=yR(t)&&!/^[a-z]/.test(t)?{type:"Identifier",name:t}:{type:"Literal",value:t};if(r.type==="Literal"){const a=r.value;return IS.call(e.components,a)?e.components[a]:a}if(e.evaluater)return e.evaluater.evaluateExpression(r);Th(e)}function Th(e,t){const n=new Sr("Cannot handle MDX estrees without `createEvaluater`",{ancestors:e.ancestors,place:t,ruleId:"mdx-estree",source:"hast-util-to-jsx-runtime"});throw n.file=e.filePath||void 0,n.url=zL+"#cannot-handle-mdx-estrees-without-createevaluater",n}function ree(e){const t={};let n;for(n in e)IS.call(e,n)&&(t[aee(n)]=e[n]);return t}function aee(e){let t=e.replace(UJ,iee);return t.slice(0,3)==="ms-"&&(t="-"+t),t}function iee(e){return"-"+e.toLowerCase()}const J1={action:["form"],cite:["blockquote","del","ins","q"],data:["object"],formAction:["button","input"],href:["a","area","base","link"],icon:["menuitem"],itemId:null,manifest:["html"],ping:["a","area"],poster:["video"],src:["audio","embed","iframe","img","input","script","source","track","video"]},oee={};function MS(e,t){const n=oee,r=typeof n.includeImageAlt=="boolean"?n.includeImageAlt:!0,a=typeof n.includeHtml=="boolean"?n.includeHtml:!0;return jL(e,r,a)}function jL(e,t,n){if(see(e)){if("value"in e)return e.type==="html"&&!n?"":e.value;if(t&&"alt"in e&&e.alt)return e.alt;if("children"in e)return RR(e.children,t,n)}return Array.isArray(e)?RR(e,t,n):""}function RR(e,t,n){const r=[];let a=-1;for(;++a<e.length;)r[a]=jL(e[a],t,n);return r.join("")}function see(e){return!!(e&&typeof e=="object")}const NR=document.createElement("i");function _h(e){const t="&"+e+";";NR.innerHTML=t;const n=NR.textContent;return n.charCodeAt(n.length-1)===59&&e!=="semi"||n===t?!1:n}function ma(e,t,n,r){const a=e.length;let i=0,o;if(t<0?t=-t>a?0:a+t:t=t>a?a:t,n=n>0?n:0,r.length<1e4)o=Array.from(r),o.unshift(t,n),e.splice(...o);else for(n&&e.splice(t,n);i<r.length;)o=r.slice(i,i+1e4),o.unshift(t,0),e.splice(...o),i+=1e4,t+=1e4}function za(e,t){return e.length>0?(ma(e,e.length,0,t),e):t}const OR={}.hasOwnProperty;function HL(e){const t={};let n=-1;for(;++n<e.length;)lee(t,e[n]);return t}function lee(e,t){let n;for(n in t){const a=(OR.call(e,n)?e[n]:void 0)||(e[n]={}),i=t[n];let o;if(i)for(o in i){OR.call(a,o)||(a[o]=[]);const l=i[o];cee(a[o],Array.isArray(l)?l:l?[l]:[])}}}function cee(e,t){let n=-1;const r=[];for(;++n<t.length;)(t[n].add==="after"?e:r).push(t[n]);ma(e,0,0,r)}function GL(e,t){const n=Number.parseInt(e,t);return n<9||n===11||n>13&&n<32||n>126&&n<160||n>55295&&n<57344||n>64975&&n<65008||(n&65535)===65535||(n&65535)===65534||n>1114111?"�":String.fromCodePoint(n)}function ni(e){return e.replace(/[\t\n\r ]+/g," ").replace(/^ | $/g,"").toLowerCase().toUpperCase()}const Ir=Is(/[A-Za-z]/),mr=Is(/[\dA-Za-z]/),uee=Is(/[#-'*+\--9=?A-Z^-~]/);function im(e){return e!==null&&(e<32||e===127)}const mx=Is(/\d/),dee=Is(/[\dA-Fa-f]/),hee=Is(/[!-/:-@[-`{-~]/);function Je(e){return e!==null&&e<-2}function rn(e){return e!==null&&(e<0||e===32)}function Ot(e){return e===-2||e===-1||e===32}const pg=Is(new RegExp("\\p{P}|\\p{S}","u")),yl=Is(/\s/);function Is(e){return t;function t(n){return n!==null&&n>-1&&e.test(String.fromCharCode(n))}}function yu(e){const t=[];let n=-1,r=0,a=0;for(;++n<e.length;){const i=e.charCodeAt(n);let o="";if(i===37&&mr(e.charCodeAt(n+1))&&mr(e.charCodeAt(n+2)))a=2;else if(i<128)/[!#$&-;=?-Z_a-z~]/.test(String.fromCharCode(i))||(o=String.fromCharCode(i));else if(i>55295&&i<57344){const l=e.charCodeAt(n+1);i<56320&&l>56319&&l<57344?(o=String.fromCharCode(i,l),a=1):o="�"}else o=String.fromCharCode(i);o&&(t.push(e.slice(r,n),encodeURIComponent(o)),r=n+a+1,o=""),a&&(n+=a,a=0)}return t.join("")+e.slice(r)}function At(e,t,n,r){const a=r?r-1:Number.POSITIVE_INFINITY;let i=0;return o;function o(u){return Ot(u)?(e.enter(n),l(u)):t(u)}function l(u){return Ot(u)&&i++<a?(e.consume(u),l):(e.exit(n),t(u))}}const pee={tokenize:fee};function fee(e){const t=e.attempt(this.parser.constructs.contentInitial,r,a);let n;return t;function r(l){if(l===null){e.consume(l);return}return e.enter("lineEnding"),e.consume(l),e.exit("lineEnding"),At(e,t,"linePrefix")}function a(l){return e.enter("paragraph"),i(l)}function i(l){const u=e.enter("chunkText",{contentType:"text",previous:n});return n&&(n.next=u),n=u,o(l)}function o(l){if(l===null){e.exit("chunkText"),e.exit("paragraph"),e.consume(l);return}return Je(l)?(e.consume(l),e.exit("chunkText"),i):(e.consume(l),o)}}const mee={tokenize:gee},IR={tokenize:bee};function gee(e){const t=this,n=[];let r=0,a,i,o;return l;function l(R){if(r<n.length){const I=n[r];return t.containerState=I[1],e.attempt(I[0].continuation,u,d)(R)}return d(R)}function u(R){if(r++,t.containerState._closeFlow){t.containerState._closeFlow=void 0,a&&k();const I=t.events.length;let L=I,A;for(;L--;)if(t.events[L][0]==="exit"&&t.events[L][1].type==="chunkFlow"){A=t.events[L][1].end;break}S(r);let M=I;for(;M<t.events.length;)t.events[M][1].end={...A},M++;return ma(t.events,L+1,0,t.events.slice(I)),t.events.length=M,d(R)}return l(R)}function d(R){if(r===n.length){if(!a)return m(R);if(a.currentConstruct&&a.currentConstruct.concrete)return y(R);t.interrupt=!!(a.currentConstruct&&!a._gfmTableDynamicInterruptHack)}return t.containerState={},e.check(IR,h,f)(R)}function h(R){return a&&k(),S(r),m(R)}function f(R){return t.parser.lazy[t.now().line]=r!==n.length,o=t.now().offset,y(R)}function m(R){return t.containerState={},e.attempt(IR,b,y)(R)}function b(R){return r++,n.push([t.currentConstruct,t.containerState]),m(R)}function y(R){if(R===null){a&&k(),S(0),e.consume(R);return}return a=a||t.parser.flow(t.now()),e.enter("chunkFlow",{_tokenizer:a,contentType:"flow",previous:i}),v(R)}function v(R){if(R===null){w(e.exit("chunkFlow"),!0),S(0),e.consume(R);return}return Je(R)?(e.consume(R),w(e.exit("chunkFlow")),r=0,t.interrupt=void 0,l):(e.consume(R),v)}function w(R,I){const L=t.sliceStream(R);if(I&&L.push(null),R.previous=i,i&&(i.next=R),i=R,a.defineSkip(R.start),a.write(L),t.parser.lazy[R.start.line]){let A=a.events.length;for(;A--;)if(a.events[A][1].start.offset<o&&(!a.events[A][1].end||a.events[A][1].end.offset>o))return;const M=t.events.length;let P=M,G,B;for(;P--;)if(t.events[P][0]==="exit"&&t.events[P][1].type==="chunkFlow"){if(G){B=t.events[P][1].end;break}G=!0}for(S(r),A=M;A<t.events.length;)t.events[A][1].end={...B},A++;ma(t.events,P+1,0,t.events.slice(M)),t.events.length=A}}function S(R){let I=n.length;for(;I-- >R;){const L=n[I];t.containerState=L[1],L[0].exit.call(t,e)}n.length=R}function k(){a.write([null]),i=void 0,a=void 0,t.containerState._closeFlow=void 0}}function bee(e,t,n){return At(e,e.attempt(this.parser.constructs.document,t,n),"linePrefix",this.parser.constructs.disable.null.includes("codeIndented")?void 0:4)}function Qc(e){if(e===null||rn(e)||yl(e))return 1;if(pg(e))return 2}function fg(e,t,n){const r=[];let a=-1;for(;++a<e.length;){const i=e[a].resolveAll;i&&!r.includes(i)&&(t=i(t,n),r.push(i))}return t}const gx={name:"attention",resolveAll:yee,tokenize:vee};function yee(e,t){let n=-1,r,a,i,o,l,u,d,h;for(;++n<e.length;)if(e[n][0]==="enter"&&e[n][1].type==="attentionSequence"&&e[n][1]._close){for(r=n;r--;)if(e[r][0]==="exit"&&e[r][1].type==="attentionSequence"&&e[r][1]._open&&t.sliceSerialize(e[r][1]).charCodeAt(0)===t.sliceSerialize(e[n][1]).charCodeAt(0)){if((e[r][1]._close||e[n][1]._open)&&(e[n][1].end.offset-e[n][1].start.offset)%3&&!((e[r][1].end.offset-e[r][1].start.offset+e[n][1].end.offset-e[n][1].start.offset)%3))continue;u=e[r][1].end.offset-e[r][1].start.offset>1&&e[n][1].end.offset-e[n][1].start.offset>1?2:1;const f={...e[r][1].end},m={...e[n][1].start};LR(f,-u),LR(m,u),o={type:u>1?"strongSequence":"emphasisSequence",start:f,end:{...e[r][1].end}},l={type:u>1?"strongSequence":"emphasisSequence",start:{...e[n][1].start},end:m},i={type:u>1?"strongText":"emphasisText",start:{...e[r][1].end},end:{...e[n][1].start}},a={type:u>1?"strong":"emphasis",start:{...o.start},end:{...l.end}},e[r][1].end={...o.start},e[n][1].start={...l.end},d=[],e[r][1].end.offset-e[r][1].start.offset&&(d=za(d,[["enter",e[r][1],t],["exit",e[r][1],t]])),d=za(d,[["enter",a,t],["enter",o,t],["exit",o,t],["enter",i,t]]),d=za(d,fg(t.parser.constructs.insideSpan.null,e.slice(r+1,n),t)),d=za(d,[["exit",i,t],["enter",l,t],["exit",l,t],["exit",a,t]]),e[n][1].end.offset-e[n][1].start.offset?(h=2,d=za(d,[["enter",e[n][1],t],["exit",e[n][1],t]])):h=0,ma(e,r-1,n-r+3,d),n=r+d.length-h-2;break}}for(n=-1;++n<e.length;)e[n][1].type==="attentionSequence"&&(e[n][1].type="data");return e}function vee(e,t){const n=this.parser.constructs.attentionMarkers.null,r=this.previous,a=Qc(r);let i;return o;function o(u){return i=u,e.enter("attentionSequence"),l(u)}function l(u){if(u===i)return e.consume(u),l;const d=e.exit("attentionSequence"),h=Qc(u),f=!h||h===2&&a||n.includes(u),m=!a||a===2&&h||n.includes(r);return d._open=!!(i===42?f:f&&(a||!m)),d._close=!!(i===42?m:m&&(h||!f)),t(u)}}function LR(e,t){e.column+=t,e.offset+=t,e._bufferIndex+=t}const xee={name:"autolink",tokenize:See};function See(e,t,n){let r=0;return a;function a(b){return e.enter("autolink"),e.enter("autolinkMarker"),e.consume(b),e.exit("autolinkMarker"),e.enter("autolinkProtocol"),i}function i(b){return Ir(b)?(e.consume(b),o):b===64?n(b):d(b)}function o(b){return b===43||b===45||b===46||mr(b)?(r=1,l(b)):d(b)}function l(b){return b===58?(e.consume(b),r=0,u):(b===43||b===45||b===46||mr(b))&&r++<32?(e.consume(b),l):(r=0,d(b))}function u(b){return b===62?(e.exit("autolinkProtocol"),e.enter("autolinkMarker"),e.consume(b),e.exit("autolinkMarker"),e.exit("autolink"),t):b===null||b===32||b===60||im(b)?n(b):(e.consume(b),u)}function d(b){return b===64?(e.consume(b),h):uee(b)?(e.consume(b),d):n(b)}function h(b){return mr(b)?f(b):n(b)}function f(b){return b===46?(e.consume(b),r=0,h):b===62?(e.exit("autolinkProtocol").type="autolinkEmail",e.enter("autolinkMarker"),e.consume(b),e.exit("autolinkMarker"),e.exit("autolink"),t):m(b)}function m(b){if((b===45||mr(b))&&r++<63){const y=b===45?m:f;return e.consume(b),y}return n(b)}}const tp={partial:!0,tokenize:wee};function wee(e,t,n){return r;function r(i){return Ot(i)?At(e,a,"linePrefix")(i):a(i)}function a(i){return i===null||Je(i)?t(i):n(i)}}const qL={continuation:{tokenize:kee},exit:Tee,name:"blockQuote",tokenize:Eee};function Eee(e,t,n){const r=this;return a;function a(o){if(o===62){const l=r.containerState;return l.open||(e.enter("blockQuote",{_container:!0}),l.open=!0),e.enter("blockQuotePrefix"),e.enter("blockQuoteMarker"),e.consume(o),e.exit("blockQuoteMarker"),i}return n(o)}function i(o){return Ot(o)?(e.enter("blockQuotePrefixWhitespace"),e.consume(o),e.exit("blockQuotePrefixWhitespace"),e.exit("blockQuotePrefix"),t):(e.exit("blockQuotePrefix"),t(o))}}function kee(e,t,n){const r=this;return a;function a(o){return Ot(o)?At(e,i,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(o):i(o)}function i(o){return e.attempt(qL,t,n)(o)}}function Tee(e){e.exit("blockQuote")}const WL={name:"characterEscape",tokenize:_ee};function _ee(e,t,n){return r;function r(i){return e.enter("characterEscape"),e.enter("escapeMarker"),e.consume(i),e.exit("escapeMarker"),a}function a(i){return hee(i)?(e.enter("characterEscapeValue"),e.consume(i),e.exit("characterEscapeValue"),e.exit("characterEscape"),t):n(i)}}const VL={name:"characterReference",tokenize:Cee};function Cee(e,t,n){const r=this;let a=0,i,o;return l;function l(f){return e.enter("characterReference"),e.enter("characterReferenceMarker"),e.consume(f),e.exit("characterReferenceMarker"),u}function u(f){return f===35?(e.enter("characterReferenceMarkerNumeric"),e.consume(f),e.exit("characterReferenceMarkerNumeric"),d):(e.enter("characterReferenceValue"),i=31,o=mr,h(f))}function d(f){return f===88||f===120?(e.enter("characterReferenceMarkerHexadecimal"),e.consume(f),e.exit("characterReferenceMarkerHexadecimal"),e.enter("characterReferenceValue"),i=6,o=dee,h):(e.enter("characterReferenceValue"),i=7,o=mx,h(f))}function h(f){if(f===59&&a){const m=e.exit("characterReferenceValue");return o===mr&&!_h(r.sliceSerialize(m))?n(f):(e.enter("characterReferenceMarker"),e.consume(f),e.exit("characterReferenceMarker"),e.exit("characterReference"),t)}return o(f)&&a++<i?(e.consume(f),h):n(f)}}const DR={partial:!0,tokenize:Ree},MR={concrete:!0,name:"codeFenced",tokenize:Aee};function Aee(e,t,n){const r=this,a={partial:!0,tokenize:L};let i=0,o=0,l;return u;function u(A){return d(A)}function d(A){const M=r.events[r.events.length-1];return i=M&&M[1].type==="linePrefix"?M[2].sliceSerialize(M[1],!0).length:0,l=A,e.enter("codeFenced"),e.enter("codeFencedFence"),e.enter("codeFencedFenceSequence"),h(A)}function h(A){return A===l?(o++,e.consume(A),h):o<3?n(A):(e.exit("codeFencedFenceSequence"),Ot(A)?At(e,f,"whitespace")(A):f(A))}function f(A){return A===null||Je(A)?(e.exit("codeFencedFence"),r.interrupt?t(A):e.check(DR,v,I)(A)):(e.enter("codeFencedFenceInfo"),e.enter("chunkString",{contentType:"string"}),m(A))}function m(A){return A===null||Je(A)?(e.exit("chunkString"),e.exit("codeFencedFenceInfo"),f(A)):Ot(A)?(e.exit("chunkString"),e.exit("codeFencedFenceInfo"),At(e,b,"whitespace")(A)):A===96&&A===l?n(A):(e.consume(A),m)}function b(A){return A===null||Je(A)?f(A):(e.enter("codeFencedFenceMeta"),e.enter("chunkString",{contentType:"string"}),y(A))}function y(A){return A===null||Je(A)?(e.exit("chunkString"),e.exit("codeFencedFenceMeta"),f(A)):A===96&&A===l?n(A):(e.consume(A),y)}function v(A){return e.attempt(a,I,w)(A)}function w(A){return e.enter("lineEnding"),e.consume(A),e.exit("lineEnding"),S}function S(A){return i>0&&Ot(A)?At(e,k,"linePrefix",i+1)(A):k(A)}function k(A){return A===null||Je(A)?e.check(DR,v,I)(A):(e.enter("codeFlowValue"),R(A))}function R(A){return A===null||Je(A)?(e.exit("codeFlowValue"),k(A)):(e.consume(A),R)}function I(A){return e.exit("codeFenced"),t(A)}function L(A,M,P){let G=0;return B;function B(X){return A.enter("lineEnding"),A.consume(X),A.exit("lineEnding"),H}function H(X){return A.enter("codeFencedFence"),Ot(X)?At(A,Z,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(X):Z(X)}function Z(X){return X===l?(A.enter("codeFencedFenceSequence"),V(X)):P(X)}function V(X){return X===l?(G++,A.consume(X),V):G>=o?(A.exit("codeFencedFenceSequence"),Ot(X)?At(A,q,"whitespace")(X):q(X)):P(X)}function q(X){return X===null||Je(X)?(A.exit("codeFencedFence"),M(X)):P(X)}}}function Ree(e,t,n){const r=this;return a;function a(o){return o===null?n(o):(e.enter("lineEnding"),e.consume(o),e.exit("lineEnding"),i)}function i(o){return r.parser.lazy[r.now().line]?n(o):t(o)}}const ev={name:"codeIndented",tokenize:Oee},Nee={partial:!0,tokenize:Iee};function Oee(e,t,n){const r=this;return a;function a(d){return e.enter("codeIndented"),At(e,i,"linePrefix",5)(d)}function i(d){const h=r.events[r.events.length-1];return h&&h[1].type==="linePrefix"&&h[2].sliceSerialize(h[1],!0).length>=4?o(d):n(d)}function o(d){return d===null?u(d):Je(d)?e.attempt(Nee,o,u)(d):(e.enter("codeFlowValue"),l(d))}function l(d){return d===null||Je(d)?(e.exit("codeFlowValue"),o(d)):(e.consume(d),l)}function u(d){return e.exit("codeIndented"),t(d)}}function Iee(e,t,n){const r=this;return a;function a(o){return r.parser.lazy[r.now().line]?n(o):Je(o)?(e.enter("lineEnding"),e.consume(o),e.exit("lineEnding"),a):At(e,i,"linePrefix",5)(o)}function i(o){const l=r.events[r.events.length-1];return l&&l[1].type==="linePrefix"&&l[2].sliceSerialize(l[1],!0).length>=4?t(o):Je(o)?a(o):n(o)}}const Lee={name:"codeText",previous:Mee,resolve:Dee,tokenize:Bee};function Dee(e){let t=e.length-4,n=3,r,a;if((e[n][1].type==="lineEnding"||e[n][1].type==="space")&&(e[t][1].type==="lineEnding"||e[t][1].type==="space")){for(r=n;++r<t;)if(e[r][1].type==="codeTextData"){e[n][1].type="codeTextPadding",e[t][1].type="codeTextPadding",n+=2,t-=2;break}}for(r=n-1,t++;++r<=t;)a===void 0?r!==t&&e[r][1].type!=="lineEnding"&&(a=r):(r===t||e[r][1].type==="lineEnding")&&(e[a][1].type="codeTextData",r!==a+2&&(e[a][1].end=e[r-1][1].end,e.splice(a+2,r-a-2),t-=r-a-2,r=a+2),a=void 0);return e}function Mee(e){return e!==96||this.events[this.events.length-1][1].type==="characterEscape"}function Bee(e,t,n){let r=0,a,i;return o;function o(f){return e.enter("codeText"),e.enter("codeTextSequence"),l(f)}function l(f){return f===96?(e.consume(f),r++,l):(e.exit("codeTextSequence"),u(f))}function u(f){return f===null?n(f):f===32?(e.enter("space"),e.consume(f),e.exit("space"),u):f===96?(i=e.enter("codeTextSequence"),a=0,h(f)):Je(f)?(e.enter("lineEnding"),e.consume(f),e.exit("lineEnding"),u):(e.enter("codeTextData"),d(f))}function d(f){return f===null||f===32||f===96||Je(f)?(e.exit("codeTextData"),u(f)):(e.consume(f),d)}function h(f){return f===96?(e.consume(f),a++,h):a===r?(e.exit("codeTextSequence"),e.exit("codeText"),t(f)):(i.type="codeTextData",d(f))}}class Fee{constructor(t){this.left=t?[...t]:[],this.right=[]}get(t){if(t<0||t>=this.left.length+this.right.length)throw new RangeError("Cannot access index `"+t+"` in a splice buffer of size `"+(this.left.length+this.right.length)+"`");return t<this.left.length?this.left[t]:this.right[this.right.length-t+this.left.length-1]}get length(){return this.left.length+this.right.length}shift(){return this.setCursor(0),this.right.pop()}slice(t,n){const r=n??Number.POSITIVE_INFINITY;return r<this.left.length?this.left.slice(t,r):t>this.left.length?this.right.slice(this.right.length-r+this.left.length,this.right.length-t+this.left.length).reverse():this.left.slice(t).concat(this.right.slice(this.right.length-r+this.left.length).reverse())}splice(t,n,r){const a=n||0;this.setCursor(Math.trunc(t));const i=this.right.splice(this.right.length-a,Number.POSITIVE_INFINITY);return r&&Bd(this.left,r),i.reverse()}pop(){return this.setCursor(Number.POSITIVE_INFINITY),this.left.pop()}push(t){this.setCursor(Number.POSITIVE_INFINITY),this.left.push(t)}pushMany(t){this.setCursor(Number.POSITIVE_INFINITY),Bd(this.left,t)}unshift(t){this.setCursor(0),this.right.push(t)}unshiftMany(t){this.setCursor(0),Bd(this.right,t.reverse())}setCursor(t){if(!(t===this.left.length||t>this.left.length&&this.right.length===0||t<0&&this.left.length===0))if(t<this.left.length){const n=this.left.splice(t,Number.POSITIVE_INFINITY);Bd(this.right,n.reverse())}else{const n=this.right.splice(this.left.length+this.right.length-t,Number.POSITIVE_INFINITY);Bd(this.left,n.reverse())}}}function Bd(e,t){let n=0;if(t.length<1e4)e.push(...t);else for(;n<t.length;)e.push(...t.slice(n,n+1e4)),n+=1e4}function YL(e){const t={};let n=-1,r,a,i,o,l,u,d;const h=new Fee(e);for(;++n<h.length;){for(;n in t;)n=t[n];if(r=h.get(n),n&&r[1].type==="chunkFlow"&&h.get(n-1)[1].type==="listItemPrefix"&&(u=r[1]._tokenizer.events,i=0,i<u.length&&u[i][1].type==="lineEndingBlank"&&(i+=2),i<u.length&&u[i][1].type==="content"))for(;++i<u.length&&u[i][1].type!=="content";)u[i][1].type==="chunkText"&&(u[i][1]._isInFirstContentOfListItem=!0,i++);if(r[0]==="enter")r[1].contentType&&(Object.assign(t,zee(h,n)),n=t[n],d=!0);else if(r[1]._container){for(i=n,a=void 0;i--;)if(o=h.get(i),o[1].type==="lineEnding"||o[1].type==="lineEndingBlank")o[0]==="enter"&&(a&&(h.get(a)[1].type="lineEndingBlank"),o[1].type="lineEnding",a=i);else if(!(o[1].type==="linePrefix"||o[1].type==="listItemIndent"))break;a&&(r[1].end={...h.get(a)[1].start},l=h.slice(a,n),l.unshift(r),h.splice(a,n-a+1,l))}}return ma(e,0,Number.POSITIVE_INFINITY,h.slice(0)),!d}function zee(e,t){const n=e.get(t)[1],r=e.get(t)[2];let a=t-1;const i=[];let o=n._tokenizer;o||(o=r.parser[n.contentType](n.start),n._contentTypeTextTrailing&&(o._contentTypeTextTrailing=!0));const l=o.events,u=[],d={};let h,f,m=-1,b=n,y=0,v=0;const w=[v];for(;b;){for(;e.get(++a)[1]!==b;);i.push(a),b._tokenizer||(h=r.sliceStream(b),b.next||h.push(null),f&&o.defineSkip(b.start),b._isInFirstContentOfListItem&&(o._gfmTasklistFirstContentOfListItem=!0),o.write(h),b._isInFirstContentOfListItem&&(o._gfmTasklistFirstContentOfListItem=void 0)),f=b,b=b.next}for(b=n;++m<l.length;)l[m][0]==="exit"&&l[m-1][0]==="enter"&&l[m][1].type===l[m-1][1].type&&l[m][1].start.line!==l[m][1].end.line&&(v=m+1,w.push(v),b._tokenizer=void 0,b.previous=void 0,b=b.next);for(o.events=[],b?(b._tokenizer=void 0,b.previous=void 0):w.pop(),m=w.length;m--;){const S=l.slice(w[m],w[m+1]),k=i.pop();u.push([k,k+S.length-1]),e.splice(k,2,S)}for(u.reverse(),m=-1;++m<u.length;)d[y+u[m][0]]=y+u[m][1],y+=u[m][1]-u[m][0]-1;return d}const $ee={resolve:Uee,tokenize:jee},Pee={partial:!0,tokenize:Hee};function Uee(e){return YL(e),e}function jee(e,t){let n;return r;function r(l){return e.enter("content"),n=e.enter("chunkContent",{contentType:"content"}),a(l)}function a(l){return l===null?i(l):Je(l)?e.check(Pee,o,i)(l):(e.consume(l),a)}function i(l){return e.exit("chunkContent"),e.exit("content"),t(l)}function o(l){return e.consume(l),e.exit("chunkContent"),n.next=e.enter("chunkContent",{contentType:"content",previous:n}),n=n.next,a}}function Hee(e,t,n){const r=this;return a;function a(o){return e.exit("chunkContent"),e.enter("lineEnding"),e.consume(o),e.exit("lineEnding"),At(e,i,"linePrefix")}function i(o){if(o===null||Je(o))return n(o);const l=r.events[r.events.length-1];return!r.parser.constructs.disable.null.includes("codeIndented")&&l&&l[1].type==="linePrefix"&&l[2].sliceSerialize(l[1],!0).length>=4?t(o):e.interrupt(r.parser.constructs.flow,n,t)(o)}}function XL(e,t,n,r,a,i,o,l,u){const d=u||Number.POSITIVE_INFINITY;let h=0;return f;function f(S){return S===60?(e.enter(r),e.enter(a),e.enter(i),e.consume(S),e.exit(i),m):S===null||S===32||S===41||im(S)?n(S):(e.enter(r),e.enter(o),e.enter(l),e.enter("chunkString",{contentType:"string"}),v(S))}function m(S){return S===62?(e.enter(i),e.consume(S),e.exit(i),e.exit(a),e.exit(r),t):(e.enter(l),e.enter("chunkString",{contentType:"string"}),b(S))}function b(S){return S===62?(e.exit("chunkString"),e.exit(l),m(S)):S===null||S===60||Je(S)?n(S):(e.consume(S),S===92?y:b)}function y(S){return S===60||S===62||S===92?(e.consume(S),b):b(S)}function v(S){return!h&&(S===null||S===41||rn(S))?(e.exit("chunkString"),e.exit(l),e.exit(o),e.exit(r),t(S)):h<d&&S===40?(e.consume(S),h++,v):S===41?(e.consume(S),h--,v):S===null||S===32||S===40||im(S)?n(S):(e.consume(S),S===92?w:v)}function w(S){return S===40||S===41||S===92?(e.consume(S),v):v(S)}}function KL(e,t,n,r,a,i){const o=this;let l=0,u;return d;function d(b){return e.enter(r),e.enter(a),e.consume(b),e.exit(a),e.enter(i),h}function h(b){return l>999||b===null||b===91||b===93&&!u||b===94&&!l&&"_hiddenFootnoteSupport"in o.parser.constructs?n(b):b===93?(e.exit(i),e.enter(a),e.consume(b),e.exit(a),e.exit(r),t):Je(b)?(e.enter("lineEnding"),e.consume(b),e.exit("lineEnding"),h):(e.enter("chunkString",{contentType:"string"}),f(b))}function f(b){return b===null||b===91||b===93||Je(b)||l++>999?(e.exit("chunkString"),h(b)):(e.consume(b),u||(u=!Ot(b)),b===92?m:f)}function m(b){return b===91||b===92||b===93?(e.consume(b),l++,f):f(b)}}function ZL(e,t,n,r,a,i){let o;return l;function l(m){return m===34||m===39||m===40?(e.enter(r),e.enter(a),e.consume(m),e.exit(a),o=m===40?41:m,u):n(m)}function u(m){return m===o?(e.enter(a),e.consume(m),e.exit(a),e.exit(r),t):(e.enter(i),d(m))}function d(m){return m===o?(e.exit(i),u(o)):m===null?n(m):Je(m)?(e.enter("lineEnding"),e.consume(m),e.exit("lineEnding"),At(e,d,"linePrefix")):(e.enter("chunkString",{contentType:"string"}),h(m))}function h(m){return m===o||m===null||Je(m)?(e.exit("chunkString"),d(m)):(e.consume(m),m===92?f:h)}function f(m){return m===o||m===92?(e.consume(m),h):h(m)}}function lh(e,t){let n;return r;function r(a){return Je(a)?(e.enter("lineEnding"),e.consume(a),e.exit("lineEnding"),n=!0,r):Ot(a)?At(e,r,n?"linePrefix":"lineSuffix")(a):t(a)}}const Gee={name:"definition",tokenize:Wee},qee={partial:!0,tokenize:Vee};function Wee(e,t,n){const r=this;let a;return i;function i(b){return e.enter("definition"),o(b)}function o(b){return KL.call(r,e,l,n,"definitionLabel","definitionLabelMarker","definitionLabelString")(b)}function l(b){return a=ni(r.sliceSerialize(r.events[r.events.length-1][1]).slice(1,-1)),b===58?(e.enter("definitionMarker"),e.consume(b),e.exit("definitionMarker"),u):n(b)}function u(b){return rn(b)?lh(e,d)(b):d(b)}function d(b){return XL(e,h,n,"definitionDestination","definitionDestinationLiteral","definitionDestinationLiteralMarker","definitionDestinationRaw","definitionDestinationString")(b)}function h(b){return e.attempt(qee,f,f)(b)}function f(b){return Ot(b)?At(e,m,"whitespace")(b):m(b)}function m(b){return b===null||Je(b)?(e.exit("definition"),r.parser.defined.push(a),t(b)):n(b)}}function Vee(e,t,n){return r;function r(l){return rn(l)?lh(e,a)(l):n(l)}function a(l){return ZL(e,i,n,"definitionTitle","definitionTitleMarker","definitionTitleString")(l)}function i(l){return Ot(l)?At(e,o,"whitespace")(l):o(l)}function o(l){return l===null||Je(l)?t(l):n(l)}}const Yee={name:"hardBreakEscape",tokenize:Xee};function Xee(e,t,n){return r;function r(i){return e.enter("hardBreakEscape"),e.consume(i),a}function a(i){return Je(i)?(e.exit("hardBreakEscape"),t(i)):n(i)}}const Kee={name:"headingAtx",resolve:Zee,tokenize:Qee};function Zee(e,t){let n=e.length-2,r=3,a,i;return e[r][1].type==="whitespace"&&(r+=2),n-2>r&&e[n][1].type==="whitespace"&&(n-=2),e[n][1].type==="atxHeadingSequence"&&(r===n-1||n-4>r&&e[n-2][1].type==="whitespace")&&(n-=r+1===n?2:4),n>r&&(a={type:"atxHeadingText",start:e[r][1].start,end:e[n][1].end},i={type:"chunkText",start:e[r][1].start,end:e[n][1].end,contentType:"text"},ma(e,r,n-r+1,[["enter",a,t],["enter",i,t],["exit",i,t],["exit",a,t]])),e}function Qee(e,t,n){let r=0;return a;function a(h){return e.enter("atxHeading"),i(h)}function i(h){return e.enter("atxHeadingSequence"),o(h)}function o(h){return h===35&&r++<6?(e.consume(h),o):h===null||rn(h)?(e.exit("atxHeadingSequence"),l(h)):n(h)}function l(h){return h===35?(e.enter("atxHeadingSequence"),u(h)):h===null||Je(h)?(e.exit("atxHeading"),t(h)):Ot(h)?At(e,l,"whitespace")(h):(e.enter("atxHeadingText"),d(h))}function u(h){return h===35?(e.consume(h),u):(e.exit("atxHeadingSequence"),l(h))}function d(h){return h===null||h===35||rn(h)?(e.exit("atxHeadingText"),l(h)):(e.consume(h),d)}}const Jee=["address","article","aside","base","basefont","blockquote","body","caption","center","col","colgroup","dd","details","dialog","dir","div","dl","dt","fieldset","figcaption","figure","footer","form","frame","frameset","h1","h2","h3","h4","h5","h6","head","header","hr","html","iframe","legend","li","link","main","menu","menuitem","nav","noframes","ol","optgroup","option","p","param","search","section","summary","table","tbody","td","tfoot","th","thead","title","tr","track","ul"],BR=["pre","script","style","textarea"],ete={concrete:!0,name:"htmlFlow",resolveTo:rte,tokenize:ate},tte={partial:!0,tokenize:ote},nte={partial:!0,tokenize:ite};function rte(e){let t=e.length;for(;t--&&!(e[t][0]==="enter"&&e[t][1].type==="htmlFlow"););return t>1&&e[t-2][1].type==="linePrefix"&&(e[t][1].start=e[t-2][1].start,e[t+1][1].start=e[t-2][1].start,e.splice(t-2,2)),e}function ate(e,t,n){const r=this;let a,i,o,l,u;return d;function d(U){return h(U)}function h(U){return e.enter("htmlFlow"),e.enter("htmlFlowData"),e.consume(U),f}function f(U){return U===33?(e.consume(U),m):U===47?(e.consume(U),i=!0,v):U===63?(e.consume(U),a=3,r.interrupt?t:F):Ir(U)?(e.consume(U),o=String.fromCharCode(U),w):n(U)}function m(U){return U===45?(e.consume(U),a=2,b):U===91?(e.consume(U),a=5,l=0,y):Ir(U)?(e.consume(U),a=4,r.interrupt?t:F):n(U)}function b(U){return U===45?(e.consume(U),r.interrupt?t:F):n(U)}function y(U){const be="CDATA[";return U===be.charCodeAt(l++)?(e.consume(U),l===be.length?r.interrupt?t:Z:y):n(U)}function v(U){return Ir(U)?(e.consume(U),o=String.fromCharCode(U),w):n(U)}function w(U){if(U===null||U===47||U===62||rn(U)){const be=U===47,ge=o.toLowerCase();return!be&&!i&&BR.includes(ge)?(a=1,r.interrupt?t(U):Z(U)):Jee.includes(o.toLowerCase())?(a=6,be?(e.consume(U),S):r.interrupt?t(U):Z(U)):(a=7,r.interrupt&&!r.parser.lazy[r.now().line]?n(U):i?k(U):R(U))}return U===45||mr(U)?(e.consume(U),o+=String.fromCharCode(U),w):n(U)}function S(U){return U===62?(e.consume(U),r.interrupt?t:Z):n(U)}function k(U){return Ot(U)?(e.consume(U),k):B(U)}function R(U){return U===47?(e.consume(U),B):U===58||U===95||Ir(U)?(e.consume(U),I):Ot(U)?(e.consume(U),R):B(U)}function I(U){return U===45||U===46||U===58||U===95||mr(U)?(e.consume(U),I):L(U)}function L(U){return U===61?(e.consume(U),A):Ot(U)?(e.consume(U),L):R(U)}function A(U){return U===null||U===60||U===61||U===62||U===96?n(U):U===34||U===39?(e.consume(U),u=U,M):Ot(U)?(e.consume(U),A):P(U)}function M(U){return U===u?(e.consume(U),u=null,G):U===null||Je(U)?n(U):(e.consume(U),M)}function P(U){return U===null||U===34||U===39||U===47||U===60||U===61||U===62||U===96||rn(U)?L(U):(e.consume(U),P)}function G(U){return U===47||U===62||Ot(U)?R(U):n(U)}function B(U){return U===62?(e.consume(U),H):n(U)}function H(U){return U===null||Je(U)?Z(U):Ot(U)?(e.consume(U),H):n(U)}function Z(U){return U===45&&a===2?(e.consume(U),$):U===60&&a===1?(e.consume(U),Q):U===62&&a===4?(e.consume(U),Y):U===63&&a===3?(e.consume(U),F):U===93&&a===5?(e.consume(U),ie):Je(U)&&(a===6||a===7)?(e.exit("htmlFlowData"),e.check(tte,oe,V)(U)):U===null||Je(U)?(e.exit("htmlFlowData"),V(U)):(e.consume(U),Z)}function V(U){return e.check(nte,q,oe)(U)}function q(U){return e.enter("lineEnding"),e.consume(U),e.exit("lineEnding"),X}function X(U){return U===null||Je(U)?V(U):(e.enter("htmlFlowData"),Z(U))}function $(U){return U===45?(e.consume(U),F):Z(U)}function Q(U){return U===47?(e.consume(U),o="",J):Z(U)}function J(U){if(U===62){const be=o.toLowerCase();return BR.includes(be)?(e.consume(U),Y):Z(U)}return Ir(U)&&o.length<8?(e.consume(U),o+=String.fromCharCode(U),J):Z(U)}function ie(U){return U===93?(e.consume(U),F):Z(U)}function F(U){return U===62?(e.consume(U),Y):U===45&&a===2?(e.consume(U),F):Z(U)}function Y(U){return U===null||Je(U)?(e.exit("htmlFlowData"),oe(U)):(e.consume(U),Y)}function oe(U){return e.exit("htmlFlow"),t(U)}}function ite(e,t,n){const r=this;return a;function a(o){return Je(o)?(e.enter("lineEnding"),e.consume(o),e.exit("lineEnding"),i):n(o)}function i(o){return r.parser.lazy[r.now().line]?n(o):t(o)}}function ote(e,t,n){return r;function r(a){return e.enter("lineEnding"),e.consume(a),e.exit("lineEnding"),e.attempt(tp,t,n)}}const ste={name:"htmlText",tokenize:lte};function lte(e,t,n){const r=this;let a,i,o;return l;function l(F){return e.enter("htmlText"),e.enter("htmlTextData"),e.consume(F),u}function u(F){return F===33?(e.consume(F),d):F===47?(e.consume(F),L):F===63?(e.consume(F),R):Ir(F)?(e.consume(F),P):n(F)}function d(F){return F===45?(e.consume(F),h):F===91?(e.consume(F),i=0,y):Ir(F)?(e.consume(F),k):n(F)}function h(F){return F===45?(e.consume(F),b):n(F)}function f(F){return F===null?n(F):F===45?(e.consume(F),m):Je(F)?(o=f,Q(F)):(e.consume(F),f)}function m(F){return F===45?(e.consume(F),b):f(F)}function b(F){return F===62?$(F):F===45?m(F):f(F)}function y(F){const Y="CDATA[";return F===Y.charCodeAt(i++)?(e.consume(F),i===Y.length?v:y):n(F)}function v(F){return F===null?n(F):F===93?(e.consume(F),w):Je(F)?(o=v,Q(F)):(e.consume(F),v)}function w(F){return F===93?(e.consume(F),S):v(F)}function S(F){return F===62?$(F):F===93?(e.consume(F),S):v(F)}function k(F){return F===null||F===62?$(F):Je(F)?(o=k,Q(F)):(e.consume(F),k)}function R(F){return F===null?n(F):F===63?(e.consume(F),I):Je(F)?(o=R,Q(F)):(e.consume(F),R)}function I(F){return F===62?$(F):R(F)}function L(F){return Ir(F)?(e.consume(F),A):n(F)}function A(F){return F===45||mr(F)?(e.consume(F),A):M(F)}function M(F){return Je(F)?(o=M,Q(F)):Ot(F)?(e.consume(F),M):$(F)}function P(F){return F===45||mr(F)?(e.consume(F),P):F===47||F===62||rn(F)?G(F):n(F)}function G(F){return F===47?(e.consume(F),$):F===58||F===95||Ir(F)?(e.consume(F),B):Je(F)?(o=G,Q(F)):Ot(F)?(e.consume(F),G):$(F)}function B(F){return F===45||F===46||F===58||F===95||mr(F)?(e.consume(F),B):H(F)}function H(F){return F===61?(e.consume(F),Z):Je(F)?(o=H,Q(F)):Ot(F)?(e.consume(F),H):G(F)}function Z(F){return F===null||F===60||F===61||F===62||F===96?n(F):F===34||F===39?(e.consume(F),a=F,V):Je(F)?(o=Z,Q(F)):Ot(F)?(e.consume(F),Z):(e.consume(F),q)}function V(F){return F===a?(e.consume(F),a=void 0,X):F===null?n(F):Je(F)?(o=V,Q(F)):(e.consume(F),V)}function q(F){return F===null||F===34||F===39||F===60||F===61||F===96?n(F):F===47||F===62||rn(F)?G(F):(e.consume(F),q)}function X(F){return F===47||F===62||rn(F)?G(F):n(F)}function $(F){return F===62?(e.consume(F),e.exit("htmlTextData"),e.exit("htmlText"),t):n(F)}function Q(F){return e.exit("htmlTextData"),e.enter("lineEnding"),e.consume(F),e.exit("lineEnding"),J}function J(F){return Ot(F)?At(e,ie,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(F):ie(F)}function ie(F){return e.enter("htmlTextData"),o(F)}}const BS={name:"labelEnd",resolveAll:hte,resolveTo:pte,tokenize:fte},cte={tokenize:mte},ute={tokenize:gte},dte={tokenize:bte};function hte(e){let t=-1;const n=[];for(;++t<e.length;){const r=e[t][1];if(n.push(e[t]),r.type==="labelImage"||r.type==="labelLink"||r.type==="labelEnd"){const a=r.type==="labelImage"?4:2;r.type="data",t+=a}}return e.length!==n.length&&ma(e,0,e.length,n),e}function pte(e,t){let n=e.length,r=0,a,i,o,l;for(;n--;)if(a=e[n][1],i){if(a.type==="link"||a.type==="labelLink"&&a._inactive)break;e[n][0]==="enter"&&a.type==="labelLink"&&(a._inactive=!0)}else if(o){if(e[n][0]==="enter"&&(a.type==="labelImage"||a.type==="labelLink")&&!a._balanced&&(i=n,a.type!=="labelLink")){r=2;break}}else a.type==="labelEnd"&&(o=n);const u={type:e[i][1].type==="labelLink"?"link":"image",start:{...e[i][1].start},end:{...e[e.length-1][1].end}},d={type:"label",start:{...e[i][1].start},end:{...e[o][1].end}},h={type:"labelText",start:{...e[i+r+2][1].end},end:{...e[o-2][1].start}};return l=[["enter",u,t],["enter",d,t]],l=za(l,e.slice(i+1,i+r+3)),l=za(l,[["enter",h,t]]),l=za(l,fg(t.parser.constructs.insideSpan.null,e.slice(i+r+4,o-3),t)),l=za(l,[["exit",h,t],e[o-2],e[o-1],["exit",d,t]]),l=za(l,e.slice(o+1)),l=za(l,[["exit",u,t]]),ma(e,i,e.length,l),e}function fte(e,t,n){const r=this;let a=r.events.length,i,o;for(;a--;)if((r.events[a][1].type==="labelImage"||r.events[a][1].type==="labelLink")&&!r.events[a][1]._balanced){i=r.events[a][1];break}return l;function l(m){return i?i._inactive?f(m):(o=r.parser.defined.includes(ni(r.sliceSerialize({start:i.end,end:r.now()}))),e.enter("labelEnd"),e.enter("labelMarker"),e.consume(m),e.exit("labelMarker"),e.exit("labelEnd"),u):n(m)}function u(m){return m===40?e.attempt(cte,h,o?h:f)(m):m===91?e.attempt(ute,h,o?d:f)(m):o?h(m):f(m)}function d(m){return e.attempt(dte,h,f)(m)}function h(m){return t(m)}function f(m){return i._balanced=!0,n(m)}}function mte(e,t,n){return r;function r(f){return e.enter("resource"),e.enter("resourceMarker"),e.consume(f),e.exit("resourceMarker"),a}function a(f){return rn(f)?lh(e,i)(f):i(f)}function i(f){return f===41?h(f):XL(e,o,l,"resourceDestination","resourceDestinationLiteral","resourceDestinationLiteralMarker","resourceDestinationRaw","resourceDestinationString",32)(f)}function o(f){return rn(f)?lh(e,u)(f):h(f)}function l(f){return n(f)}function u(f){return f===34||f===39||f===40?ZL(e,d,n,"resourceTitle","resourceTitleMarker","resourceTitleString")(f):h(f)}function d(f){return rn(f)?lh(e,h)(f):h(f)}function h(f){return f===41?(e.enter("resourceMarker"),e.consume(f),e.exit("resourceMarker"),e.exit("resource"),t):n(f)}}function gte(e,t,n){const r=this;return a;function a(l){return KL.call(r,e,i,o,"reference","referenceMarker","referenceString")(l)}function i(l){return r.parser.defined.includes(ni(r.sliceSerialize(r.events[r.events.length-1][1]).slice(1,-1)))?t(l):n(l)}function o(l){return n(l)}}function bte(e,t,n){return r;function r(i){return e.enter("reference"),e.enter("referenceMarker"),e.consume(i),e.exit("referenceMarker"),a}function a(i){return i===93?(e.enter("referenceMarker"),e.consume(i),e.exit("referenceMarker"),e.exit("reference"),t):n(i)}}const yte={name:"labelStartImage",resolveAll:BS.resolveAll,tokenize:vte};function vte(e,t,n){const r=this;return a;function a(l){return e.enter("labelImage"),e.enter("labelImageMarker"),e.consume(l),e.exit("labelImageMarker"),i}function i(l){return l===91?(e.enter("labelMarker"),e.consume(l),e.exit("labelMarker"),e.exit("labelImage"),o):n(l)}function o(l){return l===94&&"_hiddenFootnoteSupport"in r.parser.constructs?n(l):t(l)}}const xte={name:"labelStartLink",resolveAll:BS.resolveAll,tokenize:Ste};function Ste(e,t,n){const r=this;return a;function a(o){return e.enter("labelLink"),e.enter("labelMarker"),e.consume(o),e.exit("labelMarker"),e.exit("labelLink"),i}function i(o){return o===94&&"_hiddenFootnoteSupport"in r.parser.constructs?n(o):t(o)}}const tv={name:"lineEnding",tokenize:wte};function wte(e,t){return n;function n(r){return e.enter("lineEnding"),e.consume(r),e.exit("lineEnding"),At(e,t,"linePrefix")}}const N0={name:"thematicBreak",tokenize:Ete};function Ete(e,t,n){let r=0,a;return i;function i(d){return e.enter("thematicBreak"),o(d)}function o(d){return a=d,l(d)}function l(d){return d===a?(e.enter("thematicBreakSequence"),u(d)):r>=3&&(d===null||Je(d))?(e.exit("thematicBreak"),t(d)):n(d)}function u(d){return d===a?(e.consume(d),r++,u):(e.exit("thematicBreakSequence"),Ot(d)?At(e,l,"whitespace")(d):l(d))}}const Kr={continuation:{tokenize:Cte},exit:Rte,name:"list",tokenize:_te},kte={partial:!0,tokenize:Nte},Tte={partial:!0,tokenize:Ate};function _te(e,t,n){const r=this,a=r.events[r.events.length-1];let i=a&&a[1].type==="linePrefix"?a[2].sliceSerialize(a[1],!0).length:0,o=0;return l;function l(b){const y=r.containerState.type||(b===42||b===43||b===45?"listUnordered":"listOrdered");if(y==="listUnordered"?!r.containerState.marker||b===r.containerState.marker:mx(b)){if(r.containerState.type||(r.containerState.type=y,e.enter(y,{_container:!0})),y==="listUnordered")return e.enter("listItemPrefix"),b===42||b===45?e.check(N0,n,d)(b):d(b);if(!r.interrupt||b===49)return e.enter("listItemPrefix"),e.enter("listItemValue"),u(b)}return n(b)}function u(b){return mx(b)&&++o<10?(e.consume(b),u):(!r.interrupt||o<2)&&(r.containerState.marker?b===r.containerState.marker:b===41||b===46)?(e.exit("listItemValue"),d(b)):n(b)}function d(b){return e.enter("listItemMarker"),e.consume(b),e.exit("listItemMarker"),r.containerState.marker=r.containerState.marker||b,e.check(tp,r.interrupt?n:h,e.attempt(kte,m,f))}function h(b){return r.containerState.initialBlankLine=!0,i++,m(b)}function f(b){return Ot(b)?(e.enter("listItemPrefixWhitespace"),e.consume(b),e.exit("listItemPrefixWhitespace"),m):n(b)}function m(b){return r.containerState.size=i+r.sliceSerialize(e.exit("listItemPrefix"),!0).length,t(b)}}function Cte(e,t,n){const r=this;return r.containerState._closeFlow=void 0,e.check(tp,a,i);function a(l){return r.containerState.furtherBlankLines=r.containerState.furtherBlankLines||r.containerState.initialBlankLine,At(e,t,"listItemIndent",r.containerState.size+1)(l)}function i(l){return r.containerState.furtherBlankLines||!Ot(l)?(r.containerState.furtherBlankLines=void 0,r.containerState.initialBlankLine=void 0,o(l)):(r.containerState.furtherBlankLines=void 0,r.containerState.initialBlankLine=void 0,e.attempt(Tte,t,o)(l))}function o(l){return r.containerState._closeFlow=!0,r.interrupt=void 0,At(e,e.attempt(Kr,t,n),"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(l)}}function Ate(e,t,n){const r=this;return At(e,a,"listItemIndent",r.containerState.size+1);function a(i){const o=r.events[r.events.length-1];return o&&o[1].type==="listItemIndent"&&o[2].sliceSerialize(o[1],!0).length===r.containerState.size?t(i):n(i)}}function Rte(e){e.exit(this.containerState.type)}function Nte(e,t,n){const r=this;return At(e,a,"listItemPrefixWhitespace",r.parser.constructs.disable.null.includes("codeIndented")?void 0:5);function a(i){const o=r.events[r.events.length-1];return!Ot(i)&&o&&o[1].type==="listItemPrefixWhitespace"?t(i):n(i)}}const FR={name:"setextUnderline",resolveTo:Ote,tokenize:Ite};function Ote(e,t){let n=e.length,r,a,i;for(;n--;)if(e[n][0]==="enter"){if(e[n][1].type==="content"){r=n;break}e[n][1].type==="paragraph"&&(a=n)}else e[n][1].type==="content"&&e.splice(n,1),!i&&e[n][1].type==="definition"&&(i=n);const o={type:"setextHeading",start:{...e[r][1].start},end:{...e[e.length-1][1].end}};return e[a][1].type="setextHeadingText",i?(e.splice(a,0,["enter",o,t]),e.splice(i+1,0,["exit",e[r][1],t]),e[r][1].end={...e[i][1].end}):e[r][1]=o,e.push(["exit",o,t]),e}function Ite(e,t,n){const r=this;let a;return i;function i(d){let h=r.events.length,f;for(;h--;)if(r.events[h][1].type!=="lineEnding"&&r.events[h][1].type!=="linePrefix"&&r.events[h][1].type!=="content"){f=r.events[h][1].type==="paragraph";break}return!r.parser.lazy[r.now().line]&&(r.interrupt||f)?(e.enter("setextHeadingLine"),a=d,o(d)):n(d)}function o(d){return e.enter("setextHeadingLineSequence"),l(d)}function l(d){return d===a?(e.consume(d),l):(e.exit("setextHeadingLineSequence"),Ot(d)?At(e,u,"lineSuffix")(d):u(d))}function u(d){return d===null||Je(d)?(e.exit("setextHeadingLine"),t(d)):n(d)}}const Lte={tokenize:Dte};function Dte(e){const t=this,n=e.attempt(tp,r,e.attempt(this.parser.constructs.flowInitial,a,At(e,e.attempt(this.parser.constructs.flow,a,e.attempt($ee,a)),"linePrefix")));return n;function r(i){if(i===null){e.consume(i);return}return e.enter("lineEndingBlank"),e.consume(i),e.exit("lineEndingBlank"),t.currentConstruct=void 0,n}function a(i){if(i===null){e.consume(i);return}return e.enter("lineEnding"),e.consume(i),e.exit("lineEnding"),t.currentConstruct=void 0,n}}const Mte={resolveAll:JL()},Bte=QL("string"),Fte=QL("text");function QL(e){return{resolveAll:JL(e==="text"?zte:void 0),tokenize:t};function t(n){const r=this,a=this.parser.constructs[e],i=n.attempt(a,o,l);return o;function o(h){return d(h)?i(h):l(h)}function l(h){if(h===null){n.consume(h);return}return n.enter("data"),n.consume(h),u}function u(h){return d(h)?(n.exit("data"),i(h)):(n.consume(h),u)}function d(h){if(h===null)return!0;const f=a[h];let m=-1;if(f)for(;++m<f.length;){const b=f[m];if(!b.previous||b.previous.call(r,r.previous))return!0}return!1}}}function JL(e){return t;function t(n,r){let a=-1,i;for(;++a<=n.length;)i===void 0?n[a]&&n[a][1].type==="data"&&(i=a,a++):(!n[a]||n[a][1].type!=="data")&&(a!==i+2&&(n[i][1].end=n[a-1][1].end,n.splice(i+2,a-i-2),a=i+2),i=void 0);return e?e(n,r):n}}function zte(e,t){let n=0;for(;++n<=e.length;)if((n===e.length||e[n][1].type==="lineEnding")&&e[n-1][1].type==="data"){const r=e[n-1][1],a=t.sliceStream(r);let i=a.length,o=-1,l=0,u;for(;i--;){const d=a[i];if(typeof d=="string"){for(o=d.length;d.charCodeAt(o-1)===32;)l++,o--;if(o)break;o=-1}else if(d===-2)u=!0,l++;else if(d!==-1){i++;break}}if(t._contentTypeTextTrailing&&n===e.length&&(l=0),l){const d={type:n===e.length||u||l<2?"lineSuffix":"hardBreakTrailing",start:{_bufferIndex:i?o:r.start._bufferIndex+o,_index:r.start._index+i,line:r.end.line,column:r.end.column-l,offset:r.end.offset-l},end:{...r.end}};r.end={...d.start},r.start.offset===r.end.offset?Object.assign(r,d):(e.splice(n,0,["enter",d,t],["exit",d,t]),n+=2)}n++}return e}const $te={42:Kr,43:Kr,45:Kr,48:Kr,49:Kr,50:Kr,51:Kr,52:Kr,53:Kr,54:Kr,55:Kr,56:Kr,57:Kr,62:qL},Pte={91:Gee},Ute={[-2]:ev,[-1]:ev,32:ev},jte={35:Kee,42:N0,45:[FR,N0],60:ete,61:FR,95:N0,96:MR,126:MR},Hte={38:VL,92:WL},Gte={[-5]:tv,[-4]:tv,[-3]:tv,33:yte,38:VL,42:gx,60:[xee,ste],91:xte,92:[Yee,WL],93:BS,95:gx,96:Lee},qte={null:[gx,Mte]},Wte={null:[42,95]},Vte={null:[]},Yte=Object.freeze(Object.defineProperty({__proto__:null,attentionMarkers:Wte,contentInitial:Pte,disable:Vte,document:$te,flow:jte,flowInitial:Ute,insideSpan:qte,string:Hte,text:Gte},Symbol.toStringTag,{value:"Module"}));function Xte(e,t,n){let r={_bufferIndex:-1,_index:0,line:n&&n.line||1,column:n&&n.column||1,offset:n&&n.offset||0};const a={},i=[];let o=[],l=[];const u={attempt:M(L),check:M(A),consume:k,enter:R,exit:I,interrupt:M(A,{interrupt:!0})},d={code:null,containerState:{},defineSkip:v,events:[],now:y,parser:e,previous:null,sliceSerialize:m,sliceStream:b,write:f};let h=t.tokenize.call(d,u);return t.resolveAll&&i.push(t),d;function f(H){return o=za(o,H),w(),o[o.length-1]!==null?[]:(P(t,0),d.events=fg(i,d.events,d),d.events)}function m(H,Z){return Zte(b(H),Z)}function b(H){return Kte(o,H)}function y(){const{_bufferIndex:H,_index:Z,line:V,column:q,offset:X}=r;return{_bufferIndex:H,_index:Z,line:V,column:q,offset:X}}function v(H){a[H.line]=H.column,B()}function w(){let H;for(;r._index<o.length;){const Z=o[r._index];if(typeof Z=="string")for(H=r._index,r._bufferIndex<0&&(r._bufferIndex=0);r._index===H&&r._bufferIndex<Z.length;)S(Z.charCodeAt(r._bufferIndex));else S(Z)}}function S(H){h=h(H)}function k(H){Je(H)?(r.line++,r.column=1,r.offset+=H===-3?2:1,B()):H!==-1&&(r.column++,r.offset++),r._bufferIndex<0?r._index++:(r._bufferIndex++,r._bufferIndex===o[r._index].length&&(r._bufferIndex=-1,r._index++)),d.previous=H}function R(H,Z){const V=Z||{};return V.type=H,V.start=y(),d.events.push(["enter",V,d]),l.push(V),V}function I(H){const Z=l.pop();return Z.end=y(),d.events.push(["exit",Z,d]),Z}function L(H,Z){P(H,Z.from)}function A(H,Z){Z.restore()}function M(H,Z){return V;function V(q,X,$){let Q,J,ie,F;return Array.isArray(q)?oe(q):"tokenize"in q?oe([q]):Y(q);function Y(fe){return Ee;function Ee(Ae){const ve=Ae!==null&&fe[Ae],De=Ae!==null&&fe.null,Le=[...Array.isArray(ve)?ve:ve?[ve]:[],...Array.isArray(De)?De:De?[De]:[]];return oe(Le)(Ae)}}function oe(fe){return Q=fe,J=0,fe.length===0?$:U(fe[J])}function U(fe){return Ee;function Ee(Ae){return F=G(),ie=fe,fe.partial||(d.currentConstruct=fe),fe.name&&d.parser.constructs.disable.null.includes(fe.name)?ge():fe.tokenize.call(Z?Object.assign(Object.create(d),Z):d,u,be,ge)(Ae)}}function be(fe){return H(ie,F),X}function ge(fe){return F.restore(),++J<Q.length?U(Q[J]):$}}}function P(H,Z){H.resolveAll&&!i.includes(H)&&i.push(H),H.resolve&&ma(d.events,Z,d.events.length-Z,H.resolve(d.events.slice(Z),d)),H.resolveTo&&(d.events=H.resolveTo(d.events,d))}function G(){const H=y(),Z=d.previous,V=d.currentConstruct,q=d.events.length,X=Array.from(l);return{from:q,restore:$};function $(){r=H,d.previous=Z,d.currentConstruct=V,d.events.length=q,l=X,B()}}function B(){r.line in a&&r.column<2&&(r.column=a[r.line],r.offset+=a[r.line]-1)}}function Kte(e,t){const n=t.start._index,r=t.start._bufferIndex,a=t.end._index,i=t.end._bufferIndex;let o;if(n===a)o=[e[n].slice(r,i)];else{if(o=e.slice(n,a),r>-1){const l=o[0];typeof l=="string"?o[0]=l.slice(r):o.shift()}i>0&&o.push(e[a].slice(0,i))}return o}function Zte(e,t){let n=-1;const r=[];let a;for(;++n<e.length;){const i=e[n];let o;if(typeof i=="string")o=i;else switch(i){case-5:{o="\r";break}case-4:{o=`
`;break}case-3:{o=`\r
`;break}case-2:{o=t?" ":"	";break}case-1:{if(!t&&a)continue;o=" ";break}default:o=String.fromCharCode(i)}a=i===-2,r.push(o)}return r.join("")}function Qte(e){const r={constructs:HL([Yte,...(e||{}).extensions||[]]),content:a(pee),defined:[],document:a(mee),flow:a(Lte),lazy:{},string:a(Bte),text:a(Fte)};return r;function a(i){return o;function o(l){return Xte(r,i,l)}}}function Jte(e){for(;!YL(e););return e}const zR=/[\0\t\n\r]/g;function ene(){let e=1,t="",n=!0,r;return a;function a(i,o,l){const u=[];let d,h,f,m,b;for(i=t+(typeof i=="string"?i.toString():new TextDecoder(o||void 0).decode(i)),f=0,t="",n&&(i.charCodeAt(0)===65279&&f++,n=void 0);f<i.length;){if(zR.lastIndex=f,d=zR.exec(i),m=d&&d.index!==void 0?d.index:i.length,b=i.charCodeAt(m),!d){t=i.slice(f);break}if(b===10&&f===m&&r)u.push(-3),r=void 0;else switch(r&&(u.push(-5),r=void 0),f<m&&(u.push(i.slice(f,m)),e+=m-f),b){case 0:{u.push(65533),e++;break}case 9:{for(h=Math.ceil(e/4)*4,u.push(-2);e++<h;)u.push(-1);break}case 10:{u.push(-4),e=1;break}default:r=!0,e=1}f=m+1}return l&&(r&&u.push(-5),t&&u.push(t),u.push(null)),u}}const tne=/\\([!-/:-@[-`{-~])|&(#(?:\d{1,7}|x[\da-f]{1,6})|[\da-z]{1,31});/gi;function nne(e){return e.replace(tne,rne)}function rne(e,t,n){if(t)return t;if(n.charCodeAt(0)===35){const a=n.charCodeAt(1),i=a===120||a===88;return GL(n.slice(i?2:1),i?16:10)}return _h(n)||e}const eD={}.hasOwnProperty;function ane(e,t,n){return t&&typeof t=="object"&&(n=t,t=void 0),ine(n)(Jte(Qte(n).document().write(ene()(e,t,!0))))}function ine(e){const t={transforms:[],canContainEols:["emphasis","fragment","heading","paragraph","strong"],enter:{autolink:i(Cn),autolinkProtocol:G,autolinkEmail:G,atxHeading:i(Xt),blockQuote:i(De),characterEscape:G,characterReference:G,codeFenced:i(Le),codeFencedFenceInfo:o,codeFencedFenceMeta:o,codeIndented:i(Le,o),codeText:i(rt,o),codeTextData:G,data:G,codeFlowValue:G,definition:i(Xe),definitionDestinationString:o,definitionLabelString:o,definitionTitleString:o,emphasis:i(gt),hardBreakEscape:i(er),hardBreakTrailing:i(er),htmlFlow:i(Tr,o),htmlFlowData:G,htmlText:i(Tr,o),htmlTextData:G,image:i(Hn),label:o,link:i(Cn),listItem:i(wa),listItemValue:m,listOrdered:i(Zn,f),listUnordered:i(Zn),paragraph:i(di),reference:U,referenceString:o,resourceDestinationString:o,resourceTitleString:o,setextHeading:i(Xt),strong:i(qe),thematicBreak:i(ur)},exit:{atxHeading:u(),atxHeadingSequence:L,autolink:u(),autolinkEmail:ve,autolinkProtocol:Ae,blockQuote:u(),characterEscapeValue:B,characterReferenceMarkerHexadecimal:ge,characterReferenceMarkerNumeric:ge,characterReferenceValue:fe,characterReference:Ee,codeFenced:u(w),codeFencedFence:v,codeFencedFenceInfo:b,codeFencedFenceMeta:y,codeFlowValue:B,codeIndented:u(S),codeText:u(X),codeTextData:B,data:B,definition:u(),definitionDestinationString:I,definitionLabelString:k,definitionTitleString:R,emphasis:u(),hardBreakEscape:u(Z),hardBreakTrailing:u(Z),htmlFlow:u(V),htmlFlowData:B,htmlText:u(q),htmlTextData:B,image:u(Q),label:ie,labelText:J,lineEnding:H,link:u($),listItem:u(),listOrdered:u(),listUnordered:u(),paragraph:u(),referenceString:be,resourceDestinationString:F,resourceTitleString:Y,resource:oe,setextHeading:u(P),setextHeadingLineSequence:M,setextHeadingText:A,strong:u(),thematicBreak:u()}};tD(t,(e||{}).mdastExtensions||[]);const n={};return r;function r(me){let Te={type:"root",children:[]};const We={stack:[Te],tokenStack:[],config:t,enter:l,exit:d,buffer:o,resume:h,data:n},ut=[];let It=-1;for(;++It<me.length;)if(me[It][1].type==="listOrdered"||me[It][1].type==="listUnordered")if(me[It][0]==="enter")ut.push(It);else{const En=ut.pop();It=a(me,En,It)}for(It=-1;++It<me.length;){const En=t[me[It][0]];eD.call(En,me[It][1].type)&&En[me[It][1].type].call(Object.assign({sliceSerialize:me[It][2].sliceSerialize},We),me[It][1])}if(We.tokenStack.length>0){const En=We.tokenStack[We.tokenStack.length-1];(En[1]||$R).call(We,void 0,En[0])}for(Te.position={start:cs(me.length>0?me[0][1].start:{line:1,column:1,offset:0}),end:cs(me.length>0?me[me.length-2][1].end:{line:1,column:1,offset:0})},It=-1;++It<t.transforms.length;)Te=t.transforms[It](Te)||Te;return Te}function a(me,Te,We){let ut=Te-1,It=-1,En=!1,_r,In,hn,pn;for(;++ut<=We;){const zt=me[ut];switch(zt[1].type){case"listUnordered":case"listOrdered":case"blockQuote":{zt[0]==="enter"?It++:It--,pn=void 0;break}case"lineEndingBlank":{zt[0]==="enter"&&(_r&&!pn&&!It&&!hn&&(hn=ut),pn=void 0);break}case"linePrefix":case"listItemValue":case"listItemMarker":case"listItemPrefix":case"listItemPrefixWhitespace":break;default:pn=void 0}if(!It&&zt[0]==="enter"&&zt[1].type==="listItemPrefix"||It===-1&&zt[0]==="exit"&&(zt[1].type==="listUnordered"||zt[1].type==="listOrdered")){if(_r){let Ea=ut;for(In=void 0;Ea--;){const Cr=me[Ea];if(Cr[1].type==="lineEnding"||Cr[1].type==="lineEndingBlank"){if(Cr[0]==="exit")continue;In&&(me[In][1].type="lineEndingBlank",En=!0),Cr[1].type="lineEnding",In=Ea}else if(!(Cr[1].type==="linePrefix"||Cr[1].type==="blockQuotePrefix"||Cr[1].type==="blockQuotePrefixWhitespace"||Cr[1].type==="blockQuoteMarker"||Cr[1].type==="listItemIndent"))break}hn&&(!In||hn<In)&&(_r._spread=!0),_r.end=Object.assign({},In?me[In][1].start:zt[1].end),me.splice(In||ut,0,["exit",_r,zt[2]]),ut++,We++}if(zt[1].type==="listItemPrefix"){const Ea={type:"listItem",_spread:!1,start:Object.assign({},zt[1].start),end:void 0};_r=Ea,me.splice(ut,0,["enter",Ea,zt[2]]),ut++,We++,hn=void 0,pn=!0}}}return me[Te][1]._spread=En,We}function i(me,Te){return We;function We(ut){l.call(this,me(ut),ut),Te&&Te.call(this,ut)}}function o(){this.stack.push({type:"fragment",children:[]})}function l(me,Te,We){this.stack[this.stack.length-1].children.push(me),this.stack.push(me),this.tokenStack.push([Te,We||void 0]),me.position={start:cs(Te.start),end:void 0}}function u(me){return Te;function Te(We){me&&me.call(this,We),d.call(this,We)}}function d(me,Te){const We=this.stack.pop(),ut=this.tokenStack.pop();if(ut)ut[0].type!==me.type&&(Te?Te.call(this,me,ut[0]):(ut[1]||$R).call(this,me,ut[0]));else throw new Error("Cannot close `"+me.type+"` ("+sh({start:me.start,end:me.end})+"): it’s not open");We.position.end=cs(me.end)}function h(){return MS(this.stack.pop())}function f(){this.data.expectingFirstListItemValue=!0}function m(me){if(this.data.expectingFirstListItemValue){const Te=this.stack[this.stack.length-2];Te.start=Number.parseInt(this.sliceSerialize(me),10),this.data.expectingFirstListItemValue=void 0}}function b(){const me=this.resume(),Te=this.stack[this.stack.length-1];Te.lang=me}function y(){const me=this.resume(),Te=this.stack[this.stack.length-1];Te.meta=me}function v(){this.data.flowCodeInside||(this.buffer(),this.data.flowCodeInside=!0)}function w(){const me=this.resume(),Te=this.stack[this.stack.length-1];Te.value=me.replace(/^(\r?\n|\r)|(\r?\n|\r)$/g,""),this.data.flowCodeInside=void 0}function S(){const me=this.resume(),Te=this.stack[this.stack.length-1];Te.value=me.replace(/(\r?\n|\r)$/g,"")}function k(me){const Te=this.resume(),We=this.stack[this.stack.length-1];We.label=Te,We.identifier=ni(this.sliceSerialize(me)).toLowerCase()}function R(){const me=this.resume(),Te=this.stack[this.stack.length-1];Te.title=me}function I(){const me=this.resume(),Te=this.stack[this.stack.length-1];Te.url=me}function L(me){const Te=this.stack[this.stack.length-1];if(!Te.depth){const We=this.sliceSerialize(me).length;Te.depth=We}}function A(){this.data.setextHeadingSlurpLineEnding=!0}function M(me){const Te=this.stack[this.stack.length-1];Te.depth=this.sliceSerialize(me).codePointAt(0)===61?1:2}function P(){this.data.setextHeadingSlurpLineEnding=void 0}function G(me){const We=this.stack[this.stack.length-1].children;let ut=We[We.length-1];(!ut||ut.type!=="text")&&(ut=yt(),ut.position={start:cs(me.start),end:void 0},We.push(ut)),this.stack.push(ut)}function B(me){const Te=this.stack.pop();Te.value+=this.sliceSerialize(me),Te.position.end=cs(me.end)}function H(me){const Te=this.stack[this.stack.length-1];if(this.data.atHardBreak){const We=Te.children[Te.children.length-1];We.position.end=cs(me.end),this.data.atHardBreak=void 0;return}!this.data.setextHeadingSlurpLineEnding&&t.canContainEols.includes(Te.type)&&(G.call(this,me),B.call(this,me))}function Z(){this.data.atHardBreak=!0}function V(){const me=this.resume(),Te=this.stack[this.stack.length-1];Te.value=me}function q(){const me=this.resume(),Te=this.stack[this.stack.length-1];Te.value=me}function X(){const me=this.resume(),Te=this.stack[this.stack.length-1];Te.value=me}function $(){const me=this.stack[this.stack.length-1];if(this.data.inReference){const Te=this.data.referenceType||"shortcut";me.type+="Reference",me.referenceType=Te,delete me.url,delete me.title}else delete me.identifier,delete me.label;this.data.referenceType=void 0}function Q(){const me=this.stack[this.stack.length-1];if(this.data.inReference){const Te=this.data.referenceType||"shortcut";me.type+="Reference",me.referenceType=Te,delete me.url,delete me.title}else delete me.identifier,delete me.label;this.data.referenceType=void 0}function J(me){const Te=this.sliceSerialize(me),We=this.stack[this.stack.length-2];We.label=nne(Te),We.identifier=ni(Te).toLowerCase()}function ie(){const me=this.stack[this.stack.length-1],Te=this.resume(),We=this.stack[this.stack.length-1];if(this.data.inReference=!0,We.type==="link"){const ut=me.children;We.children=ut}else We.alt=Te}function F(){const me=this.resume(),Te=this.stack[this.stack.length-1];Te.url=me}function Y(){const me=this.resume(),Te=this.stack[this.stack.length-1];Te.title=me}function oe(){this.data.inReference=void 0}function U(){this.data.referenceType="collapsed"}function be(me){const Te=this.resume(),We=this.stack[this.stack.length-1];We.label=Te,We.identifier=ni(this.sliceSerialize(me)).toLowerCase(),this.data.referenceType="full"}function ge(me){this.data.characterReferenceType=me.type}function fe(me){const Te=this.sliceSerialize(me),We=this.data.characterReferenceType;let ut;We?(ut=GL(Te,We==="characterReferenceMarkerNumeric"?10:16),this.data.characterReferenceType=void 0):ut=_h(Te);const It=this.stack[this.stack.length-1];It.value+=ut}function Ee(me){const Te=this.stack.pop();Te.position.end=cs(me.end)}function Ae(me){B.call(this,me);const Te=this.stack[this.stack.length-1];Te.url=this.sliceSerialize(me)}function ve(me){B.call(this,me);const Te=this.stack[this.stack.length-1];Te.url="mailto:"+this.sliceSerialize(me)}function De(){return{type:"blockquote",children:[]}}function Le(){return{type:"code",lang:null,meta:null,value:""}}function rt(){return{type:"inlineCode",value:""}}function Xe(){return{type:"definition",identifier:"",label:null,title:null,url:""}}function gt(){return{type:"emphasis",children:[]}}function Xt(){return{type:"heading",depth:0,children:[]}}function er(){return{type:"break"}}function Tr(){return{type:"html",value:""}}function Hn(){return{type:"image",title:null,url:"",alt:null}}function Cn(){return{type:"link",title:null,url:"",children:[]}}function Zn(me){return{type:"list",ordered:me.type==="listOrdered",start:null,spread:me._spread,children:[]}}function wa(me){return{type:"listItem",spread:me._spread,checked:null,children:[]}}function di(){return{type:"paragraph",children:[]}}function qe(){return{type:"strong",children:[]}}function yt(){return{type:"text",value:""}}function ur(){return{type:"thematicBreak"}}}function cs(e){return{line:e.line,column:e.column,offset:e.offset}}function tD(e,t){let n=-1;for(;++n<t.length;){const r=t[n];Array.isArray(r)?tD(e,r):one(e,r)}}function one(e,t){let n;for(n in t)if(eD.call(t,n))switch(n){case"canContainEols":{const r=t[n];r&&e[n].push(...r);break}case"transforms":{const r=t[n];r&&e[n].push(...r);break}case"enter":case"exit":{const r=t[n];r&&Object.assign(e[n],r);break}}}function $R(e,t){throw e?new Error("Cannot close `"+e.type+"` ("+sh({start:e.start,end:e.end})+"): a different token (`"+t.type+"`, "+sh({start:t.start,end:t.end})+") is open"):new Error("Cannot close document, a token (`"+t.type+"`, "+sh({start:t.start,end:t.end})+") is still open")}function sne(e){const t=this;t.parser=n;function n(r){return ane(r,{...t.data("settings"),...e,extensions:t.data("micromarkExtensions")||[],mdastExtensions:t.data("fromMarkdownExtensions")||[]})}}function lne(e,t){const n={type:"element",tagName:"blockquote",properties:{},children:e.wrap(e.all(t),!0)};return e.patch(t,n),e.applyData(t,n)}function cne(e,t){const n={type:"element",tagName:"br",properties:{},children:[]};return e.patch(t,n),[e.applyData(t,n),{type:"text",value:`
`}]}function une(e,t){const n=t.value?t.value+`
`:"",r={},a=t.lang?t.lang.split(/\s+/):[];a.length>0&&(r.className=["language-"+a[0]]);let i={type:"element",tagName:"code",properties:r,children:[{type:"text",value:n}]};return t.meta&&(i.data={meta:t.meta}),e.patch(t,i),i=e.applyData(t,i),i={type:"element",tagName:"pre",properties:{},children:[i]},e.patch(t,i),i}function dne(e,t){const n={type:"element",tagName:"del",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function hne(e,t){const n={type:"element",tagName:"em",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function pne(e,t){const n=typeof e.options.clobberPrefix=="string"?e.options.clobberPrefix:"user-content-",r=String(t.identifier).toUpperCase(),a=yu(r.toLowerCase()),i=e.footnoteOrder.indexOf(r);let o,l=e.footnoteCounts.get(r);l===void 0?(l=0,e.footnoteOrder.push(r),o=e.footnoteOrder.length):o=i+1,l+=1,e.footnoteCounts.set(r,l);const u={type:"element",tagName:"a",properties:{href:"#"+n+"fn-"+a,id:n+"fnref-"+a+(l>1?"-"+l:""),dataFootnoteRef:!0,ariaDescribedBy:["footnote-label"]},children:[{type:"text",value:String(o)}]};e.patch(t,u);const d={type:"element",tagName:"sup",properties:{},children:[u]};return e.patch(t,d),e.applyData(t,d)}function fne(e,t){const n={type:"element",tagName:"h"+t.depth,properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function mne(e,t){if(e.options.allowDangerousHtml){const n={type:"raw",value:t.value};return e.patch(t,n),e.applyData(t,n)}}function nD(e,t){const n=t.referenceType;let r="]";if(n==="collapsed"?r+="[]":n==="full"&&(r+="["+(t.label||t.identifier)+"]"),t.type==="imageReference")return[{type:"text",value:"!["+t.alt+r}];const a=e.all(t),i=a[0];i&&i.type==="text"?i.value="["+i.value:a.unshift({type:"text",value:"["});const o=a[a.length-1];return o&&o.type==="text"?o.value+=r:a.push({type:"text",value:r}),a}function gne(e,t){const n=String(t.identifier).toUpperCase(),r=e.definitionById.get(n);if(!r)return nD(e,t);const a={src:yu(r.url||""),alt:t.alt};r.title!==null&&r.title!==void 0&&(a.title=r.title);const i={type:"element",tagName:"img",properties:a,children:[]};return e.patch(t,i),e.applyData(t,i)}function bne(e,t){const n={src:yu(t.url)};t.alt!==null&&t.alt!==void 0&&(n.alt=t.alt),t.title!==null&&t.title!==void 0&&(n.title=t.title);const r={type:"element",tagName:"img",properties:n,children:[]};return e.patch(t,r),e.applyData(t,r)}function yne(e,t){const n={type:"text",value:t.value.replace(/\r?\n|\r/g," ")};e.patch(t,n);const r={type:"element",tagName:"code",properties:{},children:[n]};return e.patch(t,r),e.applyData(t,r)}function vne(e,t){const n=String(t.identifier).toUpperCase(),r=e.definitionById.get(n);if(!r)return nD(e,t);const a={href:yu(r.url||"")};r.title!==null&&r.title!==void 0&&(a.title=r.title);const i={type:"element",tagName:"a",properties:a,children:e.all(t)};return e.patch(t,i),e.applyData(t,i)}function xne(e,t){const n={href:yu(t.url)};t.title!==null&&t.title!==void 0&&(n.title=t.title);const r={type:"element",tagName:"a",properties:n,children:e.all(t)};return e.patch(t,r),e.applyData(t,r)}function Sne(e,t,n){const r=e.all(t),a=n?wne(n):rD(t),i={},o=[];if(typeof t.checked=="boolean"){const h=r[0];let f;h&&h.type==="element"&&h.tagName==="p"?f=h:(f={type:"element",tagName:"p",properties:{},children:[]},r.unshift(f)),f.children.length>0&&f.children.unshift({type:"text",value:" "}),f.children.unshift({type:"element",tagName:"input",properties:{type:"checkbox",checked:t.checked,disabled:!0},children:[]}),i.className=["task-list-item"]}let l=-1;for(;++l<r.length;){const h=r[l];(a||l!==0||h.type!=="element"||h.tagName!=="p")&&o.push({type:"text",value:`
`}),h.type==="element"&&h.tagName==="p"&&!a?o.push(...h.children):o.push(h)}const u=r[r.length-1];u&&(a||u.type!=="element"||u.tagName!=="p")&&o.push({type:"text",value:`
`});const d={type:"element",tagName:"li",properties:i,children:o};return e.patch(t,d),e.applyData(t,d)}function wne(e){let t=!1;if(e.type==="list"){t=e.spread||!1;const n=e.children;let r=-1;for(;!t&&++r<n.length;)t=rD(n[r])}return t}function rD(e){const t=e.spread;return t??e.children.length>1}function Ene(e,t){const n={},r=e.all(t);let a=-1;for(typeof t.start=="number"&&t.start!==1&&(n.start=t.start);++a<r.length;){const o=r[a];if(o.type==="element"&&o.tagName==="li"&&o.properties&&Array.isArray(o.properties.className)&&o.properties.className.includes("task-list-item")){n.className=["contains-task-list"];break}}const i={type:"element",tagName:t.ordered?"ol":"ul",properties:n,children:e.wrap(r,!0)};return e.patch(t,i),e.applyData(t,i)}function kne(e,t){const n={type:"element",tagName:"p",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function Tne(e,t){const n={type:"root",children:e.wrap(e.all(t))};return e.patch(t,n),e.applyData(t,n)}function _ne(e,t){const n={type:"element",tagName:"strong",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function Cne(e,t){const n=e.all(t),r=n.shift(),a=[];if(r){const o={type:"element",tagName:"thead",properties:{},children:e.wrap([r],!0)};e.patch(t.children[0],o),a.push(o)}if(n.length>0){const o={type:"element",tagName:"tbody",properties:{},children:e.wrap(n,!0)},l=OS(t.children[1]),u=BL(t.children[t.children.length-1]);l&&u&&(o.position={start:l,end:u}),a.push(o)}const i={type:"element",tagName:"table",properties:{},children:e.wrap(a,!0)};return e.patch(t,i),e.applyData(t,i)}function Ane(e,t,n){const r=n?n.children:void 0,i=(r?r.indexOf(t):1)===0?"th":"td",o=n&&n.type==="table"?n.align:void 0,l=o?o.length:t.children.length;let u=-1;const d=[];for(;++u<l;){const f=t.children[u],m={},b=o?o[u]:void 0;b&&(m.align=b);let y={type:"element",tagName:i,properties:m,children:[]};f&&(y.children=e.all(f),e.patch(f,y),y=e.applyData(f,y)),d.push(y)}const h={type:"element",tagName:"tr",properties:{},children:e.wrap(d,!0)};return e.patch(t,h),e.applyData(t,h)}function Rne(e,t){const n={type:"element",tagName:"td",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}const PR=9,UR=32;function Nne(e){const t=String(e),n=/\r?\n|\r/g;let r=n.exec(t),a=0;const i=[];for(;r;)i.push(jR(t.slice(a,r.index),a>0,!0),r[0]),a=r.index+r[0].length,r=n.exec(t);return i.push(jR(t.slice(a),a>0,!1)),i.join("")}function jR(e,t,n){let r=0,a=e.length;if(t){let i=e.codePointAt(r);for(;i===PR||i===UR;)r++,i=e.codePointAt(r)}if(n){let i=e.codePointAt(a-1);for(;i===PR||i===UR;)a--,i=e.codePointAt(a-1)}return a>r?e.slice(r,a):""}function One(e,t){const n={type:"text",value:Nne(String(t.value))};return e.patch(t,n),e.applyData(t,n)}function Ine(e,t){const n={type:"element",tagName:"hr",properties:{},children:[]};return e.patch(t,n),e.applyData(t,n)}const Lne={blockquote:lne,break:cne,code:une,delete:dne,emphasis:hne,footnoteReference:pne,heading:fne,html:mne,imageReference:gne,image:bne,inlineCode:yne,linkReference:vne,link:xne,listItem:Sne,list:Ene,paragraph:kne,root:Tne,strong:_ne,table:Cne,tableCell:Rne,tableRow:Ane,text:One,thematicBreak:Ine,toml:Qf,yaml:Qf,definition:Qf,footnoteDefinition:Qf};function Qf(){}const aD=-1,mg=0,ch=1,om=2,FS=3,zS=4,$S=5,PS=6,iD=7,oD=8,HR=typeof self=="object"?self:globalThis,Dne=(e,t)=>{const n=(a,i)=>(e.set(i,a),a),r=a=>{if(e.has(a))return e.get(a);const[i,o]=t[a];switch(i){case mg:case aD:return n(o,a);case ch:{const l=n([],a);for(const u of o)l.push(r(u));return l}case om:{const l=n({},a);for(const[u,d]of o)l[r(u)]=r(d);return l}case FS:return n(new Date(o),a);case zS:{const{source:l,flags:u}=o;return n(new RegExp(l,u),a)}case $S:{const l=n(new Map,a);for(const[u,d]of o)l.set(r(u),r(d));return l}case PS:{const l=n(new Set,a);for(const u of o)l.add(r(u));return l}case iD:{const{name:l,message:u}=o;return n(new HR[l](u),a)}case oD:return n(BigInt(o),a);case"BigInt":return n(Object(BigInt(o)),a);case"ArrayBuffer":return n(new Uint8Array(o).buffer,o);case"DataView":{const{buffer:l}=new Uint8Array(o);return n(new DataView(l),o)}}return n(new HR[i](o),a)};return r},GR=e=>Dne(new Map,e)(0),kc="",{toString:Mne}={},{keys:Bne}=Object,Fd=e=>{const t=typeof e;if(t!=="object"||!e)return[mg,t];const n=Mne.call(e).slice(8,-1);switch(n){case"Array":return[ch,kc];case"Object":return[om,kc];case"Date":return[FS,kc];case"RegExp":return[zS,kc];case"Map":return[$S,kc];case"Set":return[PS,kc];case"DataView":return[ch,n]}return n.includes("Array")?[ch,n]:n.includes("Error")?[iD,n]:[om,n]},Jf=([e,t])=>e===mg&&(t==="function"||t==="symbol"),Fne=(e,t,n,r)=>{const a=(o,l)=>{const u=r.push(o)-1;return n.set(l,u),u},i=o=>{if(n.has(o))return n.get(o);let[l,u]=Fd(o);switch(l){case mg:{let h=o;switch(u){case"bigint":l=oD,h=o.toString();break;case"function":case"symbol":if(e)throw new TypeError("unable to serialize "+u);h=null;break;case"undefined":return a([aD],o)}return a([l,h],o)}case ch:{if(u){let m=o;return u==="DataView"?m=new Uint8Array(o.buffer):u==="ArrayBuffer"&&(m=new Uint8Array(o)),a([u,[...m]],o)}const h=[],f=a([l,h],o);for(const m of o)h.push(i(m));return f}case om:{if(u)switch(u){case"BigInt":return a([u,o.toString()],o);case"Boolean":case"Number":case"String":return a([u,o.valueOf()],o)}if(t&&"toJSON"in o)return i(o.toJSON());const h=[],f=a([l,h],o);for(const m of Bne(o))(e||!Jf(Fd(o[m])))&&h.push([i(m),i(o[m])]);return f}case FS:return a([l,o.toISOString()],o);case zS:{const{source:h,flags:f}=o;return a([l,{source:h,flags:f}],o)}case $S:{const h=[],f=a([l,h],o);for(const[m,b]of o)(e||!(Jf(Fd(m))||Jf(Fd(b))))&&h.push([i(m),i(b)]);return f}case PS:{const h=[],f=a([l,h],o);for(const m of o)(e||!Jf(Fd(m)))&&h.push(i(m));return f}}const{message:d}=o;return a([l,{name:u,message:d}],o)};return i},qR=(e,{json:t,lossy:n}={})=>{const r=[];return Fne(!(t||n),!!t,new Map,r)(e),r},sm=typeof structuredClone=="function"?(e,t)=>t&&("json"in t||"lossy"in t)?GR(qR(e,t)):structuredClone(e):(e,t)=>GR(qR(e,t));function zne(e,t){const n=[{type:"text",value:"↩"}];return t>1&&n.push({type:"element",tagName:"sup",properties:{},children:[{type:"text",value:String(t)}]}),n}function $ne(e,t){return"Back to reference "+(e+1)+(t>1?"-"+t:"")}function Pne(e){const t=typeof e.options.clobberPrefix=="string"?e.options.clobberPrefix:"user-content-",n=e.options.footnoteBackContent||zne,r=e.options.footnoteBackLabel||$ne,a=e.options.footnoteLabel||"Footnotes",i=e.options.footnoteLabelTagName||"h2",o=e.options.footnoteLabelProperties||{className:["sr-only"]},l=[];let u=-1;for(;++u<e.footnoteOrder.length;){const d=e.footnoteById.get(e.footnoteOrder[u]);if(!d)continue;const h=e.all(d),f=String(d.identifier).toUpperCase(),m=yu(f.toLowerCase());let b=0;const y=[],v=e.footnoteCounts.get(f);for(;v!==void 0&&++b<=v;){y.length>0&&y.push({type:"text",value:" "});let k=typeof n=="string"?n:n(u,b);typeof k=="string"&&(k={type:"text",value:k}),y.push({type:"element",tagName:"a",properties:{href:"#"+t+"fnref-"+m+(b>1?"-"+b:""),dataFootnoteBackref:"",ariaLabel:typeof r=="string"?r:r(u,b),className:["data-footnote-backref"]},children:Array.isArray(k)?k:[k]})}const w=h[h.length-1];if(w&&w.type==="element"&&w.tagName==="p"){const k=w.children[w.children.length-1];k&&k.type==="text"?k.value+=" ":w.children.push({type:"text",value:" "}),w.children.push(...y)}else h.push(...y);const S={type:"element",tagName:"li",properties:{id:t+"fn-"+m},children:e.wrap(h,!0)};e.patch(d,S),l.push(S)}if(l.length!==0)return{type:"element",tagName:"section",properties:{dataFootnotes:!0,className:["footnotes"]},children:[{type:"element",tagName:i,properties:{...sm(o),id:"footnote-label"},children:[{type:"text",value:a}]},{type:"text",value:`
`},{type:"element",tagName:"ol",properties:{},children:e.wrap(l,!0)},{type:"text",value:`
`}]}}const np=(function(e){if(e==null)return Gne;if(typeof e=="function")return gg(e);if(typeof e=="object")return Array.isArray(e)?Une(e):jne(e);if(typeof e=="string")return Hne(e);throw new Error("Expected function, string, or object as test")});function Une(e){const t=[];let n=-1;for(;++n<e.length;)t[n]=np(e[n]);return gg(r);function r(...a){let i=-1;for(;++i<t.length;)if(t[i].apply(this,a))return!0;return!1}}function jne(e){const t=e;return gg(n);function n(r){const a=r;let i;for(i in e)if(a[i]!==t[i])return!1;return!0}}function Hne(e){return gg(t);function t(n){return n&&n.type===e}}function gg(e){return t;function t(n,r,a){return!!(qne(n)&&e.call(this,n,typeof r=="number"?r:void 0,a||void 0))}}function Gne(){return!0}function qne(e){return e!==null&&typeof e=="object"&&"type"in e}const sD=[],Wne=!0,bx=!1,lD="skip";function US(e,t,n,r){let a;typeof t=="function"&&typeof n!="function"?(r=n,n=t):a=t;const i=np(a),o=r?-1:1;l(e,void 0,[])();function l(u,d,h){const f=u&&typeof u=="object"?u:{};if(typeof f.type=="string"){const b=typeof f.tagName=="string"?f.tagName:typeof f.name=="string"?f.name:void 0;Object.defineProperty(m,"name",{value:"node ("+(u.type+(b?"<"+b+">":""))+")"})}return m;function m(){let b=sD,y,v,w;if((!t||i(u,d,h[h.length-1]||void 0))&&(b=Vne(n(u,h)),b[0]===bx))return b;if("children"in u&&u.children){const S=u;if(S.children&&b[0]!==lD)for(v=(r?S.children.length:-1)+o,w=h.concat(S);v>-1&&v<S.children.length;){const k=S.children[v];if(y=l(k,v,w)(),y[0]===bx)return y;v=typeof y[1]=="number"?y[1]:v+o}}return b}}}function Vne(e){return Array.isArray(e)?e:typeof e=="number"?[Wne,e]:e==null?sD:[e]}function jS(e,t,n,r){let a,i,o;typeof t=="function"&&typeof n!="function"?(i=void 0,o=t,a=n):(i=t,o=n,a=r),US(e,i,l,a);function l(u,d){const h=d[d.length-1],f=h?h.children.indexOf(u):void 0;return o(u,f,h)}}const yx={}.hasOwnProperty,Yne={};function Xne(e,t){const n=t||Yne,r=new Map,a=new Map,i=new Map,o={...Lne,...n.handlers},l={all:d,applyData:Zne,definitionById:r,footnoteById:a,footnoteCounts:i,footnoteOrder:[],handlers:o,one:u,options:n,patch:Kne,wrap:Jne};return jS(e,function(h){if(h.type==="definition"||h.type==="footnoteDefinition"){const f=h.type==="definition"?r:a,m=String(h.identifier).toUpperCase();f.has(m)||f.set(m,h)}}),l;function u(h,f){const m=h.type,b=l.handlers[m];if(yx.call(l.handlers,m)&&b)return b(l,h,f);if(l.options.passThrough&&l.options.passThrough.includes(m)){if("children"in h){const{children:v,...w}=h,S=sm(w);return S.children=l.all(h),S}return sm(h)}return(l.options.unknownHandler||Qne)(l,h,f)}function d(h){const f=[];if("children"in h){const m=h.children;let b=-1;for(;++b<m.length;){const y=l.one(m[b],h);if(y){if(b&&m[b-1].type==="break"&&(!Array.isArray(y)&&y.type==="text"&&(y.value=WR(y.value)),!Array.isArray(y)&&y.type==="element")){const v=y.children[0];v&&v.type==="text"&&(v.value=WR(v.value))}Array.isArray(y)?f.push(...y):f.push(y)}}}return f}}function Kne(e,t){e.position&&(t.position=$J(e))}function Zne(e,t){let n=t;if(e&&e.data){const r=e.data.hName,a=e.data.hChildren,i=e.data.hProperties;if(typeof r=="string")if(n.type==="element")n.tagName=r;else{const o="children"in n?n.children:[n];n={type:"element",tagName:r,properties:{},children:o}}n.type==="element"&&i&&Object.assign(n.properties,sm(i)),"children"in n&&n.children&&a!==null&&a!==void 0&&(n.children=a)}return n}function Qne(e,t){const n=t.data||{},r="value"in t&&!(yx.call(n,"hProperties")||yx.call(n,"hChildren"))?{type:"text",value:t.value}:{type:"element",tagName:"div",properties:{},children:e.all(t)};return e.patch(t,r),e.applyData(t,r)}function Jne(e,t){const n=[];let r=-1;for(t&&n.push({type:"text",value:`
`});++r<e.length;)r&&n.push({type:"text",value:`
`}),n.push(e[r]);return t&&e.length>0&&n.push({type:"text",value:`
`}),n}function WR(e){let t=0,n=e.charCodeAt(t);for(;n===9||n===32;)t++,n=e.charCodeAt(t);return e.slice(t)}function VR(e,t){const n=Xne(e,t),r=n.one(e,void 0),a=Pne(n),i=Array.isArray(r)?{type:"root",children:r}:r||{type:"root",children:[]};return a&&i.children.push({type:"text",value:`
`},a),i}function ere(e,t){return e&&"run"in e?async function(n,r){const a=VR(n,{file:r,...t});await e.run(a,r)}:function(n,r){return VR(n,{file:r,...e||t})}}function YR(e){if(e)throw e}var nv,XR;function tre(){if(XR)return nv;XR=1;var e=Object.prototype.hasOwnProperty,t=Object.prototype.toString,n=Object.defineProperty,r=Object.getOwnPropertyDescriptor,a=function(d){return typeof Array.isArray=="function"?Array.isArray(d):t.call(d)==="[object Array]"},i=function(d){if(!d||t.call(d)!=="[object Object]")return!1;var h=e.call(d,"constructor"),f=d.constructor&&d.constructor.prototype&&e.call(d.constructor.prototype,"isPrototypeOf");if(d.constructor&&!h&&!f)return!1;var m;for(m in d);return typeof m>"u"||e.call(d,m)},o=function(d,h){n&&h.name==="__proto__"?n(d,h.name,{enumerable:!0,configurable:!0,value:h.newValue,writable:!0}):d[h.name]=h.newValue},l=function(d,h){if(h==="__proto__")if(e.call(d,h)){if(r)return r(d,h).value}else return;return d[h]};return nv=function u(){var d,h,f,m,b,y,v=arguments[0],w=1,S=arguments.length,k=!1;for(typeof v=="boolean"&&(k=v,v=arguments[1]||{},w=2),(v==null||typeof v!="object"&&typeof v!="function")&&(v={});w<S;++w)if(d=arguments[w],d!=null)for(h in d)f=l(v,h),m=l(d,h),v!==m&&(k&&m&&(i(m)||(b=a(m)))?(b?(b=!1,y=f&&a(f)?f:[]):y=f&&i(f)?f:{},o(v,{name:h,newValue:u(k,y,m)})):typeof m<"u"&&o(v,{name:h,newValue:m}));return v},nv}var nre=tre();const rv=qh(nre);function vx(e){if(typeof e!="object"||e===null)return!1;const t=Object.getPrototypeOf(e);return(t===null||t===Object.prototype||Object.getPrototypeOf(t)===null)&&!(Symbol.toStringTag in e)&&!(Symbol.iterator in e)}function rre(){const e=[],t={run:n,use:r};return t;function n(...a){let i=-1;const o=a.pop();if(typeof o!="function")throw new TypeError("Expected function as last argument, not "+o);l(null,...a);function l(u,...d){const h=e[++i];let f=-1;if(u){o(u);return}for(;++f<a.length;)(d[f]===null||d[f]===void 0)&&(d[f]=a[f]);a=d,h?are(h,l)(...d):o(null,...d)}}function r(a){if(typeof a!="function")throw new TypeError("Expected `middelware` to be a function, not "+a);return e.push(a),t}}function are(e,t){let n;return r;function r(...o){const l=e.length>o.length;let u;l&&o.push(a);try{u=e.apply(this,o)}catch(d){const h=d;if(l&&n)throw h;return a(h)}l||(u&&u.then&&typeof u.then=="function"?u.then(i,a):u instanceof Error?a(u):i(u))}function a(o,...l){n||(n=!0,t(o,...l))}function i(o){a(null,o)}}const xi={basename:ire,dirname:ore,extname:sre,join:lre,sep:"/"};function ire(e,t){if(t!==void 0&&typeof t!="string")throw new TypeError('"ext" argument must be a string');rp(e);let n=0,r=-1,a=e.length,i;if(t===void 0||t.length===0||t.length>e.length){for(;a--;)if(e.codePointAt(a)===47){if(i){n=a+1;break}}else r<0&&(i=!0,r=a+1);return r<0?"":e.slice(n,r)}if(t===e)return"";let o=-1,l=t.length-1;for(;a--;)if(e.codePointAt(a)===47){if(i){n=a+1;break}}else o<0&&(i=!0,o=a+1),l>-1&&(e.codePointAt(a)===t.codePointAt(l--)?l<0&&(r=a):(l=-1,r=o));return n===r?r=o:r<0&&(r=e.length),e.slice(n,r)}function ore(e){if(rp(e),e.length===0)return".";let t=-1,n=e.length,r;for(;--n;)if(e.codePointAt(n)===47){if(r){t=n;break}}else r||(r=!0);return t<0?e.codePointAt(0)===47?"/":".":t===1&&e.codePointAt(0)===47?"//":e.slice(0,t)}function sre(e){rp(e);let t=e.length,n=-1,r=0,a=-1,i=0,o;for(;t--;){const l=e.codePointAt(t);if(l===47){if(o){r=t+1;break}continue}n<0&&(o=!0,n=t+1),l===46?a<0?a=t:i!==1&&(i=1):a>-1&&(i=-1)}return a<0||n<0||i===0||i===1&&a===n-1&&a===r+1?"":e.slice(a,n)}function lre(...e){let t=-1,n;for(;++t<e.length;)rp(e[t]),e[t]&&(n=n===void 0?e[t]:n+"/"+e[t]);return n===void 0?".":cre(n)}function cre(e){rp(e);const t=e.codePointAt(0)===47;let n=ure(e,!t);return n.length===0&&!t&&(n="."),n.length>0&&e.codePointAt(e.length-1)===47&&(n+="/"),t?"/"+n:n}function ure(e,t){let n="",r=0,a=-1,i=0,o=-1,l,u;for(;++o<=e.length;){if(o<e.length)l=e.codePointAt(o);else{if(l===47)break;l=47}if(l===47){if(!(a===o-1||i===1))if(a!==o-1&&i===2){if(n.length<2||r!==2||n.codePointAt(n.length-1)!==46||n.codePointAt(n.length-2)!==46){if(n.length>2){if(u=n.lastIndexOf("/"),u!==n.length-1){u<0?(n="",r=0):(n=n.slice(0,u),r=n.length-1-n.lastIndexOf("/")),a=o,i=0;continue}}else if(n.length>0){n="",r=0,a=o,i=0;continue}}t&&(n=n.length>0?n+"/..":"..",r=2)}else n.length>0?n+="/"+e.slice(a+1,o):n=e.slice(a+1,o),r=o-a-1;a=o,i=0}else l===46&&i>-1?i++:i=-1}return n}function rp(e){if(typeof e!="string")throw new TypeError("Path must be a string. Received "+JSON.stringify(e))}const dre={cwd:hre};function hre(){return"/"}function xx(e){return!!(e!==null&&typeof e=="object"&&"href"in e&&e.href&&"protocol"in e&&e.protocol&&e.auth===void 0)}function pre(e){if(typeof e=="string")e=new URL(e);else if(!xx(e)){const t=new TypeError('The "path" argument must be of type string or an instance of URL. Received `'+e+"`");throw t.code="ERR_INVALID_ARG_TYPE",t}if(e.protocol!=="file:"){const t=new TypeError("The URL must be of scheme file");throw t.code="ERR_INVALID_URL_SCHEME",t}return fre(e)}function fre(e){if(e.hostname!==""){const r=new TypeError('File URL host must be "localhost" or empty on darwin');throw r.code="ERR_INVALID_FILE_URL_HOST",r}const t=e.pathname;let n=-1;for(;++n<t.length;)if(t.codePointAt(n)===37&&t.codePointAt(n+1)===50){const r=t.codePointAt(n+2);if(r===70||r===102){const a=new TypeError("File URL path must not include encoded / characters");throw a.code="ERR_INVALID_FILE_URL_PATH",a}}return decodeURIComponent(t)}const av=["history","path","basename","stem","extname","dirname"];class cD{constructor(t){let n;t?xx(t)?n={path:t}:typeof t=="string"||mre(t)?n={value:t}:n=t:n={},this.cwd="cwd"in n?"":dre.cwd(),this.data={},this.history=[],this.messages=[],this.value,this.map,this.result,this.stored;let r=-1;for(;++r<av.length;){const i=av[r];i in n&&n[i]!==void 0&&n[i]!==null&&(this[i]=i==="history"?[...n[i]]:n[i])}let a;for(a in n)av.includes(a)||(this[a]=n[a])}get basename(){return typeof this.path=="string"?xi.basename(this.path):void 0}set basename(t){ov(t,"basename"),iv(t,"basename"),this.path=xi.join(this.dirname||"",t)}get dirname(){return typeof this.path=="string"?xi.dirname(this.path):void 0}set dirname(t){KR(this.basename,"dirname"),this.path=xi.join(t||"",this.basename)}get extname(){return typeof this.path=="string"?xi.extname(this.path):void 0}set extname(t){if(iv(t,"extname"),KR(this.dirname,"extname"),t){if(t.codePointAt(0)!==46)throw new Error("`extname` must start with `.`");if(t.includes(".",1))throw new Error("`extname` cannot contain multiple dots")}this.path=xi.join(this.dirname,this.stem+(t||""))}get path(){return this.history[this.history.length-1]}set path(t){xx(t)&&(t=pre(t)),ov(t,"path"),this.path!==t&&this.history.push(t)}get stem(){return typeof this.path=="string"?xi.basename(this.path,this.extname):void 0}set stem(t){ov(t,"stem"),iv(t,"stem"),this.path=xi.join(this.dirname||"",t+(this.extname||""))}fail(t,n,r){const a=this.message(t,n,r);throw a.fatal=!0,a}info(t,n,r){const a=this.message(t,n,r);return a.fatal=void 0,a}message(t,n,r){const a=new Sr(t,n,r);return this.path&&(a.name=this.path+":"+a.name,a.file=this.path),a.fatal=!1,this.messages.push(a),a}toString(t){return this.value===void 0?"":typeof this.value=="string"?this.value:new TextDecoder(t||void 0).decode(this.value)}}function iv(e,t){if(e&&e.includes(xi.sep))throw new Error("`"+t+"` cannot be a path: did not expect `"+xi.sep+"`")}function ov(e,t){if(!e)throw new Error("`"+t+"` cannot be empty")}function KR(e,t){if(!e)throw new Error("Setting `"+t+"` requires `path` to be set too")}function mre(e){return!!(e&&typeof e=="object"&&"byteLength"in e&&"byteOffset"in e)}const gre=(function(e){const r=this.constructor.prototype,a=r[e],i=function(){return a.apply(i,arguments)};return Object.setPrototypeOf(i,r),i}),bre={}.hasOwnProperty;class HS extends gre{constructor(){super("copy"),this.Compiler=void 0,this.Parser=void 0,this.attachers=[],this.compiler=void 0,this.freezeIndex=-1,this.frozen=void 0,this.namespace={},this.parser=void 0,this.transformers=rre()}copy(){const t=new HS;let n=-1;for(;++n<this.attachers.length;){const r=this.attachers[n];t.use(...r)}return t.data(rv(!0,{},this.namespace)),t}data(t,n){return typeof t=="string"?arguments.length===2?(cv("data",this.frozen),this.namespace[t]=n,this):bre.call(this.namespace,t)&&this.namespace[t]||void 0:t?(cv("data",this.frozen),this.namespace=t,this):this.namespace}freeze(){if(this.frozen)return this;const t=this;for(;++this.freezeIndex<this.attachers.length;){const[n,...r]=this.attachers[this.freezeIndex];if(r[0]===!1)continue;r[0]===!0&&(r[0]=void 0);const a=n.call(t,...r);typeof a=="function"&&this.transformers.use(a)}return this.frozen=!0,this.freezeIndex=Number.POSITIVE_INFINITY,this}parse(t){this.freeze();const n=e0(t),r=this.parser||this.Parser;return sv("parse",r),r(String(n),n)}process(t,n){const r=this;return this.freeze(),sv("process",this.parser||this.Parser),lv("process",this.compiler||this.Compiler),n?a(void 0,n):new Promise(a);function a(i,o){const l=e0(t),u=r.parse(l);r.run(u,l,function(h,f,m){if(h||!f||!m)return d(h);const b=f,y=r.stringify(b,m);xre(y)?m.value=y:m.result=y,d(h,m)});function d(h,f){h||!f?o(h):i?i(f):n(void 0,f)}}}processSync(t){let n=!1,r;return this.freeze(),sv("processSync",this.parser||this.Parser),lv("processSync",this.compiler||this.Compiler),this.process(t,a),QR("processSync","process",n),r;function a(i,o){n=!0,YR(i),r=o}}run(t,n,r){ZR(t),this.freeze();const a=this.transformers;return!r&&typeof n=="function"&&(r=n,n=void 0),r?i(void 0,r):new Promise(i);function i(o,l){const u=e0(n);a.run(t,u,d);function d(h,f,m){const b=f||t;h?l(h):o?o(b):r(void 0,b,m)}}}runSync(t,n){let r=!1,a;return this.run(t,n,i),QR("runSync","run",r),a;function i(o,l){YR(o),a=l,r=!0}}stringify(t,n){this.freeze();const r=e0(n),a=this.compiler||this.Compiler;return lv("stringify",a),ZR(t),a(t,r)}use(t,...n){const r=this.attachers,a=this.namespace;if(cv("use",this.frozen),t!=null)if(typeof t=="function")u(t,n);else if(typeof t=="object")Array.isArray(t)?l(t):o(t);else throw new TypeError("Expected usable value, not `"+t+"`");return this;function i(d){if(typeof d=="function")u(d,[]);else if(typeof d=="object")if(Array.isArray(d)){const[h,...f]=d;u(h,f)}else o(d);else throw new TypeError("Expected usable value, not `"+d+"`")}function o(d){if(!("plugins"in d)&&!("settings"in d))throw new Error("Expected usable value but received an empty preset, which is probably a mistake: presets typically come with `plugins` and sometimes with `settings`, but this has neither");l(d.plugins),d.settings&&(a.settings=rv(!0,a.settings,d.settings))}function l(d){let h=-1;if(d!=null)if(Array.isArray(d))for(;++h<d.length;){const f=d[h];i(f)}else throw new TypeError("Expected a list of plugins, not `"+d+"`")}function u(d,h){let f=-1,m=-1;for(;++f<r.length;)if(r[f][0]===d){m=f;break}if(m===-1)r.push([d,...h]);else if(h.length>0){let[b,...y]=h;const v=r[m][1];vx(v)&&vx(b)&&(b=rv(!0,v,b)),r[m]=[d,b,...y]}}}}const yre=new HS().freeze();function sv(e,t){if(typeof t!="function")throw new TypeError("Cannot `"+e+"` without `parser`")}function lv(e,t){if(typeof t!="function")throw new TypeError("Cannot `"+e+"` without `compiler`")}function cv(e,t){if(t)throw new Error("Cannot call `"+e+"` on a frozen processor.\nCreate a new processor first, by calling it: use `processor()` instead of `processor`.")}function ZR(e){if(!vx(e)||typeof e.type!="string")throw new TypeError("Expected node, got `"+e+"`")}function QR(e,t,n){if(!n)throw new Error("`"+e+"` finished async. Use `"+t+"` instead")}function e0(e){return vre(e)?e:new cD(e)}function vre(e){return!!(e&&typeof e=="object"&&"message"in e&&"messages"in e)}function xre(e){return typeof e=="string"||Sre(e)}function Sre(e){return!!(e&&typeof e=="object"&&"byteLength"in e&&"byteOffset"in e)}const wre="https://github.com/remarkjs/react-markdown/blob/main/changelog.md",JR=[],eN={allowDangerousHtml:!0},Ere=/^(https?|ircs?|mailto|xmpp)$/i,kre=[{from:"astPlugins",id:"remove-buggy-html-in-markdown-parser"},{from:"allowDangerousHtml",id:"remove-buggy-html-in-markdown-parser"},{from:"allowNode",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"allowElement"},{from:"allowedTypes",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"allowedElements"},{from:"className",id:"remove-classname"},{from:"disallowedTypes",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"disallowedElements"},{from:"escapeHtml",id:"remove-buggy-html-in-markdown-parser"},{from:"includeElementIndex",id:"#remove-includeelementindex"},{from:"includeNodeIndex",id:"change-includenodeindex-to-includeelementindex"},{from:"linkTarget",id:"remove-linktarget"},{from:"plugins",id:"change-plugins-to-remarkplugins",to:"remarkPlugins"},{from:"rawSourcePos",id:"#remove-rawsourcepos"},{from:"renderers",id:"change-renderers-to-components",to:"components"},{from:"source",id:"change-source-to-children",to:"children"},{from:"sourcePos",id:"#remove-sourcepos"},{from:"transformImageUri",id:"#add-urltransform",to:"urlTransform"},{from:"transformLinkUri",id:"#add-urltransform",to:"urlTransform"}];function Tre(e){const t=_re(e),n=Cre(e);return Are(t.runSync(t.parse(n),n),e)}function _re(e){const t=e.rehypePlugins||JR,n=e.remarkPlugins||JR,r=e.remarkRehypeOptions?{...e.remarkRehypeOptions,...eN}:eN;return yre().use(sne).use(n).use(ere,r).use(t)}function Cre(e){const t=e.children||"",n=new cD;return typeof t=="string"&&(n.value=t),n}function Are(e,t){const n=t.allowedElements,r=t.allowElement,a=t.components,i=t.disallowedElements,o=t.skipHtml,l=t.unwrapDisallowed,u=t.urlTransform||Rre;for(const h of kre)Object.hasOwn(t,h.from)&&(""+h.from+(h.to?"use `"+h.to+"` instead":"remove it")+wre+h.id,void 0);return jS(e,d),GJ(e,{Fragment:T.Fragment,components:a,ignoreInvalidStyle:!0,jsx:T.jsx,jsxs:T.jsxs,passKeys:!0,passNode:!0});function d(h,f,m){if(h.type==="raw"&&m&&typeof f=="number")return o?m.children.splice(f,1):m.children[f]={type:"text",value:h.value},f;if(h.type==="element"){let b;for(b in J1)if(Object.hasOwn(J1,b)&&Object.hasOwn(h.properties,b)){const y=h.properties[b],v=J1[b];(v===null||v.includes(h.tagName))&&(h.properties[b]=u(String(y||""),b,h))}}if(h.type==="element"){let b=n?!n.includes(h.tagName):i?i.includes(h.tagName):!1;if(!b&&r&&typeof f=="number"&&(b=!r(h,f,m)),b&&m&&typeof f=="number")return l&&h.children?m.children.splice(f,1,...h.children):m.children.splice(f,1),f}}}function Rre(e){const t=e.indexOf(":"),n=e.indexOf("?"),r=e.indexOf("#"),a=e.indexOf("/");return t===-1||a!==-1&&t>a||n!==-1&&t>n||r!==-1&&t>r||Ere.test(e.slice(0,t))?e:""}const tN=/[#.]/g;function Nre(e,t){const n=e||"",r={};let a=0,i,o;for(;a<n.length;){tN.lastIndex=a;const l=tN.exec(n),u=n.slice(a,l?l.index:n.length);u&&(i?i==="#"?r.id=u:Array.isArray(r.className)?r.className.push(u):r.className=[u]:o=u,a+=u.length),l&&(i=l[0],a++)}return{type:"element",tagName:o||t||"div",properties:r,children:[]}}function uD(e,t,n){const r=n?Dre(n):void 0;function a(i,o,...l){let u;if(i==null){u={type:"root",children:[]};const d=o;l.unshift(d)}else{u=Nre(i,t);const d=u.tagName.toLowerCase(),h=r?r.get(d):void 0;if(u.tagName=h||d,Ore(o))l.unshift(o);else for(const[f,m]of Object.entries(o))Ire(e,u.properties,f,m)}for(const d of l)Sx(u.children,d);return u.type==="element"&&u.tagName==="template"&&(u.content={type:"root",children:u.children},u.children=[]),u}return a}function Ore(e){if(e===null||typeof e!="object"||Array.isArray(e))return!0;if(typeof e.type!="string")return!1;const t=e,n=Object.keys(e);for(const r of n){const a=t[r];if(a&&typeof a=="object"){if(!Array.isArray(a))return!0;const i=a;for(const o of i)if(typeof o!="number"&&typeof o!="string")return!0}}return!!("children"in e&&Array.isArray(e.children))}function Ire(e,t,n,r){const a=DL(e,n);let i;if(r!=null){if(typeof r=="number"){if(Number.isNaN(r))return;i=r}else typeof r=="boolean"?i=r:typeof r=="string"?a.spaceSeparated?i=wR(r):a.commaSeparated?i=bR(r):a.commaOrSpaceSeparated?i=wR(bR(r).join(" ")):i=nN(a,a.property,r):Array.isArray(r)?i=[...r]:i=a.property==="style"?Lre(r):String(r);if(Array.isArray(i)){const o=[];for(const l of i)o.push(nN(a,a.property,l));i=o}a.property==="className"&&Array.isArray(t.className)&&(i=t.className.concat(i)),t[a.property]=i}}function Sx(e,t){if(t!=null)if(typeof t=="number"||typeof t=="string")e.push({type:"text",value:String(t)});else if(Array.isArray(t))for(const n of t)Sx(e,n);else if(typeof t=="object"&&"type"in t)t.type==="root"?Sx(e,t.children):e.push(t);else throw new Error("Expected node, nodes, or string, got `"+t+"`")}function nN(e,t,n){if(typeof n=="string"){if(e.number&&n&&!Number.isNaN(Number(n)))return Number(n);if((e.boolean||e.overloadedBoolean)&&(n===""||kh(n)===kh(t)))return!0}return n}function Lre(e){const t=[];for(const[n,r]of Object.entries(e))t.push([n,r].join(": "));return t.join("; ")}function Dre(e){const t=new Map;for(const n of e)t.set(n.toLowerCase(),n);return t}const Mre=["altGlyph","altGlyphDef","altGlyphItem","animateColor","animateMotion","animateTransform","clipPath","feBlend","feColorMatrix","feComponentTransfer","feComposite","feConvolveMatrix","feDiffuseLighting","feDisplacementMap","feDistantLight","feDropShadow","feFlood","feFuncA","feFuncB","feFuncG","feFuncR","feGaussianBlur","feImage","feMerge","feMergeNode","feMorphology","feOffset","fePointLight","feSpecularLighting","feSpotLight","feTile","feTurbulence","foreignObject","glyphRef","linearGradient","radialGradient","solidColor","textArea","textPath"],dD=uD(ML,"div"),Bre=uD(hg,"g",Mre),uv={html:"http://www.w3.org/1999/xhtml",svg:"http://www.w3.org/2000/svg"};function Fre(e,t){return hD(e,{})||{type:"root",children:[]}}function hD(e,t){const n=zre(e,t);return n&&t.afterTransform&&t.afterTransform(e,n),n}function zre(e,t){switch(e.nodeType){case 1:return jre(e,t);case 3:return Pre(e);case 8:return Ure(e);case 9:return rN(e,t);case 10:return $re();case 11:return rN(e,t);default:return}}function rN(e,t){return{type:"root",children:pD(e,t)}}function $re(){return{type:"doctype"}}function Pre(e){return{type:"text",value:e.nodeValue||""}}function Ure(e){return{type:"comment",value:e.nodeValue||""}}function jre(e,t){const n=e.namespaceURI,r=n===uv.svg?Bre:dD,a=n===uv.html?e.tagName.toLowerCase():e.tagName,i=n===uv.html&&a==="template"?e.content:e,o=e.getAttributeNames(),l={};let u=-1;for(;++u<o.length;)l[o[u]]=e.getAttribute(o[u])||"";return r(a,l,pD(i,t))}function pD(e,t){const n=e.childNodes,r=[];let a=-1;for(;++a<n.length;){const i=hD(n[a],t);i!==void 0&&r.push(i)}return r}new DOMParser;function Hre(e,t){const n=Gre(e);return Fre(n)}function Gre(e){const t=document.createElement("template");return t.innerHTML=e,t.content}const aN=(function(e,t,n){const r=np(n);if(!e||!e.type||!e.children)throw new Error("Expected parent node");if(typeof t=="number"){if(t<0||t===Number.POSITIVE_INFINITY)throw new Error("Expected positive finite number as index")}else if(t=e.children.indexOf(t),t<0)throw new Error("Expected child node or index");for(;++t<e.children.length;)if(r(e.children[t],t,e))return e.children[t]}),Ol=(function(e){if(e==null)return Vre;if(typeof e=="string")return Wre(e);if(typeof e=="object")return qre(e);if(typeof e=="function")return GS(e);throw new Error("Expected function, string, or array as `test`")});function qre(e){const t=[];let n=-1;for(;++n<e.length;)t[n]=Ol(e[n]);return GS(r);function r(...a){let i=-1;for(;++i<t.length;)if(t[i].apply(this,a))return!0;return!1}}function Wre(e){return GS(t);function t(n){return n.tagName===e}}function GS(e){return t;function t(n,r,a){return!!(Yre(n)&&e.call(this,n,typeof r=="number"?r:void 0,a||void 0))}}function Vre(e){return!!(e&&typeof e=="object"&&"type"in e&&e.type==="element"&&"tagName"in e&&typeof e.tagName=="string")}function Yre(e){return e!==null&&typeof e=="object"&&"type"in e&&"tagName"in e}const iN=/\n/g,oN=/[\t ]+/g,wx=Ol("br"),sN=Ol(nae),Xre=Ol("p"),lN=Ol("tr"),Kre=Ol(["datalist","head","noembed","noframes","noscript","rp","script","style","template","title",tae,rae]),fD=Ol(["address","article","aside","blockquote","body","caption","center","dd","dialog","dir","dl","dt","div","figure","figcaption","footer","form,","h1","h2","h3","h4","h5","h6","header","hgroup","hr","html","legend","li","listing","main","menu","nav","ol","p","plaintext","pre","section","ul","xmp"]);function Zre(e,t){const n=t||{},r="children"in e?e.children:[],a=fD(e),i=bD(e,{whitespace:n.whitespace||"normal"}),o=[];(e.type==="text"||e.type==="comment")&&o.push(...gD(e,{breakBefore:!0,breakAfter:!0}));let l=-1;for(;++l<r.length;)o.push(...mD(r[l],e,{whitespace:i,breakBefore:l?void 0:a,breakAfter:l<r.length-1?wx(r[l+1]):a}));const u=[];let d;for(l=-1;++l<o.length;){const h=o[l];typeof h=="number"?d!==void 0&&h>d&&(d=h):h&&(d!==void 0&&d>-1&&u.push(`
`.repeat(d)||" "),d=-1,u.push(h))}return u.join("")}function mD(e,t,n){return e.type==="element"?Qre(e,t,n):e.type==="text"?n.whitespace==="normal"?gD(e,n):Jre(e):[]}function Qre(e,t,n){const r=bD(e,n),a=e.children||[];let i=-1,o=[];if(Kre(e))return o;let l,u;for(wx(e)||lN(e)&&aN(t,e,lN)?u=`
`:Xre(e)?(l=2,u=2):fD(e)&&(l=1,u=1);++i<a.length;)o=o.concat(mD(a[i],e,{whitespace:r,breakBefore:i?void 0:l,breakAfter:i<a.length-1?wx(a[i+1]):u}));return sN(e)&&aN(t,e,sN)&&o.push("	"),l&&o.unshift(l),u&&o.push(u),o}function gD(e,t){const n=String(e.value),r=[],a=[];let i=0;for(;i<=n.length;){iN.lastIndex=i;const u=iN.exec(n),d=u&&"index"in u?u.index:n.length;r.push(eae(n.slice(i,d).replace(/[\u061C\u200E\u200F\u202A-\u202E\u2066-\u2069]/g,""),i===0?t.breakBefore:!0,d===n.length?t.breakAfter:!0)),i=d+1}let o=-1,l;for(;++o<r.length;)r[o].charCodeAt(r[o].length-1)===8203||o<r.length-1&&r[o+1].charCodeAt(0)===8203?(a.push(r[o]),l=void 0):r[o]?(typeof l=="number"&&a.push(l),a.push(r[o]),l=0):(o===0||o===r.length-1)&&a.push(0);return a}function Jre(e){return[String(e.value)]}function eae(e,t,n){const r=[];let a=0,i;for(;a<e.length;){oN.lastIndex=a;const o=oN.exec(e);i=o?o.index:e.length,!a&&!i&&o&&!t&&r.push(""),a!==i&&r.push(e.slice(a,i)),a=o?i+o[0].length:i}return a!==i&&!n&&r.push(""),r.join(" ")}function bD(e,t){if(e.type==="element"){const n=e.properties||{};switch(e.tagName){case"listing":case"plaintext":case"xmp":return"pre";case"nobr":return"nowrap";case"pre":return n.wrap?"pre-wrap":"pre";case"td":case"th":return n.noWrap?"nowrap":t.whitespace;case"textarea":return"pre-wrap"}}return t.whitespace}function tae(e){return!!(e.properties||{}).hidden}function nae(e){return e.tagName==="td"||e.tagName==="th"}function rae(e){return e.tagName==="dialog"&&!(e.properties||{}).open}class Re extends Error{constructor(t,n){var r="KaTeX parse error: "+t,a,i,o=n&&n.loc;if(o&&o.start<=o.end){var l=o.lexer.input;a=o.start,i=o.end,a===l.length?r+=" at end of input: ":r+=" at position "+(a+1)+": ";var u=l.slice(a,i).replace(/[^]/g,"$&̲"),d;a>15?d="…"+l.slice(a-15,a):d=l.slice(0,a);var h;i+15<l.length?h=l.slice(i,i+15)+"…":h=l.slice(i),r+=d+u+h}super(r),this.name="ParseError",Object.setPrototypeOf(this,Re.prototype),this.position=a,a!=null&&i!=null&&(this.length=i-a),this.rawMessage=t}}var aae=/([A-Z])/g,qS=e=>e.replace(aae,"-$1").toLowerCase(),iae={"&":"&amp;",">":"&gt;","<":"&lt;",'"':"&quot;","'":"&#x27;"},oae=/[&><"']/g,gr=e=>String(e).replace(oae,t=>iae[t]),O0=e=>e.type==="ordgroup"||e.type==="color"?e.body.length===1?O0(e.body[0]):e:e.type==="font"?O0(e.body):e,sae=new Set(["mathord","textord","atom"]),Ro=e=>sae.has(O0(e).type),lae=e=>{var t=/^[\x00-\x20]*([^\\/#?]*?)(:|&#0*58|&#x0*3a|&colon)/i.exec(e);return t?t[2]!==":"||!/^[a-zA-Z][a-zA-Z0-9+\-.]*$/.test(t[1])?null:t[1].toLowerCase():"_relative"},lm={displayMode:{type:"boolean",description:"Render math in display mode, which puts the math in display style (so \\int and \\sum are large, for example), and centers the math on the page on its own line.",cli:"-d, --display-mode"},output:{type:{enum:["htmlAndMathml","html","mathml"]},description:"Determines the markup language of the output.",cli:"-F, --format <type>"},leqno:{type:"boolean",description:"Render display math in leqno style (left-justified tags)."},fleqn:{type:"boolean",description:"Render display math flush left."},throwOnError:{type:"boolean",default:!0,cli:"-t, --no-throw-on-error",cliDescription:"Render errors (in the color given by --error-color) instead of throwing a ParseError exception when encountering an error."},errorColor:{type:"string",default:"#cc0000",cli:"-c, --error-color <color>",cliDescription:"A color string given in the format 'rgb' or 'rrggbb' (no #). This option determines the color of errors rendered by the -t option.",cliProcessor:e=>"#"+e},macros:{type:"object",cli:"-m, --macro <def>",cliDescription:"Define custom macro of the form '\\foo:expansion' (use multiple -m arguments for multiple macros).",cliDefault:[],cliProcessor:(e,t)=>(t.push(e),t)},minRuleThickness:{type:"number",description:"Specifies a minimum thickness, in ems, for fraction lines, `\\sqrt` top lines, `{array}` vertical lines, `\\hline`, `\\hdashline`, `\\underline`, `\\overline`, and the borders of `\\fbox`, `\\boxed`, and `\\fcolorbox`.",processor:e=>Math.max(0,e),cli:"--min-rule-thickness <size>",cliProcessor:parseFloat},colorIsTextColor:{type:"boolean",description:"Makes \\color behave like LaTeX's 2-argument \\textcolor, instead of LaTeX's one-argument \\color mode change.",cli:"-b, --color-is-text-color"},strict:{type:[{enum:["warn","ignore","error"]},"boolean","function"],description:"Turn on strict / LaTeX faithfulness mode, which throws an error if the input uses features that are not supported by LaTeX.",cli:"-S, --strict",cliDefault:!1},trust:{type:["boolean","function"],description:"Trust the input, enabling all HTML features such as \\url.",cli:"-T, --trust"},maxSize:{type:"number",default:1/0,description:"If non-zero, all user-specified sizes, e.g. in \\rule{500em}{500em}, will be capped to maxSize ems. Otherwise, elements and spaces can be arbitrarily large",processor:e=>Math.max(0,e),cli:"-s, --max-size <n>",cliProcessor:parseInt},maxExpand:{type:"number",default:1e3,description:"Limit the number of macro expansions to the specified number, to prevent e.g. infinite macro loops. If set to Infinity, the macro expander will try to fully expand as in LaTeX.",processor:e=>Math.max(0,e),cli:"-e, --max-expand <n>",cliProcessor:e=>e==="Infinity"?1/0:parseInt(e)},globalGroup:{type:"boolean",cli:!1}};function cae(e){if("default"in e)return e.default;var t=e.type,n=Array.isArray(t)?t[0]:t;if(typeof n!="string")return n.enum[0];switch(n){case"boolean":return!1;case"string":return"";case"number":return 0;case"object":return{}}}class WS{constructor(t){t===void 0&&(t={}),t=t||{};for(var n of Object.keys(lm)){var r=lm[n],a=t[n];this[n]=a!==void 0?r.processor?r.processor(a):a:cae(r)}}reportNonstrict(t,n,r){var a=this.strict;if(typeof a=="function"&&(a=a(t,n,r)),!(!a||a==="ignore")){if(a===!0||a==="error")throw new Re("LaTeX-incompatible input and strict mode is set to 'error': "+(n+" ["+t+"]"),r);a==="warn"?typeof console<"u"&&console.warn("LaTeX-incompatible input and strict mode is set to 'warn': "+(n+" ["+t+"]")):typeof console<"u"&&console.warn("LaTeX-incompatible input and strict mode is set to "+("unrecognized '"+a+"': "+n+" ["+t+"]"))}}useStrictBehavior(t,n,r){var a=this.strict;if(typeof a=="function")try{a=a(t,n,r)}catch{a="error"}return!a||a==="ignore"?!1:a===!0||a==="error"?!0:a==="warn"?(typeof console<"u"&&console.warn("LaTeX-incompatible input and strict mode is set to 'warn': "+(n+" ["+t+"]")),!1):(typeof console<"u"&&console.warn("LaTeX-incompatible input and strict mode is set to "+("unrecognized '"+a+"': "+n+" ["+t+"]")),!1)}isTrusted(t){if("url"in t&&t.url&&!t.protocol){var n=lae(t.url);if(n==null)return!1;t.protocol=n}var r=typeof this.trust=="function"?this.trust(t):this.trust;return!!r}}class us{constructor(t,n,r){this.id=t,this.size=n,this.cramped=r}sup(){return wi[uae[this.id]]}sub(){return wi[dae[this.id]]}fracNum(){return wi[hae[this.id]]}fracDen(){return wi[pae[this.id]]}cramp(){return wi[fae[this.id]]}text(){return wi[mae[this.id]]}isTight(){return this.size>=2}}var VS=0,cm=1,zc=2,vo=3,Ch=4,$a=5,Jc=6,Lr=7,wi=[new us(VS,0,!1),new us(cm,0,!0),new us(zc,1,!1),new us(vo,1,!0),new us(Ch,2,!1),new us($a,2,!0),new us(Jc,3,!1),new us(Lr,3,!0)],uae=[Ch,$a,Ch,$a,Jc,Lr,Jc,Lr],dae=[$a,$a,$a,$a,Lr,Lr,Lr,Lr],hae=[zc,vo,Ch,$a,Jc,Lr,Jc,Lr],pae=[vo,vo,$a,$a,Lr,Lr,Lr,Lr],fae=[cm,cm,vo,vo,$a,$a,Lr,Lr],mae=[VS,cm,zc,vo,zc,vo,zc,vo],mt={DISPLAY:wi[VS],TEXT:wi[zc],SCRIPT:wi[Ch],SCRIPTSCRIPT:wi[Jc]},Ex=[{name:"latin",blocks:[[256,591],[768,879]]},{name:"cyrillic",blocks:[[1024,1279]]},{name:"armenian",blocks:[[1328,1423]]},{name:"brahmic",blocks:[[2304,4255]]},{name:"georgian",blocks:[[4256,4351]]},{name:"cjk",blocks:[[12288,12543],[19968,40879],[65280,65376]]},{name:"hangul",blocks:[[44032,55215]]}];function gae(e){for(var t=0;t<Ex.length;t++)for(var n=Ex[t],r=0;r<n.blocks.length;r++){var a=n.blocks[r];if(e>=a[0]&&e<=a[1])return n.name}return null}var I0=[];Ex.forEach(e=>e.blocks.forEach(t=>I0.push(...t)));function yD(e){for(var t=0;t<I0.length;t+=2)if(e>=I0[t]&&e<=I0[t+1])return!0;return!1}var Tc=80,bae=function(t,n){return"M95,"+(622+t+n)+`
c-2.7,0,-7.17,-2.7,-13.5,-8c-5.8,-5.3,-9.5,-10,-9.5,-14
c0,-2,0.3,-3.3,1,-4c1.3,-2.7,23.83,-20.7,67.5,-54
c44.2,-33.3,65.8,-50.3,66.5,-51c1.3,-1.3,3,-2,5,-2c4.7,0,8.7,3.3,12,10
s173,378,173,378c0.7,0,35.3,-71,104,-213c68.7,-142,137.5,-285,206.5,-429
c69,-144,104.5,-217.7,106.5,-221
l`+t/2.075+" -"+t+`
c5.3,-9.3,12,-14,20,-14
H400000v`+(40+t)+`H845.2724
s-225.272,467,-225.272,467s-235,486,-235,486c-2.7,4.7,-9,7,-19,7
c-6,0,-10,-1,-12,-3s-194,-422,-194,-422s-65,47,-65,47z
M`+(834+t)+" "+n+"h400000v"+(40+t)+"h-400000z"},yae=function(t,n){return"M263,"+(601+t+n)+`c0.7,0,18,39.7,52,119
c34,79.3,68.167,158.7,102.5,238c34.3,79.3,51.8,119.3,52.5,120
c340,-704.7,510.7,-1060.3,512,-1067
l`+t/2.084+" -"+t+`
c4.7,-7.3,11,-11,19,-11
H40000v`+(40+t)+`H1012.3
s-271.3,567,-271.3,567c-38.7,80.7,-84,175,-136,283c-52,108,-89.167,185.3,-111.5,232
c-22.3,46.7,-33.8,70.3,-34.5,71c-4.7,4.7,-12.3,7,-23,7s-12,-1,-12,-1
s-109,-253,-109,-253c-72.7,-168,-109.3,-252,-110,-252c-10.7,8,-22,16.7,-34,26
c-22,17.3,-33.3,26,-34,26s-26,-26,-26,-26s76,-59,76,-59s76,-60,76,-60z
M`+(1001+t)+" "+n+"h400000v"+(40+t)+"h-400000z"},vae=function(t,n){return"M983 "+(10+t+n)+`
l`+t/3.13+" -"+t+`
c4,-6.7,10,-10,18,-10 H400000v`+(40+t)+`
H1013.1s-83.4,268,-264.1,840c-180.7,572,-277,876.3,-289,913c-4.7,4.7,-12.7,7,-24,7
s-12,0,-12,0c-1.3,-3.3,-3.7,-11.7,-7,-25c-35.3,-125.3,-106.7,-373.3,-214,-744
c-10,12,-21,25,-33,39s-32,39,-32,39c-6,-5.3,-15,-14,-27,-26s25,-30,25,-30
c26.7,-32.7,52,-63,76,-91s52,-60,52,-60s208,722,208,722
c56,-175.3,126.3,-397.3,211,-666c84.7,-268.7,153.8,-488.2,207.5,-658.5
c53.7,-170.3,84.5,-266.8,92.5,-289.5z
M`+(1001+t)+" "+n+"h400000v"+(40+t)+"h-400000z"},xae=function(t,n){return"M424,"+(2398+t+n)+`
c-1.3,-0.7,-38.5,-172,-111.5,-514c-73,-342,-109.8,-513.3,-110.5,-514
c0,-2,-10.7,14.3,-32,49c-4.7,7.3,-9.8,15.7,-15.5,25c-5.7,9.3,-9.8,16,-12.5,20
s-5,7,-5,7c-4,-3.3,-8.3,-7.7,-13,-13s-13,-13,-13,-13s76,-122,76,-122s77,-121,77,-121
s209,968,209,968c0,-2,84.7,-361.7,254,-1079c169.3,-717.3,254.7,-1077.7,256,-1081
l`+t/4.223+" -"+t+`c4,-6.7,10,-10,18,-10 H400000
v`+(40+t)+`H1014.6
s-87.3,378.7,-272.6,1166c-185.3,787.3,-279.3,1182.3,-282,1185
c-2,6,-10,9,-24,9
c-8,0,-12,-0.7,-12,-2z M`+(1001+t)+" "+n+`
h400000v`+(40+t)+"h-400000z"},Sae=function(t,n){return"M473,"+(2713+t+n)+`
c339.3,-1799.3,509.3,-2700,510,-2702 l`+t/5.298+" -"+t+`
c3.3,-7.3,9.3,-11,18,-11 H400000v`+(40+t)+`H1017.7
s-90.5,478,-276.2,1466c-185.7,988,-279.5,1483,-281.5,1485c-2,6,-10,9,-24,9
c-8,0,-12,-0.7,-12,-2c0,-1.3,-5.3,-32,-16,-92c-50.7,-293.3,-119.7,-693.3,-207,-1200
c0,-1.3,-5.3,8.7,-16,30c-10.7,21.3,-21.3,42.7,-32,64s-16,33,-16,33s-26,-26,-26,-26
s76,-153,76,-153s77,-151,77,-151c0.7,0.7,35.7,202,105,604c67.3,400.7,102,602.7,104,
606zM`+(1001+t)+" "+n+"h400000v"+(40+t)+"H1017.7z"},wae=function(t){var n=t/2;return"M400000 "+t+" H0 L"+n+" 0 l65 45 L145 "+(t-80)+" H400000z"},Eae=function(t,n,r){var a=r-54-n-t;return"M702 "+(t+n)+"H400000"+(40+t)+`
H742v`+a+`l-4 4-4 4c-.667.7 -2 1.5-4 2.5s-4.167 1.833-6.5 2.5-5.5 1-9.5 1
h-12l-28-84c-16.667-52-96.667 -294.333-240-727l-212 -643 -85 170
c-4-3.333-8.333-7.667-13 -13l-13-13l77-155 77-156c66 199.333 139 419.667
219 661 l218 661zM702 `+n+"H400000v"+(40+t)+"H742z"},kae=function(t,n,r){n=1e3*n;var a="";switch(t){case"sqrtMain":a=bae(n,Tc);break;case"sqrtSize1":a=yae(n,Tc);break;case"sqrtSize2":a=vae(n,Tc);break;case"sqrtSize3":a=xae(n,Tc);break;case"sqrtSize4":a=Sae(n,Tc);break;case"sqrtTall":a=Eae(n,Tc,r)}return a},Tae=function(t,n){switch(t){case"⎜":return"M291 0 H417 V"+n+" H291z M291 0 H417 V"+n+" H291z";case"∣":return"M145 0 H188 V"+n+" H145z M145 0 H188 V"+n+" H145z";case"∥":return"M145 0 H188 V"+n+" H145z M145 0 H188 V"+n+" H145z"+("M367 0 H410 V"+n+" H367z M367 0 H410 V"+n+" H367z");case"⎟":return"M457 0 H583 V"+n+" H457z M457 0 H583 V"+n+" H457z";case"⎢":return"M319 0 H403 V"+n+" H319z M319 0 H403 V"+n+" H319z";case"⎥":return"M263 0 H347 V"+n+" H263z M263 0 H347 V"+n+" H263z";case"⎪":return"M384 0 H504 V"+n+" H384z M384 0 H504 V"+n+" H384z";case"⏐":return"M312 0 H355 V"+n+" H312z M312 0 H355 V"+n+" H312z";case"‖":return"M257 0 H300 V"+n+" H257z M257 0 H300 V"+n+" H257z"+("M478 0 H521 V"+n+" H478z M478 0 H521 V"+n+" H478z");default:return""}},cN={doubleleftarrow:`M262 157
l10-10c34-36 62.7-77 86-123 3.3-8 5-13.3 5-16 0-5.3-6.7-8-20-8-7.3
 0-12.2.5-14.5 1.5-2.3 1-4.8 4.5-7.5 10.5-49.3 97.3-121.7 169.3-217 216-28
 14-57.3 25-88 33-6.7 2-11 3.8-13 5.5-2 1.7-3 4.2-3 7.5s1 5.8 3 7.5
c2 1.7 6.3 3.5 13 5.5 68 17.3 128.2 47.8 180.5 91.5 52.3 43.7 93.8 96.2 124.5
 157.5 9.3 8 15.3 12.3 18 13h6c12-.7 18-4 18-10 0-2-1.7-7-5-15-23.3-46-52-87
-86-123l-10-10h399738v-40H218c328 0 0 0 0 0l-10-8c-26.7-20-65.7-43-117-69 2.7
-2 6-3.7 10-5 36.7-16 72.3-37.3 107-64l10-8h399782v-40z
m8 0v40h399730v-40zm0 194v40h399730v-40z`,doublerightarrow:`M399738 392l
-10 10c-34 36-62.7 77-86 123-3.3 8-5 13.3-5 16 0 5.3 6.7 8 20 8 7.3 0 12.2-.5
 14.5-1.5 2.3-1 4.8-4.5 7.5-10.5 49.3-97.3 121.7-169.3 217-216 28-14 57.3-25 88
-33 6.7-2 11-3.8 13-5.5 2-1.7 3-4.2 3-7.5s-1-5.8-3-7.5c-2-1.7-6.3-3.5-13-5.5-68
-17.3-128.2-47.8-180.5-91.5-52.3-43.7-93.8-96.2-124.5-157.5-9.3-8-15.3-12.3-18
-13h-6c-12 .7-18 4-18 10 0 2 1.7 7 5 15 23.3 46 52 87 86 123l10 10H0v40h399782
c-328 0 0 0 0 0l10 8c26.7 20 65.7 43 117 69-2.7 2-6 3.7-10 5-36.7 16-72.3 37.3
-107 64l-10 8H0v40zM0 157v40h399730v-40zm0 194v40h399730v-40z`,leftarrow:`M400000 241H110l3-3c68.7-52.7 113.7-120
 135-202 4-14.7 6-23 6-25 0-7.3-7-11-21-11-8 0-13.2.8-15.5 2.5-2.3 1.7-4.2 5.8
-5.5 12.5-1.3 4.7-2.7 10.3-4 17-12 48.7-34.8 92-68.5 130S65.3 228.3 18 247
c-10 4-16 7.7-18 11 0 8.7 6 14.3 18 17 47.3 18.7 87.8 47 121.5 85S196 441.3 208
 490c.7 2 1.3 5 2 9s1.2 6.7 1.5 8c.3 1.3 1 3.3 2 6s2.2 4.5 3.5 5.5c1.3 1 3.3
 1.8 6 2.5s6 1 10 1c14 0 21-3.7 21-11 0-2-2-10.3-6-25-20-79.3-65-146.7-135-202
 l-3-3h399890zM100 241v40h399900v-40z`,leftbrace:`M6 548l-6-6v-35l6-11c56-104 135.3-181.3 238-232 57.3-28.7 117
-45 179-50h399577v120H403c-43.3 7-81 15-113 26-100.7 33-179.7 91-237 174-2.7
 5-6 9-10 13-.7 1-7.3 1-20 1H6z`,leftbraceunder:`M0 6l6-6h17c12.688 0 19.313.3 20 1 4 4 7.313 8.3 10 13
 35.313 51.3 80.813 93.8 136.5 127.5 55.688 33.7 117.188 55.8 184.5 66.5.688
 0 2 .3 4 1 18.688 2.7 76 4.3 172 5h399450v120H429l-6-1c-124.688-8-235-61.7
-331-161C60.687 138.7 32.312 99.3 7 54L0 41V6z`,leftgroup:`M400000 80
H435C64 80 168.3 229.4 21 260c-5.9 1.2-18 0-18 0-2 0-3-1-3-3v-38C76 61 257 0
 435 0h399565z`,leftgroupunder:`M400000 262
H435C64 262 168.3 112.6 21 82c-5.9-1.2-18 0-18 0-2 0-3 1-3 3v38c76 158 257 219
 435 219h399565z`,leftharpoon:`M0 267c.7 5.3 3 10 7 14h399993v-40H93c3.3
-3.3 10.2-9.5 20.5-18.5s17.8-15.8 22.5-20.5c50.7-52 88-110.3 112-175 4-11.3 5
-18.3 3-21-1.3-4-7.3-6-18-6-8 0-13 .7-15 2s-4.7 6.7-8 16c-42 98.7-107.3 174.7
-196 228-6.7 4.7-10.7 8-12 10-1.3 2-2 5.7-2 11zm100-26v40h399900v-40z`,leftharpoonplus:`M0 267c.7 5.3 3 10 7 14h399993v-40H93c3.3-3.3 10.2-9.5
 20.5-18.5s17.8-15.8 22.5-20.5c50.7-52 88-110.3 112-175 4-11.3 5-18.3 3-21-1.3
-4-7.3-6-18-6-8 0-13 .7-15 2s-4.7 6.7-8 16c-42 98.7-107.3 174.7-196 228-6.7 4.7
-10.7 8-12 10-1.3 2-2 5.7-2 11zm100-26v40h399900v-40zM0 435v40h400000v-40z
m0 0v40h400000v-40z`,leftharpoondown:`M7 241c-4 4-6.333 8.667-7 14 0 5.333.667 9 2 11s5.333
 5.333 12 10c90.667 54 156 130 196 228 3.333 10.667 6.333 16.333 9 17 2 .667 5
 1 9 1h5c10.667 0 16.667-2 18-6 2-2.667 1-9.667-3-21-32-87.333-82.667-157.667
-152-211l-3-3h399907v-40zM93 281 H400000 v-40L7 241z`,leftharpoondownplus:`M7 435c-4 4-6.3 8.7-7 14 0 5.3.7 9 2 11s5.3 5.3 12
 10c90.7 54 156 130 196 228 3.3 10.7 6.3 16.3 9 17 2 .7 5 1 9 1h5c10.7 0 16.7
-2 18-6 2-2.7 1-9.7-3-21-32-87.3-82.7-157.7-152-211l-3-3h399907v-40H7zm93 0
v40h399900v-40zM0 241v40h399900v-40zm0 0v40h399900v-40z`,lefthook:`M400000 281 H103s-33-11.2-61-33.5S0 197.3 0 164s14.2-61.2 42.5
-83.5C70.8 58.2 104 47 142 47 c16.7 0 25 6.7 25 20 0 12-8.7 18.7-26 20-40 3.3
-68.7 15.7-86 37-10 12-15 25.3-15 40 0 22.7 9.8 40.7 29.5 54 19.7 13.3 43.5 21
 71.5 23h399859zM103 281v-40h399897v40z`,leftlinesegment:`M40 281 V428 H0 V94 H40 V241 H400000 v40z
M40 281 V428 H0 V94 H40 V241 H400000 v40z`,leftmapsto:`M40 281 V448H0V74H40V241H400000v40z
M40 281 V448H0V74H40V241H400000v40z`,leftToFrom:`M0 147h400000v40H0zm0 214c68 40 115.7 95.7 143 167h22c15.3 0 23
-.3 23-1 0-1.3-5.3-13.7-16-37-18-35.3-41.3-69-70-101l-7-8h399905v-40H95l7-8
c28.7-32 52-65.7 70-101 10.7-23.3 16-35.7 16-37 0-.7-7.7-1-23-1h-22C115.7 265.3
 68 321 0 361zm0-174v-40h399900v40zm100 154v40h399900v-40z`,longequal:`M0 50 h400000 v40H0z m0 194h40000v40H0z
M0 50 h400000 v40H0z m0 194h40000v40H0z`,midbrace:`M200428 334
c-100.7-8.3-195.3-44-280-108-55.3-42-101.7-93-139-153l-9-14c-2.7 4-5.7 8.7-9 14
-53.3 86.7-123.7 153-211 199-66.7 36-137.3 56.3-212 62H0V214h199568c178.3-11.7
 311.7-78.3 403-201 6-8 9.7-12 11-12 .7-.7 6.7-1 18-1s17.3.3 18 1c1.3 0 5 4 11
 12 44.7 59.3 101.3 106.3 170 141s145.3 54.3 229 60h199572v120z`,midbraceunder:`M199572 214
c100.7 8.3 195.3 44 280 108 55.3 42 101.7 93 139 153l9 14c2.7-4 5.7-8.7 9-14
 53.3-86.7 123.7-153 211-199 66.7-36 137.3-56.3 212-62h199568v120H200432c-178.3
 11.7-311.7 78.3-403 201-6 8-9.7 12-11 12-.7.7-6.7 1-18 1s-17.3-.3-18-1c-1.3 0
-5-4-11-12-44.7-59.3-101.3-106.3-170-141s-145.3-54.3-229-60H0V214z`,oiintSize1:`M512.6 71.6c272.6 0 320.3 106.8 320.3 178.2 0 70.8-47.7 177.6
-320.3 177.6S193.1 320.6 193.1 249.8c0-71.4 46.9-178.2 319.5-178.2z
m368.1 178.2c0-86.4-60.9-215.4-368.1-215.4-306.4 0-367.3 129-367.3 215.4 0 85.8
60.9 214.8 367.3 214.8 307.2 0 368.1-129 368.1-214.8z`,oiintSize2:`M757.8 100.1c384.7 0 451.1 137.6 451.1 230 0 91.3-66.4 228.8
-451.1 228.8-386.3 0-452.7-137.5-452.7-228.8 0-92.4 66.4-230 452.7-230z
m502.4 230c0-111.2-82.4-277.2-502.4-277.2s-504 166-504 277.2
c0 110 84 276 504 276s502.4-166 502.4-276z`,oiiintSize1:`M681.4 71.6c408.9 0 480.5 106.8 480.5 178.2 0 70.8-71.6 177.6
-480.5 177.6S202.1 320.6 202.1 249.8c0-71.4 70.5-178.2 479.3-178.2z
m525.8 178.2c0-86.4-86.8-215.4-525.7-215.4-437.9 0-524.7 129-524.7 215.4 0
85.8 86.8 214.8 524.7 214.8 438.9 0 525.7-129 525.7-214.8z`,oiiintSize2:`M1021.2 53c603.6 0 707.8 165.8 707.8 277.2 0 110-104.2 275.8
-707.8 275.8-606 0-710.2-165.8-710.2-275.8C311 218.8 415.2 53 1021.2 53z
m770.4 277.1c0-131.2-126.4-327.6-770.5-327.6S248.4 198.9 248.4 330.1
c0 130 128.8 326.4 772.7 326.4s770.5-196.4 770.5-326.4z`,rightarrow:`M0 241v40h399891c-47.3 35.3-84 78-110 128
-16.7 32-27.7 63.7-33 95 0 1.3-.2 2.7-.5 4-.3 1.3-.5 2.3-.5 3 0 7.3 6.7 11 20
 11 8 0 13.2-.8 15.5-2.5 2.3-1.7 4.2-5.5 5.5-11.5 2-13.3 5.7-27 11-41 14.7-44.7
 39-84.5 73-119.5s73.7-60.2 119-75.5c6-2 9-5.7 9-11s-3-9-9-11c-45.3-15.3-85
-40.5-119-75.5s-58.3-74.8-73-119.5c-4.7-14-8.3-27.3-11-40-1.3-6.7-3.2-10.8-5.5
-12.5-2.3-1.7-7.5-2.5-15.5-2.5-14 0-21 3.7-21 11 0 2 2 10.3 6 25 20.7 83.3 67
 151.7 139 205zm0 0v40h399900v-40z`,rightbrace:`M400000 542l
-6 6h-17c-12.7 0-19.3-.3-20-1-4-4-7.3-8.3-10-13-35.3-51.3-80.8-93.8-136.5-127.5
s-117.2-55.8-184.5-66.5c-.7 0-2-.3-4-1-18.7-2.7-76-4.3-172-5H0V214h399571l6 1
c124.7 8 235 61.7 331 161 31.3 33.3 59.7 72.7 85 118l7 13v35z`,rightbraceunder:`M399994 0l6 6v35l-6 11c-56 104-135.3 181.3-238 232-57.3
 28.7-117 45-179 50H-300V214h399897c43.3-7 81-15 113-26 100.7-33 179.7-91 237
-174 2.7-5 6-9 10-13 .7-1 7.3-1 20-1h17z`,rightgroup:`M0 80h399565c371 0 266.7 149.4 414 180 5.9 1.2 18 0 18 0 2 0
 3-1 3-3v-38c-76-158-257-219-435-219H0z`,rightgroupunder:`M0 262h399565c371 0 266.7-149.4 414-180 5.9-1.2 18 0 18
 0 2 0 3 1 3 3v38c-76 158-257 219-435 219H0z`,rightharpoon:`M0 241v40h399993c4.7-4.7 7-9.3 7-14 0-9.3
-3.7-15.3-11-18-92.7-56.7-159-133.7-199-231-3.3-9.3-6-14.7-8-16-2-1.3-7-2-15-2
-10.7 0-16.7 2-18 6-2 2.7-1 9.7 3 21 15.3 42 36.7 81.8 64 119.5 27.3 37.7 58
 69.2 92 94.5zm0 0v40h399900v-40z`,rightharpoonplus:`M0 241v40h399993c4.7-4.7 7-9.3 7-14 0-9.3-3.7-15.3-11
-18-92.7-56.7-159-133.7-199-231-3.3-9.3-6-14.7-8-16-2-1.3-7-2-15-2-10.7 0-16.7
 2-18 6-2 2.7-1 9.7 3 21 15.3 42 36.7 81.8 64 119.5 27.3 37.7 58 69.2 92 94.5z
m0 0v40h399900v-40z m100 194v40h399900v-40zm0 0v40h399900v-40z`,rightharpoondown:`M399747 511c0 7.3 6.7 11 20 11 8 0 13-.8 15-2.5s4.7-6.8
 8-15.5c40-94 99.3-166.3 178-217 13.3-8 20.3-12.3 21-13 5.3-3.3 8.5-5.8 9.5
-7.5 1-1.7 1.5-5.2 1.5-10.5s-2.3-10.3-7-15H0v40h399908c-34 25.3-64.7 57-92 95
-27.3 38-48.7 77.7-64 119-3.3 8.7-5 14-5 16zM0 241v40h399900v-40z`,rightharpoondownplus:`M399747 705c0 7.3 6.7 11 20 11 8 0 13-.8
 15-2.5s4.7-6.8 8-15.5c40-94 99.3-166.3 178-217 13.3-8 20.3-12.3 21-13 5.3-3.3
 8.5-5.8 9.5-7.5 1-1.7 1.5-5.2 1.5-10.5s-2.3-10.3-7-15H0v40h399908c-34 25.3
-64.7 57-92 95-27.3 38-48.7 77.7-64 119-3.3 8.7-5 14-5 16zM0 435v40h399900v-40z
m0-194v40h400000v-40zm0 0v40h400000v-40z`,righthook:`M399859 241c-764 0 0 0 0 0 40-3.3 68.7-15.7 86-37 10-12 15-25.3
 15-40 0-22.7-9.8-40.7-29.5-54-19.7-13.3-43.5-21-71.5-23-17.3-1.3-26-8-26-20 0
-13.3 8.7-20 26-20 38 0 71 11.2 99 33.5 0 0 7 5.6 21 16.7 14 11.2 21 33.5 21
 66.8s-14 61.2-42 83.5c-28 22.3-61 33.5-99 33.5L0 241z M0 281v-40h399859v40z`,rightlinesegment:`M399960 241 V94 h40 V428 h-40 V281 H0 v-40z
M399960 241 V94 h40 V428 h-40 V281 H0 v-40z`,rightToFrom:`M400000 167c-70.7-42-118-97.7-142-167h-23c-15.3 0-23 .3-23
 1 0 1.3 5.3 13.7 16 37 18 35.3 41.3 69 70 101l7 8H0v40h399905l-7 8c-28.7 32
-52 65.7-70 101-10.7 23.3-16 35.7-16 37 0 .7 7.7 1 23 1h23c24-69.3 71.3-125 142
-167z M100 147v40h399900v-40zM0 341v40h399900v-40z`,twoheadleftarrow:`M0 167c68 40
 115.7 95.7 143 167h22c15.3 0 23-.3 23-1 0-1.3-5.3-13.7-16-37-18-35.3-41.3-69
-70-101l-7-8h125l9 7c50.7 39.3 85 86 103 140h46c0-4.7-6.3-18.7-19-42-18-35.3
-40-67.3-66-96l-9-9h399716v-40H284l9-9c26-28.7 48-60.7 66-96 12.7-23.333 19
-37.333 19-42h-46c-18 54-52.3 100.7-103 140l-9 7H95l7-8c28.7-32 52-65.7 70-101
 10.7-23.333 16-35.7 16-37 0-.7-7.7-1-23-1h-22C115.7 71.3 68 127 0 167z`,twoheadrightarrow:`M400000 167
c-68-40-115.7-95.7-143-167h-22c-15.3 0-23 .3-23 1 0 1.3 5.3 13.7 16 37 18 35.3
 41.3 69 70 101l7 8h-125l-9-7c-50.7-39.3-85-86-103-140h-46c0 4.7 6.3 18.7 19 42
 18 35.3 40 67.3 66 96l9 9H0v40h399716l-9 9c-26 28.7-48 60.7-66 96-12.7 23.333
-19 37.333-19 42h46c18-54 52.3-100.7 103-140l9-7h125l-7 8c-28.7 32-52 65.7-70
 101-10.7 23.333-16 35.7-16 37 0 .7 7.7 1 23 1h22c27.3-71.3 75-127 143-167z`,tilde1:`M200 55.538c-77 0-168 73.953-177 73.953-3 0-7
-2.175-9-5.437L2 97c-1-2-2-4-2-6 0-4 2-7 5-9l20-12C116 12 171 0 207 0c86 0
 114 68 191 68 78 0 168-68 177-68 4 0 7 2 9 5l12 19c1 2.175 2 4.35 2 6.525 0
 4.35-2 7.613-5 9.788l-19 13.05c-92 63.077-116.937 75.308-183 76.128
-68.267.847-113-73.952-191-73.952z`,tilde2:`M344 55.266c-142 0-300.638 81.316-311.5 86.418
-8.01 3.762-22.5 10.91-23.5 5.562L1 120c-1-2-1-3-1-4 0-5 3-9 8-10l18.4-9C160.9
 31.9 283 0 358 0c148 0 188 122 331 122s314-97 326-97c4 0 8 2 10 7l7 21.114
c1 2.14 1 3.21 1 4.28 0 5.347-3 9.626-7 10.696l-22.3 12.622C852.6 158.372 751
 181.476 676 181.476c-149 0-189-126.21-332-126.21z`,tilde3:`M786 59C457 59 32 175.242 13 175.242c-6 0-10-3.457
-11-10.37L.15 138c-1-7 3-12 10-13l19.2-6.4C378.4 40.7 634.3 0 804.3 0c337 0
 411.8 157 746.8 157 328 0 754-112 773-112 5 0 10 3 11 9l1 14.075c1 8.066-.697
 16.595-6.697 17.492l-21.052 7.31c-367.9 98.146-609.15 122.696-778.15 122.696
 -338 0-409-156.573-744-156.573z`,tilde4:`M786 58C457 58 32 177.487 13 177.487c-6 0-10-3.345
-11-10.035L.15 143c-1-7 3-12 10-13l22-6.7C381.2 35 637.15 0 807.15 0c337 0 409
 177 744 177 328 0 754-127 773-127 5 0 10 3 11 9l1 14.794c1 7.805-3 13.38-9
 14.495l-20.7 5.574c-366.85 99.79-607.3 139.372-776.3 139.372-338 0-409
 -175.236-744-175.236z`,vec:`M377 20c0-5.333 1.833-10 5.5-14S391 0 397 0c4.667 0 8.667 1.667 12 5
3.333 2.667 6.667 9 10 19 6.667 24.667 20.333 43.667 41 57 7.333 4.667 11
10.667 11 18 0 6-1 10-3 12s-6.667 5-14 9c-28.667 14.667-53.667 35.667-75 63
-1.333 1.333-3.167 3.5-5.5 6.5s-4 4.833-5 5.5c-1 .667-2.5 1.333-4.5 2s-4.333 1
-7 1c-4.667 0-9.167-1.833-13.5-5.5S337 184 337 178c0-12.667 15.667-32.333 47-59
H213l-171-1c-8.667-6-13-12.333-13-19 0-4.667 4.333-11.333 13-20h359
c-16-25.333-24-45-24-59z`,widehat1:`M529 0h5l519 115c5 1 9 5 9 10 0 1-1 2-1 3l-4 22
c-1 5-5 9-11 9h-2L532 67 19 159h-2c-5 0-9-4-11-9l-5-22c-1-6 2-12 8-13z`,widehat2:`M1181 0h2l1171 176c6 0 10 5 10 11l-2 23c-1 6-5 10
-11 10h-1L1182 67 15 220h-1c-6 0-10-4-11-10l-2-23c-1-6 4-11 10-11z`,widehat3:`M1181 0h2l1171 236c6 0 10 5 10 11l-2 23c-1 6-5 10
-11 10h-1L1182 67 15 280h-1c-6 0-10-4-11-10l-2-23c-1-6 4-11 10-11z`,widehat4:`M1181 0h2l1171 296c6 0 10 5 10 11l-2 23c-1 6-5 10
-11 10h-1L1182 67 15 340h-1c-6 0-10-4-11-10l-2-23c-1-6 4-11 10-11z`,widecheck1:`M529,159h5l519,-115c5,-1,9,-5,9,-10c0,-1,-1,-2,-1,-3l-4,-22c-1,
-5,-5,-9,-11,-9h-2l-512,92l-513,-92h-2c-5,0,-9,4,-11,9l-5,22c-1,6,2,12,8,13z`,widecheck2:`M1181,220h2l1171,-176c6,0,10,-5,10,-11l-2,-23c-1,-6,-5,-10,
-11,-10h-1l-1168,153l-1167,-153h-1c-6,0,-10,4,-11,10l-2,23c-1,6,4,11,10,11z`,widecheck3:`M1181,280h2l1171,-236c6,0,10,-5,10,-11l-2,-23c-1,-6,-5,-10,
-11,-10h-1l-1168,213l-1167,-213h-1c-6,0,-10,4,-11,10l-2,23c-1,6,4,11,10,11z`,widecheck4:`M1181,340h2l1171,-296c6,0,10,-5,10,-11l-2,-23c-1,-6,-5,-10,
-11,-10h-1l-1168,273l-1167,-273h-1c-6,0,-10,4,-11,10l-2,23c-1,6,4,11,10,11z`,baraboveleftarrow:`M400000 620h-399890l3 -3c68.7 -52.7 113.7 -120 135 -202
c4 -14.7 6 -23 6 -25c0 -7.3 -7 -11 -21 -11c-8 0 -13.2 0.8 -15.5 2.5
c-2.3 1.7 -4.2 5.8 -5.5 12.5c-1.3 4.7 -2.7 10.3 -4 17c-12 48.7 -34.8 92 -68.5 130
s-74.2 66.3 -121.5 85c-10 4 -16 7.7 -18 11c0 8.7 6 14.3 18 17c47.3 18.7 87.8 47
121.5 85s56.5 81.3 68.5 130c0.7 2 1.3 5 2 9s1.2 6.7 1.5 8c0.3 1.3 1 3.3 2 6
s2.2 4.5 3.5 5.5c1.3 1 3.3 1.8 6 2.5s6 1 10 1c14 0 21 -3.7 21 -11
c0 -2 -2 -10.3 -6 -25c-20 -79.3 -65 -146.7 -135 -202l-3 -3h399890z
M100 620v40h399900v-40z M0 241v40h399900v-40zM0 241v40h399900v-40z`,rightarrowabovebar:`M0 241v40h399891c-47.3 35.3-84 78-110 128-16.7 32
-27.7 63.7-33 95 0 1.3-.2 2.7-.5 4-.3 1.3-.5 2.3-.5 3 0 7.3 6.7 11 20 11 8 0
13.2-.8 15.5-2.5 2.3-1.7 4.2-5.5 5.5-11.5 2-13.3 5.7-27 11-41 14.7-44.7 39
-84.5 73-119.5s73.7-60.2 119-75.5c6-2 9-5.7 9-11s-3-9-9-11c-45.3-15.3-85-40.5
-119-75.5s-58.3-74.8-73-119.5c-4.7-14-8.3-27.3-11-40-1.3-6.7-3.2-10.8-5.5
-12.5-2.3-1.7-7.5-2.5-15.5-2.5-14 0-21 3.7-21 11 0 2 2 10.3 6 25 20.7 83.3 67
151.7 139 205zm96 379h399894v40H0zm0 0h399904v40H0z`,baraboveshortleftharpoon:`M507,435c-4,4,-6.3,8.7,-7,14c0,5.3,0.7,9,2,11
c1.3,2,5.3,5.3,12,10c90.7,54,156,130,196,228c3.3,10.7,6.3,16.3,9,17
c2,0.7,5,1,9,1c0,0,5,0,5,0c10.7,0,16.7,-2,18,-6c2,-2.7,1,-9.7,-3,-21
c-32,-87.3,-82.7,-157.7,-152,-211c0,0,-3,-3,-3,-3l399351,0l0,-40
c-398570,0,-399437,0,-399437,0z M593 435 v40 H399500 v-40z
M0 281 v-40 H399908 v40z M0 281 v-40 H399908 v40z`,rightharpoonaboveshortbar:`M0,241 l0,40c399126,0,399993,0,399993,0
c4.7,-4.7,7,-9.3,7,-14c0,-9.3,-3.7,-15.3,-11,-18c-92.7,-56.7,-159,-133.7,-199,
-231c-3.3,-9.3,-6,-14.7,-8,-16c-2,-1.3,-7,-2,-15,-2c-10.7,0,-16.7,2,-18,6
c-2,2.7,-1,9.7,3,21c15.3,42,36.7,81.8,64,119.5c27.3,37.7,58,69.2,92,94.5z
M0 241 v40 H399908 v-40z M0 475 v-40 H399500 v40z M0 475 v-40 H399500 v40z`,shortbaraboveleftharpoon:`M7,435c-4,4,-6.3,8.7,-7,14c0,5.3,0.7,9,2,11
c1.3,2,5.3,5.3,12,10c90.7,54,156,130,196,228c3.3,10.7,6.3,16.3,9,17c2,0.7,5,1,9,
1c0,0,5,0,5,0c10.7,0,16.7,-2,18,-6c2,-2.7,1,-9.7,-3,-21c-32,-87.3,-82.7,-157.7,
-152,-211c0,0,-3,-3,-3,-3l399907,0l0,-40c-399126,0,-399993,0,-399993,0z
M93 435 v40 H400000 v-40z M500 241 v40 H400000 v-40z M500 241 v40 H400000 v-40z`,shortrightharpoonabovebar:`M53,241l0,40c398570,0,399437,0,399437,0
c4.7,-4.7,7,-9.3,7,-14c0,-9.3,-3.7,-15.3,-11,-18c-92.7,-56.7,-159,-133.7,-199,
-231c-3.3,-9.3,-6,-14.7,-8,-16c-2,-1.3,-7,-2,-15,-2c-10.7,0,-16.7,2,-18,6
c-2,2.7,-1,9.7,3,21c15.3,42,36.7,81.8,64,119.5c27.3,37.7,58,69.2,92,94.5z
M500 241 v40 H399408 v-40z M500 435 v40 H400000 v-40z`},_ae=function(t,n){switch(t){case"lbrack":return"M403 1759 V84 H666 V0 H319 V1759 v"+n+` v1759 h347 v-84
H403z M403 1759 V0 H319 V1759 v`+n+" v1759 h84z";case"rbrack":return"M347 1759 V0 H0 V84 H263 V1759 v"+n+` v1759 H0 v84 H347z
M347 1759 V0 H263 V1759 v`+n+" v1759 h84z";case"vert":return"M145 15 v585 v"+n+` v585 c2.667,10,9.667,15,21,15
c10,0,16.667,-5,20,-15 v-585 v`+-n+` v-585 c-2.667,-10,-9.667,-15,-21,-15
c-10,0,-16.667,5,-20,15z M188 15 H145 v585 v`+n+" v585 h43z";case"doublevert":return"M145 15 v585 v"+n+` v585 c2.667,10,9.667,15,21,15
c10,0,16.667,-5,20,-15 v-585 v`+-n+` v-585 c-2.667,-10,-9.667,-15,-21,-15
c-10,0,-16.667,5,-20,15z M188 15 H145 v585 v`+n+` v585 h43z
M367 15 v585 v`+n+` v585 c2.667,10,9.667,15,21,15
c10,0,16.667,-5,20,-15 v-585 v`+-n+` v-585 c-2.667,-10,-9.667,-15,-21,-15
c-10,0,-16.667,5,-20,15z M410 15 H367 v585 v`+n+" v585 h43z";case"lfloor":return"M319 602 V0 H403 V602 v"+n+` v1715 h263 v84 H319z
MM319 602 V0 H403 V602 v`+n+" v1715 H319z";case"rfloor":return"M319 602 V0 H403 V602 v"+n+` v1799 H0 v-84 H319z
MM319 602 V0 H403 V602 v`+n+" v1715 H319z";case"lceil":return"M403 1759 V84 H666 V0 H319 V1759 v"+n+` v602 h84z
M403 1759 V0 H319 V1759 v`+n+" v602 h84z";case"rceil":return"M347 1759 V0 H0 V84 H263 V1759 v"+n+` v602 h84z
M347 1759 V0 h-84 V1759 v`+n+" v602 h84z";case"lparen":return`M863,9c0,-2,-2,-5,-6,-9c0,0,-17,0,-17,0c-12.7,0,-19.3,0.3,-20,1
c-5.3,5.3,-10.3,11,-15,17c-242.7,294.7,-395.3,682,-458,1162c-21.3,163.3,-33.3,349,
-36,557 l0,`+(n+84)+`c0.2,6,0,26,0,60c2,159.3,10,310.7,24,454c53.3,528,210,
949.7,470,1265c4.7,6,9.7,11.7,15,17c0.7,0.7,7,1,19,1c0,0,18,0,18,0c4,-4,6,-7,6,-9
c0,-2.7,-3.3,-8.7,-10,-18c-135.3,-192.7,-235.5,-414.3,-300.5,-665c-65,-250.7,-102.5,
-544.7,-112.5,-882c-2,-104,-3,-167,-3,-189
l0,-`+(n+92)+`c0,-162.7,5.7,-314,17,-454c20.7,-272,63.7,-513,129,-723c65.3,
-210,155.3,-396.3,270,-559c6.7,-9.3,10,-15.3,10,-18z`;case"rparen":return`M76,0c-16.7,0,-25,3,-25,9c0,2,2,6.3,6,13c21.3,28.7,42.3,60.3,
63,95c96.7,156.7,172.8,332.5,228.5,527.5c55.7,195,92.8,416.5,111.5,664.5
c11.3,139.3,17,290.7,17,454c0,28,1.7,43,3.3,45l0,`+(n+9)+`
c-3,4,-3.3,16.7,-3.3,38c0,162,-5.7,313.7,-17,455c-18.7,248,-55.8,469.3,-111.5,664
c-55.7,194.7,-131.8,370.3,-228.5,527c-20.7,34.7,-41.7,66.3,-63,95c-2,3.3,-4,7,-6,11
c0,7.3,5.7,11,17,11c0,0,11,0,11,0c9.3,0,14.3,-0.3,15,-1c5.3,-5.3,10.3,-11,15,-17
c242.7,-294.7,395.3,-681.7,458,-1161c21.3,-164.7,33.3,-350.7,36,-558
l0,-`+(n+144)+`c-2,-159.3,-10,-310.7,-24,-454c-53.3,-528,-210,-949.7,
-470,-1265c-4.7,-6,-9.7,-11.7,-15,-17c-0.7,-0.7,-6.7,-1,-18,-1z`;default:throw new Error("Unknown stretchy delimiter.")}};class vu{constructor(t){this.children=t,this.classes=[],this.height=0,this.depth=0,this.maxFontSize=0,this.style={}}hasClass(t){return this.classes.includes(t)}toNode(){for(var t=document.createDocumentFragment(),n=0;n<this.children.length;n++)t.appendChild(this.children[n].toNode());return t}toMarkup(){for(var t="",n=0;n<this.children.length;n++)t+=this.children[n].toMarkup();return t}toText(){var t=n=>n.toText();return this.children.map(t).join("")}}var kx={pt:1,mm:7227/2540,cm:7227/254,in:72.27,bp:803/800,pc:12,dd:1238/1157,cc:14856/1157,nd:685/642,nc:1370/107,sp:1/65536,px:803/800},Cae={ex:!0,em:!0,mu:!0},vD=function(t){return typeof t!="string"&&(t=t.unit),t in kx||t in Cae||t==="ex"},wn=function(t,n){var r;if(t.unit in kx)r=kx[t.unit]/n.fontMetrics().ptPerEm/n.sizeMultiplier;else if(t.unit==="mu")r=n.fontMetrics().cssEmPerMu;else{var a;if(n.style.isTight()?a=n.havingStyle(n.style.text()):a=n,t.unit==="ex")r=a.fontMetrics().xHeight;else if(t.unit==="em")r=a.fontMetrics().quad;else throw new Re("Invalid unit: '"+t.unit+"'");a!==n&&(r*=a.sizeMultiplier/n.sizeMultiplier)}return Math.min(t.number*r,n.maxSize)},Ie=function(t){return+t.toFixed(4)+"em"},ws=function(t){return t.filter(n=>n).join(" ")},xD=function(t,n,r){if(this.classes=t||[],this.attributes={},this.height=0,this.depth=0,this.maxFontSize=0,this.style=r||{},n){n.style.isTight()&&this.classes.push("mtight");var a=n.getColor();a&&(this.style.color=a)}},SD=function(t){var n=document.createElement(t);n.className=ws(this.classes);for(var r of Object.keys(this.style))n.style[r]=this.style[r];for(var a of Object.keys(this.attributes))n.setAttribute(a,this.attributes[a]);for(var i=0;i<this.children.length;i++)n.appendChild(this.children[i].toNode());return n},Aae=/[\s"'>/=\x00-\x1f]/,wD=function(t){var n="<"+t;this.classes.length&&(n+=' class="'+gr(ws(this.classes))+'"');var r="";for(var a of Object.keys(this.style))r+=qS(a)+":"+this.style[a]+";";r&&(n+=' style="'+gr(r)+'"');for(var i of Object.keys(this.attributes)){if(Aae.test(i))throw new Re("Invalid attribute name '"+i+"'");n+=" "+i+'="'+gr(this.attributes[i])+'"'}n+=">";for(var o=0;o<this.children.length;o++)n+=this.children[o].toMarkup();return n+="</"+t+">",n};class xu{constructor(t,n,r,a){xD.call(this,t,r,a),this.children=n||[]}setAttribute(t,n){this.attributes[t]=n}hasClass(t){return this.classes.includes(t)}toNode(){return SD.call(this,"span")}toMarkup(){return wD.call(this,"span")}}class bg{constructor(t,n,r,a){xD.call(this,n,a),this.children=r||[],this.setAttribute("href",t)}setAttribute(t,n){this.attributes[t]=n}hasClass(t){return this.classes.includes(t)}toNode(){return SD.call(this,"a")}toMarkup(){return wD.call(this,"a")}}class Rae{constructor(t,n,r){this.alt=n,this.src=t,this.classes=["mord"],this.height=0,this.depth=0,this.maxFontSize=0,this.style=r}hasClass(t){return this.classes.includes(t)}toNode(){var t=document.createElement("img");t.src=this.src,t.alt=this.alt,t.className="mord";for(var n of Object.keys(this.style))t.style[n]=this.style[n];return t}toMarkup(){var t='<img src="'+gr(this.src)+'"'+(' alt="'+gr(this.alt)+'"'),n="";for(var r of Object.keys(this.style))n+=qS(r)+":"+this.style[r]+";";return n&&(t+=' style="'+gr(n)+'"'),t+="'/>",t}}var Nae={î:"ı̂",ï:"ı̈",í:"ı́",ì:"ı̀"};class ba{constructor(t,n,r,a,i,o,l,u){this.text=t,this.height=n||0,this.depth=r||0,this.italic=a||0,this.skew=i||0,this.width=o||0,this.classes=l||[],this.style=u||{},this.maxFontSize=0;var d=gae(this.text.charCodeAt(0));d&&this.classes.push(d+"_fallback"),/[îïíì]/.test(this.text)&&(this.text=Nae[this.text])}hasClass(t){return this.classes.includes(t)}toNode(){var t=document.createTextNode(this.text),n=null;this.italic>0&&(n=document.createElement("span"),n.style.marginRight=Ie(this.italic)),this.classes.length>0&&(n=n||document.createElement("span"),n.className=ws(this.classes));for(var r of Object.keys(this.style))n=n||document.createElement("span"),n.style[r]=this.style[r];return n?(n.appendChild(t),n):t}toMarkup(){var t=!1,n="<span";this.classes.length&&(t=!0,n+=' class="',n+=gr(ws(this.classes)),n+='"');var r="";this.italic>0&&(r+="margin-right:"+this.italic+"em;");for(var a of Object.keys(this.style))r+=qS(a)+":"+this.style[a]+";";r&&(t=!0,n+=' style="'+gr(r)+'"');var i=gr(this.text);return t?(n+=">",n+=i,n+="</span>",n):i}}class To{constructor(t,n){this.children=t||[],this.attributes=n||{}}toNode(){var t="http://www.w3.org/2000/svg",n=document.createElementNS(t,"svg");for(var r of Object.keys(this.attributes))n.setAttribute(r,this.attributes[r]);for(var a=0;a<this.children.length;a++)n.appendChild(this.children[a].toNode());return n}toMarkup(){var t='<svg xmlns="http://www.w3.org/2000/svg"';for(var n of Object.keys(this.attributes))t+=" "+n+'="'+gr(this.attributes[n])+'"';t+=">";for(var r=0;r<this.children.length;r++)t+=this.children[r].toMarkup();return t+="</svg>",t}}class Es{constructor(t,n){this.pathName=t,this.alternate=n}toNode(){var t="http://www.w3.org/2000/svg",n=document.createElementNS(t,"path");return this.alternate?n.setAttribute("d",this.alternate):n.setAttribute("d",cN[this.pathName]),n}toMarkup(){return this.alternate?'<path d="'+gr(this.alternate)+'"/>':'<path d="'+gr(cN[this.pathName])+'"/>'}}class Tx{constructor(t){this.attributes=t||{}}toNode(){var t="http://www.w3.org/2000/svg",n=document.createElementNS(t,"line");for(var r of Object.keys(this.attributes))n.setAttribute(r,this.attributes[r]);return n}toMarkup(){var t="<line";for(var n of Object.keys(this.attributes))t+=" "+n+'="'+gr(this.attributes[n])+'"';return t+="/>",t}}function Oae(e){if(e instanceof ba)return e;throw new Error("Expected symbolNode but got "+String(e)+".")}function Iae(e){if(e instanceof xu)return e;throw new Error("Expected span<HtmlDomNode> but got "+String(e)+".")}var Lae=e=>e instanceof xu||e instanceof bg||e instanceof vu,Ti={"AMS-Regular":{32:[0,0,0,0,.25],65:[0,.68889,0,0,.72222],66:[0,.68889,0,0,.66667],67:[0,.68889,0,0,.72222],68:[0,.68889,0,0,.72222],69:[0,.68889,0,0,.66667],70:[0,.68889,0,0,.61111],71:[0,.68889,0,0,.77778],72:[0,.68889,0,0,.77778],73:[0,.68889,0,0,.38889],74:[.16667,.68889,0,0,.5],75:[0,.68889,0,0,.77778],76:[0,.68889,0,0,.66667],77:[0,.68889,0,0,.94445],78:[0,.68889,0,0,.72222],79:[.16667,.68889,0,0,.77778],80:[0,.68889,0,0,.61111],81:[.16667,.68889,0,0,.77778],82:[0,.68889,0,0,.72222],83:[0,.68889,0,0,.55556],84:[0,.68889,0,0,.66667],85:[0,.68889,0,0,.72222],86:[0,.68889,0,0,.72222],87:[0,.68889,0,0,1],88:[0,.68889,0,0,.72222],89:[0,.68889,0,0,.72222],90:[0,.68889,0,0,.66667],107:[0,.68889,0,0,.55556],160:[0,0,0,0,.25],165:[0,.675,.025,0,.75],174:[.15559,.69224,0,0,.94666],240:[0,.68889,0,0,.55556],295:[0,.68889,0,0,.54028],710:[0,.825,0,0,2.33334],732:[0,.9,0,0,2.33334],770:[0,.825,0,0,2.33334],771:[0,.9,0,0,2.33334],989:[.08167,.58167,0,0,.77778],1008:[0,.43056,.04028,0,.66667],8245:[0,.54986,0,0,.275],8463:[0,.68889,0,0,.54028],8487:[0,.68889,0,0,.72222],8498:[0,.68889,0,0,.55556],8502:[0,.68889,0,0,.66667],8503:[0,.68889,0,0,.44445],8504:[0,.68889,0,0,.66667],8513:[0,.68889,0,0,.63889],8592:[-.03598,.46402,0,0,.5],8594:[-.03598,.46402,0,0,.5],8602:[-.13313,.36687,0,0,1],8603:[-.13313,.36687,0,0,1],8606:[.01354,.52239,0,0,1],8608:[.01354,.52239,0,0,1],8610:[.01354,.52239,0,0,1.11111],8611:[.01354,.52239,0,0,1.11111],8619:[0,.54986,0,0,1],8620:[0,.54986,0,0,1],8621:[-.13313,.37788,0,0,1.38889],8622:[-.13313,.36687,0,0,1],8624:[0,.69224,0,0,.5],8625:[0,.69224,0,0,.5],8630:[0,.43056,0,0,1],8631:[0,.43056,0,0,1],8634:[.08198,.58198,0,0,.77778],8635:[.08198,.58198,0,0,.77778],8638:[.19444,.69224,0,0,.41667],8639:[.19444,.69224,0,0,.41667],8642:[.19444,.69224,0,0,.41667],8643:[.19444,.69224,0,0,.41667],8644:[.1808,.675,0,0,1],8646:[.1808,.675,0,0,1],8647:[.1808,.675,0,0,1],8648:[.19444,.69224,0,0,.83334],8649:[.1808,.675,0,0,1],8650:[.19444,.69224,0,0,.83334],8651:[.01354,.52239,0,0,1],8652:[.01354,.52239,0,0,1],8653:[-.13313,.36687,0,0,1],8654:[-.13313,.36687,0,0,1],8655:[-.13313,.36687,0,0,1],8666:[.13667,.63667,0,0,1],8667:[.13667,.63667,0,0,1],8669:[-.13313,.37788,0,0,1],8672:[-.064,.437,0,0,1.334],8674:[-.064,.437,0,0,1.334],8705:[0,.825,0,0,.5],8708:[0,.68889,0,0,.55556],8709:[.08167,.58167,0,0,.77778],8717:[0,.43056,0,0,.42917],8722:[-.03598,.46402,0,0,.5],8724:[.08198,.69224,0,0,.77778],8726:[.08167,.58167,0,0,.77778],8733:[0,.69224,0,0,.77778],8736:[0,.69224,0,0,.72222],8737:[0,.69224,0,0,.72222],8738:[.03517,.52239,0,0,.72222],8739:[.08167,.58167,0,0,.22222],8740:[.25142,.74111,0,0,.27778],8741:[.08167,.58167,0,0,.38889],8742:[.25142,.74111,0,0,.5],8756:[0,.69224,0,0,.66667],8757:[0,.69224,0,0,.66667],8764:[-.13313,.36687,0,0,.77778],8765:[-.13313,.37788,0,0,.77778],8769:[-.13313,.36687,0,0,.77778],8770:[-.03625,.46375,0,0,.77778],8774:[.30274,.79383,0,0,.77778],8776:[-.01688,.48312,0,0,.77778],8778:[.08167,.58167,0,0,.77778],8782:[.06062,.54986,0,0,.77778],8783:[.06062,.54986,0,0,.77778],8785:[.08198,.58198,0,0,.77778],8786:[.08198,.58198,0,0,.77778],8787:[.08198,.58198,0,0,.77778],8790:[0,.69224,0,0,.77778],8791:[.22958,.72958,0,0,.77778],8796:[.08198,.91667,0,0,.77778],8806:[.25583,.75583,0,0,.77778],8807:[.25583,.75583,0,0,.77778],8808:[.25142,.75726,0,0,.77778],8809:[.25142,.75726,0,0,.77778],8812:[.25583,.75583,0,0,.5],8814:[.20576,.70576,0,0,.77778],8815:[.20576,.70576,0,0,.77778],8816:[.30274,.79383,0,0,.77778],8817:[.30274,.79383,0,0,.77778],8818:[.22958,.72958,0,0,.77778],8819:[.22958,.72958,0,0,.77778],8822:[.1808,.675,0,0,.77778],8823:[.1808,.675,0,0,.77778],8828:[.13667,.63667,0,0,.77778],8829:[.13667,.63667,0,0,.77778],8830:[.22958,.72958,0,0,.77778],8831:[.22958,.72958,0,0,.77778],8832:[.20576,.70576,0,0,.77778],8833:[.20576,.70576,0,0,.77778],8840:[.30274,.79383,0,0,.77778],8841:[.30274,.79383,0,0,.77778],8842:[.13597,.63597,0,0,.77778],8843:[.13597,.63597,0,0,.77778],8847:[.03517,.54986,0,0,.77778],8848:[.03517,.54986,0,0,.77778],8858:[.08198,.58198,0,0,.77778],8859:[.08198,.58198,0,0,.77778],8861:[.08198,.58198,0,0,.77778],8862:[0,.675,0,0,.77778],8863:[0,.675,0,0,.77778],8864:[0,.675,0,0,.77778],8865:[0,.675,0,0,.77778],8872:[0,.69224,0,0,.61111],8873:[0,.69224,0,0,.72222],8874:[0,.69224,0,0,.88889],8876:[0,.68889,0,0,.61111],8877:[0,.68889,0,0,.61111],8878:[0,.68889,0,0,.72222],8879:[0,.68889,0,0,.72222],8882:[.03517,.54986,0,0,.77778],8883:[.03517,.54986,0,0,.77778],8884:[.13667,.63667,0,0,.77778],8885:[.13667,.63667,0,0,.77778],8888:[0,.54986,0,0,1.11111],8890:[.19444,.43056,0,0,.55556],8891:[.19444,.69224,0,0,.61111],8892:[.19444,.69224,0,0,.61111],8901:[0,.54986,0,0,.27778],8903:[.08167,.58167,0,0,.77778],8905:[.08167,.58167,0,0,.77778],8906:[.08167,.58167,0,0,.77778],8907:[0,.69224,0,0,.77778],8908:[0,.69224,0,0,.77778],8909:[-.03598,.46402,0,0,.77778],8910:[0,.54986,0,0,.76042],8911:[0,.54986,0,0,.76042],8912:[.03517,.54986,0,0,.77778],8913:[.03517,.54986,0,0,.77778],8914:[0,.54986,0,0,.66667],8915:[0,.54986,0,0,.66667],8916:[0,.69224,0,0,.66667],8918:[.0391,.5391,0,0,.77778],8919:[.0391,.5391,0,0,.77778],8920:[.03517,.54986,0,0,1.33334],8921:[.03517,.54986,0,0,1.33334],8922:[.38569,.88569,0,0,.77778],8923:[.38569,.88569,0,0,.77778],8926:[.13667,.63667,0,0,.77778],8927:[.13667,.63667,0,0,.77778],8928:[.30274,.79383,0,0,.77778],8929:[.30274,.79383,0,0,.77778],8934:[.23222,.74111,0,0,.77778],8935:[.23222,.74111,0,0,.77778],8936:[.23222,.74111,0,0,.77778],8937:[.23222,.74111,0,0,.77778],8938:[.20576,.70576,0,0,.77778],8939:[.20576,.70576,0,0,.77778],8940:[.30274,.79383,0,0,.77778],8941:[.30274,.79383,0,0,.77778],8994:[.19444,.69224,0,0,.77778],8995:[.19444,.69224,0,0,.77778],9416:[.15559,.69224,0,0,.90222],9484:[0,.69224,0,0,.5],9488:[0,.69224,0,0,.5],9492:[0,.37788,0,0,.5],9496:[0,.37788,0,0,.5],9585:[.19444,.68889,0,0,.88889],9586:[.19444,.74111,0,0,.88889],9632:[0,.675,0,0,.77778],9633:[0,.675,0,0,.77778],9650:[0,.54986,0,0,.72222],9651:[0,.54986,0,0,.72222],9654:[.03517,.54986,0,0,.77778],9660:[0,.54986,0,0,.72222],9661:[0,.54986,0,0,.72222],9664:[.03517,.54986,0,0,.77778],9674:[.11111,.69224,0,0,.66667],9733:[.19444,.69224,0,0,.94445],10003:[0,.69224,0,0,.83334],10016:[0,.69224,0,0,.83334],10731:[.11111,.69224,0,0,.66667],10846:[.19444,.75583,0,0,.61111],10877:[.13667,.63667,0,0,.77778],10878:[.13667,.63667,0,0,.77778],10885:[.25583,.75583,0,0,.77778],10886:[.25583,.75583,0,0,.77778],10887:[.13597,.63597,0,0,.77778],10888:[.13597,.63597,0,0,.77778],10889:[.26167,.75726,0,0,.77778],10890:[.26167,.75726,0,0,.77778],10891:[.48256,.98256,0,0,.77778],10892:[.48256,.98256,0,0,.77778],10901:[.13667,.63667,0,0,.77778],10902:[.13667,.63667,0,0,.77778],10933:[.25142,.75726,0,0,.77778],10934:[.25142,.75726,0,0,.77778],10935:[.26167,.75726,0,0,.77778],10936:[.26167,.75726,0,0,.77778],10937:[.26167,.75726,0,0,.77778],10938:[.26167,.75726,0,0,.77778],10949:[.25583,.75583,0,0,.77778],10950:[.25583,.75583,0,0,.77778],10955:[.28481,.79383,0,0,.77778],10956:[.28481,.79383,0,0,.77778],57350:[.08167,.58167,0,0,.22222],57351:[.08167,.58167,0,0,.38889],57352:[.08167,.58167,0,0,.77778],57353:[0,.43056,.04028,0,.66667],57356:[.25142,.75726,0,0,.77778],57357:[.25142,.75726,0,0,.77778],57358:[.41951,.91951,0,0,.77778],57359:[.30274,.79383,0,0,.77778],57360:[.30274,.79383,0,0,.77778],57361:[.41951,.91951,0,0,.77778],57366:[.25142,.75726,0,0,.77778],57367:[.25142,.75726,0,0,.77778],57368:[.25142,.75726,0,0,.77778],57369:[.25142,.75726,0,0,.77778],57370:[.13597,.63597,0,0,.77778],57371:[.13597,.63597,0,0,.77778]},"Caligraphic-Regular":{32:[0,0,0,0,.25],65:[0,.68333,0,.19445,.79847],66:[0,.68333,.03041,.13889,.65681],67:[0,.68333,.05834,.13889,.52653],68:[0,.68333,.02778,.08334,.77139],69:[0,.68333,.08944,.11111,.52778],70:[0,.68333,.09931,.11111,.71875],71:[.09722,.68333,.0593,.11111,.59487],72:[0,.68333,.00965,.11111,.84452],73:[0,.68333,.07382,0,.54452],74:[.09722,.68333,.18472,.16667,.67778],75:[0,.68333,.01445,.05556,.76195],76:[0,.68333,0,.13889,.68972],77:[0,.68333,0,.13889,1.2009],78:[0,.68333,.14736,.08334,.82049],79:[0,.68333,.02778,.11111,.79611],80:[0,.68333,.08222,.08334,.69556],81:[.09722,.68333,0,.11111,.81667],82:[0,.68333,0,.08334,.8475],83:[0,.68333,.075,.13889,.60556],84:[0,.68333,.25417,0,.54464],85:[0,.68333,.09931,.08334,.62583],86:[0,.68333,.08222,0,.61278],87:[0,.68333,.08222,.08334,.98778],88:[0,.68333,.14643,.13889,.7133],89:[.09722,.68333,.08222,.08334,.66834],90:[0,.68333,.07944,.13889,.72473],160:[0,0,0,0,.25]},"Fraktur-Regular":{32:[0,0,0,0,.25],33:[0,.69141,0,0,.29574],34:[0,.69141,0,0,.21471],38:[0,.69141,0,0,.73786],39:[0,.69141,0,0,.21201],40:[.24982,.74947,0,0,.38865],41:[.24982,.74947,0,0,.38865],42:[0,.62119,0,0,.27764],43:[.08319,.58283,0,0,.75623],44:[0,.10803,0,0,.27764],45:[.08319,.58283,0,0,.75623],46:[0,.10803,0,0,.27764],47:[.24982,.74947,0,0,.50181],48:[0,.47534,0,0,.50181],49:[0,.47534,0,0,.50181],50:[0,.47534,0,0,.50181],51:[.18906,.47534,0,0,.50181],52:[.18906,.47534,0,0,.50181],53:[.18906,.47534,0,0,.50181],54:[0,.69141,0,0,.50181],55:[.18906,.47534,0,0,.50181],56:[0,.69141,0,0,.50181],57:[.18906,.47534,0,0,.50181],58:[0,.47534,0,0,.21606],59:[.12604,.47534,0,0,.21606],61:[-.13099,.36866,0,0,.75623],63:[0,.69141,0,0,.36245],65:[0,.69141,0,0,.7176],66:[0,.69141,0,0,.88397],67:[0,.69141,0,0,.61254],68:[0,.69141,0,0,.83158],69:[0,.69141,0,0,.66278],70:[.12604,.69141,0,0,.61119],71:[0,.69141,0,0,.78539],72:[.06302,.69141,0,0,.7203],73:[0,.69141,0,0,.55448],74:[.12604,.69141,0,0,.55231],75:[0,.69141,0,0,.66845],76:[0,.69141,0,0,.66602],77:[0,.69141,0,0,1.04953],78:[0,.69141,0,0,.83212],79:[0,.69141,0,0,.82699],80:[.18906,.69141,0,0,.82753],81:[.03781,.69141,0,0,.82699],82:[0,.69141,0,0,.82807],83:[0,.69141,0,0,.82861],84:[0,.69141,0,0,.66899],85:[0,.69141,0,0,.64576],86:[0,.69141,0,0,.83131],87:[0,.69141,0,0,1.04602],88:[0,.69141,0,0,.71922],89:[.18906,.69141,0,0,.83293],90:[.12604,.69141,0,0,.60201],91:[.24982,.74947,0,0,.27764],93:[.24982,.74947,0,0,.27764],94:[0,.69141,0,0,.49965],97:[0,.47534,0,0,.50046],98:[0,.69141,0,0,.51315],99:[0,.47534,0,0,.38946],100:[0,.62119,0,0,.49857],101:[0,.47534,0,0,.40053],102:[.18906,.69141,0,0,.32626],103:[.18906,.47534,0,0,.5037],104:[.18906,.69141,0,0,.52126],105:[0,.69141,0,0,.27899],106:[0,.69141,0,0,.28088],107:[0,.69141,0,0,.38946],108:[0,.69141,0,0,.27953],109:[0,.47534,0,0,.76676],110:[0,.47534,0,0,.52666],111:[0,.47534,0,0,.48885],112:[.18906,.52396,0,0,.50046],113:[.18906,.47534,0,0,.48912],114:[0,.47534,0,0,.38919],115:[0,.47534,0,0,.44266],116:[0,.62119,0,0,.33301],117:[0,.47534,0,0,.5172],118:[0,.52396,0,0,.5118],119:[0,.52396,0,0,.77351],120:[.18906,.47534,0,0,.38865],121:[.18906,.47534,0,0,.49884],122:[.18906,.47534,0,0,.39054],160:[0,0,0,0,.25],8216:[0,.69141,0,0,.21471],8217:[0,.69141,0,0,.21471],58112:[0,.62119,0,0,.49749],58113:[0,.62119,0,0,.4983],58114:[.18906,.69141,0,0,.33328],58115:[.18906,.69141,0,0,.32923],58116:[.18906,.47534,0,0,.50343],58117:[0,.69141,0,0,.33301],58118:[0,.62119,0,0,.33409],58119:[0,.47534,0,0,.50073]},"Main-Bold":{32:[0,0,0,0,.25],33:[0,.69444,0,0,.35],34:[0,.69444,0,0,.60278],35:[.19444,.69444,0,0,.95833],36:[.05556,.75,0,0,.575],37:[.05556,.75,0,0,.95833],38:[0,.69444,0,0,.89444],39:[0,.69444,0,0,.31944],40:[.25,.75,0,0,.44722],41:[.25,.75,0,0,.44722],42:[0,.75,0,0,.575],43:[.13333,.63333,0,0,.89444],44:[.19444,.15556,0,0,.31944],45:[0,.44444,0,0,.38333],46:[0,.15556,0,0,.31944],47:[.25,.75,0,0,.575],48:[0,.64444,0,0,.575],49:[0,.64444,0,0,.575],50:[0,.64444,0,0,.575],51:[0,.64444,0,0,.575],52:[0,.64444,0,0,.575],53:[0,.64444,0,0,.575],54:[0,.64444,0,0,.575],55:[0,.64444,0,0,.575],56:[0,.64444,0,0,.575],57:[0,.64444,0,0,.575],58:[0,.44444,0,0,.31944],59:[.19444,.44444,0,0,.31944],60:[.08556,.58556,0,0,.89444],61:[-.10889,.39111,0,0,.89444],62:[.08556,.58556,0,0,.89444],63:[0,.69444,0,0,.54305],64:[0,.69444,0,0,.89444],65:[0,.68611,0,0,.86944],66:[0,.68611,0,0,.81805],67:[0,.68611,0,0,.83055],68:[0,.68611,0,0,.88194],69:[0,.68611,0,0,.75555],70:[0,.68611,0,0,.72361],71:[0,.68611,0,0,.90416],72:[0,.68611,0,0,.9],73:[0,.68611,0,0,.43611],74:[0,.68611,0,0,.59444],75:[0,.68611,0,0,.90138],76:[0,.68611,0,0,.69166],77:[0,.68611,0,0,1.09166],78:[0,.68611,0,0,.9],79:[0,.68611,0,0,.86388],80:[0,.68611,0,0,.78611],81:[.19444,.68611,0,0,.86388],82:[0,.68611,0,0,.8625],83:[0,.68611,0,0,.63889],84:[0,.68611,0,0,.8],85:[0,.68611,0,0,.88472],86:[0,.68611,.01597,0,.86944],87:[0,.68611,.01597,0,1.18888],88:[0,.68611,0,0,.86944],89:[0,.68611,.02875,0,.86944],90:[0,.68611,0,0,.70277],91:[.25,.75,0,0,.31944],92:[.25,.75,0,0,.575],93:[.25,.75,0,0,.31944],94:[0,.69444,0,0,.575],95:[.31,.13444,.03194,0,.575],97:[0,.44444,0,0,.55902],98:[0,.69444,0,0,.63889],99:[0,.44444,0,0,.51111],100:[0,.69444,0,0,.63889],101:[0,.44444,0,0,.52708],102:[0,.69444,.10903,0,.35139],103:[.19444,.44444,.01597,0,.575],104:[0,.69444,0,0,.63889],105:[0,.69444,0,0,.31944],106:[.19444,.69444,0,0,.35139],107:[0,.69444,0,0,.60694],108:[0,.69444,0,0,.31944],109:[0,.44444,0,0,.95833],110:[0,.44444,0,0,.63889],111:[0,.44444,0,0,.575],112:[.19444,.44444,0,0,.63889],113:[.19444,.44444,0,0,.60694],114:[0,.44444,0,0,.47361],115:[0,.44444,0,0,.45361],116:[0,.63492,0,0,.44722],117:[0,.44444,0,0,.63889],118:[0,.44444,.01597,0,.60694],119:[0,.44444,.01597,0,.83055],120:[0,.44444,0,0,.60694],121:[.19444,.44444,.01597,0,.60694],122:[0,.44444,0,0,.51111],123:[.25,.75,0,0,.575],124:[.25,.75,0,0,.31944],125:[.25,.75,0,0,.575],126:[.35,.34444,0,0,.575],160:[0,0,0,0,.25],163:[0,.69444,0,0,.86853],168:[0,.69444,0,0,.575],172:[0,.44444,0,0,.76666],176:[0,.69444,0,0,.86944],177:[.13333,.63333,0,0,.89444],184:[.17014,0,0,0,.51111],198:[0,.68611,0,0,1.04166],215:[.13333,.63333,0,0,.89444],216:[.04861,.73472,0,0,.89444],223:[0,.69444,0,0,.59722],230:[0,.44444,0,0,.83055],247:[.13333,.63333,0,0,.89444],248:[.09722,.54167,0,0,.575],305:[0,.44444,0,0,.31944],338:[0,.68611,0,0,1.16944],339:[0,.44444,0,0,.89444],567:[.19444,.44444,0,0,.35139],710:[0,.69444,0,0,.575],711:[0,.63194,0,0,.575],713:[0,.59611,0,0,.575],714:[0,.69444,0,0,.575],715:[0,.69444,0,0,.575],728:[0,.69444,0,0,.575],729:[0,.69444,0,0,.31944],730:[0,.69444,0,0,.86944],732:[0,.69444,0,0,.575],733:[0,.69444,0,0,.575],915:[0,.68611,0,0,.69166],916:[0,.68611,0,0,.95833],920:[0,.68611,0,0,.89444],923:[0,.68611,0,0,.80555],926:[0,.68611,0,0,.76666],928:[0,.68611,0,0,.9],931:[0,.68611,0,0,.83055],933:[0,.68611,0,0,.89444],934:[0,.68611,0,0,.83055],936:[0,.68611,0,0,.89444],937:[0,.68611,0,0,.83055],8211:[0,.44444,.03194,0,.575],8212:[0,.44444,.03194,0,1.14999],8216:[0,.69444,0,0,.31944],8217:[0,.69444,0,0,.31944],8220:[0,.69444,0,0,.60278],8221:[0,.69444,0,0,.60278],8224:[.19444,.69444,0,0,.51111],8225:[.19444,.69444,0,0,.51111],8242:[0,.55556,0,0,.34444],8407:[0,.72444,.15486,0,.575],8463:[0,.69444,0,0,.66759],8465:[0,.69444,0,0,.83055],8467:[0,.69444,0,0,.47361],8472:[.19444,.44444,0,0,.74027],8476:[0,.69444,0,0,.83055],8501:[0,.69444,0,0,.70277],8592:[-.10889,.39111,0,0,1.14999],8593:[.19444,.69444,0,0,.575],8594:[-.10889,.39111,0,0,1.14999],8595:[.19444,.69444,0,0,.575],8596:[-.10889,.39111,0,0,1.14999],8597:[.25,.75,0,0,.575],8598:[.19444,.69444,0,0,1.14999],8599:[.19444,.69444,0,0,1.14999],8600:[.19444,.69444,0,0,1.14999],8601:[.19444,.69444,0,0,1.14999],8636:[-.10889,.39111,0,0,1.14999],8637:[-.10889,.39111,0,0,1.14999],8640:[-.10889,.39111,0,0,1.14999],8641:[-.10889,.39111,0,0,1.14999],8656:[-.10889,.39111,0,0,1.14999],8657:[.19444,.69444,0,0,.70277],8658:[-.10889,.39111,0,0,1.14999],8659:[.19444,.69444,0,0,.70277],8660:[-.10889,.39111,0,0,1.14999],8661:[.25,.75,0,0,.70277],8704:[0,.69444,0,0,.63889],8706:[0,.69444,.06389,0,.62847],8707:[0,.69444,0,0,.63889],8709:[.05556,.75,0,0,.575],8711:[0,.68611,0,0,.95833],8712:[.08556,.58556,0,0,.76666],8715:[.08556,.58556,0,0,.76666],8722:[.13333,.63333,0,0,.89444],8723:[.13333,.63333,0,0,.89444],8725:[.25,.75,0,0,.575],8726:[.25,.75,0,0,.575],8727:[-.02778,.47222,0,0,.575],8728:[-.02639,.47361,0,0,.575],8729:[-.02639,.47361,0,0,.575],8730:[.18,.82,0,0,.95833],8733:[0,.44444,0,0,.89444],8734:[0,.44444,0,0,1.14999],8736:[0,.69224,0,0,.72222],8739:[.25,.75,0,0,.31944],8741:[.25,.75,0,0,.575],8743:[0,.55556,0,0,.76666],8744:[0,.55556,0,0,.76666],8745:[0,.55556,0,0,.76666],8746:[0,.55556,0,0,.76666],8747:[.19444,.69444,.12778,0,.56875],8764:[-.10889,.39111,0,0,.89444],8768:[.19444,.69444,0,0,.31944],8771:[.00222,.50222,0,0,.89444],8773:[.027,.638,0,0,.894],8776:[.02444,.52444,0,0,.89444],8781:[.00222,.50222,0,0,.89444],8801:[.00222,.50222,0,0,.89444],8804:[.19667,.69667,0,0,.89444],8805:[.19667,.69667,0,0,.89444],8810:[.08556,.58556,0,0,1.14999],8811:[.08556,.58556,0,0,1.14999],8826:[.08556,.58556,0,0,.89444],8827:[.08556,.58556,0,0,.89444],8834:[.08556,.58556,0,0,.89444],8835:[.08556,.58556,0,0,.89444],8838:[.19667,.69667,0,0,.89444],8839:[.19667,.69667,0,0,.89444],8846:[0,.55556,0,0,.76666],8849:[.19667,.69667,0,0,.89444],8850:[.19667,.69667,0,0,.89444],8851:[0,.55556,0,0,.76666],8852:[0,.55556,0,0,.76666],8853:[.13333,.63333,0,0,.89444],8854:[.13333,.63333,0,0,.89444],8855:[.13333,.63333,0,0,.89444],8856:[.13333,.63333,0,0,.89444],8857:[.13333,.63333,0,0,.89444],8866:[0,.69444,0,0,.70277],8867:[0,.69444,0,0,.70277],8868:[0,.69444,0,0,.89444],8869:[0,.69444,0,0,.89444],8900:[-.02639,.47361,0,0,.575],8901:[-.02639,.47361,0,0,.31944],8902:[-.02778,.47222,0,0,.575],8968:[.25,.75,0,0,.51111],8969:[.25,.75,0,0,.51111],8970:[.25,.75,0,0,.51111],8971:[.25,.75,0,0,.51111],8994:[-.13889,.36111,0,0,1.14999],8995:[-.13889,.36111,0,0,1.14999],9651:[.19444,.69444,0,0,1.02222],9657:[-.02778,.47222,0,0,.575],9661:[.19444,.69444,0,0,1.02222],9667:[-.02778,.47222,0,0,.575],9711:[.19444,.69444,0,0,1.14999],9824:[.12963,.69444,0,0,.89444],9825:[.12963,.69444,0,0,.89444],9826:[.12963,.69444,0,0,.89444],9827:[.12963,.69444,0,0,.89444],9837:[0,.75,0,0,.44722],9838:[.19444,.69444,0,0,.44722],9839:[.19444,.69444,0,0,.44722],10216:[.25,.75,0,0,.44722],10217:[.25,.75,0,0,.44722],10815:[0,.68611,0,0,.9],10927:[.19667,.69667,0,0,.89444],10928:[.19667,.69667,0,0,.89444],57376:[.19444,.69444,0,0,0]},"Main-BoldItalic":{32:[0,0,0,0,.25],33:[0,.69444,.11417,0,.38611],34:[0,.69444,.07939,0,.62055],35:[.19444,.69444,.06833,0,.94444],37:[.05556,.75,.12861,0,.94444],38:[0,.69444,.08528,0,.88555],39:[0,.69444,.12945,0,.35555],40:[.25,.75,.15806,0,.47333],41:[.25,.75,.03306,0,.47333],42:[0,.75,.14333,0,.59111],43:[.10333,.60333,.03306,0,.88555],44:[.19444,.14722,0,0,.35555],45:[0,.44444,.02611,0,.41444],46:[0,.14722,0,0,.35555],47:[.25,.75,.15806,0,.59111],48:[0,.64444,.13167,0,.59111],49:[0,.64444,.13167,0,.59111],50:[0,.64444,.13167,0,.59111],51:[0,.64444,.13167,0,.59111],52:[.19444,.64444,.13167,0,.59111],53:[0,.64444,.13167,0,.59111],54:[0,.64444,.13167,0,.59111],55:[.19444,.64444,.13167,0,.59111],56:[0,.64444,.13167,0,.59111],57:[0,.64444,.13167,0,.59111],58:[0,.44444,.06695,0,.35555],59:[.19444,.44444,.06695,0,.35555],61:[-.10889,.39111,.06833,0,.88555],63:[0,.69444,.11472,0,.59111],64:[0,.69444,.09208,0,.88555],65:[0,.68611,0,0,.86555],66:[0,.68611,.0992,0,.81666],67:[0,.68611,.14208,0,.82666],68:[0,.68611,.09062,0,.87555],69:[0,.68611,.11431,0,.75666],70:[0,.68611,.12903,0,.72722],71:[0,.68611,.07347,0,.89527],72:[0,.68611,.17208,0,.8961],73:[0,.68611,.15681,0,.47166],74:[0,.68611,.145,0,.61055],75:[0,.68611,.14208,0,.89499],76:[0,.68611,0,0,.69777],77:[0,.68611,.17208,0,1.07277],78:[0,.68611,.17208,0,.8961],79:[0,.68611,.09062,0,.85499],80:[0,.68611,.0992,0,.78721],81:[.19444,.68611,.09062,0,.85499],82:[0,.68611,.02559,0,.85944],83:[0,.68611,.11264,0,.64999],84:[0,.68611,.12903,0,.7961],85:[0,.68611,.17208,0,.88083],86:[0,.68611,.18625,0,.86555],87:[0,.68611,.18625,0,1.15999],88:[0,.68611,.15681,0,.86555],89:[0,.68611,.19803,0,.86555],90:[0,.68611,.14208,0,.70888],91:[.25,.75,.1875,0,.35611],93:[.25,.75,.09972,0,.35611],94:[0,.69444,.06709,0,.59111],95:[.31,.13444,.09811,0,.59111],97:[0,.44444,.09426,0,.59111],98:[0,.69444,.07861,0,.53222],99:[0,.44444,.05222,0,.53222],100:[0,.69444,.10861,0,.59111],101:[0,.44444,.085,0,.53222],102:[.19444,.69444,.21778,0,.4],103:[.19444,.44444,.105,0,.53222],104:[0,.69444,.09426,0,.59111],105:[0,.69326,.11387,0,.35555],106:[.19444,.69326,.1672,0,.35555],107:[0,.69444,.11111,0,.53222],108:[0,.69444,.10861,0,.29666],109:[0,.44444,.09426,0,.94444],110:[0,.44444,.09426,0,.64999],111:[0,.44444,.07861,0,.59111],112:[.19444,.44444,.07861,0,.59111],113:[.19444,.44444,.105,0,.53222],114:[0,.44444,.11111,0,.50167],115:[0,.44444,.08167,0,.48694],116:[0,.63492,.09639,0,.385],117:[0,.44444,.09426,0,.62055],118:[0,.44444,.11111,0,.53222],119:[0,.44444,.11111,0,.76777],120:[0,.44444,.12583,0,.56055],121:[.19444,.44444,.105,0,.56166],122:[0,.44444,.13889,0,.49055],126:[.35,.34444,.11472,0,.59111],160:[0,0,0,0,.25],168:[0,.69444,.11473,0,.59111],176:[0,.69444,0,0,.94888],184:[.17014,0,0,0,.53222],198:[0,.68611,.11431,0,1.02277],216:[.04861,.73472,.09062,0,.88555],223:[.19444,.69444,.09736,0,.665],230:[0,.44444,.085,0,.82666],248:[.09722,.54167,.09458,0,.59111],305:[0,.44444,.09426,0,.35555],338:[0,.68611,.11431,0,1.14054],339:[0,.44444,.085,0,.82666],567:[.19444,.44444,.04611,0,.385],710:[0,.69444,.06709,0,.59111],711:[0,.63194,.08271,0,.59111],713:[0,.59444,.10444,0,.59111],714:[0,.69444,.08528,0,.59111],715:[0,.69444,0,0,.59111],728:[0,.69444,.10333,0,.59111],729:[0,.69444,.12945,0,.35555],730:[0,.69444,0,0,.94888],732:[0,.69444,.11472,0,.59111],733:[0,.69444,.11472,0,.59111],915:[0,.68611,.12903,0,.69777],916:[0,.68611,0,0,.94444],920:[0,.68611,.09062,0,.88555],923:[0,.68611,0,0,.80666],926:[0,.68611,.15092,0,.76777],928:[0,.68611,.17208,0,.8961],931:[0,.68611,.11431,0,.82666],933:[0,.68611,.10778,0,.88555],934:[0,.68611,.05632,0,.82666],936:[0,.68611,.10778,0,.88555],937:[0,.68611,.0992,0,.82666],8211:[0,.44444,.09811,0,.59111],8212:[0,.44444,.09811,0,1.18221],8216:[0,.69444,.12945,0,.35555],8217:[0,.69444,.12945,0,.35555],8220:[0,.69444,.16772,0,.62055],8221:[0,.69444,.07939,0,.62055]},"Main-Italic":{32:[0,0,0,0,.25],33:[0,.69444,.12417,0,.30667],34:[0,.69444,.06961,0,.51444],35:[.19444,.69444,.06616,0,.81777],37:[.05556,.75,.13639,0,.81777],38:[0,.69444,.09694,0,.76666],39:[0,.69444,.12417,0,.30667],40:[.25,.75,.16194,0,.40889],41:[.25,.75,.03694,0,.40889],42:[0,.75,.14917,0,.51111],43:[.05667,.56167,.03694,0,.76666],44:[.19444,.10556,0,0,.30667],45:[0,.43056,.02826,0,.35778],46:[0,.10556,0,0,.30667],47:[.25,.75,.16194,0,.51111],48:[0,.64444,.13556,0,.51111],49:[0,.64444,.13556,0,.51111],50:[0,.64444,.13556,0,.51111],51:[0,.64444,.13556,0,.51111],52:[.19444,.64444,.13556,0,.51111],53:[0,.64444,.13556,0,.51111],54:[0,.64444,.13556,0,.51111],55:[.19444,.64444,.13556,0,.51111],56:[0,.64444,.13556,0,.51111],57:[0,.64444,.13556,0,.51111],58:[0,.43056,.0582,0,.30667],59:[.19444,.43056,.0582,0,.30667],61:[-.13313,.36687,.06616,0,.76666],63:[0,.69444,.1225,0,.51111],64:[0,.69444,.09597,0,.76666],65:[0,.68333,0,0,.74333],66:[0,.68333,.10257,0,.70389],67:[0,.68333,.14528,0,.71555],68:[0,.68333,.09403,0,.755],69:[0,.68333,.12028,0,.67833],70:[0,.68333,.13305,0,.65277],71:[0,.68333,.08722,0,.77361],72:[0,.68333,.16389,0,.74333],73:[0,.68333,.15806,0,.38555],74:[0,.68333,.14028,0,.525],75:[0,.68333,.14528,0,.76888],76:[0,.68333,0,0,.62722],77:[0,.68333,.16389,0,.89666],78:[0,.68333,.16389,0,.74333],79:[0,.68333,.09403,0,.76666],80:[0,.68333,.10257,0,.67833],81:[.19444,.68333,.09403,0,.76666],82:[0,.68333,.03868,0,.72944],83:[0,.68333,.11972,0,.56222],84:[0,.68333,.13305,0,.71555],85:[0,.68333,.16389,0,.74333],86:[0,.68333,.18361,0,.74333],87:[0,.68333,.18361,0,.99888],88:[0,.68333,.15806,0,.74333],89:[0,.68333,.19383,0,.74333],90:[0,.68333,.14528,0,.61333],91:[.25,.75,.1875,0,.30667],93:[.25,.75,.10528,0,.30667],94:[0,.69444,.06646,0,.51111],95:[.31,.12056,.09208,0,.51111],97:[0,.43056,.07671,0,.51111],98:[0,.69444,.06312,0,.46],99:[0,.43056,.05653,0,.46],100:[0,.69444,.10333,0,.51111],101:[0,.43056,.07514,0,.46],102:[.19444,.69444,.21194,0,.30667],103:[.19444,.43056,.08847,0,.46],104:[0,.69444,.07671,0,.51111],105:[0,.65536,.1019,0,.30667],106:[.19444,.65536,.14467,0,.30667],107:[0,.69444,.10764,0,.46],108:[0,.69444,.10333,0,.25555],109:[0,.43056,.07671,0,.81777],110:[0,.43056,.07671,0,.56222],111:[0,.43056,.06312,0,.51111],112:[.19444,.43056,.06312,0,.51111],113:[.19444,.43056,.08847,0,.46],114:[0,.43056,.10764,0,.42166],115:[0,.43056,.08208,0,.40889],116:[0,.61508,.09486,0,.33222],117:[0,.43056,.07671,0,.53666],118:[0,.43056,.10764,0,.46],119:[0,.43056,.10764,0,.66444],120:[0,.43056,.12042,0,.46389],121:[.19444,.43056,.08847,0,.48555],122:[0,.43056,.12292,0,.40889],126:[.35,.31786,.11585,0,.51111],160:[0,0,0,0,.25],168:[0,.66786,.10474,0,.51111],176:[0,.69444,0,0,.83129],184:[.17014,0,0,0,.46],198:[0,.68333,.12028,0,.88277],216:[.04861,.73194,.09403,0,.76666],223:[.19444,.69444,.10514,0,.53666],230:[0,.43056,.07514,0,.71555],248:[.09722,.52778,.09194,0,.51111],338:[0,.68333,.12028,0,.98499],339:[0,.43056,.07514,0,.71555],710:[0,.69444,.06646,0,.51111],711:[0,.62847,.08295,0,.51111],713:[0,.56167,.10333,0,.51111],714:[0,.69444,.09694,0,.51111],715:[0,.69444,0,0,.51111],728:[0,.69444,.10806,0,.51111],729:[0,.66786,.11752,0,.30667],730:[0,.69444,0,0,.83129],732:[0,.66786,.11585,0,.51111],733:[0,.69444,.1225,0,.51111],915:[0,.68333,.13305,0,.62722],916:[0,.68333,0,0,.81777],920:[0,.68333,.09403,0,.76666],923:[0,.68333,0,0,.69222],926:[0,.68333,.15294,0,.66444],928:[0,.68333,.16389,0,.74333],931:[0,.68333,.12028,0,.71555],933:[0,.68333,.11111,0,.76666],934:[0,.68333,.05986,0,.71555],936:[0,.68333,.11111,0,.76666],937:[0,.68333,.10257,0,.71555],8211:[0,.43056,.09208,0,.51111],8212:[0,.43056,.09208,0,1.02222],8216:[0,.69444,.12417,0,.30667],8217:[0,.69444,.12417,0,.30667],8220:[0,.69444,.1685,0,.51444],8221:[0,.69444,.06961,0,.51444],8463:[0,.68889,0,0,.54028]},"Main-Regular":{32:[0,0,0,0,.25],33:[0,.69444,0,0,.27778],34:[0,.69444,0,0,.5],35:[.19444,.69444,0,0,.83334],36:[.05556,.75,0,0,.5],37:[.05556,.75,0,0,.83334],38:[0,.69444,0,0,.77778],39:[0,.69444,0,0,.27778],40:[.25,.75,0,0,.38889],41:[.25,.75,0,0,.38889],42:[0,.75,0,0,.5],43:[.08333,.58333,0,0,.77778],44:[.19444,.10556,0,0,.27778],45:[0,.43056,0,0,.33333],46:[0,.10556,0,0,.27778],47:[.25,.75,0,0,.5],48:[0,.64444,0,0,.5],49:[0,.64444,0,0,.5],50:[0,.64444,0,0,.5],51:[0,.64444,0,0,.5],52:[0,.64444,0,0,.5],53:[0,.64444,0,0,.5],54:[0,.64444,0,0,.5],55:[0,.64444,0,0,.5],56:[0,.64444,0,0,.5],57:[0,.64444,0,0,.5],58:[0,.43056,0,0,.27778],59:[.19444,.43056,0,0,.27778],60:[.0391,.5391,0,0,.77778],61:[-.13313,.36687,0,0,.77778],62:[.0391,.5391,0,0,.77778],63:[0,.69444,0,0,.47222],64:[0,.69444,0,0,.77778],65:[0,.68333,0,0,.75],66:[0,.68333,0,0,.70834],67:[0,.68333,0,0,.72222],68:[0,.68333,0,0,.76389],69:[0,.68333,0,0,.68056],70:[0,.68333,0,0,.65278],71:[0,.68333,0,0,.78472],72:[0,.68333,0,0,.75],73:[0,.68333,0,0,.36111],74:[0,.68333,0,0,.51389],75:[0,.68333,0,0,.77778],76:[0,.68333,0,0,.625],77:[0,.68333,0,0,.91667],78:[0,.68333,0,0,.75],79:[0,.68333,0,0,.77778],80:[0,.68333,0,0,.68056],81:[.19444,.68333,0,0,.77778],82:[0,.68333,0,0,.73611],83:[0,.68333,0,0,.55556],84:[0,.68333,0,0,.72222],85:[0,.68333,0,0,.75],86:[0,.68333,.01389,0,.75],87:[0,.68333,.01389,0,1.02778],88:[0,.68333,0,0,.75],89:[0,.68333,.025,0,.75],90:[0,.68333,0,0,.61111],91:[.25,.75,0,0,.27778],92:[.25,.75,0,0,.5],93:[.25,.75,0,0,.27778],94:[0,.69444,0,0,.5],95:[.31,.12056,.02778,0,.5],97:[0,.43056,0,0,.5],98:[0,.69444,0,0,.55556],99:[0,.43056,0,0,.44445],100:[0,.69444,0,0,.55556],101:[0,.43056,0,0,.44445],102:[0,.69444,.07778,0,.30556],103:[.19444,.43056,.01389,0,.5],104:[0,.69444,0,0,.55556],105:[0,.66786,0,0,.27778],106:[.19444,.66786,0,0,.30556],107:[0,.69444,0,0,.52778],108:[0,.69444,0,0,.27778],109:[0,.43056,0,0,.83334],110:[0,.43056,0,0,.55556],111:[0,.43056,0,0,.5],112:[.19444,.43056,0,0,.55556],113:[.19444,.43056,0,0,.52778],114:[0,.43056,0,0,.39167],115:[0,.43056,0,0,.39445],116:[0,.61508,0,0,.38889],117:[0,.43056,0,0,.55556],118:[0,.43056,.01389,0,.52778],119:[0,.43056,.01389,0,.72222],120:[0,.43056,0,0,.52778],121:[.19444,.43056,.01389,0,.52778],122:[0,.43056,0,0,.44445],123:[.25,.75,0,0,.5],124:[.25,.75,0,0,.27778],125:[.25,.75,0,0,.5],126:[.35,.31786,0,0,.5],160:[0,0,0,0,.25],163:[0,.69444,0,0,.76909],167:[.19444,.69444,0,0,.44445],168:[0,.66786,0,0,.5],172:[0,.43056,0,0,.66667],176:[0,.69444,0,0,.75],177:[.08333,.58333,0,0,.77778],182:[.19444,.69444,0,0,.61111],184:[.17014,0,0,0,.44445],198:[0,.68333,0,0,.90278],215:[.08333,.58333,0,0,.77778],216:[.04861,.73194,0,0,.77778],223:[0,.69444,0,0,.5],230:[0,.43056,0,0,.72222],247:[.08333,.58333,0,0,.77778],248:[.09722,.52778,0,0,.5],305:[0,.43056,0,0,.27778],338:[0,.68333,0,0,1.01389],339:[0,.43056,0,0,.77778],567:[.19444,.43056,0,0,.30556],710:[0,.69444,0,0,.5],711:[0,.62847,0,0,.5],713:[0,.56778,0,0,.5],714:[0,.69444,0,0,.5],715:[0,.69444,0,0,.5],728:[0,.69444,0,0,.5],729:[0,.66786,0,0,.27778],730:[0,.69444,0,0,.75],732:[0,.66786,0,0,.5],733:[0,.69444,0,0,.5],915:[0,.68333,0,0,.625],916:[0,.68333,0,0,.83334],920:[0,.68333,0,0,.77778],923:[0,.68333,0,0,.69445],926:[0,.68333,0,0,.66667],928:[0,.68333,0,0,.75],931:[0,.68333,0,0,.72222],933:[0,.68333,0,0,.77778],934:[0,.68333,0,0,.72222],936:[0,.68333,0,0,.77778],937:[0,.68333,0,0,.72222],8211:[0,.43056,.02778,0,.5],8212:[0,.43056,.02778,0,1],8216:[0,.69444,0,0,.27778],8217:[0,.69444,0,0,.27778],8220:[0,.69444,0,0,.5],8221:[0,.69444,0,0,.5],8224:[.19444,.69444,0,0,.44445],8225:[.19444,.69444,0,0,.44445],8230:[0,.123,0,0,1.172],8242:[0,.55556,0,0,.275],8407:[0,.71444,.15382,0,.5],8463:[0,.68889,0,0,.54028],8465:[0,.69444,0,0,.72222],8467:[0,.69444,0,.11111,.41667],8472:[.19444,.43056,0,.11111,.63646],8476:[0,.69444,0,0,.72222],8501:[0,.69444,0,0,.61111],8592:[-.13313,.36687,0,0,1],8593:[.19444,.69444,0,0,.5],8594:[-.13313,.36687,0,0,1],8595:[.19444,.69444,0,0,.5],8596:[-.13313,.36687,0,0,1],8597:[.25,.75,0,0,.5],8598:[.19444,.69444,0,0,1],8599:[.19444,.69444,0,0,1],8600:[.19444,.69444,0,0,1],8601:[.19444,.69444,0,0,1],8614:[.011,.511,0,0,1],8617:[.011,.511,0,0,1.126],8618:[.011,.511,0,0,1.126],8636:[-.13313,.36687,0,0,1],8637:[-.13313,.36687,0,0,1],8640:[-.13313,.36687,0,0,1],8641:[-.13313,.36687,0,0,1],8652:[.011,.671,0,0,1],8656:[-.13313,.36687,0,0,1],8657:[.19444,.69444,0,0,.61111],8658:[-.13313,.36687,0,0,1],8659:[.19444,.69444,0,0,.61111],8660:[-.13313,.36687,0,0,1],8661:[.25,.75,0,0,.61111],8704:[0,.69444,0,0,.55556],8706:[0,.69444,.05556,.08334,.5309],8707:[0,.69444,0,0,.55556],8709:[.05556,.75,0,0,.5],8711:[0,.68333,0,0,.83334],8712:[.0391,.5391,0,0,.66667],8715:[.0391,.5391,0,0,.66667],8722:[.08333,.58333,0,0,.77778],8723:[.08333,.58333,0,0,.77778],8725:[.25,.75,0,0,.5],8726:[.25,.75,0,0,.5],8727:[-.03472,.46528,0,0,.5],8728:[-.05555,.44445,0,0,.5],8729:[-.05555,.44445,0,0,.5],8730:[.2,.8,0,0,.83334],8733:[0,.43056,0,0,.77778],8734:[0,.43056,0,0,1],8736:[0,.69224,0,0,.72222],8739:[.25,.75,0,0,.27778],8741:[.25,.75,0,0,.5],8743:[0,.55556,0,0,.66667],8744:[0,.55556,0,0,.66667],8745:[0,.55556,0,0,.66667],8746:[0,.55556,0,0,.66667],8747:[.19444,.69444,.11111,0,.41667],8764:[-.13313,.36687,0,0,.77778],8768:[.19444,.69444,0,0,.27778],8771:[-.03625,.46375,0,0,.77778],8773:[-.022,.589,0,0,.778],8776:[-.01688,.48312,0,0,.77778],8781:[-.03625,.46375,0,0,.77778],8784:[-.133,.673,0,0,.778],8801:[-.03625,.46375,0,0,.77778],8804:[.13597,.63597,0,0,.77778],8805:[.13597,.63597,0,0,.77778],8810:[.0391,.5391,0,0,1],8811:[.0391,.5391,0,0,1],8826:[.0391,.5391,0,0,.77778],8827:[.0391,.5391,0,0,.77778],8834:[.0391,.5391,0,0,.77778],8835:[.0391,.5391,0,0,.77778],8838:[.13597,.63597,0,0,.77778],8839:[.13597,.63597,0,0,.77778],8846:[0,.55556,0,0,.66667],8849:[.13597,.63597,0,0,.77778],8850:[.13597,.63597,0,0,.77778],8851:[0,.55556,0,0,.66667],8852:[0,.55556,0,0,.66667],8853:[.08333,.58333,0,0,.77778],8854:[.08333,.58333,0,0,.77778],8855:[.08333,.58333,0,0,.77778],8856:[.08333,.58333,0,0,.77778],8857:[.08333,.58333,0,0,.77778],8866:[0,.69444,0,0,.61111],8867:[0,.69444,0,0,.61111],8868:[0,.69444,0,0,.77778],8869:[0,.69444,0,0,.77778],8872:[.249,.75,0,0,.867],8900:[-.05555,.44445,0,0,.5],8901:[-.05555,.44445,0,0,.27778],8902:[-.03472,.46528,0,0,.5],8904:[.005,.505,0,0,.9],8942:[.03,.903,0,0,.278],8943:[-.19,.313,0,0,1.172],8945:[-.1,.823,0,0,1.282],8968:[.25,.75,0,0,.44445],8969:[.25,.75,0,0,.44445],8970:[.25,.75,0,0,.44445],8971:[.25,.75,0,0,.44445],8994:[-.14236,.35764,0,0,1],8995:[-.14236,.35764,0,0,1],9136:[.244,.744,0,0,.412],9137:[.244,.745,0,0,.412],9651:[.19444,.69444,0,0,.88889],9657:[-.03472,.46528,0,0,.5],9661:[.19444,.69444,0,0,.88889],9667:[-.03472,.46528,0,0,.5],9711:[.19444,.69444,0,0,1],9824:[.12963,.69444,0,0,.77778],9825:[.12963,.69444,0,0,.77778],9826:[.12963,.69444,0,0,.77778],9827:[.12963,.69444,0,0,.77778],9837:[0,.75,0,0,.38889],9838:[.19444,.69444,0,0,.38889],9839:[.19444,.69444,0,0,.38889],10216:[.25,.75,0,0,.38889],10217:[.25,.75,0,0,.38889],10222:[.244,.744,0,0,.412],10223:[.244,.745,0,0,.412],10229:[.011,.511,0,0,1.609],10230:[.011,.511,0,0,1.638],10231:[.011,.511,0,0,1.859],10232:[.024,.525,0,0,1.609],10233:[.024,.525,0,0,1.638],10234:[.024,.525,0,0,1.858],10236:[.011,.511,0,0,1.638],10815:[0,.68333,0,0,.75],10927:[.13597,.63597,0,0,.77778],10928:[.13597,.63597,0,0,.77778],57376:[.19444,.69444,0,0,0]},"Math-BoldItalic":{32:[0,0,0,0,.25],48:[0,.44444,0,0,.575],49:[0,.44444,0,0,.575],50:[0,.44444,0,0,.575],51:[.19444,.44444,0,0,.575],52:[.19444,.44444,0,0,.575],53:[.19444,.44444,0,0,.575],54:[0,.64444,0,0,.575],55:[.19444,.44444,0,0,.575],56:[0,.64444,0,0,.575],57:[.19444,.44444,0,0,.575],65:[0,.68611,0,0,.86944],66:[0,.68611,.04835,0,.8664],67:[0,.68611,.06979,0,.81694],68:[0,.68611,.03194,0,.93812],69:[0,.68611,.05451,0,.81007],70:[0,.68611,.15972,0,.68889],71:[0,.68611,0,0,.88673],72:[0,.68611,.08229,0,.98229],73:[0,.68611,.07778,0,.51111],74:[0,.68611,.10069,0,.63125],75:[0,.68611,.06979,0,.97118],76:[0,.68611,0,0,.75555],77:[0,.68611,.11424,0,1.14201],78:[0,.68611,.11424,0,.95034],79:[0,.68611,.03194,0,.83666],80:[0,.68611,.15972,0,.72309],81:[.19444,.68611,0,0,.86861],82:[0,.68611,.00421,0,.87235],83:[0,.68611,.05382,0,.69271],84:[0,.68611,.15972,0,.63663],85:[0,.68611,.11424,0,.80027],86:[0,.68611,.25555,0,.67778],87:[0,.68611,.15972,0,1.09305],88:[0,.68611,.07778,0,.94722],89:[0,.68611,.25555,0,.67458],90:[0,.68611,.06979,0,.77257],97:[0,.44444,0,0,.63287],98:[0,.69444,0,0,.52083],99:[0,.44444,0,0,.51342],100:[0,.69444,0,0,.60972],101:[0,.44444,0,0,.55361],102:[.19444,.69444,.11042,0,.56806],103:[.19444,.44444,.03704,0,.5449],104:[0,.69444,0,0,.66759],105:[0,.69326,0,0,.4048],106:[.19444,.69326,.0622,0,.47083],107:[0,.69444,.01852,0,.6037],108:[0,.69444,.0088,0,.34815],109:[0,.44444,0,0,1.0324],110:[0,.44444,0,0,.71296],111:[0,.44444,0,0,.58472],112:[.19444,.44444,0,0,.60092],113:[.19444,.44444,.03704,0,.54213],114:[0,.44444,.03194,0,.5287],115:[0,.44444,0,0,.53125],116:[0,.63492,0,0,.41528],117:[0,.44444,0,0,.68102],118:[0,.44444,.03704,0,.56666],119:[0,.44444,.02778,0,.83148],120:[0,.44444,0,0,.65903],121:[.19444,.44444,.03704,0,.59028],122:[0,.44444,.04213,0,.55509],160:[0,0,0,0,.25],915:[0,.68611,.15972,0,.65694],916:[0,.68611,0,0,.95833],920:[0,.68611,.03194,0,.86722],923:[0,.68611,0,0,.80555],926:[0,.68611,.07458,0,.84125],928:[0,.68611,.08229,0,.98229],931:[0,.68611,.05451,0,.88507],933:[0,.68611,.15972,0,.67083],934:[0,.68611,0,0,.76666],936:[0,.68611,.11653,0,.71402],937:[0,.68611,.04835,0,.8789],945:[0,.44444,0,0,.76064],946:[.19444,.69444,.03403,0,.65972],947:[.19444,.44444,.06389,0,.59003],948:[0,.69444,.03819,0,.52222],949:[0,.44444,0,0,.52882],950:[.19444,.69444,.06215,0,.50833],951:[.19444,.44444,.03704,0,.6],952:[0,.69444,.03194,0,.5618],953:[0,.44444,0,0,.41204],954:[0,.44444,0,0,.66759],955:[0,.69444,0,0,.67083],956:[.19444,.44444,0,0,.70787],957:[0,.44444,.06898,0,.57685],958:[.19444,.69444,.03021,0,.50833],959:[0,.44444,0,0,.58472],960:[0,.44444,.03704,0,.68241],961:[.19444,.44444,0,0,.6118],962:[.09722,.44444,.07917,0,.42361],963:[0,.44444,.03704,0,.68588],964:[0,.44444,.13472,0,.52083],965:[0,.44444,.03704,0,.63055],966:[.19444,.44444,0,0,.74722],967:[.19444,.44444,0,0,.71805],968:[.19444,.69444,.03704,0,.75833],969:[0,.44444,.03704,0,.71782],977:[0,.69444,0,0,.69155],981:[.19444,.69444,0,0,.7125],982:[0,.44444,.03194,0,.975],1009:[.19444,.44444,0,0,.6118],1013:[0,.44444,0,0,.48333],57649:[0,.44444,0,0,.39352],57911:[.19444,.44444,0,0,.43889]},"Math-Italic":{32:[0,0,0,0,.25],48:[0,.43056,0,0,.5],49:[0,.43056,0,0,.5],50:[0,.43056,0,0,.5],51:[.19444,.43056,0,0,.5],52:[.19444,.43056,0,0,.5],53:[.19444,.43056,0,0,.5],54:[0,.64444,0,0,.5],55:[.19444,.43056,0,0,.5],56:[0,.64444,0,0,.5],57:[.19444,.43056,0,0,.5],65:[0,.68333,0,.13889,.75],66:[0,.68333,.05017,.08334,.75851],67:[0,.68333,.07153,.08334,.71472],68:[0,.68333,.02778,.05556,.82792],69:[0,.68333,.05764,.08334,.7382],70:[0,.68333,.13889,.08334,.64306],71:[0,.68333,0,.08334,.78625],72:[0,.68333,.08125,.05556,.83125],73:[0,.68333,.07847,.11111,.43958],74:[0,.68333,.09618,.16667,.55451],75:[0,.68333,.07153,.05556,.84931],76:[0,.68333,0,.02778,.68056],77:[0,.68333,.10903,.08334,.97014],78:[0,.68333,.10903,.08334,.80347],79:[0,.68333,.02778,.08334,.76278],80:[0,.68333,.13889,.08334,.64201],81:[.19444,.68333,0,.08334,.79056],82:[0,.68333,.00773,.08334,.75929],83:[0,.68333,.05764,.08334,.6132],84:[0,.68333,.13889,.08334,.58438],85:[0,.68333,.10903,.02778,.68278],86:[0,.68333,.22222,0,.58333],87:[0,.68333,.13889,0,.94445],88:[0,.68333,.07847,.08334,.82847],89:[0,.68333,.22222,0,.58056],90:[0,.68333,.07153,.08334,.68264],97:[0,.43056,0,0,.52859],98:[0,.69444,0,0,.42917],99:[0,.43056,0,.05556,.43276],100:[0,.69444,0,.16667,.52049],101:[0,.43056,0,.05556,.46563],102:[.19444,.69444,.10764,.16667,.48959],103:[.19444,.43056,.03588,.02778,.47697],104:[0,.69444,0,0,.57616],105:[0,.65952,0,0,.34451],106:[.19444,.65952,.05724,0,.41181],107:[0,.69444,.03148,0,.5206],108:[0,.69444,.01968,.08334,.29838],109:[0,.43056,0,0,.87801],110:[0,.43056,0,0,.60023],111:[0,.43056,0,.05556,.48472],112:[.19444,.43056,0,.08334,.50313],113:[.19444,.43056,.03588,.08334,.44641],114:[0,.43056,.02778,.05556,.45116],115:[0,.43056,0,.05556,.46875],116:[0,.61508,0,.08334,.36111],117:[0,.43056,0,.02778,.57246],118:[0,.43056,.03588,.02778,.48472],119:[0,.43056,.02691,.08334,.71592],120:[0,.43056,0,.02778,.57153],121:[.19444,.43056,.03588,.05556,.49028],122:[0,.43056,.04398,.05556,.46505],160:[0,0,0,0,.25],915:[0,.68333,.13889,.08334,.61528],916:[0,.68333,0,.16667,.83334],920:[0,.68333,.02778,.08334,.76278],923:[0,.68333,0,.16667,.69445],926:[0,.68333,.07569,.08334,.74236],928:[0,.68333,.08125,.05556,.83125],931:[0,.68333,.05764,.08334,.77986],933:[0,.68333,.13889,.05556,.58333],934:[0,.68333,0,.08334,.66667],936:[0,.68333,.11,.05556,.61222],937:[0,.68333,.05017,.08334,.7724],945:[0,.43056,.0037,.02778,.6397],946:[.19444,.69444,.05278,.08334,.56563],947:[.19444,.43056,.05556,0,.51773],948:[0,.69444,.03785,.05556,.44444],949:[0,.43056,0,.08334,.46632],950:[.19444,.69444,.07378,.08334,.4375],951:[.19444,.43056,.03588,.05556,.49653],952:[0,.69444,.02778,.08334,.46944],953:[0,.43056,0,.05556,.35394],954:[0,.43056,0,0,.57616],955:[0,.69444,0,0,.58334],956:[.19444,.43056,0,.02778,.60255],957:[0,.43056,.06366,.02778,.49398],958:[.19444,.69444,.04601,.11111,.4375],959:[0,.43056,0,.05556,.48472],960:[0,.43056,.03588,0,.57003],961:[.19444,.43056,0,.08334,.51702],962:[.09722,.43056,.07986,.08334,.36285],963:[0,.43056,.03588,0,.57141],964:[0,.43056,.1132,.02778,.43715],965:[0,.43056,.03588,.02778,.54028],966:[.19444,.43056,0,.08334,.65417],967:[.19444,.43056,0,.05556,.62569],968:[.19444,.69444,.03588,.11111,.65139],969:[0,.43056,.03588,0,.62245],977:[0,.69444,0,.08334,.59144],981:[.19444,.69444,0,.08334,.59583],982:[0,.43056,.02778,0,.82813],1009:[.19444,.43056,0,.08334,.51702],1013:[0,.43056,0,.05556,.4059],57649:[0,.43056,0,.02778,.32246],57911:[.19444,.43056,0,.08334,.38403]},"SansSerif-Bold":{32:[0,0,0,0,.25],33:[0,.69444,0,0,.36667],34:[0,.69444,0,0,.55834],35:[.19444,.69444,0,0,.91667],36:[.05556,.75,0,0,.55],37:[.05556,.75,0,0,1.02912],38:[0,.69444,0,0,.83056],39:[0,.69444,0,0,.30556],40:[.25,.75,0,0,.42778],41:[.25,.75,0,0,.42778],42:[0,.75,0,0,.55],43:[.11667,.61667,0,0,.85556],44:[.10556,.13056,0,0,.30556],45:[0,.45833,0,0,.36667],46:[0,.13056,0,0,.30556],47:[.25,.75,0,0,.55],48:[0,.69444,0,0,.55],49:[0,.69444,0,0,.55],50:[0,.69444,0,0,.55],51:[0,.69444,0,0,.55],52:[0,.69444,0,0,.55],53:[0,.69444,0,0,.55],54:[0,.69444,0,0,.55],55:[0,.69444,0,0,.55],56:[0,.69444,0,0,.55],57:[0,.69444,0,0,.55],58:[0,.45833,0,0,.30556],59:[.10556,.45833,0,0,.30556],61:[-.09375,.40625,0,0,.85556],63:[0,.69444,0,0,.51945],64:[0,.69444,0,0,.73334],65:[0,.69444,0,0,.73334],66:[0,.69444,0,0,.73334],67:[0,.69444,0,0,.70278],68:[0,.69444,0,0,.79445],69:[0,.69444,0,0,.64167],70:[0,.69444,0,0,.61111],71:[0,.69444,0,0,.73334],72:[0,.69444,0,0,.79445],73:[0,.69444,0,0,.33056],74:[0,.69444,0,0,.51945],75:[0,.69444,0,0,.76389],76:[0,.69444,0,0,.58056],77:[0,.69444,0,0,.97778],78:[0,.69444,0,0,.79445],79:[0,.69444,0,0,.79445],80:[0,.69444,0,0,.70278],81:[.10556,.69444,0,0,.79445],82:[0,.69444,0,0,.70278],83:[0,.69444,0,0,.61111],84:[0,.69444,0,0,.73334],85:[0,.69444,0,0,.76389],86:[0,.69444,.01528,0,.73334],87:[0,.69444,.01528,0,1.03889],88:[0,.69444,0,0,.73334],89:[0,.69444,.0275,0,.73334],90:[0,.69444,0,0,.67223],91:[.25,.75,0,0,.34306],93:[.25,.75,0,0,.34306],94:[0,.69444,0,0,.55],95:[.35,.10833,.03056,0,.55],97:[0,.45833,0,0,.525],98:[0,.69444,0,0,.56111],99:[0,.45833,0,0,.48889],100:[0,.69444,0,0,.56111],101:[0,.45833,0,0,.51111],102:[0,.69444,.07639,0,.33611],103:[.19444,.45833,.01528,0,.55],104:[0,.69444,0,0,.56111],105:[0,.69444,0,0,.25556],106:[.19444,.69444,0,0,.28611],107:[0,.69444,0,0,.53056],108:[0,.69444,0,0,.25556],109:[0,.45833,0,0,.86667],110:[0,.45833,0,0,.56111],111:[0,.45833,0,0,.55],112:[.19444,.45833,0,0,.56111],113:[.19444,.45833,0,0,.56111],114:[0,.45833,.01528,0,.37222],115:[0,.45833,0,0,.42167],116:[0,.58929,0,0,.40417],117:[0,.45833,0,0,.56111],118:[0,.45833,.01528,0,.5],119:[0,.45833,.01528,0,.74445],120:[0,.45833,0,0,.5],121:[.19444,.45833,.01528,0,.5],122:[0,.45833,0,0,.47639],126:[.35,.34444,0,0,.55],160:[0,0,0,0,.25],168:[0,.69444,0,0,.55],176:[0,.69444,0,0,.73334],180:[0,.69444,0,0,.55],184:[.17014,0,0,0,.48889],305:[0,.45833,0,0,.25556],567:[.19444,.45833,0,0,.28611],710:[0,.69444,0,0,.55],711:[0,.63542,0,0,.55],713:[0,.63778,0,0,.55],728:[0,.69444,0,0,.55],729:[0,.69444,0,0,.30556],730:[0,.69444,0,0,.73334],732:[0,.69444,0,0,.55],733:[0,.69444,0,0,.55],915:[0,.69444,0,0,.58056],916:[0,.69444,0,0,.91667],920:[0,.69444,0,0,.85556],923:[0,.69444,0,0,.67223],926:[0,.69444,0,0,.73334],928:[0,.69444,0,0,.79445],931:[0,.69444,0,0,.79445],933:[0,.69444,0,0,.85556],934:[0,.69444,0,0,.79445],936:[0,.69444,0,0,.85556],937:[0,.69444,0,0,.79445],8211:[0,.45833,.03056,0,.55],8212:[0,.45833,.03056,0,1.10001],8216:[0,.69444,0,0,.30556],8217:[0,.69444,0,0,.30556],8220:[0,.69444,0,0,.55834],8221:[0,.69444,0,0,.55834]},"SansSerif-Italic":{32:[0,0,0,0,.25],33:[0,.69444,.05733,0,.31945],34:[0,.69444,.00316,0,.5],35:[.19444,.69444,.05087,0,.83334],36:[.05556,.75,.11156,0,.5],37:[.05556,.75,.03126,0,.83334],38:[0,.69444,.03058,0,.75834],39:[0,.69444,.07816,0,.27778],40:[.25,.75,.13164,0,.38889],41:[.25,.75,.02536,0,.38889],42:[0,.75,.11775,0,.5],43:[.08333,.58333,.02536,0,.77778],44:[.125,.08333,0,0,.27778],45:[0,.44444,.01946,0,.33333],46:[0,.08333,0,0,.27778],47:[.25,.75,.13164,0,.5],48:[0,.65556,.11156,0,.5],49:[0,.65556,.11156,0,.5],50:[0,.65556,.11156,0,.5],51:[0,.65556,.11156,0,.5],52:[0,.65556,.11156,0,.5],53:[0,.65556,.11156,0,.5],54:[0,.65556,.11156,0,.5],55:[0,.65556,.11156,0,.5],56:[0,.65556,.11156,0,.5],57:[0,.65556,.11156,0,.5],58:[0,.44444,.02502,0,.27778],59:[.125,.44444,.02502,0,.27778],61:[-.13,.37,.05087,0,.77778],63:[0,.69444,.11809,0,.47222],64:[0,.69444,.07555,0,.66667],65:[0,.69444,0,0,.66667],66:[0,.69444,.08293,0,.66667],67:[0,.69444,.11983,0,.63889],68:[0,.69444,.07555,0,.72223],69:[0,.69444,.11983,0,.59722],70:[0,.69444,.13372,0,.56945],71:[0,.69444,.11983,0,.66667],72:[0,.69444,.08094,0,.70834],73:[0,.69444,.13372,0,.27778],74:[0,.69444,.08094,0,.47222],75:[0,.69444,.11983,0,.69445],76:[0,.69444,0,0,.54167],77:[0,.69444,.08094,0,.875],78:[0,.69444,.08094,0,.70834],79:[0,.69444,.07555,0,.73611],80:[0,.69444,.08293,0,.63889],81:[.125,.69444,.07555,0,.73611],82:[0,.69444,.08293,0,.64584],83:[0,.69444,.09205,0,.55556],84:[0,.69444,.13372,0,.68056],85:[0,.69444,.08094,0,.6875],86:[0,.69444,.1615,0,.66667],87:[0,.69444,.1615,0,.94445],88:[0,.69444,.13372,0,.66667],89:[0,.69444,.17261,0,.66667],90:[0,.69444,.11983,0,.61111],91:[.25,.75,.15942,0,.28889],93:[.25,.75,.08719,0,.28889],94:[0,.69444,.0799,0,.5],95:[.35,.09444,.08616,0,.5],97:[0,.44444,.00981,0,.48056],98:[0,.69444,.03057,0,.51667],99:[0,.44444,.08336,0,.44445],100:[0,.69444,.09483,0,.51667],101:[0,.44444,.06778,0,.44445],102:[0,.69444,.21705,0,.30556],103:[.19444,.44444,.10836,0,.5],104:[0,.69444,.01778,0,.51667],105:[0,.67937,.09718,0,.23889],106:[.19444,.67937,.09162,0,.26667],107:[0,.69444,.08336,0,.48889],108:[0,.69444,.09483,0,.23889],109:[0,.44444,.01778,0,.79445],110:[0,.44444,.01778,0,.51667],111:[0,.44444,.06613,0,.5],112:[.19444,.44444,.0389,0,.51667],113:[.19444,.44444,.04169,0,.51667],114:[0,.44444,.10836,0,.34167],115:[0,.44444,.0778,0,.38333],116:[0,.57143,.07225,0,.36111],117:[0,.44444,.04169,0,.51667],118:[0,.44444,.10836,0,.46111],119:[0,.44444,.10836,0,.68334],120:[0,.44444,.09169,0,.46111],121:[.19444,.44444,.10836,0,.46111],122:[0,.44444,.08752,0,.43472],126:[.35,.32659,.08826,0,.5],160:[0,0,0,0,.25],168:[0,.67937,.06385,0,.5],176:[0,.69444,0,0,.73752],184:[.17014,0,0,0,.44445],305:[0,.44444,.04169,0,.23889],567:[.19444,.44444,.04169,0,.26667],710:[0,.69444,.0799,0,.5],711:[0,.63194,.08432,0,.5],713:[0,.60889,.08776,0,.5],714:[0,.69444,.09205,0,.5],715:[0,.69444,0,0,.5],728:[0,.69444,.09483,0,.5],729:[0,.67937,.07774,0,.27778],730:[0,.69444,0,0,.73752],732:[0,.67659,.08826,0,.5],733:[0,.69444,.09205,0,.5],915:[0,.69444,.13372,0,.54167],916:[0,.69444,0,0,.83334],920:[0,.69444,.07555,0,.77778],923:[0,.69444,0,0,.61111],926:[0,.69444,.12816,0,.66667],928:[0,.69444,.08094,0,.70834],931:[0,.69444,.11983,0,.72222],933:[0,.69444,.09031,0,.77778],934:[0,.69444,.04603,0,.72222],936:[0,.69444,.09031,0,.77778],937:[0,.69444,.08293,0,.72222],8211:[0,.44444,.08616,0,.5],8212:[0,.44444,.08616,0,1],8216:[0,.69444,.07816,0,.27778],8217:[0,.69444,.07816,0,.27778],8220:[0,.69444,.14205,0,.5],8221:[0,.69444,.00316,0,.5]},"SansSerif-Regular":{32:[0,0,0,0,.25],33:[0,.69444,0,0,.31945],34:[0,.69444,0,0,.5],35:[.19444,.69444,0,0,.83334],36:[.05556,.75,0,0,.5],37:[.05556,.75,0,0,.83334],38:[0,.69444,0,0,.75834],39:[0,.69444,0,0,.27778],40:[.25,.75,0,0,.38889],41:[.25,.75,0,0,.38889],42:[0,.75,0,0,.5],43:[.08333,.58333,0,0,.77778],44:[.125,.08333,0,0,.27778],45:[0,.44444,0,0,.33333],46:[0,.08333,0,0,.27778],47:[.25,.75,0,0,.5],48:[0,.65556,0,0,.5],49:[0,.65556,0,0,.5],50:[0,.65556,0,0,.5],51:[0,.65556,0,0,.5],52:[0,.65556,0,0,.5],53:[0,.65556,0,0,.5],54:[0,.65556,0,0,.5],55:[0,.65556,0,0,.5],56:[0,.65556,0,0,.5],57:[0,.65556,0,0,.5],58:[0,.44444,0,0,.27778],59:[.125,.44444,0,0,.27778],61:[-.13,.37,0,0,.77778],63:[0,.69444,0,0,.47222],64:[0,.69444,0,0,.66667],65:[0,.69444,0,0,.66667],66:[0,.69444,0,0,.66667],67:[0,.69444,0,0,.63889],68:[0,.69444,0,0,.72223],69:[0,.69444,0,0,.59722],70:[0,.69444,0,0,.56945],71:[0,.69444,0,0,.66667],72:[0,.69444,0,0,.70834],73:[0,.69444,0,0,.27778],74:[0,.69444,0,0,.47222],75:[0,.69444,0,0,.69445],76:[0,.69444,0,0,.54167],77:[0,.69444,0,0,.875],78:[0,.69444,0,0,.70834],79:[0,.69444,0,0,.73611],80:[0,.69444,0,0,.63889],81:[.125,.69444,0,0,.73611],82:[0,.69444,0,0,.64584],83:[0,.69444,0,0,.55556],84:[0,.69444,0,0,.68056],85:[0,.69444,0,0,.6875],86:[0,.69444,.01389,0,.66667],87:[0,.69444,.01389,0,.94445],88:[0,.69444,0,0,.66667],89:[0,.69444,.025,0,.66667],90:[0,.69444,0,0,.61111],91:[.25,.75,0,0,.28889],93:[.25,.75,0,0,.28889],94:[0,.69444,0,0,.5],95:[.35,.09444,.02778,0,.5],97:[0,.44444,0,0,.48056],98:[0,.69444,0,0,.51667],99:[0,.44444,0,0,.44445],100:[0,.69444,0,0,.51667],101:[0,.44444,0,0,.44445],102:[0,.69444,.06944,0,.30556],103:[.19444,.44444,.01389,0,.5],104:[0,.69444,0,0,.51667],105:[0,.67937,0,0,.23889],106:[.19444,.67937,0,0,.26667],107:[0,.69444,0,0,.48889],108:[0,.69444,0,0,.23889],109:[0,.44444,0,0,.79445],110:[0,.44444,0,0,.51667],111:[0,.44444,0,0,.5],112:[.19444,.44444,0,0,.51667],113:[.19444,.44444,0,0,.51667],114:[0,.44444,.01389,0,.34167],115:[0,.44444,0,0,.38333],116:[0,.57143,0,0,.36111],117:[0,.44444,0,0,.51667],118:[0,.44444,.01389,0,.46111],119:[0,.44444,.01389,0,.68334],120:[0,.44444,0,0,.46111],121:[.19444,.44444,.01389,0,.46111],122:[0,.44444,0,0,.43472],126:[.35,.32659,0,0,.5],160:[0,0,0,0,.25],168:[0,.67937,0,0,.5],176:[0,.69444,0,0,.66667],184:[.17014,0,0,0,.44445],305:[0,.44444,0,0,.23889],567:[.19444,.44444,0,0,.26667],710:[0,.69444,0,0,.5],711:[0,.63194,0,0,.5],713:[0,.60889,0,0,.5],714:[0,.69444,0,0,.5],715:[0,.69444,0,0,.5],728:[0,.69444,0,0,.5],729:[0,.67937,0,0,.27778],730:[0,.69444,0,0,.66667],732:[0,.67659,0,0,.5],733:[0,.69444,0,0,.5],915:[0,.69444,0,0,.54167],916:[0,.69444,0,0,.83334],920:[0,.69444,0,0,.77778],923:[0,.69444,0,0,.61111],926:[0,.69444,0,0,.66667],928:[0,.69444,0,0,.70834],931:[0,.69444,0,0,.72222],933:[0,.69444,0,0,.77778],934:[0,.69444,0,0,.72222],936:[0,.69444,0,0,.77778],937:[0,.69444,0,0,.72222],8211:[0,.44444,.02778,0,.5],8212:[0,.44444,.02778,0,1],8216:[0,.69444,0,0,.27778],8217:[0,.69444,0,0,.27778],8220:[0,.69444,0,0,.5],8221:[0,.69444,0,0,.5]},"Script-Regular":{32:[0,0,0,0,.25],65:[0,.7,.22925,0,.80253],66:[0,.7,.04087,0,.90757],67:[0,.7,.1689,0,.66619],68:[0,.7,.09371,0,.77443],69:[0,.7,.18583,0,.56162],70:[0,.7,.13634,0,.89544],71:[0,.7,.17322,0,.60961],72:[0,.7,.29694,0,.96919],73:[0,.7,.19189,0,.80907],74:[.27778,.7,.19189,0,1.05159],75:[0,.7,.31259,0,.91364],76:[0,.7,.19189,0,.87373],77:[0,.7,.15981,0,1.08031],78:[0,.7,.3525,0,.9015],79:[0,.7,.08078,0,.73787],80:[0,.7,.08078,0,1.01262],81:[0,.7,.03305,0,.88282],82:[0,.7,.06259,0,.85],83:[0,.7,.19189,0,.86767],84:[0,.7,.29087,0,.74697],85:[0,.7,.25815,0,.79996],86:[0,.7,.27523,0,.62204],87:[0,.7,.27523,0,.80532],88:[0,.7,.26006,0,.94445],89:[0,.7,.2939,0,.70961],90:[0,.7,.24037,0,.8212],160:[0,0,0,0,.25]},"Size1-Regular":{32:[0,0,0,0,.25],40:[.35001,.85,0,0,.45834],41:[.35001,.85,0,0,.45834],47:[.35001,.85,0,0,.57778],91:[.35001,.85,0,0,.41667],92:[.35001,.85,0,0,.57778],93:[.35001,.85,0,0,.41667],123:[.35001,.85,0,0,.58334],125:[.35001,.85,0,0,.58334],160:[0,0,0,0,.25],710:[0,.72222,0,0,.55556],732:[0,.72222,0,0,.55556],770:[0,.72222,0,0,.55556],771:[0,.72222,0,0,.55556],8214:[-99e-5,.601,0,0,.77778],8593:[1e-5,.6,0,0,.66667],8595:[1e-5,.6,0,0,.66667],8657:[1e-5,.6,0,0,.77778],8659:[1e-5,.6,0,0,.77778],8719:[.25001,.75,0,0,.94445],8720:[.25001,.75,0,0,.94445],8721:[.25001,.75,0,0,1.05556],8730:[.35001,.85,0,0,1],8739:[-.00599,.606,0,0,.33333],8741:[-.00599,.606,0,0,.55556],8747:[.30612,.805,.19445,0,.47222],8748:[.306,.805,.19445,0,.47222],8749:[.306,.805,.19445,0,.47222],8750:[.30612,.805,.19445,0,.47222],8896:[.25001,.75,0,0,.83334],8897:[.25001,.75,0,0,.83334],8898:[.25001,.75,0,0,.83334],8899:[.25001,.75,0,0,.83334],8968:[.35001,.85,0,0,.47222],8969:[.35001,.85,0,0,.47222],8970:[.35001,.85,0,0,.47222],8971:[.35001,.85,0,0,.47222],9168:[-99e-5,.601,0,0,.66667],10216:[.35001,.85,0,0,.47222],10217:[.35001,.85,0,0,.47222],10752:[.25001,.75,0,0,1.11111],10753:[.25001,.75,0,0,1.11111],10754:[.25001,.75,0,0,1.11111],10756:[.25001,.75,0,0,.83334],10758:[.25001,.75,0,0,.83334]},"Size2-Regular":{32:[0,0,0,0,.25],40:[.65002,1.15,0,0,.59722],41:[.65002,1.15,0,0,.59722],47:[.65002,1.15,0,0,.81111],91:[.65002,1.15,0,0,.47222],92:[.65002,1.15,0,0,.81111],93:[.65002,1.15,0,0,.47222],123:[.65002,1.15,0,0,.66667],125:[.65002,1.15,0,0,.66667],160:[0,0,0,0,.25],710:[0,.75,0,0,1],732:[0,.75,0,0,1],770:[0,.75,0,0,1],771:[0,.75,0,0,1],8719:[.55001,1.05,0,0,1.27778],8720:[.55001,1.05,0,0,1.27778],8721:[.55001,1.05,0,0,1.44445],8730:[.65002,1.15,0,0,1],8747:[.86225,1.36,.44445,0,.55556],8748:[.862,1.36,.44445,0,.55556],8749:[.862,1.36,.44445,0,.55556],8750:[.86225,1.36,.44445,0,.55556],8896:[.55001,1.05,0,0,1.11111],8897:[.55001,1.05,0,0,1.11111],8898:[.55001,1.05,0,0,1.11111],8899:[.55001,1.05,0,0,1.11111],8968:[.65002,1.15,0,0,.52778],8969:[.65002,1.15,0,0,.52778],8970:[.65002,1.15,0,0,.52778],8971:[.65002,1.15,0,0,.52778],10216:[.65002,1.15,0,0,.61111],10217:[.65002,1.15,0,0,.61111],10752:[.55001,1.05,0,0,1.51112],10753:[.55001,1.05,0,0,1.51112],10754:[.55001,1.05,0,0,1.51112],10756:[.55001,1.05,0,0,1.11111],10758:[.55001,1.05,0,0,1.11111]},"Size3-Regular":{32:[0,0,0,0,.25],40:[.95003,1.45,0,0,.73611],41:[.95003,1.45,0,0,.73611],47:[.95003,1.45,0,0,1.04445],91:[.95003,1.45,0,0,.52778],92:[.95003,1.45,0,0,1.04445],93:[.95003,1.45,0,0,.52778],123:[.95003,1.45,0,0,.75],125:[.95003,1.45,0,0,.75],160:[0,0,0,0,.25],710:[0,.75,0,0,1.44445],732:[0,.75,0,0,1.44445],770:[0,.75,0,0,1.44445],771:[0,.75,0,0,1.44445],8730:[.95003,1.45,0,0,1],8968:[.95003,1.45,0,0,.58334],8969:[.95003,1.45,0,0,.58334],8970:[.95003,1.45,0,0,.58334],8971:[.95003,1.45,0,0,.58334],10216:[.95003,1.45,0,0,.75],10217:[.95003,1.45,0,0,.75]},"Size4-Regular":{32:[0,0,0,0,.25],40:[1.25003,1.75,0,0,.79167],41:[1.25003,1.75,0,0,.79167],47:[1.25003,1.75,0,0,1.27778],91:[1.25003,1.75,0,0,.58334],92:[1.25003,1.75,0,0,1.27778],93:[1.25003,1.75,0,0,.58334],123:[1.25003,1.75,0,0,.80556],125:[1.25003,1.75,0,0,.80556],160:[0,0,0,0,.25],710:[0,.825,0,0,1.8889],732:[0,.825,0,0,1.8889],770:[0,.825,0,0,1.8889],771:[0,.825,0,0,1.8889],8730:[1.25003,1.75,0,0,1],8968:[1.25003,1.75,0,0,.63889],8969:[1.25003,1.75,0,0,.63889],8970:[1.25003,1.75,0,0,.63889],8971:[1.25003,1.75,0,0,.63889],9115:[.64502,1.155,0,0,.875],9116:[1e-5,.6,0,0,.875],9117:[.64502,1.155,0,0,.875],9118:[.64502,1.155,0,0,.875],9119:[1e-5,.6,0,0,.875],9120:[.64502,1.155,0,0,.875],9121:[.64502,1.155,0,0,.66667],9122:[-99e-5,.601,0,0,.66667],9123:[.64502,1.155,0,0,.66667],9124:[.64502,1.155,0,0,.66667],9125:[-99e-5,.601,0,0,.66667],9126:[.64502,1.155,0,0,.66667],9127:[1e-5,.9,0,0,.88889],9128:[.65002,1.15,0,0,.88889],9129:[.90001,0,0,0,.88889],9130:[0,.3,0,0,.88889],9131:[1e-5,.9,0,0,.88889],9132:[.65002,1.15,0,0,.88889],9133:[.90001,0,0,0,.88889],9143:[.88502,.915,0,0,1.05556],10216:[1.25003,1.75,0,0,.80556],10217:[1.25003,1.75,0,0,.80556],57344:[-.00499,.605,0,0,1.05556],57345:[-.00499,.605,0,0,1.05556],57680:[0,.12,0,0,.45],57681:[0,.12,0,0,.45],57682:[0,.12,0,0,.45],57683:[0,.12,0,0,.45]},"Typewriter-Regular":{32:[0,0,0,0,.525],33:[0,.61111,0,0,.525],34:[0,.61111,0,0,.525],35:[0,.61111,0,0,.525],36:[.08333,.69444,0,0,.525],37:[.08333,.69444,0,0,.525],38:[0,.61111,0,0,.525],39:[0,.61111,0,0,.525],40:[.08333,.69444,0,0,.525],41:[.08333,.69444,0,0,.525],42:[0,.52083,0,0,.525],43:[-.08056,.53055,0,0,.525],44:[.13889,.125,0,0,.525],45:[-.08056,.53055,0,0,.525],46:[0,.125,0,0,.525],47:[.08333,.69444,0,0,.525],48:[0,.61111,0,0,.525],49:[0,.61111,0,0,.525],50:[0,.61111,0,0,.525],51:[0,.61111,0,0,.525],52:[0,.61111,0,0,.525],53:[0,.61111,0,0,.525],54:[0,.61111,0,0,.525],55:[0,.61111,0,0,.525],56:[0,.61111,0,0,.525],57:[0,.61111,0,0,.525],58:[0,.43056,0,0,.525],59:[.13889,.43056,0,0,.525],60:[-.05556,.55556,0,0,.525],61:[-.19549,.41562,0,0,.525],62:[-.05556,.55556,0,0,.525],63:[0,.61111,0,0,.525],64:[0,.61111,0,0,.525],65:[0,.61111,0,0,.525],66:[0,.61111,0,0,.525],67:[0,.61111,0,0,.525],68:[0,.61111,0,0,.525],69:[0,.61111,0,0,.525],70:[0,.61111,0,0,.525],71:[0,.61111,0,0,.525],72:[0,.61111,0,0,.525],73:[0,.61111,0,0,.525],74:[0,.61111,0,0,.525],75:[0,.61111,0,0,.525],76:[0,.61111,0,0,.525],77:[0,.61111,0,0,.525],78:[0,.61111,0,0,.525],79:[0,.61111,0,0,.525],80:[0,.61111,0,0,.525],81:[.13889,.61111,0,0,.525],82:[0,.61111,0,0,.525],83:[0,.61111,0,0,.525],84:[0,.61111,0,0,.525],85:[0,.61111,0,0,.525],86:[0,.61111,0,0,.525],87:[0,.61111,0,0,.525],88:[0,.61111,0,0,.525],89:[0,.61111,0,0,.525],90:[0,.61111,0,0,.525],91:[.08333,.69444,0,0,.525],92:[.08333,.69444,0,0,.525],93:[.08333,.69444,0,0,.525],94:[0,.61111,0,0,.525],95:[.09514,0,0,0,.525],96:[0,.61111,0,0,.525],97:[0,.43056,0,0,.525],98:[0,.61111,0,0,.525],99:[0,.43056,0,0,.525],100:[0,.61111,0,0,.525],101:[0,.43056,0,0,.525],102:[0,.61111,0,0,.525],103:[.22222,.43056,0,0,.525],104:[0,.61111,0,0,.525],105:[0,.61111,0,0,.525],106:[.22222,.61111,0,0,.525],107:[0,.61111,0,0,.525],108:[0,.61111,0,0,.525],109:[0,.43056,0,0,.525],110:[0,.43056,0,0,.525],111:[0,.43056,0,0,.525],112:[.22222,.43056,0,0,.525],113:[.22222,.43056,0,0,.525],114:[0,.43056,0,0,.525],115:[0,.43056,0,0,.525],116:[0,.55358,0,0,.525],117:[0,.43056,0,0,.525],118:[0,.43056,0,0,.525],119:[0,.43056,0,0,.525],120:[0,.43056,0,0,.525],121:[.22222,.43056,0,0,.525],122:[0,.43056,0,0,.525],123:[.08333,.69444,0,0,.525],124:[.08333,.69444,0,0,.525],125:[.08333,.69444,0,0,.525],126:[0,.61111,0,0,.525],127:[0,.61111,0,0,.525],160:[0,0,0,0,.525],176:[0,.61111,0,0,.525],184:[.19445,0,0,0,.525],305:[0,.43056,0,0,.525],567:[.22222,.43056,0,0,.525],711:[0,.56597,0,0,.525],713:[0,.56555,0,0,.525],714:[0,.61111,0,0,.525],715:[0,.61111,0,0,.525],728:[0,.61111,0,0,.525],730:[0,.61111,0,0,.525],770:[0,.61111,0,0,.525],771:[0,.61111,0,0,.525],776:[0,.61111,0,0,.525],915:[0,.61111,0,0,.525],916:[0,.61111,0,0,.525],920:[0,.61111,0,0,.525],923:[0,.61111,0,0,.525],926:[0,.61111,0,0,.525],928:[0,.61111,0,0,.525],931:[0,.61111,0,0,.525],933:[0,.61111,0,0,.525],934:[0,.61111,0,0,.525],936:[0,.61111,0,0,.525],937:[0,.61111,0,0,.525],8216:[0,.61111,0,0,.525],8217:[0,.61111,0,0,.525],8242:[0,.61111,0,0,.525],9251:[.11111,.21944,0,0,.525]}},t0={slant:[.25,.25,.25],space:[0,0,0],stretch:[0,0,0],shrink:[0,0,0],xHeight:[.431,.431,.431],quad:[1,1.171,1.472],extraSpace:[0,0,0],num1:[.677,.732,.925],num2:[.394,.384,.387],num3:[.444,.471,.504],denom1:[.686,.752,1.025],denom2:[.345,.344,.532],sup1:[.413,.503,.504],sup2:[.363,.431,.404],sup3:[.289,.286,.294],sub1:[.15,.143,.2],sub2:[.247,.286,.4],supDrop:[.386,.353,.494],subDrop:[.05,.071,.1],delim1:[2.39,1.7,1.98],delim2:[1.01,1.157,1.42],axisHeight:[.25,.25,.25],defaultRuleThickness:[.04,.049,.049],bigOpSpacing1:[.111,.111,.111],bigOpSpacing2:[.166,.166,.166],bigOpSpacing3:[.2,.2,.2],bigOpSpacing4:[.6,.611,.611],bigOpSpacing5:[.1,.143,.143],sqrtRuleThickness:[.04,.04,.04],ptPerEm:[10,10,10],doubleRuleSep:[.2,.2,.2],arrayRuleWidth:[.04,.04,.04],fboxsep:[.3,.3,.3],fboxrule:[.04,.04,.04]},uN={Å:"A",Ð:"D",Þ:"o",å:"a",ð:"d",þ:"o",А:"A",Б:"B",В:"B",Г:"F",Д:"A",Е:"E",Ж:"K",З:"3",И:"N",Й:"N",К:"K",Л:"N",М:"M",Н:"H",О:"O",П:"N",Р:"P",С:"C",Т:"T",У:"y",Ф:"O",Х:"X",Ц:"U",Ч:"h",Ш:"W",Щ:"W",Ъ:"B",Ы:"X",Ь:"B",Э:"3",Ю:"X",Я:"R",а:"a",б:"b",в:"a",г:"r",д:"y",е:"e",ж:"m",з:"e",и:"n",й:"n",к:"n",л:"n",м:"m",н:"n",о:"o",п:"n",р:"p",с:"c",т:"o",у:"y",ф:"b",х:"x",ц:"n",ч:"n",ш:"w",щ:"w",ъ:"a",ы:"m",ь:"a",э:"e",ю:"m",я:"r"};function ED(e,t){Ti[e]=t}function YS(e,t,n){if(!Ti[t])throw new Error("Font metrics not found for font: "+t+".");var r=e.charCodeAt(0),a=Ti[t][r];if(!a&&e[0]in uN&&(r=uN[e[0]].charCodeAt(0),a=Ti[t][r]),!a&&n==="text"&&yD(r)&&(a=Ti[t][77]),a)return{depth:a[0],height:a[1],italic:a[2],skew:a[3],width:a[4]}}var dv={};function Dae(e){var t;if(e>=5?t=0:e>=3?t=1:t=2,!dv[t]){var n=dv[t]={cssEmPerMu:t0.quad[t]/18};for(var r in t0)t0.hasOwnProperty(r)&&(n[r]=t0[r][t])}return dv[t]}var Mae={bin:1,close:1,inner:1,open:1,punct:1,rel:1},Bae={"accent-token":1,mathord:1,"op-token":1,spacing:1,textord:1},yn={math:{},text:{}};function C(e,t,n,r,a,i){yn[e][a]={font:t,group:n,replace:r},i&&r&&(yn[e][r]=yn[e][a])}var O="math",ke="text",z="main",ee="ams",vn="accent-token",ze="bin",Pr="close",Su="inner",at="mathord",jn="op-token",xa="open",yg="punct",te="rel",No="spacing",se="textord";C(O,z,te,"≡","\\equiv",!0);C(O,z,te,"≺","\\prec",!0);C(O,z,te,"≻","\\succ",!0);C(O,z,te,"∼","\\sim",!0);C(O,z,te,"⊥","\\perp");C(O,z,te,"⪯","\\preceq",!0);C(O,z,te,"⪰","\\succeq",!0);C(O,z,te,"≃","\\simeq",!0);C(O,z,te,"∣","\\mid",!0);C(O,z,te,"≪","\\ll",!0);C(O,z,te,"≫","\\gg",!0);C(O,z,te,"≍","\\asymp",!0);C(O,z,te,"∥","\\parallel");C(O,z,te,"⋈","\\bowtie",!0);C(O,z,te,"⌣","\\smile",!0);C(O,z,te,"⊑","\\sqsubseteq",!0);C(O,z,te,"⊒","\\sqsupseteq",!0);C(O,z,te,"≐","\\doteq",!0);C(O,z,te,"⌢","\\frown",!0);C(O,z,te,"∋","\\ni",!0);C(O,z,te,"∝","\\propto",!0);C(O,z,te,"⊢","\\vdash",!0);C(O,z,te,"⊣","\\dashv",!0);C(O,z,te,"∋","\\owns");C(O,z,yg,".","\\ldotp");C(O,z,yg,"⋅","\\cdotp");C(O,z,se,"#","\\#");C(ke,z,se,"#","\\#");C(O,z,se,"&","\\&");C(ke,z,se,"&","\\&");C(O,z,se,"ℵ","\\aleph",!0);C(O,z,se,"∀","\\forall",!0);C(O,z,se,"ℏ","\\hbar",!0);C(O,z,se,"∃","\\exists",!0);C(O,z,se,"∇","\\nabla",!0);C(O,z,se,"♭","\\flat",!0);C(O,z,se,"ℓ","\\ell",!0);C(O,z,se,"♮","\\natural",!0);C(O,z,se,"♣","\\clubsuit",!0);C(O,z,se,"℘","\\wp",!0);C(O,z,se,"♯","\\sharp",!0);C(O,z,se,"♢","\\diamondsuit",!0);C(O,z,se,"ℜ","\\Re",!0);C(O,z,se,"♡","\\heartsuit",!0);C(O,z,se,"ℑ","\\Im",!0);C(O,z,se,"♠","\\spadesuit",!0);C(O,z,se,"§","\\S",!0);C(ke,z,se,"§","\\S");C(O,z,se,"¶","\\P",!0);C(ke,z,se,"¶","\\P");C(O,z,se,"†","\\dag");C(ke,z,se,"†","\\dag");C(ke,z,se,"†","\\textdagger");C(O,z,se,"‡","\\ddag");C(ke,z,se,"‡","\\ddag");C(ke,z,se,"‡","\\textdaggerdbl");C(O,z,Pr,"⎱","\\rmoustache",!0);C(O,z,xa,"⎰","\\lmoustache",!0);C(O,z,Pr,"⟯","\\rgroup",!0);C(O,z,xa,"⟮","\\lgroup",!0);C(O,z,ze,"∓","\\mp",!0);C(O,z,ze,"⊖","\\ominus",!0);C(O,z,ze,"⊎","\\uplus",!0);C(O,z,ze,"⊓","\\sqcap",!0);C(O,z,ze,"∗","\\ast");C(O,z,ze,"⊔","\\sqcup",!0);C(O,z,ze,"◯","\\bigcirc",!0);C(O,z,ze,"∙","\\bullet",!0);C(O,z,ze,"‡","\\ddagger");C(O,z,ze,"≀","\\wr",!0);C(O,z,ze,"⨿","\\amalg");C(O,z,ze,"&","\\And");C(O,z,te,"⟵","\\longleftarrow",!0);C(O,z,te,"⇐","\\Leftarrow",!0);C(O,z,te,"⟸","\\Longleftarrow",!0);C(O,z,te,"⟶","\\longrightarrow",!0);C(O,z,te,"⇒","\\Rightarrow",!0);C(O,z,te,"⟹","\\Longrightarrow",!0);C(O,z,te,"↔","\\leftrightarrow",!0);C(O,z,te,"⟷","\\longleftrightarrow",!0);C(O,z,te,"⇔","\\Leftrightarrow",!0);C(O,z,te,"⟺","\\Longleftrightarrow",!0);C(O,z,te,"↦","\\mapsto",!0);C(O,z,te,"⟼","\\longmapsto",!0);C(O,z,te,"↗","\\nearrow",!0);C(O,z,te,"↩","\\hookleftarrow",!0);C(O,z,te,"↪","\\hookrightarrow",!0);C(O,z,te,"↘","\\searrow",!0);C(O,z,te,"↼","\\leftharpoonup",!0);C(O,z,te,"⇀","\\rightharpoonup",!0);C(O,z,te,"↙","\\swarrow",!0);C(O,z,te,"↽","\\leftharpoondown",!0);C(O,z,te,"⇁","\\rightharpoondown",!0);C(O,z,te,"↖","\\nwarrow",!0);C(O,z,te,"⇌","\\rightleftharpoons",!0);C(O,ee,te,"≮","\\nless",!0);C(O,ee,te,"","\\@nleqslant");C(O,ee,te,"","\\@nleqq");C(O,ee,te,"⪇","\\lneq",!0);C(O,ee,te,"≨","\\lneqq",!0);C(O,ee,te,"","\\@lvertneqq");C(O,ee,te,"⋦","\\lnsim",!0);C(O,ee,te,"⪉","\\lnapprox",!0);C(O,ee,te,"⊀","\\nprec",!0);C(O,ee,te,"⋠","\\npreceq",!0);C(O,ee,te,"⋨","\\precnsim",!0);C(O,ee,te,"⪹","\\precnapprox",!0);C(O,ee,te,"≁","\\nsim",!0);C(O,ee,te,"","\\@nshortmid");C(O,ee,te,"∤","\\nmid",!0);C(O,ee,te,"⊬","\\nvdash",!0);C(O,ee,te,"⊭","\\nvDash",!0);C(O,ee,te,"⋪","\\ntriangleleft");C(O,ee,te,"⋬","\\ntrianglelefteq",!0);C(O,ee,te,"⊊","\\subsetneq",!0);C(O,ee,te,"","\\@varsubsetneq");C(O,ee,te,"⫋","\\subsetneqq",!0);C(O,ee,te,"","\\@varsubsetneqq");C(O,ee,te,"≯","\\ngtr",!0);C(O,ee,te,"","\\@ngeqslant");C(O,ee,te,"","\\@ngeqq");C(O,ee,te,"⪈","\\gneq",!0);C(O,ee,te,"≩","\\gneqq",!0);C(O,ee,te,"","\\@gvertneqq");C(O,ee,te,"⋧","\\gnsim",!0);C(O,ee,te,"⪊","\\gnapprox",!0);C(O,ee,te,"⊁","\\nsucc",!0);C(O,ee,te,"⋡","\\nsucceq",!0);C(O,ee,te,"⋩","\\succnsim",!0);C(O,ee,te,"⪺","\\succnapprox",!0);C(O,ee,te,"≆","\\ncong",!0);C(O,ee,te,"","\\@nshortparallel");C(O,ee,te,"∦","\\nparallel",!0);C(O,ee,te,"⊯","\\nVDash",!0);C(O,ee,te,"⋫","\\ntriangleright");C(O,ee,te,"⋭","\\ntrianglerighteq",!0);C(O,ee,te,"","\\@nsupseteqq");C(O,ee,te,"⊋","\\supsetneq",!0);C(O,ee,te,"","\\@varsupsetneq");C(O,ee,te,"⫌","\\supsetneqq",!0);C(O,ee,te,"","\\@varsupsetneqq");C(O,ee,te,"⊮","\\nVdash",!0);C(O,ee,te,"⪵","\\precneqq",!0);C(O,ee,te,"⪶","\\succneqq",!0);C(O,ee,te,"","\\@nsubseteqq");C(O,ee,ze,"⊴","\\unlhd");C(O,ee,ze,"⊵","\\unrhd");C(O,ee,te,"↚","\\nleftarrow",!0);C(O,ee,te,"↛","\\nrightarrow",!0);C(O,ee,te,"⇍","\\nLeftarrow",!0);C(O,ee,te,"⇏","\\nRightarrow",!0);C(O,ee,te,"↮","\\nleftrightarrow",!0);C(O,ee,te,"⇎","\\nLeftrightarrow",!0);C(O,ee,te,"△","\\vartriangle");C(O,ee,se,"ℏ","\\hslash");C(O,ee,se,"▽","\\triangledown");C(O,ee,se,"◊","\\lozenge");C(O,ee,se,"Ⓢ","\\circledS");C(O,ee,se,"®","\\circledR");C(ke,ee,se,"®","\\circledR");C(O,ee,se,"∡","\\measuredangle",!0);C(O,ee,se,"∄","\\nexists");C(O,ee,se,"℧","\\mho");C(O,ee,se,"Ⅎ","\\Finv",!0);C(O,ee,se,"⅁","\\Game",!0);C(O,ee,se,"‵","\\backprime");C(O,ee,se,"▲","\\blacktriangle");C(O,ee,se,"▼","\\blacktriangledown");C(O,ee,se,"■","\\blacksquare");C(O,ee,se,"⧫","\\blacklozenge");C(O,ee,se,"★","\\bigstar");C(O,ee,se,"∢","\\sphericalangle",!0);C(O,ee,se,"∁","\\complement",!0);C(O,ee,se,"ð","\\eth",!0);C(ke,z,se,"ð","ð");C(O,ee,se,"╱","\\diagup");C(O,ee,se,"╲","\\diagdown");C(O,ee,se,"□","\\square");C(O,ee,se,"□","\\Box");C(O,ee,se,"◊","\\Diamond");C(O,ee,se,"¥","\\yen",!0);C(ke,ee,se,"¥","\\yen",!0);C(O,ee,se,"✓","\\checkmark",!0);C(ke,ee,se,"✓","\\checkmark");C(O,ee,se,"ℶ","\\beth",!0);C(O,ee,se,"ℸ","\\daleth",!0);C(O,ee,se,"ℷ","\\gimel",!0);C(O,ee,se,"ϝ","\\digamma",!0);C(O,ee,se,"ϰ","\\varkappa");C(O,ee,xa,"┌","\\@ulcorner",!0);C(O,ee,Pr,"┐","\\@urcorner",!0);C(O,ee,xa,"└","\\@llcorner",!0);C(O,ee,Pr,"┘","\\@lrcorner",!0);C(O,ee,te,"≦","\\leqq",!0);C(O,ee,te,"⩽","\\leqslant",!0);C(O,ee,te,"⪕","\\eqslantless",!0);C(O,ee,te,"≲","\\lesssim",!0);C(O,ee,te,"⪅","\\lessapprox",!0);C(O,ee,te,"≊","\\approxeq",!0);C(O,ee,ze,"⋖","\\lessdot");C(O,ee,te,"⋘","\\lll",!0);C(O,ee,te,"≶","\\lessgtr",!0);C(O,ee,te,"⋚","\\lesseqgtr",!0);C(O,ee,te,"⪋","\\lesseqqgtr",!0);C(O,ee,te,"≑","\\doteqdot");C(O,ee,te,"≓","\\risingdotseq",!0);C(O,ee,te,"≒","\\fallingdotseq",!0);C(O,ee,te,"∽","\\backsim",!0);C(O,ee,te,"⋍","\\backsimeq",!0);C(O,ee,te,"⫅","\\subseteqq",!0);C(O,ee,te,"⋐","\\Subset",!0);C(O,ee,te,"⊏","\\sqsubset",!0);C(O,ee,te,"≼","\\preccurlyeq",!0);C(O,ee,te,"⋞","\\curlyeqprec",!0);C(O,ee,te,"≾","\\precsim",!0);C(O,ee,te,"⪷","\\precapprox",!0);C(O,ee,te,"⊲","\\vartriangleleft");C(O,ee,te,"⊴","\\trianglelefteq");C(O,ee,te,"⊨","\\vDash",!0);C(O,ee,te,"⊪","\\Vvdash",!0);C(O,ee,te,"⌣","\\smallsmile");C(O,ee,te,"⌢","\\smallfrown");C(O,ee,te,"≏","\\bumpeq",!0);C(O,ee,te,"≎","\\Bumpeq",!0);C(O,ee,te,"≧","\\geqq",!0);C(O,ee,te,"⩾","\\geqslant",!0);C(O,ee,te,"⪖","\\eqslantgtr",!0);C(O,ee,te,"≳","\\gtrsim",!0);C(O,ee,te,"⪆","\\gtrapprox",!0);C(O,ee,ze,"⋗","\\gtrdot");C(O,ee,te,"⋙","\\ggg",!0);C(O,ee,te,"≷","\\gtrless",!0);C(O,ee,te,"⋛","\\gtreqless",!0);C(O,ee,te,"⪌","\\gtreqqless",!0);C(O,ee,te,"≖","\\eqcirc",!0);C(O,ee,te,"≗","\\circeq",!0);C(O,ee,te,"≜","\\triangleq",!0);C(O,ee,te,"∼","\\thicksim");C(O,ee,te,"≈","\\thickapprox");C(O,ee,te,"⫆","\\supseteqq",!0);C(O,ee,te,"⋑","\\Supset",!0);C(O,ee,te,"⊐","\\sqsupset",!0);C(O,ee,te,"≽","\\succcurlyeq",!0);C(O,ee,te,"⋟","\\curlyeqsucc",!0);C(O,ee,te,"≿","\\succsim",!0);C(O,ee,te,"⪸","\\succapprox",!0);C(O,ee,te,"⊳","\\vartriangleright");C(O,ee,te,"⊵","\\trianglerighteq");C(O,ee,te,"⊩","\\Vdash",!0);C(O,ee,te,"∣","\\shortmid");C(O,ee,te,"∥","\\shortparallel");C(O,ee,te,"≬","\\between",!0);C(O,ee,te,"⋔","\\pitchfork",!0);C(O,ee,te,"∝","\\varpropto");C(O,ee,te,"◀","\\blacktriangleleft");C(O,ee,te,"∴","\\therefore",!0);C(O,ee,te,"∍","\\backepsilon");C(O,ee,te,"▶","\\blacktriangleright");C(O,ee,te,"∵","\\because",!0);C(O,ee,te,"⋘","\\llless");C(O,ee,te,"⋙","\\gggtr");C(O,ee,ze,"⊲","\\lhd");C(O,ee,ze,"⊳","\\rhd");C(O,ee,te,"≂","\\eqsim",!0);C(O,z,te,"⋈","\\Join");C(O,ee,te,"≑","\\Doteq",!0);C(O,ee,ze,"∔","\\dotplus",!0);C(O,ee,ze,"∖","\\smallsetminus");C(O,ee,ze,"⋒","\\Cap",!0);C(O,ee,ze,"⋓","\\Cup",!0);C(O,ee,ze,"⩞","\\doublebarwedge",!0);C(O,ee,ze,"⊟","\\boxminus",!0);C(O,ee,ze,"⊞","\\boxplus",!0);C(O,ee,ze,"⋇","\\divideontimes",!0);C(O,ee,ze,"⋉","\\ltimes",!0);C(O,ee,ze,"⋊","\\rtimes",!0);C(O,ee,ze,"⋋","\\leftthreetimes",!0);C(O,ee,ze,"⋌","\\rightthreetimes",!0);C(O,ee,ze,"⋏","\\curlywedge",!0);C(O,ee,ze,"⋎","\\curlyvee",!0);C(O,ee,ze,"⊝","\\circleddash",!0);C(O,ee,ze,"⊛","\\circledast",!0);C(O,ee,ze,"⋅","\\centerdot");C(O,ee,ze,"⊺","\\intercal",!0);C(O,ee,ze,"⋒","\\doublecap");C(O,ee,ze,"⋓","\\doublecup");C(O,ee,ze,"⊠","\\boxtimes",!0);C(O,ee,te,"⇢","\\dashrightarrow",!0);C(O,ee,te,"⇠","\\dashleftarrow",!0);C(O,ee,te,"⇇","\\leftleftarrows",!0);C(O,ee,te,"⇆","\\leftrightarrows",!0);C(O,ee,te,"⇚","\\Lleftarrow",!0);C(O,ee,te,"↞","\\twoheadleftarrow",!0);C(O,ee,te,"↢","\\leftarrowtail",!0);C(O,ee,te,"↫","\\looparrowleft",!0);C(O,ee,te,"⇋","\\leftrightharpoons",!0);C(O,ee,te,"↶","\\curvearrowleft",!0);C(O,ee,te,"↺","\\circlearrowleft",!0);C(O,ee,te,"↰","\\Lsh",!0);C(O,ee,te,"⇈","\\upuparrows",!0);C(O,ee,te,"↿","\\upharpoonleft",!0);C(O,ee,te,"⇃","\\downharpoonleft",!0);C(O,z,te,"⊶","\\origof",!0);C(O,z,te,"⊷","\\imageof",!0);C(O,ee,te,"⊸","\\multimap",!0);C(O,ee,te,"↭","\\leftrightsquigarrow",!0);C(O,ee,te,"⇉","\\rightrightarrows",!0);C(O,ee,te,"⇄","\\rightleftarrows",!0);C(O,ee,te,"↠","\\twoheadrightarrow",!0);C(O,ee,te,"↣","\\rightarrowtail",!0);C(O,ee,te,"↬","\\looparrowright",!0);C(O,ee,te,"↷","\\curvearrowright",!0);C(O,ee,te,"↻","\\circlearrowright",!0);C(O,ee,te,"↱","\\Rsh",!0);C(O,ee,te,"⇊","\\downdownarrows",!0);C(O,ee,te,"↾","\\upharpoonright",!0);C(O,ee,te,"⇂","\\downharpoonright",!0);C(O,ee,te,"⇝","\\rightsquigarrow",!0);C(O,ee,te,"⇝","\\leadsto");C(O,ee,te,"⇛","\\Rrightarrow",!0);C(O,ee,te,"↾","\\restriction");C(O,z,se,"‘","`");C(O,z,se,"$","\\$");C(ke,z,se,"$","\\$");C(ke,z,se,"$","\\textdollar");C(O,z,se,"%","\\%");C(ke,z,se,"%","\\%");C(O,z,se,"_","\\_");C(ke,z,se,"_","\\_");C(ke,z,se,"_","\\textunderscore");C(O,z,se,"∠","\\angle",!0);C(O,z,se,"∞","\\infty",!0);C(O,z,se,"′","\\prime");C(O,z,se,"△","\\triangle");C(O,z,se,"Γ","\\Gamma",!0);C(O,z,se,"Δ","\\Delta",!0);C(O,z,se,"Θ","\\Theta",!0);C(O,z,se,"Λ","\\Lambda",!0);C(O,z,se,"Ξ","\\Xi",!0);C(O,z,se,"Π","\\Pi",!0);C(O,z,se,"Σ","\\Sigma",!0);C(O,z,se,"Υ","\\Upsilon",!0);C(O,z,se,"Φ","\\Phi",!0);C(O,z,se,"Ψ","\\Psi",!0);C(O,z,se,"Ω","\\Omega",!0);C(O,z,se,"A","Α");C(O,z,se,"B","Β");C(O,z,se,"E","Ε");C(O,z,se,"Z","Ζ");C(O,z,se,"H","Η");C(O,z,se,"I","Ι");C(O,z,se,"K","Κ");C(O,z,se,"M","Μ");C(O,z,se,"N","Ν");C(O,z,se,"O","Ο");C(O,z,se,"P","Ρ");C(O,z,se,"T","Τ");C(O,z,se,"X","Χ");C(O,z,se,"¬","\\neg",!0);C(O,z,se,"¬","\\lnot");C(O,z,se,"⊤","\\top");C(O,z,se,"⊥","\\bot");C(O,z,se,"∅","\\emptyset");C(O,ee,se,"∅","\\varnothing");C(O,z,at,"α","\\alpha",!0);C(O,z,at,"β","\\beta",!0);C(O,z,at,"γ","\\gamma",!0);C(O,z,at,"δ","\\delta",!0);C(O,z,at,"ϵ","\\epsilon",!0);C(O,z,at,"ζ","\\zeta",!0);C(O,z,at,"η","\\eta",!0);C(O,z,at,"θ","\\theta",!0);C(O,z,at,"ι","\\iota",!0);C(O,z,at,"κ","\\kappa",!0);C(O,z,at,"λ","\\lambda",!0);C(O,z,at,"μ","\\mu",!0);C(O,z,at,"ν","\\nu",!0);C(O,z,at,"ξ","\\xi",!0);C(O,z,at,"ο","\\omicron",!0);C(O,z,at,"π","\\pi",!0);C(O,z,at,"ρ","\\rho",!0);C(O,z,at,"σ","\\sigma",!0);C(O,z,at,"τ","\\tau",!0);C(O,z,at,"υ","\\upsilon",!0);C(O,z,at,"ϕ","\\phi",!0);C(O,z,at,"χ","\\chi",!0);C(O,z,at,"ψ","\\psi",!0);C(O,z,at,"ω","\\omega",!0);C(O,z,at,"ε","\\varepsilon",!0);C(O,z,at,"ϑ","\\vartheta",!0);C(O,z,at,"ϖ","\\varpi",!0);C(O,z,at,"ϱ","\\varrho",!0);C(O,z,at,"ς","\\varsigma",!0);C(O,z,at,"φ","\\varphi",!0);C(O,z,ze,"∗","*",!0);C(O,z,ze,"+","+");C(O,z,ze,"−","-",!0);C(O,z,ze,"⋅","\\cdot",!0);C(O,z,ze,"∘","\\circ",!0);C(O,z,ze,"÷","\\div",!0);C(O,z,ze,"±","\\pm",!0);C(O,z,ze,"×","\\times",!0);C(O,z,ze,"∩","\\cap",!0);C(O,z,ze,"∪","\\cup",!0);C(O,z,ze,"∖","\\setminus",!0);C(O,z,ze,"∧","\\land");C(O,z,ze,"∨","\\lor");C(O,z,ze,"∧","\\wedge",!0);C(O,z,ze,"∨","\\vee",!0);C(O,z,se,"√","\\surd");C(O,z,xa,"⟨","\\langle",!0);C(O,z,xa,"∣","\\lvert");C(O,z,xa,"∥","\\lVert");C(O,z,Pr,"?","?");C(O,z,Pr,"!","!");C(O,z,Pr,"⟩","\\rangle",!0);C(O,z,Pr,"∣","\\rvert");C(O,z,Pr,"∥","\\rVert");C(O,z,te,"=","=");C(O,z,te,":",":");C(O,z,te,"≈","\\approx",!0);C(O,z,te,"≅","\\cong",!0);C(O,z,te,"≥","\\ge");C(O,z,te,"≥","\\geq",!0);C(O,z,te,"←","\\gets");C(O,z,te,">","\\gt",!0);C(O,z,te,"∈","\\in",!0);C(O,z,te,"","\\@not");C(O,z,te,"⊂","\\subset",!0);C(O,z,te,"⊃","\\supset",!0);C(O,z,te,"⊆","\\subseteq",!0);C(O,z,te,"⊇","\\supseteq",!0);C(O,ee,te,"⊈","\\nsubseteq",!0);C(O,ee,te,"⊉","\\nsupseteq",!0);C(O,z,te,"⊨","\\models");C(O,z,te,"←","\\leftarrow",!0);C(O,z,te,"≤","\\le");C(O,z,te,"≤","\\leq",!0);C(O,z,te,"<","\\lt",!0);C(O,z,te,"→","\\rightarrow",!0);C(O,z,te,"→","\\to");C(O,ee,te,"≱","\\ngeq",!0);C(O,ee,te,"≰","\\nleq",!0);C(O,z,No," ","\\ ");C(O,z,No," ","\\space");C(O,z,No," ","\\nobreakspace");C(ke,z,No," ","\\ ");C(ke,z,No," "," ");C(ke,z,No," ","\\space");C(ke,z,No," ","\\nobreakspace");C(O,z,No,null,"\\nobreak");C(O,z,No,null,"\\allowbreak");C(O,z,yg,",",",");C(O,z,yg,";",";");C(O,ee,ze,"⊼","\\barwedge",!0);C(O,ee,ze,"⊻","\\veebar",!0);C(O,z,ze,"⊙","\\odot",!0);C(O,z,ze,"⊕","\\oplus",!0);C(O,z,ze,"⊗","\\otimes",!0);C(O,z,se,"∂","\\partial",!0);C(O,z,ze,"⊘","\\oslash",!0);C(O,ee,ze,"⊚","\\circledcirc",!0);C(O,ee,ze,"⊡","\\boxdot",!0);C(O,z,ze,"△","\\bigtriangleup");C(O,z,ze,"▽","\\bigtriangledown");C(O,z,ze,"†","\\dagger");C(O,z,ze,"⋄","\\diamond");C(O,z,ze,"⋆","\\star");C(O,z,ze,"◃","\\triangleleft");C(O,z,ze,"▹","\\triangleright");C(O,z,xa,"{","\\{");C(ke,z,se,"{","\\{");C(ke,z,se,"{","\\textbraceleft");C(O,z,Pr,"}","\\}");C(ke,z,se,"}","\\}");C(ke,z,se,"}","\\textbraceright");C(O,z,xa,"{","\\lbrace");C(O,z,Pr,"}","\\rbrace");C(O,z,xa,"[","\\lbrack",!0);C(ke,z,se,"[","\\lbrack",!0);C(O,z,Pr,"]","\\rbrack",!0);C(ke,z,se,"]","\\rbrack",!0);C(O,z,xa,"(","\\lparen",!0);C(O,z,Pr,")","\\rparen",!0);C(ke,z,se,"<","\\textless",!0);C(ke,z,se,">","\\textgreater",!0);C(O,z,xa,"⌊","\\lfloor",!0);C(O,z,Pr,"⌋","\\rfloor",!0);C(O,z,xa,"⌈","\\lceil",!0);C(O,z,Pr,"⌉","\\rceil",!0);C(O,z,se,"\\","\\backslash");C(O,z,se,"∣","|");C(O,z,se,"∣","\\vert");C(ke,z,se,"|","\\textbar",!0);C(O,z,se,"∥","\\|");C(O,z,se,"∥","\\Vert");C(ke,z,se,"∥","\\textbardbl");C(ke,z,se,"~","\\textasciitilde");C(ke,z,se,"\\","\\textbackslash");C(ke,z,se,"^","\\textasciicircum");C(O,z,te,"↑","\\uparrow",!0);C(O,z,te,"⇑","\\Uparrow",!0);C(O,z,te,"↓","\\downarrow",!0);C(O,z,te,"⇓","\\Downarrow",!0);C(O,z,te,"↕","\\updownarrow",!0);C(O,z,te,"⇕","\\Updownarrow",!0);C(O,z,jn,"∐","\\coprod");C(O,z,jn,"⋁","\\bigvee");C(O,z,jn,"⋀","\\bigwedge");C(O,z,jn,"⨄","\\biguplus");C(O,z,jn,"⋂","\\bigcap");C(O,z,jn,"⋃","\\bigcup");C(O,z,jn,"∫","\\int");C(O,z,jn,"∫","\\intop");C(O,z,jn,"∬","\\iint");C(O,z,jn,"∭","\\iiint");C(O,z,jn,"∏","\\prod");C(O,z,jn,"∑","\\sum");C(O,z,jn,"⨂","\\bigotimes");C(O,z,jn,"⨁","\\bigoplus");C(O,z,jn,"⨀","\\bigodot");C(O,z,jn,"∮","\\oint");C(O,z,jn,"∯","\\oiint");C(O,z,jn,"∰","\\oiiint");C(O,z,jn,"⨆","\\bigsqcup");C(O,z,jn,"∫","\\smallint");C(ke,z,Su,"…","\\textellipsis");C(O,z,Su,"…","\\mathellipsis");C(ke,z,Su,"…","\\ldots",!0);C(O,z,Su,"…","\\ldots",!0);C(O,z,Su,"⋯","\\@cdots",!0);C(O,z,Su,"⋱","\\ddots",!0);C(O,z,se,"⋮","\\varvdots");C(ke,z,se,"⋮","\\varvdots");C(O,z,vn,"ˊ","\\acute");C(O,z,vn,"ˋ","\\grave");C(O,z,vn,"¨","\\ddot");C(O,z,vn,"~","\\tilde");C(O,z,vn,"ˉ","\\bar");C(O,z,vn,"˘","\\breve");C(O,z,vn,"ˇ","\\check");C(O,z,vn,"^","\\hat");C(O,z,vn,"⃗","\\vec");C(O,z,vn,"˙","\\dot");C(O,z,vn,"˚","\\mathring");C(O,z,at,"","\\@imath");C(O,z,at,"","\\@jmath");C(O,z,se,"ı","ı");C(O,z,se,"ȷ","ȷ");C(ke,z,se,"ı","\\i",!0);C(ke,z,se,"ȷ","\\j",!0);C(ke,z,se,"ß","\\ss",!0);C(ke,z,se,"æ","\\ae",!0);C(ke,z,se,"œ","\\oe",!0);C(ke,z,se,"ø","\\o",!0);C(ke,z,se,"Æ","\\AE",!0);C(ke,z,se,"Œ","\\OE",!0);C(ke,z,se,"Ø","\\O",!0);C(ke,z,vn,"ˊ","\\'");C(ke,z,vn,"ˋ","\\`");C(ke,z,vn,"ˆ","\\^");C(ke,z,vn,"˜","\\~");C(ke,z,vn,"ˉ","\\=");C(ke,z,vn,"˘","\\u");C(ke,z,vn,"˙","\\.");C(ke,z,vn,"¸","\\c");C(ke,z,vn,"˚","\\r");C(ke,z,vn,"ˇ","\\v");C(ke,z,vn,"¨",'\\"');C(ke,z,vn,"˝","\\H");C(ke,z,vn,"◯","\\textcircled");var kD={"--":!0,"---":!0,"``":!0,"''":!0};C(ke,z,se,"–","--",!0);C(ke,z,se,"–","\\textendash");C(ke,z,se,"—","---",!0);C(ke,z,se,"—","\\textemdash");C(ke,z,se,"‘","`",!0);C(ke,z,se,"‘","\\textquoteleft");C(ke,z,se,"’","'",!0);C(ke,z,se,"’","\\textquoteright");C(ke,z,se,"“","``",!0);C(ke,z,se,"“","\\textquotedblleft");C(ke,z,se,"”","''",!0);C(ke,z,se,"”","\\textquotedblright");C(O,z,se,"°","\\degree",!0);C(ke,z,se,"°","\\degree");C(ke,z,se,"°","\\textdegree",!0);C(O,z,se,"£","\\pounds");C(O,z,se,"£","\\mathsterling",!0);C(ke,z,se,"£","\\pounds");C(ke,z,se,"£","\\textsterling",!0);C(O,ee,se,"✠","\\maltese");C(ke,ee,se,"✠","\\maltese");var dN='0123456789/@."';for(var hv=0;hv<dN.length;hv++){var hN=dN.charAt(hv);C(O,z,se,hN,hN)}var pN='0123456789!@*()-=+";:?/.,';for(var pv=0;pv<pN.length;pv++){var fN=pN.charAt(pv);C(ke,z,se,fN,fN)}var um="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz";for(var fv=0;fv<um.length;fv++){var n0=um.charAt(fv);C(O,z,at,n0,n0),C(ke,z,se,n0,n0)}C(O,ee,se,"C","ℂ");C(ke,ee,se,"C","ℂ");C(O,ee,se,"H","ℍ");C(ke,ee,se,"H","ℍ");C(O,ee,se,"N","ℕ");C(ke,ee,se,"N","ℕ");C(O,ee,se,"P","ℙ");C(ke,ee,se,"P","ℙ");C(O,ee,se,"Q","ℚ");C(ke,ee,se,"Q","ℚ");C(O,ee,se,"R","ℝ");C(ke,ee,se,"R","ℝ");C(O,ee,se,"Z","ℤ");C(ke,ee,se,"Z","ℤ");C(O,z,at,"h","ℎ");C(ke,z,at,"h","ℎ");var dt="";for(var Rr=0;Rr<um.length;Rr++){var _n=um.charAt(Rr);dt=String.fromCharCode(55349,56320+Rr),C(O,z,at,_n,dt),C(ke,z,se,_n,dt),dt=String.fromCharCode(55349,56372+Rr),C(O,z,at,_n,dt),C(ke,z,se,_n,dt),dt=String.fromCharCode(55349,56424+Rr),C(O,z,at,_n,dt),C(ke,z,se,_n,dt),dt=String.fromCharCode(55349,56580+Rr),C(O,z,at,_n,dt),C(ke,z,se,_n,dt),dt=String.fromCharCode(55349,56684+Rr),C(O,z,at,_n,dt),C(ke,z,se,_n,dt),dt=String.fromCharCode(55349,56736+Rr),C(O,z,at,_n,dt),C(ke,z,se,_n,dt),dt=String.fromCharCode(55349,56788+Rr),C(O,z,at,_n,dt),C(ke,z,se,_n,dt),dt=String.fromCharCode(55349,56840+Rr),C(O,z,at,_n,dt),C(ke,z,se,_n,dt),dt=String.fromCharCode(55349,56944+Rr),C(O,z,at,_n,dt),C(ke,z,se,_n,dt),Rr<26&&(dt=String.fromCharCode(55349,56632+Rr),C(O,z,at,_n,dt),C(ke,z,se,_n,dt),dt=String.fromCharCode(55349,56476+Rr),C(O,z,at,_n,dt),C(ke,z,se,_n,dt))}dt="𝕜";C(O,z,at,"k",dt);C(ke,z,se,"k",dt);for(var nl=0;nl<10;nl++){var ds=nl.toString();dt=String.fromCharCode(55349,57294+nl),C(O,z,at,ds,dt),C(ke,z,se,ds,dt),dt=String.fromCharCode(55349,57314+nl),C(O,z,at,ds,dt),C(ke,z,se,ds,dt),dt=String.fromCharCode(55349,57324+nl),C(O,z,at,ds,dt),C(ke,z,se,ds,dt),dt=String.fromCharCode(55349,57334+nl),C(O,z,at,ds,dt),C(ke,z,se,ds,dt)}var _x="ÐÞþ";for(var mv=0;mv<_x.length;mv++){var r0=_x.charAt(mv);C(O,z,at,r0,r0),C(ke,z,se,r0,r0)}var a0=[["mathbf","textbf","Main-Bold"],["mathbf","textbf","Main-Bold"],["mathnormal","textit","Math-Italic"],["mathnormal","textit","Math-Italic"],["boldsymbol","boldsymbol","Main-BoldItalic"],["boldsymbol","boldsymbol","Main-BoldItalic"],["mathscr","textscr","Script-Regular"],["","",""],["","",""],["","",""],["mathfrak","textfrak","Fraktur-Regular"],["mathfrak","textfrak","Fraktur-Regular"],["mathbb","textbb","AMS-Regular"],["mathbb","textbb","AMS-Regular"],["mathboldfrak","textboldfrak","Fraktur-Regular"],["mathboldfrak","textboldfrak","Fraktur-Regular"],["mathsf","textsf","SansSerif-Regular"],["mathsf","textsf","SansSerif-Regular"],["mathboldsf","textboldsf","SansSerif-Bold"],["mathboldsf","textboldsf","SansSerif-Bold"],["mathitsf","textitsf","SansSerif-Italic"],["mathitsf","textitsf","SansSerif-Italic"],["","",""],["","",""],["mathtt","texttt","Typewriter-Regular"],["mathtt","texttt","Typewriter-Regular"]],mN=[["mathbf","textbf","Main-Bold"],["","",""],["mathsf","textsf","SansSerif-Regular"],["mathboldsf","textboldsf","SansSerif-Bold"],["mathtt","texttt","Typewriter-Regular"]],Fae=(e,t)=>{var n=e.charCodeAt(0),r=e.charCodeAt(1),a=(n-55296)*1024+(r-56320)+65536,i=t==="math"?0:1;if(119808<=a&&a<120484){var o=Math.floor((a-119808)/26);return[a0[o][2],a0[o][i]]}else if(120782<=a&&a<=120831){var l=Math.floor((a-120782)/10);return[mN[l][2],mN[l][i]]}else{if(a===120485||a===120486)return[a0[0][2],a0[0][i]];if(120486<a&&a<120782)return["",""];throw new Re("Unsupported character: "+e)}},vg=function(t,n,r){if(yn[r][t]){var a=yn[r][t].replace;a&&(t=a)}return{value:t,metrics:YS(t,n,r)}},Or=function(t,n,r,a,i){var o=vg(t,n,r),l=o.metrics;t=o.value;var u;if(l){var d=l.italic;(r==="text"||a&&a.font==="mathit")&&(d=0),u=new ba(t,l.height,l.depth,d,l.skew,l.width,i)}else typeof console<"u"&&console.warn("No character metrics "+("for '"+t+"' in style '"+n+"' and mode '"+r+"'")),u=new ba(t,0,0,0,0,0,i);if(a){u.maxFontSize=a.sizeMultiplier,a.style.isTight()&&u.classes.push("mtight");var h=a.getColor();h&&(u.style.color=h)}return u},XS=function(t,n,r,a){return a===void 0&&(a=[]),r.font==="boldsymbol"&&vg(t,"Main-Bold",n).metrics?Or(t,"Main-Bold",n,r,a.concat(["mathbf"])):t==="\\"||yn[n][t].font==="main"?Or(t,"Main-Regular",n,r,a):Or(t,"AMS-Regular",n,r,a.concat(["amsrm"]))},zae=function(t,n,r,a,i){return i!=="textord"&&vg(t,"Math-BoldItalic",n).metrics?{fontName:"Math-BoldItalic",fontClass:"boldsymbol"}:{fontName:"Main-Bold",fontClass:"mathbf"}},xg=function(t,n,r){var a=t.mode,i=t.text,o=["mord"],l=a==="math"||a==="text"&&n.font,u=l?n.font:n.fontFamily,d="",h="";if(i.charCodeAt(0)===55349&&([d,h]=Fae(i,a)),d.length>0)return Or(i,d,a,n,o.concat(h));if(u){var f,m;if(u==="boldsymbol"){var b=zae(i,a,n,o,r);f=b.fontName,m=[b.fontClass]}else l?(f=Cx[u].fontName,m=[u]):(f=i0(u,n.fontWeight,n.fontShape),m=[u,n.fontWeight,n.fontShape]);if(vg(i,f,a).metrics)return Or(i,f,a,n,o.concat(m));if(kD.hasOwnProperty(i)&&f.slice(0,10)==="Typewriter"){for(var y=[],v=0;v<i.length;v++)y.push(Or(i[v],f,a,n,o.concat(m)));return Oo(y)}}if(r==="mathord")return Or(i,"Math-Italic",a,n,o.concat(["mathnormal"]));if(r==="textord"){var w=yn[a][i]&&yn[a][i].font;if(w==="ams"){var S=i0("amsrm",n.fontWeight,n.fontShape);return Or(i,S,a,n,o.concat("amsrm",n.fontWeight,n.fontShape))}else if(w==="main"||!w){var k=i0("textrm",n.fontWeight,n.fontShape);return Or(i,k,a,n,o.concat(n.fontWeight,n.fontShape))}else{var R=i0(w,n.fontWeight,n.fontShape);return Or(i,R,a,n,o.concat(R,n.fontWeight,n.fontShape))}}else throw new Error("unexpected type: "+r+" in makeOrd")},$ae=(e,t)=>{if(ws(e.classes)!==ws(t.classes)||e.skew!==t.skew||e.maxFontSize!==t.maxFontSize||e.italic!==0&&e.hasClass("mathnormal"))return!1;if(e.classes.length===1){var n=e.classes[0];if(n==="mbin"||n==="mord")return!1}for(var r of Object.keys(e.style))if(e.style[r]!==t.style[r])return!1;for(var a of Object.keys(t.style))if(e.style[a]!==t.style[a])return!1;return!0},TD=e=>{for(var t=0;t<e.length-1;t++){var n=e[t],r=e[t+1];n instanceof ba&&r instanceof ba&&$ae(n,r)&&(n.text+=r.text,n.height=Math.max(n.height,r.height),n.depth=Math.max(n.depth,r.depth),n.italic=r.italic,e.splice(t+1,1),t--)}return e},KS=function(t){for(var n=0,r=0,a=0,i=0;i<t.children.length;i++){var o=t.children[i];o.height>n&&(n=o.height),o.depth>r&&(r=o.depth),o.maxFontSize>a&&(a=o.maxFontSize)}t.height=n,t.depth=r,t.maxFontSize=a},Ce=function(t,n,r,a){var i=new xu(t,n,r,a);return KS(i),i},ks=(e,t,n,r)=>new xu(e,t,n,r),eu=function(t,n,r){var a=Ce([t],[],n);return a.height=Math.max(r||n.fontMetrics().defaultRuleThickness,n.minRuleThickness),a.style.borderBottomWidth=Ie(a.height),a.maxFontSize=1,a},Pae=function(t,n,r,a){var i=new bg(t,n,r,a);return KS(i),i},Oo=function(t){var n=new vu(t);return KS(n),n},tu=function(t,n){return t instanceof vu?Ce([],[t],n):t},Uae=function(t){if(t.positionType==="individualShift"){for(var n=t.children,r=[n[0]],a=-n[0].shift-n[0].elem.depth,i=a,o=1;o<n.length;o++){var l=-n[o].shift-i-n[o].elem.depth,u=l-(n[o-1].elem.height+n[o-1].elem.depth);i=i+l,r.push({type:"kern",size:u}),r.push(n[o])}return{children:r,depth:a}}var d;if(t.positionType==="top"){for(var h=t.positionData,f=0;f<t.children.length;f++){var m=t.children[f];h-=m.type==="kern"?m.size:m.elem.height+m.elem.depth}d=h}else if(t.positionType==="bottom")d=-t.positionData;else{var b=t.children[0];if(b.type!=="elem")throw new Error('First child must have type "elem".');if(t.positionType==="shift")d=-b.elem.depth-t.positionData;else if(t.positionType==="firstBaseline")d=-b.elem.depth;else throw new Error("Invalid positionType "+t.positionType+".")}return{children:t.children,depth:d}},Gt=function(t,n){for(var{children:r,depth:a}=Uae(t),i=0,o=0;o<r.length;o++){var l=r[o];if(l.type==="elem"){var u=l.elem;i=Math.max(i,u.maxFontSize,u.height)}}i+=2;var d=Ce(["pstrut"],[]);d.style.height=Ie(i);for(var h=[],f=a,m=a,b=a,y=0;y<r.length;y++){var v=r[y];if(v.type==="kern")b+=v.size;else{var w=v.elem,S=v.wrapperClasses||[],k=v.wrapperStyle||{},R=Ce(S,[d,w],void 0,k);R.style.top=Ie(-i-b-w.depth),v.marginLeft&&(R.style.marginLeft=v.marginLeft),v.marginRight&&(R.style.marginRight=v.marginRight),h.push(R),b+=w.height+w.depth}f=Math.min(f,b),m=Math.max(m,b)}var I=Ce(["vlist"],h);I.style.height=Ie(m);var L;if(f<0){var A=Ce([],[]),M=Ce(["vlist"],[A]);M.style.height=Ie(-f);var P=Ce(["vlist-s"],[new ba("​")]);L=[Ce(["vlist-r"],[I,P]),Ce(["vlist-r"],[M])]}else L=[Ce(["vlist-r"],[I])];var G=Ce(["vlist-t"],L);return L.length===2&&G.classes.push("vlist-t2"),G.height=m,G.depth=-f,G},_D=(e,t)=>{var n=Ce(["mspace"],[],t),r=wn(e,t);return n.style.marginRight=Ie(r),n},i0=function(t,n,r){var a="";switch(t){case"amsrm":a="AMS";break;case"textrm":a="Main";break;case"textsf":a="SansSerif";break;case"texttt":a="Typewriter";break;default:a=t}var i;return n==="textbf"&&r==="textit"?i="BoldItalic":n==="textbf"?i="Bold":n==="textit"?i="Italic":i="Regular",a+"-"+i},Cx={mathbf:{variant:"bold",fontName:"Main-Bold"},mathrm:{variant:"normal",fontName:"Main-Regular"},textit:{variant:"italic",fontName:"Main-Italic"},mathit:{variant:"italic",fontName:"Main-Italic"},mathnormal:{variant:"italic",fontName:"Math-Italic"},mathsfit:{variant:"sans-serif-italic",fontName:"SansSerif-Italic"},mathbb:{variant:"double-struck",fontName:"AMS-Regular"},mathcal:{variant:"script",fontName:"Caligraphic-Regular"},mathfrak:{variant:"fraktur",fontName:"Fraktur-Regular"},mathscr:{variant:"script",fontName:"Script-Regular"},mathsf:{variant:"sans-serif",fontName:"SansSerif-Regular"},mathtt:{variant:"monospace",fontName:"Typewriter-Regular"}},CD={vec:["vec",.471,.714],oiintSize1:["oiintSize1",.957,.499],oiintSize2:["oiintSize2",1.472,.659],oiiintSize1:["oiiintSize1",1.304,.499],oiiintSize2:["oiiintSize2",1.98,.659]},AD=function(t,n){var[r,a,i]=CD[t],o=new Es(r),l=new To([o],{width:Ie(a),height:Ie(i),style:"width:"+Ie(a),viewBox:"0 0 "+1e3*a+" "+1e3*i,preserveAspectRatio:"xMinYMin"}),u=ks(["overlay"],[l],n);return u.height=i,u.style.height=Ie(i),u.style.width=Ie(a),u},Sn={number:3,unit:"mu"},rl={number:4,unit:"mu"},po={number:5,unit:"mu"},jae={mord:{mop:Sn,mbin:rl,mrel:po,minner:Sn},mop:{mord:Sn,mop:Sn,mrel:po,minner:Sn},mbin:{mord:rl,mop:rl,mopen:rl,minner:rl},mrel:{mord:po,mop:po,mopen:po,minner:po},mopen:{},mclose:{mop:Sn,mbin:rl,mrel:po,minner:Sn},mpunct:{mord:Sn,mop:Sn,mrel:po,mopen:Sn,mclose:Sn,mpunct:Sn,minner:Sn},minner:{mord:Sn,mop:Sn,mbin:rl,mrel:po,mopen:Sn,mpunct:Sn,minner:Sn}},Hae={mord:{mop:Sn},mop:{mord:Sn,mop:Sn},mbin:{},mrel:{},mopen:{},mclose:{mop:Sn},mpunct:{},minner:{mop:Sn}},RD={},dm={},hm={};function Be(e){for(var{type:t,names:n,props:r,handler:a,htmlBuilder:i,mathmlBuilder:o}=e,l={type:t,numArgs:r.numArgs,argTypes:r.argTypes,allowedInArgument:!!r.allowedInArgument,allowedInText:!!r.allowedInText,allowedInMath:r.allowedInMath===void 0?!0:r.allowedInMath,numOptionalArgs:r.numOptionalArgs||0,infix:!!r.infix,primitive:!!r.primitive,handler:a},u=0;u<n.length;++u)RD[n[u]]=l;t&&(i&&(dm[t]=i),o&&(hm[t]=o))}function Il(e){var{type:t,htmlBuilder:n,mathmlBuilder:r}=e;Be({type:t,names:[],props:{numArgs:0},handler(){throw new Error("Should never be called.")},htmlBuilder:n,mathmlBuilder:r})}var pm=function(t){return t.type==="ordgroup"&&t.body.length===1?t.body[0]:t},Pn=function(t){return t.type==="ordgroup"?t.body:[t]},Gae=new Set(["leftmost","mbin","mopen","mrel","mop","mpunct"]),qae=new Set(["rightmost","mrel","mclose","mpunct"]),Wae={display:mt.DISPLAY,text:mt.TEXT,script:mt.SCRIPT,scriptscript:mt.SCRIPTSCRIPT},Vae={mord:"mord",mop:"mop",mbin:"mbin",mrel:"mrel",mopen:"mopen",mclose:"mclose",mpunct:"mpunct",minner:"minner"},Kn=function(t,n,r,a){a===void 0&&(a=[null,null]);for(var i=[],o=0;o<t.length;o++){var l=Wt(t[o],n);if(l instanceof vu){var u=l.children;i.push(...u)}else i.push(l)}if(TD(i),!r)return i;var d=n;if(t.length===1){var h=t[0];h.type==="sizing"?d=n.havingSize(h.size):h.type==="styling"&&(d=n.havingStyle(Wae[h.style]))}var f=Ce([a[0]||"leftmost"],[],n),m=Ce([a[1]||"rightmost"],[],n),b=r==="root";return Ax(i,(y,v)=>{var w=v.classes[0],S=y.classes[0];w==="mbin"&&qae.has(S)?v.classes[0]="mord":S==="mbin"&&Gae.has(w)&&(y.classes[0]="mord")},{node:f},m,b),Ax(i,(y,v)=>{var w,S,k=Nx(v),R=Nx(y),I=k&&R?y.hasClass("mtight")?(w=Hae[k])==null?void 0:w[R]:(S=jae[k])==null?void 0:S[R]:null;if(I)return _D(I,d)},{node:f},m,b),i},Ax=function(t,n,r,a,i){a&&t.push(a);for(var o=0;o<t.length;o++){var l=t[o],u=ND(l);if(u){Ax(u.children,n,r,null,i);continue}var d=!l.hasClass("mspace");if(d){var h=n(l,r.node);h&&(r.insertAfter?r.insertAfter(h):(t.unshift(h),o++))}d?r.node=l:i&&l.hasClass("newline")&&(r.node=Ce(["leftmost"])),r.insertAfter=(f=>m=>{t.splice(f+1,0,m),o++})(o)}a&&t.pop()},ND=function(t){return t instanceof vu||t instanceof bg||t instanceof xu&&t.hasClass("enclosing")?t:null},Rx=function(t,n){var r=ND(t);if(r){var a=r.children;if(a.length){if(n==="right")return Rx(a[a.length-1],"right");if(n==="left")return Rx(a[0],"left")}}return t},Nx=function(t,n){if(!t)return null;n&&(t=Rx(t,n));var r=t.classes[0];return Vae[r]||null},Ah=function(t,n){var r=["nulldelimiter"].concat(t.baseSizingClasses());return Ce(n.concat(r))},Wt=function(t,n,r){if(!t)return Ce();if(dm[t.type]){var a=dm[t.type](t,n);if(r&&n.size!==r.size){a=Ce(n.sizingClasses(r),[a],n);var i=n.sizeMultiplier/r.sizeMultiplier;a.height*=i,a.depth*=i}return a}else throw new Re("Got group of unknown type: '"+t.type+"'")};function o0(e,t){var n=Ce(["base"],e,t),r=Ce(["strut"]);return r.style.height=Ie(n.height+n.depth),n.depth&&(r.style.verticalAlign=Ie(-n.depth)),n.children.unshift(r),n}function Ox(e,t){var n=null;e.length===1&&e[0].type==="tag"&&(n=e[0].tag,e=e[0].body);var r=Kn(e,t,"root"),a;r.length===2&&r[1].hasClass("tag")&&(a=r.pop());for(var i=[],o=[],l=0;l<r.length;l++)if(o.push(r[l]),r[l].hasClass("mbin")||r[l].hasClass("mrel")||r[l].hasClass("allowbreak")){for(var u=!1;l<r.length-1&&r[l+1].hasClass("mspace")&&!r[l+1].hasClass("newline");)l++,o.push(r[l]),r[l].hasClass("nobreak")&&(u=!0);u||(i.push(o0(o,t)),o=[])}else r[l].hasClass("newline")&&(o.pop(),o.length>0&&(i.push(o0(o,t)),o=[]),i.push(r[l]));o.length>0&&i.push(o0(o,t));var d;n?(d=o0(Kn(n,t,!0),t),d.classes=["tag"],i.push(d)):a&&i.push(a);var h=Ce(["katex-html"],i);if(h.setAttribute("aria-hidden","true"),d){var f=d.children[0];f.style.height=Ie(h.height+h.depth),h.depth&&(f.style.verticalAlign=Ie(-h.depth))}return h}function OD(e){return new vu(e)}class Oe{constructor(t,n,r){this.type=t,this.attributes={},this.children=n||[],this.classes=r||[]}setAttribute(t,n){this.attributes[t]=n}getAttribute(t){return this.attributes[t]}toNode(){var t=document.createElementNS("http://www.w3.org/1998/Math/MathML",this.type);for(var n in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,n)&&t.setAttribute(n,this.attributes[n]);this.classes.length>0&&(t.className=ws(this.classes));for(var r=0;r<this.children.length;r++)if(this.children[r]instanceof Un&&this.children[r+1]instanceof Un){for(var a=this.children[r].toText()+this.children[++r].toText();this.children[r+1]instanceof Un;)a+=this.children[++r].toText();t.appendChild(new Un(a).toNode())}else t.appendChild(this.children[r].toNode());return t}toMarkup(){var t="<"+this.type;for(var n in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,n)&&(t+=" "+n+'="',t+=gr(this.attributes[n]),t+='"');this.classes.length>0&&(t+=' class ="'+gr(ws(this.classes))+'"'),t+=">";for(var r=0;r<this.children.length;r++)t+=this.children[r].toMarkup();return t+="</"+this.type+">",t}toText(){return this.children.map(t=>t.toText()).join("")}}class Un{constructor(t){this.text=t}toNode(){return document.createTextNode(this.text)}toMarkup(){return gr(this.toText())}toText(){return this.text}}class ID{constructor(t){this.width=t,t>=.05555&&t<=.05556?this.character=" ":t>=.1666&&t<=.1667?this.character=" ":t>=.2222&&t<=.2223?this.character=" ":t>=.2777&&t<=.2778?this.character="  ":t>=-.05556&&t<=-.05555?this.character=" ⁣":t>=-.1667&&t<=-.1666?this.character=" ⁣":t>=-.2223&&t<=-.2222?this.character=" ⁣":t>=-.2778&&t<=-.2777?this.character=" ⁣":this.character=null}toNode(){if(this.character)return document.createTextNode(this.character);var t=document.createElementNS("http://www.w3.org/1998/Math/MathML","mspace");return t.setAttribute("width",Ie(this.width)),t}toMarkup(){return this.character?"<mtext>"+this.character+"</mtext>":'<mspace width="'+Ie(this.width)+'"/>'}toText(){return this.character?this.character:" "}}var Yae=new Set(["\\imath","\\jmath"]),Xae=new Set(["mrow","mtable"]),Ha=function(t,n,r){return yn[n][t]&&yn[n][t].replace&&t.charCodeAt(0)!==55349&&!(kD.hasOwnProperty(t)&&r&&(r.fontFamily&&r.fontFamily.slice(4,6)==="tt"||r.font&&r.font.slice(4,6)==="tt"))&&(t=yn[n][t].replace),new Un(t)},ZS=function(t){return t.length===1?t[0]:new Oe("mrow",t)},QS=function(t,n){if(n.fontFamily==="texttt")return"monospace";if(n.fontFamily==="textsf")return n.fontShape==="textit"&&n.fontWeight==="textbf"?"sans-serif-bold-italic":n.fontShape==="textit"?"sans-serif-italic":n.fontWeight==="textbf"?"bold-sans-serif":"sans-serif";if(n.fontShape==="textit"&&n.fontWeight==="textbf")return"bold-italic";if(n.fontShape==="textit")return"italic";if(n.fontWeight==="textbf")return"bold";var r=n.font;if(!r||r==="mathnormal")return null;var a=t.mode;if(r==="mathit")return"italic";if(r==="boldsymbol")return t.type==="textord"?"bold":"bold-italic";if(r==="mathbf")return"bold";if(r==="mathbb")return"double-struck";if(r==="mathsfit")return"sans-serif-italic";if(r==="mathfrak")return"fraktur";if(r==="mathscr"||r==="mathcal")return"script";if(r==="mathsf")return"sans-serif";if(r==="mathtt")return"monospace";var i=t.text;if(Yae.has(i))return null;if(yn[a][i]){var o=yn[a][i].replace;o&&(i=o)}var l=Cx[r].fontName;return YS(i,l,a)?Cx[r].variant:null};function gv(e){if(!e)return!1;if(e.type==="mi"&&e.children.length===1){var t=e.children[0];return t instanceof Un&&t.text==="."}else if(e.type==="mo"&&e.children.length===1&&e.getAttribute("separator")==="true"&&e.getAttribute("lspace")==="0em"&&e.getAttribute("rspace")==="0em"){var n=e.children[0];return n instanceof Un&&n.text===","}else return!1}var Sa=function(t,n,r){if(t.length===1){var a=an(t[0],n);return r&&a instanceof Oe&&a.type==="mo"&&(a.setAttribute("lspace","0em"),a.setAttribute("rspace","0em")),[a]}for(var i=[],o,l=0;l<t.length;l++){var u=an(t[l],n);if(u instanceof Oe&&o instanceof Oe){if(u.type==="mtext"&&o.type==="mtext"&&u.getAttribute("mathvariant")===o.getAttribute("mathvariant")){o.children.push(...u.children);continue}else if(u.type==="mn"&&o.type==="mn"){o.children.push(...u.children);continue}else if(gv(u)&&o.type==="mn"){o.children.push(...u.children);continue}else if(u.type==="mn"&&gv(o))u.children=[...o.children,...u.children],i.pop();else if((u.type==="msup"||u.type==="msub")&&u.children.length>=1&&(o.type==="mn"||gv(o))){var d=u.children[0];d instanceof Oe&&d.type==="mn"&&(d.children=[...o.children,...d.children],i.pop())}else if(o.type==="mi"&&o.children.length===1){var h=o.children[0];if(h instanceof Un&&h.text==="̸"&&(u.type==="mo"||u.type==="mi"||u.type==="mn")){var f=u.children[0];f instanceof Un&&f.text.length>0&&(f.text=f.text.slice(0,1)+"̸"+f.text.slice(1),i.pop())}}}i.push(u),o=u}return i},Ts=function(t,n,r){return ZS(Sa(t,n,r))},an=function(t,n){if(!t)return new Oe("mrow");if(hm[t.type]){var r=hm[t.type](t,n);return r}else throw new Re("Got group of unknown type: '"+t.type+"'")};function gN(e,t,n,r,a){var i=Sa(e,n),o;i.length===1&&i[0]instanceof Oe&&Xae.has(i[0].type)?o=i[0]:o=new Oe("mrow",i);var l=new Oe("annotation",[new Un(t)]);l.setAttribute("encoding","application/x-tex");var u=new Oe("semantics",[o,l]),d=new Oe("math",[u]);d.setAttribute("xmlns","http://www.w3.org/1998/Math/MathML"),r&&d.setAttribute("display","block");var h=a?"katex":"katex-mathml";return Ce([h],[d])}var Kae=[[1,1,1],[2,1,1],[3,1,1],[4,2,1],[5,2,1],[6,3,1],[7,4,2],[8,6,3],[9,7,6],[10,8,7],[11,10,9]],bN=[.5,.6,.7,.8,.9,1,1.2,1.44,1.728,2.074,2.488],yN=function(t,n){return n.size<2?t:Kae[t-1][n.size-1]};class yo{constructor(t){this.style=t.style,this.color=t.color,this.size=t.size||yo.BASESIZE,this.textSize=t.textSize||this.size,this.phantom=!!t.phantom,this.font=t.font||"",this.fontFamily=t.fontFamily||"",this.fontWeight=t.fontWeight||"",this.fontShape=t.fontShape||"",this.sizeMultiplier=bN[this.size-1],this.maxSize=t.maxSize,this.minRuleThickness=t.minRuleThickness,this._fontMetrics=void 0}extend(t){var n={style:this.style,size:this.size,textSize:this.textSize,color:this.color,phantom:this.phantom,font:this.font,fontFamily:this.fontFamily,fontWeight:this.fontWeight,fontShape:this.fontShape,maxSize:this.maxSize,minRuleThickness:this.minRuleThickness};return Object.assign(n,t),new yo(n)}havingStyle(t){return this.style===t?this:this.extend({style:t,size:yN(this.textSize,t)})}havingCrampedStyle(){return this.havingStyle(this.style.cramp())}havingSize(t){return this.size===t&&this.textSize===t?this:this.extend({style:this.style.text(),size:t,textSize:t,sizeMultiplier:bN[t-1]})}havingBaseStyle(t){t=t||this.style.text();var n=yN(yo.BASESIZE,t);return this.size===n&&this.textSize===yo.BASESIZE&&this.style===t?this:this.extend({style:t,size:n})}havingBaseSizing(){var t;switch(this.style.id){case 4:case 5:t=3;break;case 6:case 7:t=1;break;default:t=6}return this.extend({style:this.style.text(),size:t})}withColor(t){return this.extend({color:t})}withPhantom(){return this.extend({phantom:!0})}withFont(t){return this.extend({font:t})}withTextFontFamily(t){return this.extend({fontFamily:t,font:""})}withTextFontWeight(t){return this.extend({fontWeight:t,font:""})}withTextFontShape(t){return this.extend({fontShape:t,font:""})}sizingClasses(t){return t.size!==this.size?["sizing","reset-size"+t.size,"size"+this.size]:[]}baseSizingClasses(){return this.size!==yo.BASESIZE?["sizing","reset-size"+this.size,"size"+yo.BASESIZE]:[]}fontMetrics(){return this._fontMetrics||(this._fontMetrics=Dae(this.size)),this._fontMetrics}getColor(){return this.phantom?"transparent":this.color}}yo.BASESIZE=6;var LD=function(t){return new yo({style:t.displayMode?mt.DISPLAY:mt.TEXT,maxSize:t.maxSize,minRuleThickness:t.minRuleThickness})},DD=function(t,n){if(n.displayMode){var r=["katex-display"];n.leqno&&r.push("leqno"),n.fleqn&&r.push("fleqn"),t=Ce(r,[t])}return t},Zae=function(t,n,r){var a=LD(r),i;if(r.output==="mathml")return gN(t,n,a,r.displayMode,!0);if(r.output==="html"){var o=Ox(t,a);i=Ce(["katex"],[o])}else{var l=gN(t,n,a,r.displayMode,!1),u=Ox(t,a);i=Ce(["katex"],[l,u])}return DD(i,r)},Qae=function(t,n,r){var a=LD(r),i=Ox(t,a),o=Ce(["katex"],[i]);return DD(o,r)},Jae={widehat:"^",widecheck:"ˇ",widetilde:"~",utilde:"~",overleftarrow:"←",underleftarrow:"←",xleftarrow:"←",overrightarrow:"→",underrightarrow:"→",xrightarrow:"→",underbrace:"⏟",overbrace:"⏞",overgroup:"⏠",undergroup:"⏡",overleftrightarrow:"↔",underleftrightarrow:"↔",xleftrightarrow:"↔",Overrightarrow:"⇒",xRightarrow:"⇒",overleftharpoon:"↼",xleftharpoonup:"↼",overrightharpoon:"⇀",xrightharpoonup:"⇀",xLeftarrow:"⇐",xLeftrightarrow:"⇔",xhookleftarrow:"↩",xhookrightarrow:"↪",xmapsto:"↦",xrightharpoondown:"⇁",xleftharpoondown:"↽",xrightleftharpoons:"⇌",xleftrightharpoons:"⇋",xtwoheadleftarrow:"↞",xtwoheadrightarrow:"↠",xlongequal:"=",xtofrom:"⇄",xrightleftarrows:"⇄",xrightequilibrium:"⇌",xleftequilibrium:"⇋","\\cdrightarrow":"→","\\cdleftarrow":"←","\\cdlongequal":"="},Sg=function(t){var n=new Oe("mo",[new Un(Jae[t.replace(/^\\/,"")])]);return n.setAttribute("stretchy","true"),n},eie={overrightarrow:[["rightarrow"],.888,522,"xMaxYMin"],overleftarrow:[["leftarrow"],.888,522,"xMinYMin"],underrightarrow:[["rightarrow"],.888,522,"xMaxYMin"],underleftarrow:[["leftarrow"],.888,522,"xMinYMin"],xrightarrow:[["rightarrow"],1.469,522,"xMaxYMin"],"\\cdrightarrow":[["rightarrow"],3,522,"xMaxYMin"],xleftarrow:[["leftarrow"],1.469,522,"xMinYMin"],"\\cdleftarrow":[["leftarrow"],3,522,"xMinYMin"],Overrightarrow:[["doublerightarrow"],.888,560,"xMaxYMin"],xRightarrow:[["doublerightarrow"],1.526,560,"xMaxYMin"],xLeftarrow:[["doubleleftarrow"],1.526,560,"xMinYMin"],overleftharpoon:[["leftharpoon"],.888,522,"xMinYMin"],xleftharpoonup:[["leftharpoon"],.888,522,"xMinYMin"],xleftharpoondown:[["leftharpoondown"],.888,522,"xMinYMin"],overrightharpoon:[["rightharpoon"],.888,522,"xMaxYMin"],xrightharpoonup:[["rightharpoon"],.888,522,"xMaxYMin"],xrightharpoondown:[["rightharpoondown"],.888,522,"xMaxYMin"],xlongequal:[["longequal"],.888,334,"xMinYMin"],"\\cdlongequal":[["longequal"],3,334,"xMinYMin"],xtwoheadleftarrow:[["twoheadleftarrow"],.888,334,"xMinYMin"],xtwoheadrightarrow:[["twoheadrightarrow"],.888,334,"xMaxYMin"],overleftrightarrow:[["leftarrow","rightarrow"],.888,522],overbrace:[["leftbrace","midbrace","rightbrace"],1.6,548],underbrace:[["leftbraceunder","midbraceunder","rightbraceunder"],1.6,548],underleftrightarrow:[["leftarrow","rightarrow"],.888,522],xleftrightarrow:[["leftarrow","rightarrow"],1.75,522],xLeftrightarrow:[["doubleleftarrow","doublerightarrow"],1.75,560],xrightleftharpoons:[["leftharpoondownplus","rightharpoonplus"],1.75,716],xleftrightharpoons:[["leftharpoonplus","rightharpoondownplus"],1.75,716],xhookleftarrow:[["leftarrow","righthook"],1.08,522],xhookrightarrow:[["lefthook","rightarrow"],1.08,522],overlinesegment:[["leftlinesegment","rightlinesegment"],.888,522],underlinesegment:[["leftlinesegment","rightlinesegment"],.888,522],overgroup:[["leftgroup","rightgroup"],.888,342],undergroup:[["leftgroupunder","rightgroupunder"],.888,342],xmapsto:[["leftmapsto","rightarrow"],1.5,522],xtofrom:[["leftToFrom","rightToFrom"],1.75,528],xrightleftarrows:[["baraboveleftarrow","rightarrowabovebar"],1.75,901],xrightequilibrium:[["baraboveshortleftharpoon","rightharpoonaboveshortbar"],1.75,716],xleftequilibrium:[["shortbaraboveleftharpoon","shortrightharpoonabovebar"],1.75,716]},tie=new Set(["widehat","widecheck","widetilde","utilde"]),wg=function(t,n){function r(){var l=4e5,u=t.label.slice(1);if(tie.has(u)){var d=t,h=d.base.type==="ordgroup"?d.base.body.length:1,f,m,b;if(h>5)u==="widehat"||u==="widecheck"?(f=420,l=2364,b=.42,m=u+"4"):(f=312,l=2340,b=.34,m="tilde4");else{var y=[1,1,2,2,3,3][h];u==="widehat"||u==="widecheck"?(l=[0,1062,2364,2364,2364][y],f=[0,239,300,360,420][y],b=[0,.24,.3,.3,.36,.42][y],m=u+y):(l=[0,600,1033,2339,2340][y],f=[0,260,286,306,312][y],b=[0,.26,.286,.3,.306,.34][y],m="tilde"+y)}var v=new Es(m),w=new To([v],{width:"100%",height:Ie(b),viewBox:"0 0 "+l+" "+f,preserveAspectRatio:"none"});return{span:ks([],[w],n),minWidth:0,height:b}}else{var S=[],k=eie[u],[R,I,L]=k,A=L/1e3,M=R.length,P,G;if(M===1){var B=k[3];P=["hide-tail"],G=[B]}else if(M===2)P=["halfarrow-left","halfarrow-right"],G=["xMinYMin","xMaxYMin"];else if(M===3)P=["brace-left","brace-center","brace-right"],G=["xMinYMin","xMidYMin","xMaxYMin"];else throw new Error(`Correct katexImagesData or update code here to support
                    `+M+" children.");for(var H=0;H<M;H++){var Z=new Es(R[H]),V=new To([Z],{width:"400em",height:Ie(A),viewBox:"0 0 "+l+" "+L,preserveAspectRatio:G[H]+" slice"}),q=ks([P[H]],[V],n);if(M===1)return{span:q,minWidth:I,height:A};q.style.height=Ie(A),S.push(q)}return{span:Ce(["stretchy"],S,n),minWidth:I,height:A}}}var{span:a,minWidth:i,height:o}=r();return a.height=o,a.style.height=Ie(o),i>0&&(a.style.minWidth=Ie(i)),a},nie=function(t,n,r,a,i){var o,l=t.height+t.depth+r+a;if(/fbox|color|angl/.test(n)){if(o=Ce(["stretchy",n],[],i),n==="fbox"){var u=i.color&&i.getColor();u&&(o.style.borderColor=u)}}else{var d=[];/^[bx]cancel$/.test(n)&&d.push(new Tx({x1:"0",y1:"0",x2:"100%",y2:"100%","stroke-width":"0.046em"})),/^x?cancel$/.test(n)&&d.push(new Tx({x1:"0",y1:"100%",x2:"100%",y2:"0","stroke-width":"0.046em"}));var h=new To(d,{width:"100%",height:Ie(l)});o=ks([],[h],i)}return o.height=l,o.style.height=Ie(l),o};function wt(e,t){if(!e||e.type!==t)throw new Error("Expected node of type "+t+", but got "+(e?"node of type "+e.type:String(e)));return e}function Eg(e){var t=kg(e);if(!t)throw new Error("Expected node of symbol group type, but got "+(e?"node of type "+e.type:String(e)));return t}function kg(e){return e&&(e.type==="atom"||Bae.hasOwnProperty(e.type))?e:null}var MD=e=>{if(e instanceof ba)return e;if(Lae(e)&&e.children.length===1)return MD(e.children[0])},JS=(e,t)=>{var n,r,a;e&&e.type==="supsub"?(r=wt(e.base,"accent"),n=r.base,e.base=n,a=Iae(Wt(e,t)),e.base=r):(r=wt(e,"accent"),n=r.base);var i=Wt(n,t.havingCrampedStyle()),o=r.isShifty&&Ro(n),l=0;if(o){var u,d;l=(u=(d=MD(i))==null?void 0:d.skew)!=null?u:0}var h=r.label==="\\c",f=h?i.height+i.depth:Math.min(i.height,t.fontMetrics().xHeight),m;if(r.isStretchy)m=wg(r,t),m=Gt({positionType:"firstBaseline",children:[{type:"elem",elem:i},{type:"elem",elem:m,wrapperClasses:["svg-align"],wrapperStyle:l>0?{width:"calc(100% - "+Ie(2*l)+")",marginLeft:Ie(2*l)}:void 0}]});else{var b,y;r.label==="\\vec"?(b=AD("vec",t),y=CD.vec[1]):(b=xg({mode:r.mode,text:r.label},t,"textord"),b=Oae(b),b.italic=0,y=b.width,h&&(f+=b.depth)),m=Ce(["accent-body"],[b]);var v=r.label==="\\textcircled";v&&(m.classes.push("accent-full"),f=i.height);var w=l;v||(w-=y/2),m.style.left=Ie(w),r.label==="\\textcircled"&&(m.style.top=".2em"),m=Gt({positionType:"firstBaseline",children:[{type:"elem",elem:i},{type:"kern",size:-f},{type:"elem",elem:m}]})}var S=Ce(["mord","accent"],[m],t);return a?(a.children[0]=S,a.height=Math.max(S.height,a.height),a.classes[0]="mord",a):S},BD=(e,t)=>{var n=e.isStretchy?Sg(e.label):new Oe("mo",[Ha(e.label,e.mode)]),r=new Oe("mover",[an(e.base,t),n]);return r.setAttribute("accent","true"),r},rie=new RegExp(["\\acute","\\grave","\\ddot","\\tilde","\\bar","\\breve","\\check","\\hat","\\vec","\\dot","\\mathring"].map(e=>"\\"+e).join("|"));Be({type:"accent",names:["\\acute","\\grave","\\ddot","\\tilde","\\bar","\\breve","\\check","\\hat","\\vec","\\dot","\\mathring","\\widecheck","\\widehat","\\widetilde","\\overrightarrow","\\overleftarrow","\\Overrightarrow","\\overleftrightarrow","\\overgroup","\\overlinesegment","\\overleftharpoon","\\overrightharpoon"],props:{numArgs:1},handler:(e,t)=>{var n=pm(t[0]),r=!rie.test(e.funcName),a=!r||e.funcName==="\\widehat"||e.funcName==="\\widetilde"||e.funcName==="\\widecheck";return{type:"accent",mode:e.parser.mode,label:e.funcName,isStretchy:r,isShifty:a,base:n}},htmlBuilder:JS,mathmlBuilder:BD});Be({type:"accent",names:["\\'","\\`","\\^","\\~","\\=","\\u","\\.",'\\"',"\\c","\\r","\\H","\\v","\\textcircled"],props:{numArgs:1,allowedInText:!0,allowedInMath:!0,argTypes:["primitive"]},handler:(e,t)=>{var n=t[0],r=e.parser.mode;return r==="math"&&(e.parser.settings.reportNonstrict("mathVsTextAccents","LaTeX's accent "+e.funcName+" works only in text mode"),r="text"),{type:"accent",mode:r,label:e.funcName,isStretchy:!1,isShifty:!0,base:n}},htmlBuilder:JS,mathmlBuilder:BD});Be({type:"accentUnder",names:["\\underleftarrow","\\underrightarrow","\\underleftrightarrow","\\undergroup","\\underlinesegment","\\utilde"],props:{numArgs:1},handler:(e,t)=>{var{parser:n,funcName:r}=e,a=t[0];return{type:"accentUnder",mode:n.mode,label:r,base:a}},htmlBuilder:(e,t)=>{var n=Wt(e.base,t),r=wg(e,t),a=e.label==="\\utilde"?.12:0,i=Gt({positionType:"top",positionData:n.height,children:[{type:"elem",elem:r,wrapperClasses:["svg-align"]},{type:"kern",size:a},{type:"elem",elem:n}]});return Ce(["mord","accentunder"],[i],t)},mathmlBuilder:(e,t)=>{var n=Sg(e.label),r=new Oe("munder",[an(e.base,t),n]);return r.setAttribute("accentunder","true"),r}});var s0=e=>{var t=new Oe("mpadded",e?[e]:[]);return t.setAttribute("width","+0.6em"),t.setAttribute("lspace","0.3em"),t};Be({type:"xArrow",names:["\\xleftarrow","\\xrightarrow","\\xLeftarrow","\\xRightarrow","\\xleftrightarrow","\\xLeftrightarrow","\\xhookleftarrow","\\xhookrightarrow","\\xmapsto","\\xrightharpoondown","\\xrightharpoonup","\\xleftharpoondown","\\xleftharpoonup","\\xrightleftharpoons","\\xleftrightharpoons","\\xlongequal","\\xtwoheadrightarrow","\\xtwoheadleftarrow","\\xtofrom","\\xrightleftarrows","\\xrightequilibrium","\\xleftequilibrium","\\\\cdrightarrow","\\\\cdleftarrow","\\\\cdlongequal"],props:{numArgs:1,numOptionalArgs:1},handler(e,t,n){var{parser:r,funcName:a}=e;return{type:"xArrow",mode:r.mode,label:a,body:t[0],below:n[0]}},htmlBuilder(e,t){var n=t.style,r=t.havingStyle(n.sup()),a=tu(Wt(e.body,r,t),t),i=e.label.slice(0,2)==="\\x"?"x":"cd";a.classes.push(i+"-arrow-pad");var o;e.below&&(r=t.havingStyle(n.sub()),o=tu(Wt(e.below,r,t),t),o.classes.push(i+"-arrow-pad"));var l=wg(e,t),u=-t.fontMetrics().axisHeight+.5*l.height,d=-t.fontMetrics().axisHeight-.5*l.height-.111;(a.depth>.25||e.label==="\\xleftequilibrium")&&(d-=a.depth);var h;if(o){var f=-t.fontMetrics().axisHeight+o.height+.5*l.height+.111;h=Gt({positionType:"individualShift",children:[{type:"elem",elem:a,shift:d},{type:"elem",elem:l,shift:u},{type:"elem",elem:o,shift:f}]})}else h=Gt({positionType:"individualShift",children:[{type:"elem",elem:a,shift:d},{type:"elem",elem:l,shift:u}]});return h.children[0].children[0].children[1].classes.push("svg-align"),Ce(["mrel","x-arrow"],[h],t)},mathmlBuilder(e,t){var n=Sg(e.label);n.setAttribute("minsize",e.label.charAt(0)==="x"?"1.75em":"3.0em");var r;if(e.body){var a=s0(an(e.body,t));if(e.below){var i=s0(an(e.below,t));r=new Oe("munderover",[n,i,a])}else r=new Oe("mover",[n,a])}else if(e.below){var o=s0(an(e.below,t));r=new Oe("munder",[n,o])}else r=s0(),r=new Oe("mover",[n,r]);return r}});function FD(e,t){var n=Kn(e.body,t,!0);return Ce([e.mclass],n,t)}function zD(e,t){var n,r=Sa(e.body,t);return e.mclass==="minner"?n=new Oe("mpadded",r):e.mclass==="mord"?e.isCharacterBox?(n=r[0],n.type="mi"):n=new Oe("mi",r):(e.isCharacterBox?(n=r[0],n.type="mo"):n=new Oe("mo",r),e.mclass==="mbin"?(n.attributes.lspace="0.22em",n.attributes.rspace="0.22em"):e.mclass==="mpunct"?(n.attributes.lspace="0em",n.attributes.rspace="0.17em"):e.mclass==="mopen"||e.mclass==="mclose"?(n.attributes.lspace="0em",n.attributes.rspace="0em"):e.mclass==="minner"&&(n.attributes.lspace="0.0556em",n.attributes.width="+0.1111em")),n}Be({type:"mclass",names:["\\mathord","\\mathbin","\\mathrel","\\mathopen","\\mathclose","\\mathpunct","\\mathinner"],props:{numArgs:1,primitive:!0},handler(e,t){var{parser:n,funcName:r}=e,a=t[0];return{type:"mclass",mode:n.mode,mclass:"m"+r.slice(5),body:Pn(a),isCharacterBox:Ro(a)}},htmlBuilder:FD,mathmlBuilder:zD});var Tg=e=>{var t=e.type==="ordgroup"&&e.body.length?e.body[0]:e;return t.type==="atom"&&(t.family==="bin"||t.family==="rel")?"m"+t.family:"mord"};Be({type:"mclass",names:["\\@binrel"],props:{numArgs:2},handler(e,t){var{parser:n}=e;return{type:"mclass",mode:n.mode,mclass:Tg(t[0]),body:Pn(t[1]),isCharacterBox:Ro(t[1])}}});Be({type:"mclass",names:["\\stackrel","\\overset","\\underset"],props:{numArgs:2},handler(e,t){var{parser:n,funcName:r}=e,a=t[1],i=t[0],o;r!=="\\stackrel"?o=Tg(a):o="mrel";var l={type:"op",mode:a.mode,limits:!0,alwaysHandleSupSub:!0,parentIsSupSub:!1,symbol:!1,suppressBaseShift:r!=="\\stackrel",body:Pn(a)},u={type:"supsub",mode:i.mode,base:l,sup:r==="\\underset"?null:i,sub:r==="\\underset"?i:null};return{type:"mclass",mode:n.mode,mclass:o,body:[u],isCharacterBox:Ro(u)}},htmlBuilder:FD,mathmlBuilder:zD});Be({type:"pmb",names:["\\pmb"],props:{numArgs:1,allowedInText:!0},handler(e,t){var{parser:n}=e;return{type:"pmb",mode:n.mode,mclass:Tg(t[0]),body:Pn(t[0])}},htmlBuilder(e,t){var n=Kn(e.body,t,!0),r=Ce([e.mclass],n,t);return r.style.textShadow="0.02em 0.01em 0.04px",r},mathmlBuilder(e,t){var n=Sa(e.body,t),r=new Oe("mstyle",n);return r.setAttribute("style","text-shadow: 0.02em 0.01em 0.04px"),r}});var aie={">":"\\\\cdrightarrow","<":"\\\\cdleftarrow","=":"\\\\cdlongequal",A:"\\uparrow",V:"\\downarrow","|":"\\Vert",".":"no arrow"},vN=()=>({type:"styling",body:[],mode:"math",style:"display"}),xN=e=>e.type==="textord"&&e.text==="@",iie=(e,t)=>(e.type==="mathord"||e.type==="atom")&&e.text===t;function oie(e,t,n){var r=aie[e];switch(r){case"\\\\cdrightarrow":case"\\\\cdleftarrow":return n.callFunction(r,[t[0]],[t[1]]);case"\\uparrow":case"\\downarrow":{var a=n.callFunction("\\\\cdleft",[t[0]],[]),i={type:"atom",text:r,mode:"math",family:"rel"},o=n.callFunction("\\Big",[i],[]),l=n.callFunction("\\\\cdright",[t[1]],[]),u={type:"ordgroup",mode:"math",body:[a,o,l]};return n.callFunction("\\\\cdparent",[u],[])}case"\\\\cdlongequal":return n.callFunction("\\\\cdlongequal",[],[]);case"\\Vert":{var d={type:"textord",text:"\\Vert",mode:"math"};return n.callFunction("\\Big",[d],[])}default:return{type:"textord",text:" ",mode:"math"}}}function sie(e){var t=[];for(e.gullet.beginGroup(),e.gullet.macros.set("\\cr","\\\\\\relax"),e.gullet.beginGroup();;){t.push(e.parseExpression(!1,"\\\\")),e.gullet.endGroup(),e.gullet.beginGroup();var n=e.fetch().text;if(n==="&"||n==="\\\\")e.consume();else if(n==="\\end"){t[t.length-1].length===0&&t.pop();break}else throw new Re("Expected \\\\ or \\cr or \\end",e.nextToken)}for(var r=[],a=[r],i=0;i<t.length;i++){for(var o=t[i],l=vN(),u=0;u<o.length;u++)if(!xN(o[u]))l.body.push(o[u]);else{r.push(l),u+=1;var d=Eg(o[u]).text,h=new Array(2);if(h[0]={type:"ordgroup",mode:"math",body:[]},h[1]={type:"ordgroup",mode:"math",body:[]},!"=|.".includes(d))if("<>AV".includes(d))for(var f=0;f<2;f++){for(var m=!0,b=u+1;b<o.length;b++){if(iie(o[b],d)){m=!1,u=b;break}if(xN(o[b]))throw new Re("Missing a "+d+" character to complete a CD arrow.",o[b]);h[f].body.push(o[b])}if(m)throw new Re("Missing a "+d+" character to complete a CD arrow.",o[u])}else throw new Re('Expected one of "<>AV=|." after @',o[u]);var y=oie(d,h,e),v={type:"styling",body:[y],mode:"math",style:"display"};r.push(v),l=vN()}i%2===0?r.push(l):r.shift(),r=[],a.push(r)}e.gullet.endGroup(),e.gullet.endGroup();var w=new Array(a[0].length).fill({type:"align",align:"c",pregap:.25,postgap:.25});return{type:"array",mode:"math",body:a,arraystretch:1,addJot:!0,rowGaps:[null],cols:w,colSeparationType:"CD",hLinesBeforeRow:new Array(a.length+1).fill([])}}Be({type:"cdlabel",names:["\\\\cdleft","\\\\cdright"],props:{numArgs:1},handler(e,t){var{parser:n,funcName:r}=e;return{type:"cdlabel",mode:n.mode,side:r.slice(4),label:t[0]}},htmlBuilder(e,t){var n=t.havingStyle(t.style.sup()),r=tu(Wt(e.label,n,t),t);return r.classes.push("cd-label-"+e.side),r.style.bottom=Ie(.8-r.depth),r.height=0,r.depth=0,r},mathmlBuilder(e,t){var n=new Oe("mrow",[an(e.label,t)]);return n=new Oe("mpadded",[n]),n.setAttribute("width","0"),e.side==="left"&&n.setAttribute("lspace","-1width"),n.setAttribute("voffset","0.7em"),n=new Oe("mstyle",[n]),n.setAttribute("displaystyle","false"),n.setAttribute("scriptlevel","1"),n}});Be({type:"cdlabelparent",names:["\\\\cdparent"],props:{numArgs:1},handler(e,t){var{parser:n}=e;return{type:"cdlabelparent",mode:n.mode,fragment:t[0]}},htmlBuilder(e,t){var n=tu(Wt(e.fragment,t),t);return n.classes.push("cd-vert-arrow"),n},mathmlBuilder(e,t){return new Oe("mrow",[an(e.fragment,t)])}});Be({type:"textord",names:["\\@char"],props:{numArgs:1,allowedInText:!0},handler(e,t){for(var{parser:n}=e,r=wt(t[0],"ordgroup"),a=r.body,i="",o=0;o<a.length;o++){var l=wt(a[o],"textord");i+=l.text}var u=parseInt(i),d;if(isNaN(u))throw new Re("\\@char has non-numeric argument "+i);if(u<0||u>=1114111)throw new Re("\\@char with invalid code point "+i);return u<=65535?d=String.fromCharCode(u):(u-=65536,d=String.fromCharCode((u>>10)+55296,(u&1023)+56320)),{type:"textord",mode:n.mode,text:d}}});var $D=(e,t)=>{var n=Kn(e.body,t.withColor(e.color),!1);return Oo(n)},PD=(e,t)=>{var n=Sa(e.body,t.withColor(e.color)),r=new Oe("mstyle",n);return r.setAttribute("mathcolor",e.color),r};Be({type:"color",names:["\\textcolor"],props:{numArgs:2,allowedInText:!0,argTypes:["color","original"]},handler(e,t){var{parser:n}=e,r=wt(t[0],"color-token").color,a=t[1];return{type:"color",mode:n.mode,color:r,body:Pn(a)}},htmlBuilder:$D,mathmlBuilder:PD});Be({type:"color",names:["\\color"],props:{numArgs:1,allowedInText:!0,argTypes:["color"]},handler(e,t){var{parser:n,breakOnTokenText:r}=e,a=wt(t[0],"color-token").color;n.gullet.macros.set("\\current@color",a);var i=n.parseExpression(!0,r);return{type:"color",mode:n.mode,color:a,body:i}},htmlBuilder:$D,mathmlBuilder:PD});Be({type:"cr",names:["\\\\"],props:{numArgs:0,numOptionalArgs:0,allowedInText:!0},handler(e,t,n){var{parser:r}=e,a=r.gullet.future().text==="["?r.parseSizeGroup(!0):null,i=!r.settings.displayMode||!r.settings.useStrictBehavior("newLineInDisplayMode","In LaTeX, \\\\ or \\newline does nothing in display mode");return{type:"cr",mode:r.mode,newLine:i,size:a&&wt(a,"size").value}},htmlBuilder(e,t){var n=Ce(["mspace"],[],t);return e.newLine&&(n.classes.push("newline"),e.size&&(n.style.marginTop=Ie(wn(e.size,t)))),n},mathmlBuilder(e,t){var n=new Oe("mspace");return e.newLine&&(n.setAttribute("linebreak","newline"),e.size&&n.setAttribute("height",Ie(wn(e.size,t)))),n}});var Ix={"\\global":"\\global","\\long":"\\\\globallong","\\\\globallong":"\\\\globallong","\\def":"\\gdef","\\gdef":"\\gdef","\\edef":"\\xdef","\\xdef":"\\xdef","\\let":"\\\\globallet","\\futurelet":"\\\\globalfuture"},UD=e=>{var t=e.text;if(/^(?:[\\{}$&#^_]|EOF)$/.test(t))throw new Re("Expected a control sequence",e);return t},lie=e=>{var t=e.gullet.popToken();return t.text==="="&&(t=e.gullet.popToken(),t.text===" "&&(t=e.gullet.popToken())),t},jD=(e,t,n,r)=>{var a=e.gullet.macros.get(n.text);a==null&&(n.noexpand=!0,a={tokens:[n],numArgs:0,unexpandable:!e.gullet.isExpandable(n.text)}),e.gullet.macros.set(t,a,r)};Be({type:"internal",names:["\\global","\\long","\\\\globallong"],props:{numArgs:0,allowedInText:!0},handler(e){var{parser:t,funcName:n}=e;t.consumeSpaces();var r=t.fetch();if(Ix[r.text])return(n==="\\global"||n==="\\\\globallong")&&(r.text=Ix[r.text]),wt(t.parseFunction(),"internal");throw new Re("Invalid token after macro prefix",r)}});Be({type:"internal",names:["\\def","\\gdef","\\edef","\\xdef"],props:{numArgs:0,allowedInText:!0,primitive:!0},handler(e){var{parser:t,funcName:n}=e,r=t.gullet.popToken(),a=r.text;if(/^(?:[\\{}$&#^_]|EOF)$/.test(a))throw new Re("Expected a control sequence",r);for(var i=0,o,l=[[]];t.gullet.future().text!=="{";)if(r=t.gullet.popToken(),r.text==="#"){if(t.gullet.future().text==="{"){o=t.gullet.future(),l[i].push("{");break}if(r=t.gullet.popToken(),!/^[1-9]$/.test(r.text))throw new Re('Invalid argument number "'+r.text+'"');if(parseInt(r.text)!==i+1)throw new Re('Argument number "'+r.text+'" out of order');i++,l.push([])}else{if(r.text==="EOF")throw new Re("Expected a macro definition");l[i].push(r.text)}var{tokens:u}=t.gullet.consumeArg();return o&&u.unshift(o),(n==="\\edef"||n==="\\xdef")&&(u=t.gullet.expandTokens(u),u.reverse()),t.gullet.macros.set(a,{tokens:u,numArgs:i,delimiters:l},n===Ix[n]),{type:"internal",mode:t.mode}}});Be({type:"internal",names:["\\let","\\\\globallet"],props:{numArgs:0,allowedInText:!0,primitive:!0},handler(e){var{parser:t,funcName:n}=e,r=UD(t.gullet.popToken());t.gullet.consumeSpaces();var a=lie(t);return jD(t,r,a,n==="\\\\globallet"),{type:"internal",mode:t.mode}}});Be({type:"internal",names:["\\futurelet","\\\\globalfuture"],props:{numArgs:0,allowedInText:!0,primitive:!0},handler(e){var{parser:t,funcName:n}=e,r=UD(t.gullet.popToken()),a=t.gullet.popToken(),i=t.gullet.popToken();return jD(t,r,i,n==="\\\\globalfuture"),t.gullet.pushToken(i),t.gullet.pushToken(a),{type:"internal",mode:t.mode}}});var Qd=function(t,n,r){var a=yn.math[t]&&yn.math[t].replace,i=YS(a||t,n,r);if(!i)throw new Error("Unsupported symbol "+t+" and font size "+n+".");return i},ew=function(t,n,r,a){var i=r.havingBaseStyle(n),o=Ce(a.concat(i.sizingClasses(r)),[t],r),l=i.sizeMultiplier/r.sizeMultiplier;return o.height*=l,o.depth*=l,o.maxFontSize=i.sizeMultiplier,o},HD=function(t,n,r){var a=n.havingBaseStyle(r),i=(1-n.sizeMultiplier/a.sizeMultiplier)*n.fontMetrics().axisHeight;t.classes.push("delimcenter"),t.style.top=Ie(i),t.height-=i,t.depth+=i},cie=function(t,n,r,a,i,o){var l=Or(t,"Main-Regular",i,a),u=ew(l,n,a,o);return HD(u,a,n),u},uie=function(t,n,r,a){return Or(t,"Size"+n+"-Regular",r,a)},GD=function(t,n,r,a,i,o){var l=uie(t,n,i,a),u=ew(Ce(["delimsizing","size"+n],[l],a),mt.TEXT,a,o);return r&&HD(u,a,mt.TEXT),u},bv=function(t,n,r){var a;n==="Size1-Regular"?a="delim-size1":a="delim-size4";var i=Ce(["delimsizinginner",a],[Ce([],[Or(t,n,r)])]);return{type:"elem",elem:i}},yv=function(t,n,r){var a=Ti["Size4-Regular"][t.charCodeAt(0)]?Ti["Size4-Regular"][t.charCodeAt(0)][4]:Ti["Size1-Regular"][t.charCodeAt(0)][4],i=new Es("inner",Tae(t,Math.round(1e3*n))),o=new To([i],{width:Ie(a),height:Ie(n),style:"width:"+Ie(a),viewBox:"0 0 "+1e3*a+" "+Math.round(1e3*n),preserveAspectRatio:"xMinYMin"}),l=ks([],[o],r);return l.height=n,l.style.height=Ie(n),l.style.width=Ie(a),{type:"elem",elem:l}},Lx=.008,l0={type:"kern",size:-1*Lx},die=new Set(["|","\\lvert","\\rvert","\\vert"]),hie=new Set(["\\|","\\lVert","\\rVert","\\Vert"]),qD=function(t,n,r,a,i,o){var l,u,d,h,f="",m=0;l=d=h=t,u=null;var b="Size1-Regular";t==="\\uparrow"?d=h="⏐":t==="\\Uparrow"?d=h="‖":t==="\\downarrow"?l=d="⏐":t==="\\Downarrow"?l=d="‖":t==="\\updownarrow"?(l="\\uparrow",d="⏐",h="\\downarrow"):t==="\\Updownarrow"?(l="\\Uparrow",d="‖",h="\\Downarrow"):die.has(t)?(d="∣",f="vert",m=333):hie.has(t)?(d="∥",f="doublevert",m=556):t==="["||t==="\\lbrack"?(l="⎡",d="⎢",h="⎣",b="Size4-Regular",f="lbrack",m=667):t==="]"||t==="\\rbrack"?(l="⎤",d="⎥",h="⎦",b="Size4-Regular",f="rbrack",m=667):t==="\\lfloor"||t==="⌊"?(d=l="⎢",h="⎣",b="Size4-Regular",f="lfloor",m=667):t==="\\lceil"||t==="⌈"?(l="⎡",d=h="⎢",b="Size4-Regular",f="lceil",m=667):t==="\\rfloor"||t==="⌋"?(d=l="⎥",h="⎦",b="Size4-Regular",f="rfloor",m=667):t==="\\rceil"||t==="⌉"?(l="⎤",d=h="⎥",b="Size4-Regular",f="rceil",m=667):t==="("||t==="\\lparen"?(l="⎛",d="⎜",h="⎝",b="Size4-Regular",f="lparen",m=875):t===")"||t==="\\rparen"?(l="⎞",d="⎟",h="⎠",b="Size4-Regular",f="rparen",m=875):t==="\\{"||t==="\\lbrace"?(l="⎧",u="⎨",h="⎩",d="⎪",b="Size4-Regular"):t==="\\}"||t==="\\rbrace"?(l="⎫",u="⎬",h="⎭",d="⎪",b="Size4-Regular"):t==="\\lgroup"||t==="⟮"?(l="⎧",h="⎩",d="⎪",b="Size4-Regular"):t==="\\rgroup"||t==="⟯"?(l="⎫",h="⎭",d="⎪",b="Size4-Regular"):t==="\\lmoustache"||t==="⎰"?(l="⎧",h="⎭",d="⎪",b="Size4-Regular"):(t==="\\rmoustache"||t==="⎱")&&(l="⎫",h="⎩",d="⎪",b="Size4-Regular");var y=Qd(l,b,i),v=y.height+y.depth,w=Qd(d,b,i),S=w.height+w.depth,k=Qd(h,b,i),R=k.height+k.depth,I=0,L=1;if(u!==null){var A=Qd(u,b,i);I=A.height+A.depth,L=2}var M=v+R+I,P=Math.max(0,Math.ceil((n-M)/(L*S))),G=M+P*L*S,B=a.fontMetrics().axisHeight;r&&(B*=a.sizeMultiplier);var H=G/2-B,Z=[];if(f.length>0){var V=G-v-R,q=Math.round(G*1e3),X=_ae(f,Math.round(V*1e3)),$=new Es(f,X),Q=(m/1e3).toFixed(3)+"em",J=(q/1e3).toFixed(3)+"em",ie=new To([$],{width:Q,height:J,viewBox:"0 0 "+m+" "+q}),F=ks([],[ie],a);F.height=q/1e3,F.style.width=Q,F.style.height=J,Z.push({type:"elem",elem:F})}else{if(Z.push(bv(h,b,i)),Z.push(l0),u===null){var Y=G-v-R+2*Lx;Z.push(yv(d,Y,a))}else{var oe=(G-v-R-I)/2+2*Lx;Z.push(yv(d,oe,a)),Z.push(l0),Z.push(bv(u,b,i)),Z.push(l0),Z.push(yv(d,oe,a))}Z.push(l0),Z.push(bv(l,b,i))}var U=a.havingBaseStyle(mt.TEXT),be=Gt({positionType:"bottom",positionData:H,children:Z});return ew(Ce(["delimsizing","mult"],[be],U),mt.TEXT,a,o)},vv=80,xv=.08,Sv=function(t,n,r,a,i){var o=kae(t,a,r),l=new Es(t,o),u=new To([l],{width:"400em",height:Ie(n),viewBox:"0 0 400000 "+r,preserveAspectRatio:"xMinYMin slice"});return ks(["hide-tail"],[u],i)},pie=function(t,n){var r=n.havingBaseSizing(),a=KD("\\surd",t*r.sizeMultiplier,XD,r),i=r.sizeMultiplier,o=Math.max(0,n.minRuleThickness-n.fontMetrics().sqrtRuleThickness),l,u=0,d=0,h=0,f;return a.type==="small"?(h=1e3+1e3*o+vv,t<1?i=1:t<1.4&&(i=.7),u=(1+o+xv)/i,d=(1+o)/i,l=Sv("sqrtMain",u,h,o,n),l.style.minWidth="0.853em",f=.833/i):a.type==="large"?(h=(1e3+vv)*uh[a.size],d=(uh[a.size]+o)/i,u=(uh[a.size]+o+xv)/i,l=Sv("sqrtSize"+a.size,u,h,o,n),l.style.minWidth="1.02em",f=1/i):(u=t+o+xv,d=t+o,h=Math.floor(1e3*t+o)+vv,l=Sv("sqrtTall",u,h,o,n),l.style.minWidth="0.742em",f=1.056),l.height=d,l.style.height=Ie(u),{span:l,advanceWidth:f,ruleWidth:(n.fontMetrics().sqrtRuleThickness+o)*i}},WD=new Set(["(","\\lparen",")","\\rparen","[","\\lbrack","]","\\rbrack","\\{","\\lbrace","\\}","\\rbrace","\\lfloor","\\rfloor","⌊","⌋","\\lceil","\\rceil","⌈","⌉","\\surd"]),fie=new Set(["\\uparrow","\\downarrow","\\updownarrow","\\Uparrow","\\Downarrow","\\Updownarrow","|","\\|","\\vert","\\Vert","\\lvert","\\rvert","\\lVert","\\rVert","\\lgroup","\\rgroup","⟮","⟯","\\lmoustache","\\rmoustache","⎰","⎱"]),VD=new Set(["<",">","\\langle","\\rangle","/","\\backslash","\\lt","\\gt"]),uh=[0,1.2,1.8,2.4,3],YD=function(t,n,r,a,i){if(t==="<"||t==="\\lt"||t==="⟨"?t="\\langle":(t===">"||t==="\\gt"||t==="⟩")&&(t="\\rangle"),WD.has(t)||VD.has(t))return GD(t,n,!1,r,a,i);if(fie.has(t))return qD(t,uh[n],!1,r,a,i);throw new Re("Illegal delimiter: '"+t+"'")},mie=[{type:"small",style:mt.SCRIPTSCRIPT},{type:"small",style:mt.SCRIPT},{type:"small",style:mt.TEXT},{type:"large",size:1},{type:"large",size:2},{type:"large",size:3},{type:"large",size:4}],gie=[{type:"small",style:mt.SCRIPTSCRIPT},{type:"small",style:mt.SCRIPT},{type:"small",style:mt.TEXT},{type:"stack"}],XD=[{type:"small",style:mt.SCRIPTSCRIPT},{type:"small",style:mt.SCRIPT},{type:"small",style:mt.TEXT},{type:"large",size:1},{type:"large",size:2},{type:"large",size:3},{type:"large",size:4},{type:"stack"}],bie=function(t){if(t.type==="small")return"Main-Regular";if(t.type==="large")return"Size"+t.size+"-Regular";if(t.type==="stack")return"Size4-Regular";var n=t.type;throw new Error("Add support for delim type '"+n+"' here.")},KD=function(t,n,r,a){for(var i=Math.min(2,3-a.style.size),o=i;o<r.length;o++){var l=r[o];if(l.type==="stack")break;var u=Qd(t,bie(l),"math"),d=u.height+u.depth;if(l.type==="small"){var h=a.havingBaseStyle(l.style);d*=h.sizeMultiplier}if(d>n)return l}return r[r.length-1]},Dx=function(t,n,r,a,i,o){t==="<"||t==="\\lt"||t==="⟨"?t="\\langle":(t===">"||t==="\\gt"||t==="⟩")&&(t="\\rangle");var l;VD.has(t)?l=mie:WD.has(t)?l=XD:l=gie;var u=KD(t,n,l,a);return u.type==="small"?cie(t,u.style,r,a,i,o):u.type==="large"?GD(t,u.size,r,a,i,o):qD(t,n,r,a,i,o)},wv=function(t,n,r,a,i,o){var l=a.fontMetrics().axisHeight*a.sizeMultiplier,u=901,d=5/a.fontMetrics().ptPerEm,h=Math.max(n-l,r+l),f=Math.max(h/500*u,2*h-d);return Dx(t,f,!0,a,i,o)},SN={"\\bigl":{mclass:"mopen",size:1},"\\Bigl":{mclass:"mopen",size:2},"\\biggl":{mclass:"mopen",size:3},"\\Biggl":{mclass:"mopen",size:4},"\\bigr":{mclass:"mclose",size:1},"\\Bigr":{mclass:"mclose",size:2},"\\biggr":{mclass:"mclose",size:3},"\\Biggr":{mclass:"mclose",size:4},"\\bigm":{mclass:"mrel",size:1},"\\Bigm":{mclass:"mrel",size:2},"\\biggm":{mclass:"mrel",size:3},"\\Biggm":{mclass:"mrel",size:4},"\\big":{mclass:"mord",size:1},"\\Big":{mclass:"mord",size:2},"\\bigg":{mclass:"mord",size:3},"\\Bigg":{mclass:"mord",size:4}},yie=new Set(["(","\\lparen",")","\\rparen","[","\\lbrack","]","\\rbrack","\\{","\\lbrace","\\}","\\rbrace","\\lfloor","\\rfloor","⌊","⌋","\\lceil","\\rceil","⌈","⌉","<",">","\\langle","⟨","\\rangle","⟩","\\lt","\\gt","\\lvert","\\rvert","\\lVert","\\rVert","\\lgroup","\\rgroup","⟮","⟯","\\lmoustache","\\rmoustache","⎰","⎱","/","\\backslash","|","\\vert","\\|","\\Vert","\\uparrow","\\Uparrow","\\downarrow","\\Downarrow","\\updownarrow","\\Updownarrow","."]);function _g(e,t){var n=kg(e);if(n&&yie.has(n.text))return n;throw n?new Re("Invalid delimiter '"+n.text+"' after '"+t.funcName+"'",e):new Re("Invalid delimiter type '"+e.type+"'",e)}Be({type:"delimsizing",names:["\\bigl","\\Bigl","\\biggl","\\Biggl","\\bigr","\\Bigr","\\biggr","\\Biggr","\\bigm","\\Bigm","\\biggm","\\Biggm","\\big","\\Big","\\bigg","\\Bigg"],props:{numArgs:1,argTypes:["primitive"]},handler:(e,t)=>{var n=_g(t[0],e);return{type:"delimsizing",mode:e.parser.mode,size:SN[e.funcName].size,mclass:SN[e.funcName].mclass,delim:n.text}},htmlBuilder:(e,t)=>e.delim==="."?Ce([e.mclass]):YD(e.delim,e.size,t,e.mode,[e.mclass]),mathmlBuilder:e=>{var t=[];e.delim!=="."&&t.push(Ha(e.delim,e.mode));var n=new Oe("mo",t);e.mclass==="mopen"||e.mclass==="mclose"?n.setAttribute("fence","true"):n.setAttribute("fence","false"),n.setAttribute("stretchy","true");var r=Ie(uh[e.size]);return n.setAttribute("minsize",r),n.setAttribute("maxsize",r),n}});function wN(e){if(!e.body)throw new Error("Bug: The leftright ParseNode wasn't fully parsed.")}Be({type:"leftright-right",names:["\\right"],props:{numArgs:1,primitive:!0},handler:(e,t)=>{var n=e.parser.gullet.macros.get("\\current@color");if(n&&typeof n!="string")throw new Re("\\current@color set to non-string in \\right");return{type:"leftright-right",mode:e.parser.mode,delim:_g(t[0],e).text,color:n}}});Be({type:"leftright",names:["\\left"],props:{numArgs:1,primitive:!0},handler:(e,t)=>{var n=_g(t[0],e),r=e.parser;++r.leftrightDepth;var a=r.parseExpression(!1);--r.leftrightDepth,r.expect("\\right",!1);var i=wt(r.parseFunction(),"leftright-right");return{type:"leftright",mode:r.mode,body:a,left:n.text,right:i.delim,rightColor:i.color}},htmlBuilder:(e,t)=>{wN(e);for(var n=Kn(e.body,t,!0,["mopen","mclose"]),r=0,a=0,i=!1,o=0;o<n.length;o++)n[o].isMiddle?i=!0:(r=Math.max(n[o].height,r),a=Math.max(n[o].depth,a));r*=t.sizeMultiplier,a*=t.sizeMultiplier;var l;if(e.left==="."?l=Ah(t,["mopen"]):l=wv(e.left,r,a,t,e.mode,["mopen"]),n.unshift(l),i)for(var u=1;u<n.length;u++){var d=n[u],h=d.isMiddle;h&&(n[u]=wv(h.delim,r,a,h.options,e.mode,[]))}var f;if(e.right===".")f=Ah(t,["mclose"]);else{var m=e.rightColor?t.withColor(e.rightColor):t;f=wv(e.right,r,a,m,e.mode,["mclose"])}return n.push(f),Ce(["minner"],n,t)},mathmlBuilder:(e,t)=>{wN(e);var n=Sa(e.body,t);if(e.left!=="."){var r=new Oe("mo",[Ha(e.left,e.mode)]);r.setAttribute("fence","true"),n.unshift(r)}if(e.right!=="."){var a=new Oe("mo",[Ha(e.right,e.mode)]);a.setAttribute("fence","true"),e.rightColor&&a.setAttribute("mathcolor",e.rightColor),n.push(a)}return ZS(n)}});Be({type:"middle",names:["\\middle"],props:{numArgs:1,primitive:!0},handler:(e,t)=>{var n=_g(t[0],e);if(!e.parser.leftrightDepth)throw new Re("\\middle without preceding \\left",n);return{type:"middle",mode:e.parser.mode,delim:n.text}},htmlBuilder:(e,t)=>{var n;if(e.delim===".")n=Ah(t,[]);else{n=YD(e.delim,1,t,e.mode,[]);var r={delim:e.delim,options:t};n.isMiddle=r}return n},mathmlBuilder:(e,t)=>{var n=e.delim==="\\vert"||e.delim==="|"?Ha("|","text"):Ha(e.delim,e.mode),r=new Oe("mo",[n]);return r.setAttribute("fence","true"),r.setAttribute("lspace","0.05em"),r.setAttribute("rspace","0.05em"),r}});var tw=(e,t)=>{var n=tu(Wt(e.body,t),t),r=e.label.slice(1),a=t.sizeMultiplier,i,o=0,l=Ro(e.body);if(r==="sout")i=Ce(["stretchy","sout"]),i.height=t.fontMetrics().defaultRuleThickness/a,o=-.5*t.fontMetrics().xHeight;else if(r==="phase"){var u=wn({number:.6,unit:"pt"},t),d=wn({number:.35,unit:"ex"},t),h=t.havingBaseSizing();a=a/h.sizeMultiplier;var f=n.height+n.depth+u+d;n.style.paddingLeft=Ie(f/2+u);var m=Math.floor(1e3*f*a),b=wae(m),y=new To([new Es("phase",b)],{width:"400em",height:Ie(m/1e3),viewBox:"0 0 400000 "+m,preserveAspectRatio:"xMinYMin slice"});i=ks(["hide-tail"],[y],t),i.style.height=Ie(f),o=n.depth+u+d}else{/cancel/.test(r)?l||n.classes.push("cancel-pad"):r==="angl"?n.classes.push("anglpad"):n.classes.push("boxpad");var v=0,w=0,S=0;/box/.test(r)?(S=Math.max(t.fontMetrics().fboxrule,t.minRuleThickness),v=t.fontMetrics().fboxsep+(r==="colorbox"?0:S),w=v):r==="angl"?(S=Math.max(t.fontMetrics().defaultRuleThickness,t.minRuleThickness),v=4*S,w=Math.max(0,.25-n.depth)):(v=l?.2:0,w=v),i=nie(n,r,v,w,t),/fbox|boxed|fcolorbox/.test(r)?(i.style.borderStyle="solid",i.style.borderWidth=Ie(S)):r==="angl"&&S!==.049&&(i.style.borderTopWidth=Ie(S),i.style.borderRightWidth=Ie(S)),o=n.depth+w,e.backgroundColor&&(i.style.backgroundColor=e.backgroundColor,e.borderColor&&(i.style.borderColor=e.borderColor))}var k;if(e.backgroundColor)k=Gt({positionType:"individualShift",children:[{type:"elem",elem:i,shift:o},{type:"elem",elem:n,shift:0}]});else{var R=/cancel|phase/.test(r)?["svg-align"]:[];k=Gt({positionType:"individualShift",children:[{type:"elem",elem:n,shift:0},{type:"elem",elem:i,shift:o,wrapperClasses:R}]})}return/cancel/.test(r)&&(k.height=n.height,k.depth=n.depth),/cancel/.test(r)&&!l?Ce(["mord","cancel-lap"],[k],t):Ce(["mord"],[k],t)},nw=(e,t)=>{var n=0,r=new Oe(e.label.includes("colorbox")?"mpadded":"menclose",[an(e.body,t)]);switch(e.label){case"\\cancel":r.setAttribute("notation","updiagonalstrike");break;case"\\bcancel":r.setAttribute("notation","downdiagonalstrike");break;case"\\phase":r.setAttribute("notation","phasorangle");break;case"\\sout":r.setAttribute("notation","horizontalstrike");break;case"\\fbox":r.setAttribute("notation","box");break;case"\\angl":r.setAttribute("notation","actuarial");break;case"\\fcolorbox":case"\\colorbox":if(n=t.fontMetrics().fboxsep*t.fontMetrics().ptPerEm,r.setAttribute("width","+"+2*n+"pt"),r.setAttribute("height","+"+2*n+"pt"),r.setAttribute("lspace",n+"pt"),r.setAttribute("voffset",n+"pt"),e.label==="\\fcolorbox"){var a=Math.max(t.fontMetrics().fboxrule,t.minRuleThickness);r.setAttribute("style","border: "+a+"em solid "+String(e.borderColor))}break;case"\\xcancel":r.setAttribute("notation","updiagonalstrike downdiagonalstrike");break}return e.backgroundColor&&r.setAttribute("mathbackground",e.backgroundColor),r};Be({type:"enclose",names:["\\colorbox"],props:{numArgs:2,allowedInText:!0,argTypes:["color","text"]},handler(e,t,n){var{parser:r,funcName:a}=e,i=wt(t[0],"color-token").color,o=t[1];return{type:"enclose",mode:r.mode,label:a,backgroundColor:i,body:o}},htmlBuilder:tw,mathmlBuilder:nw});Be({type:"enclose",names:["\\fcolorbox"],props:{numArgs:3,allowedInText:!0,argTypes:["color","color","text"]},handler(e,t,n){var{parser:r,funcName:a}=e,i=wt(t[0],"color-token").color,o=wt(t[1],"color-token").color,l=t[2];return{type:"enclose",mode:r.mode,label:a,backgroundColor:o,borderColor:i,body:l}},htmlBuilder:tw,mathmlBuilder:nw});Be({type:"enclose",names:["\\fbox"],props:{numArgs:1,argTypes:["hbox"],allowedInText:!0},handler(e,t){var{parser:n}=e;return{type:"enclose",mode:n.mode,label:"\\fbox",body:t[0]}}});Be({type:"enclose",names:["\\cancel","\\bcancel","\\xcancel","\\sout","\\phase"],props:{numArgs:1},handler(e,t){var{parser:n,funcName:r}=e,a=t[0];return{type:"enclose",mode:n.mode,label:r,body:a}},htmlBuilder:tw,mathmlBuilder:nw});Be({type:"enclose",names:["\\angl"],props:{numArgs:1,argTypes:["hbox"],allowedInText:!1},handler(e,t){var{parser:n}=e;return{type:"enclose",mode:n.mode,label:"\\angl",body:t[0]}}});var ZD={};function Mi(e){for(var{type:t,names:n,props:r,handler:a,htmlBuilder:i,mathmlBuilder:o}=e,l={type:t,numArgs:r.numArgs||0,allowedInText:!1,numOptionalArgs:0,handler:a},u=0;u<n.length;++u)ZD[n[u]]=l;i&&(dm[t]=i),o&&(hm[t]=o)}var QD={};function W(e,t){QD[e]=t}class Zr{constructor(t,n,r){this.lexer=t,this.start=n,this.end=r}static range(t,n){return n?!t||!t.loc||!n.loc||t.loc.lexer!==n.loc.lexer?null:new Zr(t.loc.lexer,t.loc.start,n.loc.end):t&&t.loc}}let ri=class JD{constructor(t,n){this.text=t,this.loc=n}range(t,n){return new JD(n,Zr.range(this,t))}};function EN(e){var t=[];e.consumeSpaces();var n=e.fetch().text;for(n==="\\relax"&&(e.consume(),e.consumeSpaces(),n=e.fetch().text);n==="\\hline"||n==="\\hdashline";)e.consume(),t.push(n==="\\hdashline"),e.consumeSpaces(),n=e.fetch().text;return t}var Cg=e=>{var t=e.parser.settings;if(!t.displayMode)throw new Re("{"+e.envName+"} can be used only in display mode.")},vie=new Set(["gather","gather*"]);function rw(e){if(!e.includes("ed"))return!e.includes("*")}function Ls(e,t,n){var{hskipBeforeAndAfter:r,addJot:a,cols:i,arraystretch:o,colSeparationType:l,autoTag:u,singleRow:d,emptySingleRow:h,maxNumCols:f,leqno:m}=t;if(e.gullet.beginGroup(),d||e.gullet.macros.set("\\cr","\\\\\\relax"),!o){var b=e.gullet.expandMacroAsText("\\arraystretch");if(b==null)o=1;else if(o=parseFloat(b),!o||o<0)throw new Re("Invalid \\arraystretch: "+b)}e.gullet.beginGroup();var y=[],v=[y],w=[],S=[],k=u!=null?[]:void 0;function R(){u&&e.gullet.macros.set("\\@eqnsw","1",!0)}function I(){k&&(e.gullet.macros.get("\\df@tag")?(k.push(e.subparse([new ri("\\df@tag")])),e.gullet.macros.set("\\df@tag",void 0,!0)):k.push(!!u&&e.gullet.macros.get("\\@eqnsw")==="1"))}for(R(),S.push(EN(e));;){var L=e.parseExpression(!1,d?"\\end":"\\\\");e.gullet.endGroup(),e.gullet.beginGroup();var A={type:"ordgroup",mode:e.mode,body:L};n&&(A={type:"styling",mode:e.mode,style:n,body:[A]}),y.push(A);var M=e.fetch().text;if(M==="&"){if(f&&y.length===f){if(d||l)throw new Re("Too many tab characters: &",e.nextToken);e.settings.reportNonstrict("textEnv","Too few columns specified in the {array} column argument.")}e.consume()}else if(M==="\\end"){I(),y.length===1&&A.type==="styling"&&A.body.length===1&&A.body[0].type==="ordgroup"&&A.body[0].body.length===0&&(v.length>1||!h)&&v.pop(),S.length<v.length+1&&S.push([]);break}else if(M==="\\\\"){e.consume();var P=void 0;e.gullet.future().text!==" "&&(P=e.parseSizeGroup(!0)),w.push(P?P.value:null),I(),S.push(EN(e)),y=[],v.push(y),R()}else throw new Re("Expected & or \\\\ or \\cr or \\end",e.nextToken)}return e.gullet.endGroup(),e.gullet.endGroup(),{type:"array",mode:e.mode,addJot:a,arraystretch:o,body:v,cols:i,rowGaps:w,hskipBeforeAndAfter:r,hLinesBeforeRow:S,colSeparationType:l,tags:k,leqno:m}}function aw(e){return e.slice(0,1)==="d"?"display":"text"}var Bi=function(t,n){var r,a,i=t.body.length,o=t.hLinesBeforeRow,l=0,u=new Array(i),d=[],h=Math.max(n.fontMetrics().arrayRuleWidth,n.minRuleThickness),f=1/n.fontMetrics().ptPerEm,m=5*f;if(t.colSeparationType&&t.colSeparationType==="small"){var b=n.havingStyle(mt.SCRIPT).sizeMultiplier;m=.2778*(b/n.sizeMultiplier)}var y=t.colSeparationType==="CD"?wn({number:3,unit:"ex"},n):12*f,v=3*f,w=t.arraystretch*y,S=.7*w,k=.3*w,R=0;function I(We){for(var ut=0;ut<We.length;++ut)ut>0&&(R+=.25),d.push({pos:R,isDashed:We[ut]})}for(I(o[0]),r=0;r<t.body.length;++r){var L=t.body[r],A=S,M=k;l<L.length&&(l=L.length);var P=new Array(L.length);for(a=0;a<L.length;++a){var G=Wt(L[a],n);M<G.depth&&(M=G.depth),A<G.height&&(A=G.height),P[a]=G}var B=t.rowGaps[r],H=0;B&&(H=wn(B,n),H>0&&(H+=k,M<H&&(M=H),H=0)),t.addJot&&(M+=v),P.height=A,P.depth=M,R+=A,P.pos=R,R+=M+H,u[r]=P,I(o[r+1])}var Z=R/2+n.fontMetrics().axisHeight,V=t.cols||[],q=[],X,$,Q=[];if(t.tags&&t.tags.some(We=>We))for(r=0;r<i;++r){var J=u[r],ie=J.pos-Z,F=t.tags[r],Y=void 0;F===!0?Y=Ce(["eqn-num"],[],n):F===!1?Y=Ce([],[],n):Y=Ce([],Kn(F,n,!0),n),Y.depth=J.depth,Y.height=J.height,Q.push({type:"elem",elem:Y,shift:ie})}for(a=0,$=0;a<l||$<V.length;++a,++$){for(var oe,U=V[$],be=!0;((ge=U)==null?void 0:ge.type)==="separator";){var ge;if(be||(X=Ce(["arraycolsep"],[]),X.style.width=Ie(n.fontMetrics().doubleRuleSep),q.push(X)),U.separator==="|"||U.separator===":"){var fe=U.separator==="|"?"solid":"dashed",Ee=Ce(["vertical-separator"],[],n);Ee.style.height=Ie(R),Ee.style.borderRightWidth=Ie(h),Ee.style.borderRightStyle=fe,Ee.style.margin="0 "+Ie(-h/2);var Ae=R-Z;Ae&&(Ee.style.verticalAlign=Ie(-Ae)),q.push(Ee)}else throw new Re("Invalid separator type: "+U.separator);$++,U=V[$],be=!1}if(!(a>=l)){var ve=void 0;if(a>0||t.hskipBeforeAndAfter){var De,Le;ve=(De=(Le=U)==null?void 0:Le.pregap)!=null?De:m,ve!==0&&(X=Ce(["arraycolsep"],[]),X.style.width=Ie(ve),q.push(X))}var rt=[];for(r=0;r<i;++r){var Xe=u[r],gt=Xe[a];if(gt){var Xt=Xe.pos-Z;gt.depth=Xe.depth,gt.height=Xe.height,rt.push({type:"elem",elem:gt,shift:Xt})}}var er=Gt({positionType:"individualShift",children:rt}),Tr=Ce(["col-align-"+(((oe=U)==null?void 0:oe.align)||"c")],[er]);if(q.push(Tr),a<l-1||t.hskipBeforeAndAfter){var Hn,Cn;ve=(Hn=(Cn=U)==null?void 0:Cn.postgap)!=null?Hn:m,ve!==0&&(X=Ce(["arraycolsep"],[]),X.style.width=Ie(ve),q.push(X))}}}var Zn=Ce(["mtable"],q);if(d.length>0){for(var wa=eu("hline",n,h),di=eu("hdashline",n,h),qe=[{type:"elem",elem:Zn,shift:0}];d.length>0;){var yt=d.pop(),ur=yt.pos-Z;yt.isDashed?qe.push({type:"elem",elem:di,shift:ur}):qe.push({type:"elem",elem:wa,shift:ur})}Zn=Gt({positionType:"individualShift",children:qe})}if(Q.length===0)return Ce(["mord"],[Zn],n);var me=Gt({positionType:"individualShift",children:Q}),Te=Ce(["tag"],[me],n);return Oo([Zn,Te])},xie={c:"center ",l:"left ",r:"right "},Fi=function(t,n){for(var r=[],a=new Oe("mtd",[],["mtr-glue"]),i=new Oe("mtd",[],["mml-eqn-num"]),o=0;o<t.body.length;o++){for(var l=t.body[o],u=[],d=0;d<l.length;d++)u.push(new Oe("mtd",[an(l[d],n)]));t.tags&&t.tags[o]&&(u.unshift(a),u.push(a),t.leqno?u.unshift(i):u.push(i)),r.push(new Oe("mtr",u))}var h=new Oe("mtable",r),f=t.arraystretch===.5?.1:.16+t.arraystretch-1+(t.addJot?.09:0);h.setAttribute("rowspacing",Ie(f));var m="",b="";if(t.cols&&t.cols.length>0){var y=t.cols,v="",w=!1,S=0,k=y.length;y[0].type==="separator"&&(m+="top ",S=1),y[y.length-1].type==="separator"&&(m+="bottom ",k-=1);for(var R=S;R<k;R++){var I=y[R];I.type==="align"?(b+=xie[I.align],w&&(v+="none "),w=!0):I.type==="separator"&&w&&(v+=I.separator==="|"?"solid ":"dashed ",w=!1)}h.setAttribute("columnalign",b.trim()),/[sd]/.test(v)&&h.setAttribute("columnlines",v.trim())}if(t.colSeparationType==="align"){for(var L=t.cols||[],A="",M=1;M<L.length;M++)A+=M%2?"0em ":"1em ";h.setAttribute("columnspacing",A.trim())}else t.colSeparationType==="alignat"||t.colSeparationType==="gather"?h.setAttribute("columnspacing","0em"):t.colSeparationType==="small"?h.setAttribute("columnspacing","0.2778em"):t.colSeparationType==="CD"?h.setAttribute("columnspacing","0.5em"):h.setAttribute("columnspacing","1em");var P="",G=t.hLinesBeforeRow;m+=G[0].length>0?"left ":"",m+=G[G.length-1].length>0?"right ":"";for(var B=1;B<G.length-1;B++)P+=G[B].length===0?"none ":G[B][0]?"dashed ":"solid ";return/[sd]/.test(P)&&h.setAttribute("rowlines",P.trim()),m!==""&&(h=new Oe("menclose",[h]),h.setAttribute("notation",m.trim())),t.arraystretch&&t.arraystretch<1&&(h=new Oe("mstyle",[h]),h.setAttribute("scriptlevel","1")),h},eM=function(t,n){t.envName.includes("ed")||Cg(t);var r=[],a=t.envName.includes("at")?"alignat":"align",i=t.envName==="split",o=Ls(t.parser,{cols:r,addJot:!0,autoTag:i?void 0:rw(t.envName),emptySingleRow:!0,colSeparationType:a,maxNumCols:i?2:void 0,leqno:t.parser.settings.leqno},"display"),l=0,u=0,d={type:"ordgroup",mode:t.mode,body:[]};if(n[0]&&n[0].type==="ordgroup"){for(var h="",f=0;f<n[0].body.length;f++){var m=wt(n[0].body[f],"textord");h+=m.text}l=Number(h),u=l*2}var b=!u;o.body.forEach(function(S){for(var k=1;k<S.length;k+=2){var R=wt(S[k],"styling"),I=wt(R.body[0],"ordgroup");I.body.unshift(d)}if(b)u<S.length&&(u=S.length);else{var L=S.length/2;if(l<L)throw new Re("Too many math in a row: "+("expected "+l+", but got "+L),S[0])}});for(var y=0;y<u;++y){var v="r",w=0;y%2===1?v="l":y>0&&b&&(w=1),r[y]={type:"align",align:v,pregap:w,postgap:0}}return o.colSeparationType=b?"align":"alignat",o};Mi({type:"array",names:["array","darray"],props:{numArgs:1},handler(e,t){var n=kg(t[0]),r=n?[t[0]]:wt(t[0],"ordgroup").body,a=r.map(function(o){var l=Eg(o),u=l.text;if("lcr".includes(u))return{type:"align",align:u};if(u==="|")return{type:"separator",separator:"|"};if(u===":")return{type:"separator",separator:":"};throw new Re("Unknown column alignment: "+u,o)}),i={cols:a,hskipBeforeAndAfter:!0,maxNumCols:a.length};return Ls(e.parser,i,aw(e.envName))},htmlBuilder:Bi,mathmlBuilder:Fi});Mi({type:"array",names:["matrix","pmatrix","bmatrix","Bmatrix","vmatrix","Vmatrix","matrix*","pmatrix*","bmatrix*","Bmatrix*","vmatrix*","Vmatrix*"],props:{numArgs:0},handler(e){var t={matrix:null,pmatrix:["(",")"],bmatrix:["[","]"],Bmatrix:["\\{","\\}"],vmatrix:["|","|"],Vmatrix:["\\Vert","\\Vert"]}[e.envName.replace("*","")],n="c",r={hskipBeforeAndAfter:!1,cols:[{type:"align",align:n}]};if(e.envName.charAt(e.envName.length-1)==="*"){var a=e.parser;if(a.consumeSpaces(),a.fetch().text==="["){if(a.consume(),a.consumeSpaces(),n=a.fetch().text,!"lcr".includes(n))throw new Re("Expected l or c or r",a.nextToken);a.consume(),a.consumeSpaces(),a.expect("]"),a.consume(),r.cols=[{type:"align",align:n}]}}var i=Ls(e.parser,r,aw(e.envName)),o=Math.max(0,...i.body.map(l=>l.length));return i.cols=new Array(o).fill({type:"align",align:n}),t?{type:"leftright",mode:e.mode,body:[i],left:t[0],right:t[1],rightColor:void 0}:i},htmlBuilder:Bi,mathmlBuilder:Fi});Mi({type:"array",names:["smallmatrix"],props:{numArgs:0},handler(e){var t={arraystretch:.5},n=Ls(e.parser,t,"script");return n.colSeparationType="small",n},htmlBuilder:Bi,mathmlBuilder:Fi});Mi({type:"array",names:["subarray"],props:{numArgs:1},handler(e,t){var n=kg(t[0]),r=n?[t[0]]:wt(t[0],"ordgroup").body,a=r.map(function(l){var u=Eg(l),d=u.text;if("lc".includes(d))return{type:"align",align:d};throw new Re("Unknown column alignment: "+d,l)});if(a.length>1)throw new Re("{subarray} can contain only one column");var i={cols:a,hskipBeforeAndAfter:!1,arraystretch:.5},o=Ls(e.parser,i,"script");if(o.body.length>0&&o.body[0].length>1)throw new Re("{subarray} can contain only one column");return o},htmlBuilder:Bi,mathmlBuilder:Fi});Mi({type:"array",names:["cases","dcases","rcases","drcases"],props:{numArgs:0},handler(e){var t={arraystretch:1.2,cols:[{type:"align",align:"l",pregap:0,postgap:1},{type:"align",align:"l",pregap:0,postgap:0}]},n=Ls(e.parser,t,aw(e.envName));return{type:"leftright",mode:e.mode,body:[n],left:e.envName.includes("r")?".":"\\{",right:e.envName.includes("r")?"\\}":".",rightColor:void 0}},htmlBuilder:Bi,mathmlBuilder:Fi});Mi({type:"array",names:["align","align*","aligned","split"],props:{numArgs:0},handler:eM,htmlBuilder:Bi,mathmlBuilder:Fi});Mi({type:"array",names:["gathered","gather","gather*"],props:{numArgs:0},handler(e){vie.has(e.envName)&&Cg(e);var t={cols:[{type:"align",align:"c"}],addJot:!0,colSeparationType:"gather",autoTag:rw(e.envName),emptySingleRow:!0,leqno:e.parser.settings.leqno};return Ls(e.parser,t,"display")},htmlBuilder:Bi,mathmlBuilder:Fi});Mi({type:"array",names:["alignat","alignat*","alignedat"],props:{numArgs:1},handler:eM,htmlBuilder:Bi,mathmlBuilder:Fi});Mi({type:"array",names:["equation","equation*"],props:{numArgs:0},handler(e){Cg(e);var t={autoTag:rw(e.envName),emptySingleRow:!0,singleRow:!0,maxNumCols:1,leqno:e.parser.settings.leqno};return Ls(e.parser,t,"display")},htmlBuilder:Bi,mathmlBuilder:Fi});Mi({type:"array",names:["CD"],props:{numArgs:0},handler(e){return Cg(e),sie(e.parser)},htmlBuilder:Bi,mathmlBuilder:Fi});W("\\nonumber","\\gdef\\@eqnsw{0}");W("\\notag","\\nonumber");Be({type:"text",names:["\\hline","\\hdashline"],props:{numArgs:0,allowedInText:!0,allowedInMath:!0},handler(e,t){throw new Re(e.funcName+" valid only within array environment")}});var kN=ZD;Be({type:"environment",names:["\\begin","\\end"],props:{numArgs:1,argTypes:["text"]},handler(e,t){var{parser:n,funcName:r}=e,a=t[0];if(a.type!=="ordgroup")throw new Re("Invalid environment name",a);for(var i="",o=0;o<a.body.length;++o)i+=wt(a.body[o],"textord").text;if(r==="\\begin"){if(!kN.hasOwnProperty(i))throw new Re("No such environment: "+i,a);var l=kN[i],{args:u,optArgs:d}=n.parseArguments("\\begin{"+i+"}",l),h={mode:n.mode,envName:i,parser:n},f=l.handler(h,u,d);n.expect("\\end",!1);var m=n.nextToken,b=wt(n.parseFunction(),"environment");if(b.name!==i)throw new Re("Mismatch: \\begin{"+i+"} matched by \\end{"+b.name+"}",m);return f}return{type:"environment",mode:n.mode,name:i,nameGroup:a}}});var tM=(e,t)=>{var n=e.font,r=t.withFont(n);return Wt(e.body,r)},nM=(e,t)=>{var n=e.font,r=t.withFont(n);return an(e.body,r)},TN={"\\Bbb":"\\mathbb","\\bold":"\\mathbf","\\frak":"\\mathfrak","\\bm":"\\boldsymbol"};Be({type:"font",names:["\\mathrm","\\mathit","\\mathbf","\\mathnormal","\\mathsfit","\\mathbb","\\mathcal","\\mathfrak","\\mathscr","\\mathsf","\\mathtt","\\Bbb","\\bold","\\frak"],props:{numArgs:1,allowedInArgument:!0},handler:(e,t)=>{var{parser:n,funcName:r}=e,a=pm(t[0]),i=r;return i in TN&&(i=TN[i]),{type:"font",mode:n.mode,font:i.slice(1),body:a}},htmlBuilder:tM,mathmlBuilder:nM});Be({type:"mclass",names:["\\boldsymbol","\\bm"],props:{numArgs:1},handler:(e,t)=>{var{parser:n}=e,r=t[0];return{type:"mclass",mode:n.mode,mclass:Tg(r),body:[{type:"font",mode:n.mode,font:"boldsymbol",body:r}],isCharacterBox:Ro(r)}}});Be({type:"font",names:["\\rm","\\sf","\\tt","\\bf","\\it","\\cal"],props:{numArgs:0,allowedInText:!0},handler:(e,t)=>{var{parser:n,funcName:r,breakOnTokenText:a}=e,{mode:i}=n,o=n.parseExpression(!0,a),l="math"+r.slice(1);return{type:"font",mode:i,font:l,body:{type:"ordgroup",mode:n.mode,body:o}}},htmlBuilder:tM,mathmlBuilder:nM});var Sie=(e,t)=>{var n=t.style,r=n.fracNum(),a=n.fracDen(),i;i=t.havingStyle(r);var o=Wt(e.numer,i,t);if(e.continued){var l=8.5/t.fontMetrics().ptPerEm,u=3.5/t.fontMetrics().ptPerEm;o.height=o.height<l?l:o.height,o.depth=o.depth<u?u:o.depth}i=t.havingStyle(a);var d=Wt(e.denom,i,t),h,f,m;e.hasBarLine?(e.barSize?(f=wn(e.barSize,t),h=eu("frac-line",t,f)):h=eu("frac-line",t),f=h.height,m=h.height):(h=null,f=0,m=t.fontMetrics().defaultRuleThickness);var b,y,v;n.size===mt.DISPLAY.size?(b=t.fontMetrics().num1,f>0?y=3*m:y=7*m,v=t.fontMetrics().denom1):(f>0?(b=t.fontMetrics().num2,y=m):(b=t.fontMetrics().num3,y=3*m),v=t.fontMetrics().denom2);var w;if(h){var k=t.fontMetrics().axisHeight;b-o.depth-(k+.5*f)<y&&(b+=y-(b-o.depth-(k+.5*f))),k-.5*f-(d.height-v)<y&&(v+=y-(k-.5*f-(d.height-v)));var R=-(k-.5*f);w=Gt({positionType:"individualShift",children:[{type:"elem",elem:d,shift:v},{type:"elem",elem:h,shift:R},{type:"elem",elem:o,shift:-b}]})}else{var S=b-o.depth-(d.height-v);S<y&&(b+=.5*(y-S),v+=.5*(y-S)),w=Gt({positionType:"individualShift",children:[{type:"elem",elem:d,shift:v},{type:"elem",elem:o,shift:-b}]})}i=t.havingStyle(n),w.height*=i.sizeMultiplier/t.sizeMultiplier,w.depth*=i.sizeMultiplier/t.sizeMultiplier;var I;n.size===mt.DISPLAY.size?I=t.fontMetrics().delim1:n.size===mt.SCRIPTSCRIPT.size?I=t.havingStyle(mt.SCRIPT).fontMetrics().delim2:I=t.fontMetrics().delim2;var L,A;return e.leftDelim==null?L=Ah(t,["mopen"]):L=Dx(e.leftDelim,I,!0,t.havingStyle(n),e.mode,["mopen"]),e.continued?A=Ce([]):e.rightDelim==null?A=Ah(t,["mclose"]):A=Dx(e.rightDelim,I,!0,t.havingStyle(n),e.mode,["mclose"]),Ce(["mord"].concat(i.sizingClasses(t)),[L,Ce(["mfrac"],[w]),A],t)},wie=(e,t)=>{var n=new Oe("mfrac",[an(e.numer,t),an(e.denom,t)]);if(!e.hasBarLine)n.setAttribute("linethickness","0px");else if(e.barSize){var r=wn(e.barSize,t);n.setAttribute("linethickness",Ie(r))}if(e.leftDelim!=null||e.rightDelim!=null){var a=[];if(e.leftDelim!=null){var i=new Oe("mo",[new Un(e.leftDelim.replace("\\",""))]);i.setAttribute("fence","true"),a.push(i)}if(a.push(n),e.rightDelim!=null){var o=new Oe("mo",[new Un(e.rightDelim.replace("\\",""))]);o.setAttribute("fence","true"),a.push(o)}return ZS(a)}return n},rM=(e,t)=>{if(!t)return e;var n={type:"styling",mode:e.mode,style:t,body:[e]};return n};Be({type:"genfrac",names:["\\cfrac","\\dfrac","\\frac","\\tfrac","\\dbinom","\\binom","\\tbinom","\\\\atopfrac","\\\\bracefrac","\\\\brackfrac"],props:{numArgs:2,allowedInArgument:!0},handler:(e,t)=>{var{parser:n,funcName:r}=e,a=t[0],i=t[1],o,l=null,u=null;switch(r){case"\\cfrac":case"\\dfrac":case"\\frac":case"\\tfrac":o=!0;break;case"\\\\atopfrac":o=!1;break;case"\\dbinom":case"\\binom":case"\\tbinom":o=!1,l="(",u=")";break;case"\\\\bracefrac":o=!1,l="\\{",u="\\}";break;case"\\\\brackfrac":o=!1,l="[",u="]";break;default:throw new Error("Unrecognized genfrac command")}var d=r==="\\cfrac",h=null;return d||r.startsWith("\\d")?h="display":r.startsWith("\\t")&&(h="text"),rM({type:"genfrac",mode:n.mode,numer:a,denom:i,continued:d,hasBarLine:o,leftDelim:l,rightDelim:u,barSize:null},h)},htmlBuilder:Sie,mathmlBuilder:wie});Be({type:"infix",names:["\\over","\\choose","\\atop","\\brace","\\brack"],props:{numArgs:0,infix:!0},handler(e){var{parser:t,funcName:n,token:r}=e,a;switch(n){case"\\over":a="\\frac";break;case"\\choose":a="\\binom";break;case"\\atop":a="\\\\atopfrac";break;case"\\brace":a="\\\\bracefrac";break;case"\\brack":a="\\\\brackfrac";break;default:throw new Error("Unrecognized infix genfrac command")}return{type:"infix",mode:t.mode,replaceWith:a,token:r}}});var _N=["display","text","script","scriptscript"],CN=function(t){var n=null;return t.length>0&&(n=t,n=n==="."?null:n),n};Be({type:"genfrac",names:["\\genfrac"],props:{numArgs:6,allowedInArgument:!0,argTypes:["math","math","size","text","math","math"]},handler(e,t){var{parser:n}=e,r=t[4],a=t[5],i=pm(t[0]),o=i.type==="atom"&&i.family==="open"?CN(i.text):null,l=pm(t[1]),u=l.type==="atom"&&l.family==="close"?CN(l.text):null,d=wt(t[2],"size"),h,f=null;d.isBlank?h=!0:(f=d.value,h=f.number>0);var m=null,b=t[3];if(b.type==="ordgroup"){if(b.body.length>0){var y=wt(b.body[0],"textord");m=_N[Number(y.text)]}}else b=wt(b,"textord"),m=_N[Number(b.text)];return rM({type:"genfrac",mode:n.mode,numer:r,denom:a,continued:!1,hasBarLine:h,barSize:f,leftDelim:o,rightDelim:u},m)}});Be({type:"infix",names:["\\above"],props:{numArgs:1,argTypes:["size"],infix:!0},handler(e,t){var{parser:n,funcName:r,token:a}=e;return{type:"infix",mode:n.mode,replaceWith:"\\\\abovefrac",size:wt(t[0],"size").value,token:a}}});Be({type:"genfrac",names:["\\\\abovefrac"],props:{numArgs:3,argTypes:["math","size","math"]},handler:(e,t)=>{var{parser:n,funcName:r}=e,a=t[0],i=wt(t[1],"infix").size;if(!i)throw new Error("\\\\abovefrac expected size, but got "+String(i));var o=t[2],l=i.number>0;return{type:"genfrac",mode:n.mode,numer:a,denom:o,continued:!1,hasBarLine:l,barSize:i,leftDelim:null,rightDelim:null}}});var aM=(e,t)=>{var n=t.style,r,a;e.type==="supsub"?(r=e.sup?Wt(e.sup,t.havingStyle(n.sup()),t):Wt(e.sub,t.havingStyle(n.sub()),t),a=wt(e.base,"horizBrace")):a=wt(e,"horizBrace");var i=Wt(a.base,t.havingBaseStyle(mt.DISPLAY)),o=wg(a,t),l;if(a.isOver?(l=Gt({positionType:"firstBaseline",children:[{type:"elem",elem:i},{type:"kern",size:.1},{type:"elem",elem:o}]}),l.children[0].children[0].children[1].classes.push("svg-align")):(l=Gt({positionType:"bottom",positionData:i.depth+.1+o.height,children:[{type:"elem",elem:o},{type:"kern",size:.1},{type:"elem",elem:i}]}),l.children[0].children[0].children[0].classes.push("svg-align")),r){var u=Ce(["mord",a.isOver?"mover":"munder"],[l],t);a.isOver?l=Gt({positionType:"firstBaseline",children:[{type:"elem",elem:u},{type:"kern",size:.2},{type:"elem",elem:r}]}):l=Gt({positionType:"bottom",positionData:u.depth+.2+r.height+r.depth,children:[{type:"elem",elem:r},{type:"kern",size:.2},{type:"elem",elem:u}]})}return Ce(["mord",a.isOver?"mover":"munder"],[l],t)},Eie=(e,t)=>{var n=Sg(e.label);return new Oe(e.isOver?"mover":"munder",[an(e.base,t),n])};Be({type:"horizBrace",names:["\\overbrace","\\underbrace"],props:{numArgs:1},handler(e,t){var{parser:n,funcName:r}=e;return{type:"horizBrace",mode:n.mode,label:r,isOver:/^\\over/.test(r),base:t[0]}},htmlBuilder:aM,mathmlBuilder:Eie});Be({type:"href",names:["\\href"],props:{numArgs:2,argTypes:["url","original"],allowedInText:!0},handler:(e,t)=>{var{parser:n}=e,r=t[1],a=wt(t[0],"url").url;return n.settings.isTrusted({command:"\\href",url:a})?{type:"href",mode:n.mode,href:a,body:Pn(r)}:n.formatUnsupportedCmd("\\href")},htmlBuilder:(e,t)=>{var n=Kn(e.body,t,!1);return Pae(e.href,[],n,t)},mathmlBuilder:(e,t)=>{var n=Ts(e.body,t);return n instanceof Oe||(n=new Oe("mrow",[n])),n.setAttribute("href",e.href),n}});Be({type:"href",names:["\\url"],props:{numArgs:1,argTypes:["url"],allowedInText:!0},handler:(e,t)=>{var{parser:n}=e,r=wt(t[0],"url").url;if(!n.settings.isTrusted({command:"\\url",url:r}))return n.formatUnsupportedCmd("\\url");for(var a=[],i=0;i<r.length;i++){var o=r[i];o==="~"&&(o="\\textasciitilde"),a.push({type:"textord",mode:"text",text:o})}var l={type:"text",mode:n.mode,font:"\\texttt",body:a};return{type:"href",mode:n.mode,href:r,body:Pn(l)}}});Be({type:"hbox",names:["\\hbox"],props:{numArgs:1,argTypes:["text"],allowedInText:!0,primitive:!0},handler(e,t){var{parser:n}=e;return{type:"hbox",mode:n.mode,body:Pn(t[0])}},htmlBuilder(e,t){var n=Kn(e.body,t,!1);return Oo(n)},mathmlBuilder(e,t){return new Oe("mrow",Sa(e.body,t))}});Be({type:"html",names:["\\htmlClass","\\htmlId","\\htmlStyle","\\htmlData"],props:{numArgs:2,argTypes:["raw","original"],allowedInText:!0},handler:(e,t)=>{var{parser:n,funcName:r,token:a}=e,i=wt(t[0],"raw").string,o=t[1];n.settings.strict&&n.settings.reportNonstrict("htmlExtension","HTML extension is disabled on strict mode");var l,u={};switch(r){case"\\htmlClass":u.class=i,l={command:"\\htmlClass",class:i};break;case"\\htmlId":u.id=i,l={command:"\\htmlId",id:i};break;case"\\htmlStyle":u.style=i,l={command:"\\htmlStyle",style:i};break;case"\\htmlData":{for(var d=i.split(","),h=0;h<d.length;h++){var f=d[h],m=f.indexOf("=");if(m<0)throw new Re("\\htmlData key/value '"+f+"' missing equals sign");var b=f.slice(0,m),y=f.slice(m+1);u["data-"+b.trim()]=y}l={command:"\\htmlData",attributes:u};break}default:throw new Error("Unrecognized html command")}return n.settings.isTrusted(l)?{type:"html",mode:n.mode,attributes:u,body:Pn(o)}:n.formatUnsupportedCmd(r)},htmlBuilder:(e,t)=>{var n=Kn(e.body,t,!1),r=["enclosing"];e.attributes.class&&r.push(...e.attributes.class.trim().split(/\s+/));var a=Ce(r,n,t);for(var i in e.attributes)i!=="class"&&e.attributes.hasOwnProperty(i)&&a.setAttribute(i,e.attributes[i]);return a},mathmlBuilder:(e,t)=>Ts(e.body,t)});Be({type:"htmlmathml",names:["\\html@mathml"],props:{numArgs:2,allowedInArgument:!0,allowedInText:!0},handler:(e,t)=>{var{parser:n}=e;return{type:"htmlmathml",mode:n.mode,html:Pn(t[0]),mathml:Pn(t[1])}},htmlBuilder:(e,t)=>{var n=Kn(e.html,t,!1);return Oo(n)},mathmlBuilder:(e,t)=>Ts(e.mathml,t)});var Ev=function(t){if(/^[-+]? *(\d+(\.\d*)?|\.\d+)$/.test(t))return{number:+t,unit:"bp"};var n=/([-+]?) *(\d+(?:\.\d*)?|\.\d+) *([a-z]{2})/.exec(t);if(!n)throw new Re("Invalid size: '"+t+"' in \\includegraphics");var r={number:+(n[1]+n[2]),unit:n[3]};if(!vD(r))throw new Re("Invalid unit: '"+r.unit+"' in \\includegraphics.");return r};Be({type:"includegraphics",names:["\\includegraphics"],props:{numArgs:1,numOptionalArgs:1,argTypes:["raw","url"],allowedInText:!1},handler:(e,t,n)=>{var{parser:r}=e,a={number:0,unit:"em"},i={number:.9,unit:"em"},o={number:0,unit:"em"},l="";if(n[0])for(var u=wt(n[0],"raw").string,d=u.split(","),h=0;h<d.length;h++){var f=d[h].split("=");if(f.length===2){var m=f[1].trim();switch(f[0].trim()){case"alt":l=m;break;case"width":a=Ev(m);break;case"height":i=Ev(m);break;case"totalheight":o=Ev(m);break;default:throw new Re("Invalid key: '"+f[0]+"' in \\includegraphics.")}}}var b=wt(t[0],"url").url;return l===""&&(l=b,l=l.replace(/^.*[\\/]/,""),l=l.substring(0,l.lastIndexOf("."))),r.settings.isTrusted({command:"\\includegraphics",url:b})?{type:"includegraphics",mode:r.mode,alt:l,width:a,height:i,totalheight:o,src:b}:r.formatUnsupportedCmd("\\includegraphics")},htmlBuilder:(e,t)=>{var n=wn(e.height,t),r=0;e.totalheight.number>0&&(r=wn(e.totalheight,t)-n);var a=0;e.width.number>0&&(a=wn(e.width,t));var i={height:Ie(n+r)};a>0&&(i.width=Ie(a)),r>0&&(i.verticalAlign=Ie(-r));var o=new Rae(e.src,e.alt,i);return o.height=n,o.depth=r,o},mathmlBuilder:(e,t)=>{var n=new Oe("mglyph",[]);n.setAttribute("alt",e.alt);var r=wn(e.height,t),a=0;if(e.totalheight.number>0&&(a=wn(e.totalheight,t)-r,n.setAttribute("valign",Ie(-a))),n.setAttribute("height",Ie(r+a)),e.width.number>0){var i=wn(e.width,t);n.setAttribute("width",Ie(i))}return n.setAttribute("src",e.src),n}});Be({type:"kern",names:["\\kern","\\mkern","\\hskip","\\mskip"],props:{numArgs:1,argTypes:["size"],primitive:!0,allowedInText:!0},handler(e,t){var{parser:n,funcName:r}=e,a=wt(t[0],"size");if(n.settings.strict){var i=r[1]==="m",o=a.value.unit==="mu";i?(o||n.settings.reportNonstrict("mathVsTextUnits","LaTeX's "+r+" supports only mu units, "+("not "+a.value.unit+" units")),n.mode!=="math"&&n.settings.reportNonstrict("mathVsTextUnits","LaTeX's "+r+" works only in math mode")):o&&n.settings.reportNonstrict("mathVsTextUnits","LaTeX's "+r+" doesn't support mu units")}return{type:"kern",mode:n.mode,dimension:a.value}},htmlBuilder(e,t){return _D(e.dimension,t)},mathmlBuilder(e,t){var n=wn(e.dimension,t);return new ID(n)}});Be({type:"lap",names:["\\mathllap","\\mathrlap","\\mathclap"],props:{numArgs:1,allowedInText:!0},handler:(e,t)=>{var{parser:n,funcName:r}=e,a=t[0];return{type:"lap",mode:n.mode,alignment:r.slice(5),body:a}},htmlBuilder:(e,t)=>{var n;e.alignment==="clap"?(n=Ce([],[Wt(e.body,t)]),n=Ce(["inner"],[n],t)):n=Ce(["inner"],[Wt(e.body,t)]);var r=Ce(["fix"],[]),a=Ce([e.alignment],[n,r],t),i=Ce(["strut"]);return i.style.height=Ie(a.height+a.depth),a.depth&&(i.style.verticalAlign=Ie(-a.depth)),a.children.unshift(i),a=Ce(["thinbox"],[a],t),Ce(["mord","vbox"],[a],t)},mathmlBuilder:(e,t)=>{var n=new Oe("mpadded",[an(e.body,t)]);if(e.alignment!=="rlap"){var r=e.alignment==="llap"?"-1":"-0.5";n.setAttribute("lspace",r+"width")}return n.setAttribute("width","0px"),n}});Be({type:"styling",names:["\\(","$"],props:{numArgs:0,allowedInText:!0,allowedInMath:!1},handler(e,t){var{funcName:n,parser:r}=e,a=r.mode;r.switchMode("math");var i=n==="\\("?"\\)":"$",o=r.parseExpression(!1,i);return r.expect(i),r.switchMode(a),{type:"styling",mode:r.mode,style:"text",body:o}}});Be({type:"text",names:["\\)","\\]"],props:{numArgs:0,allowedInText:!0,allowedInMath:!1},handler(e,t){throw new Re("Mismatched "+e.funcName)}});var AN=(e,t)=>{switch(t.style.size){case mt.DISPLAY.size:return e.display;case mt.TEXT.size:return e.text;case mt.SCRIPT.size:return e.script;case mt.SCRIPTSCRIPT.size:return e.scriptscript;default:return e.text}};Be({type:"mathchoice",names:["\\mathchoice"],props:{numArgs:4,primitive:!0},handler:(e,t)=>{var{parser:n}=e;return{type:"mathchoice",mode:n.mode,display:Pn(t[0]),text:Pn(t[1]),script:Pn(t[2]),scriptscript:Pn(t[3])}},htmlBuilder:(e,t)=>{var n=AN(e,t),r=Kn(n,t,!1);return Oo(r)},mathmlBuilder:(e,t)=>{var n=AN(e,t);return Ts(n,t)}});var iM=(e,t,n,r,a,i,o)=>{e=Ce([],[e]);var l=n&&Ro(n),u,d;if(t){var h=Wt(t,r.havingStyle(a.sup()),r);d={elem:h,kern:Math.max(r.fontMetrics().bigOpSpacing1,r.fontMetrics().bigOpSpacing3-h.depth)}}if(n){var f=Wt(n,r.havingStyle(a.sub()),r);u={elem:f,kern:Math.max(r.fontMetrics().bigOpSpacing2,r.fontMetrics().bigOpSpacing4-f.height)}}var m;if(d&&u){var b=r.fontMetrics().bigOpSpacing5+u.elem.height+u.elem.depth+u.kern+e.depth+o;m=Gt({positionType:"bottom",positionData:b,children:[{type:"kern",size:r.fontMetrics().bigOpSpacing5},{type:"elem",elem:u.elem,marginLeft:Ie(-i)},{type:"kern",size:u.kern},{type:"elem",elem:e},{type:"kern",size:d.kern},{type:"elem",elem:d.elem,marginLeft:Ie(i)},{type:"kern",size:r.fontMetrics().bigOpSpacing5}]})}else if(u){var y=e.height-o;m=Gt({positionType:"top",positionData:y,children:[{type:"kern",size:r.fontMetrics().bigOpSpacing5},{type:"elem",elem:u.elem,marginLeft:Ie(-i)},{type:"kern",size:u.kern},{type:"elem",elem:e}]})}else if(d){var v=e.depth+o;m=Gt({positionType:"bottom",positionData:v,children:[{type:"elem",elem:e},{type:"kern",size:d.kern},{type:"elem",elem:d.elem,marginLeft:Ie(i)},{type:"kern",size:r.fontMetrics().bigOpSpacing5}]})}else return e;var w=[m];if(u&&i!==0&&!l){var S=Ce(["mspace"],[],r);S.style.marginRight=Ie(i),w.unshift(S)}return Ce(["mop","op-limits"],w,r)},oM=new Set(["\\smallint"]),wu=(e,t)=>{var n,r,a=!1,i;e.type==="supsub"?(n=e.sup,r=e.sub,i=wt(e.base,"op"),a=!0):i=wt(e,"op");var o=t.style,l=!1;o.size===mt.DISPLAY.size&&i.symbol&&!oM.has(i.name)&&(l=!0);var u;if(i.symbol){var d=l?"Size2-Regular":"Size1-Regular",h="";if((i.name==="\\oiint"||i.name==="\\oiiint")&&(h=i.name.slice(1),i.name=h==="oiint"?"\\iint":"\\iiint"),u=Or(i.name,d,"math",t,["mop","op-symbol",l?"large-op":"small-op"]),h.length>0){var f=u.italic,m=AD(h+"Size"+(l?"2":"1"),t);u=Gt({positionType:"individualShift",children:[{type:"elem",elem:u,shift:0},{type:"elem",elem:m,shift:l?.08:0}]}),i.name="\\"+h,u.classes.unshift("mop"),u.italic=f}}else if(i.body){var b=Kn(i.body,t,!0);b.length===1&&b[0]instanceof ba?(u=b[0],u.classes[0]="mop"):u=Ce(["mop"],b,t)}else{for(var y=[],v=1;v<i.name.length;v++)y.push(XS(i.name[v],i.mode,t));u=Ce(["mop"],y,t)}var w=0,S=0;return(u instanceof ba||i.name==="\\oiint"||i.name==="\\oiiint")&&!i.suppressBaseShift&&(w=(u.height-u.depth)/2-t.fontMetrics().axisHeight,S=u.italic||0),a?iM(u,n,r,t,o,S,w):(w&&(u.style.position="relative",u.style.top=Ie(w)),u)},ap=(e,t)=>{var n;if(e.symbol)n=new Oe("mo",[Ha(e.name,e.mode)]),oM.has(e.name)&&n.setAttribute("largeop","false");else if(e.body)n=new Oe("mo",Sa(e.body,t));else{n=new Oe("mi",[new Un(e.name.slice(1))]);var r=new Oe("mo",[Ha("⁡","text")]);e.parentIsSupSub?n=new Oe("mrow",[n,r]):n=OD([n,r])}return n},kie={"∏":"\\prod","∐":"\\coprod","∑":"\\sum","⋀":"\\bigwedge","⋁":"\\bigvee","⋂":"\\bigcap","⋃":"\\bigcup","⨀":"\\bigodot","⨁":"\\bigoplus","⨂":"\\bigotimes","⨄":"\\biguplus","⨆":"\\bigsqcup"};Be({type:"op",names:["\\coprod","\\bigvee","\\bigwedge","\\biguplus","\\bigcap","\\bigcup","\\intop","\\prod","\\sum","\\bigotimes","\\bigoplus","\\bigodot","\\bigsqcup","\\smallint","∏","∐","∑","⋀","⋁","⋂","⋃","⨀","⨁","⨂","⨄","⨆"],props:{numArgs:0},handler:(e,t)=>{var{parser:n,funcName:r}=e,a=r;return a.length===1&&(a=kie[a]),{type:"op",mode:n.mode,limits:!0,parentIsSupSub:!1,symbol:!0,name:a}},htmlBuilder:wu,mathmlBuilder:ap});Be({type:"op",names:["\\mathop"],props:{numArgs:1,primitive:!0},handler:(e,t)=>{var{parser:n}=e,r=t[0];return{type:"op",mode:n.mode,limits:!1,parentIsSupSub:!1,symbol:!1,body:Pn(r)}},htmlBuilder:wu,mathmlBuilder:ap});var Tie={"∫":"\\int","∬":"\\iint","∭":"\\iiint","∮":"\\oint","∯":"\\oiint","∰":"\\oiiint"};Be({type:"op",names:["\\arcsin","\\arccos","\\arctan","\\arctg","\\arcctg","\\arg","\\ch","\\cos","\\cosec","\\cosh","\\cot","\\cotg","\\coth","\\csc","\\ctg","\\cth","\\deg","\\dim","\\exp","\\hom","\\ker","\\lg","\\ln","\\log","\\sec","\\sin","\\sinh","\\sh","\\tan","\\tanh","\\tg","\\th"],props:{numArgs:0},handler(e){var{parser:t,funcName:n}=e;return{type:"op",mode:t.mode,limits:!1,parentIsSupSub:!1,symbol:!1,name:n}},htmlBuilder:wu,mathmlBuilder:ap});Be({type:"op",names:["\\det","\\gcd","\\inf","\\lim","\\max","\\min","\\Pr","\\sup"],props:{numArgs:0},handler(e){var{parser:t,funcName:n}=e;return{type:"op",mode:t.mode,limits:!0,parentIsSupSub:!1,symbol:!1,name:n}},htmlBuilder:wu,mathmlBuilder:ap});Be({type:"op",names:["\\int","\\iint","\\iiint","\\oint","\\oiint","\\oiiint","∫","∬","∭","∮","∯","∰"],props:{numArgs:0,allowedInArgument:!0},handler(e){var{parser:t,funcName:n}=e,r=n;return r.length===1&&(r=Tie[r]),{type:"op",mode:t.mode,limits:!1,parentIsSupSub:!1,symbol:!0,name:r}},htmlBuilder:wu,mathmlBuilder:ap});var sM=(e,t)=>{var n,r,a=!1,i;e.type==="supsub"?(n=e.sup,r=e.sub,i=wt(e.base,"operatorname"),a=!0):i=wt(e,"operatorname");var o;if(i.body.length>0){for(var l=i.body.map(f=>{var m="text"in f?f.text:void 0;return typeof m=="string"?{type:"textord",mode:f.mode,text:m}:f}),u=Kn(l,t.withFont("mathrm"),!0),d=0;d<u.length;d++){var h=u[d];h instanceof ba&&(h.text=h.text.replace(/\u2212/,"-").replace(/\u2217/,"*"))}o=Ce(["mop"],u,t)}else o=Ce(["mop"],[],t);return a?iM(o,n,r,t,t.style,0,0):o},_ie=(e,t)=>{for(var n=Sa(e.body,t.withFont("mathrm")),r=!0,a=0;a<n.length;a++){var i=n[a];if(!(i instanceof ID))if(i instanceof Oe)switch(i.type){case"mi":case"mn":case"mspace":case"mtext":break;case"mo":{var o=i.children[0];i.children.length===1&&o instanceof Un?o.text=o.text.replace(/\u2212/,"-").replace(/\u2217/,"*"):r=!1;break}default:r=!1}else r=!1}if(r){var l=n.map(h=>h.toText()).join("");n=[new Un(l)]}var u=new Oe("mi",n);u.setAttribute("mathvariant","normal");var d=new Oe("mo",[Ha("⁡","text")]);return e.parentIsSupSub?new Oe("mrow",[u,d]):OD([u,d])};Be({type:"operatorname",names:["\\operatorname@","\\operatornamewithlimits"],props:{numArgs:1},handler:(e,t)=>{var{parser:n,funcName:r}=e,a=t[0];return{type:"operatorname",mode:n.mode,body:Pn(a),alwaysHandleSupSub:r==="\\operatornamewithlimits",limits:!1,parentIsSupSub:!1}},htmlBuilder:sM,mathmlBuilder:_ie});W("\\operatorname","\\@ifstar\\operatornamewithlimits\\operatorname@");Il({type:"ordgroup",htmlBuilder(e,t){return e.semisimple?Oo(Kn(e.body,t,!1)):Ce(["mord"],Kn(e.body,t,!0),t)},mathmlBuilder(e,t){return Ts(e.body,t,!0)}});Be({type:"overline",names:["\\overline"],props:{numArgs:1},handler(e,t){var{parser:n}=e,r=t[0];return{type:"overline",mode:n.mode,body:r}},htmlBuilder(e,t){var n=Wt(e.body,t.havingCrampedStyle()),r=eu("overline-line",t),a=t.fontMetrics().defaultRuleThickness,i=Gt({positionType:"firstBaseline",children:[{type:"elem",elem:n},{type:"kern",size:3*a},{type:"elem",elem:r},{type:"kern",size:a}]});return Ce(["mord","overline"],[i],t)},mathmlBuilder(e,t){var n=new Oe("mo",[new Un("‾")]);n.setAttribute("stretchy","true");var r=new Oe("mover",[an(e.body,t),n]);return r.setAttribute("accent","true"),r}});Be({type:"phantom",names:["\\phantom"],props:{numArgs:1,allowedInText:!0},handler:(e,t)=>{var{parser:n}=e,r=t[0];return{type:"phantom",mode:n.mode,body:Pn(r)}},htmlBuilder:(e,t)=>{var n=Kn(e.body,t.withPhantom(),!1);return Oo(n)},mathmlBuilder:(e,t)=>{var n=Sa(e.body,t);return new Oe("mphantom",n)}});W("\\hphantom","\\smash{\\phantom{#1}}");Be({type:"vphantom",names:["\\vphantom"],props:{numArgs:1,allowedInText:!0},handler:(e,t)=>{var{parser:n}=e,r=t[0];return{type:"vphantom",mode:n.mode,body:r}},htmlBuilder:(e,t)=>{var n=Ce(["inner"],[Wt(e.body,t.withPhantom())]),r=Ce(["fix"],[]);return Ce(["mord","rlap"],[n,r],t)},mathmlBuilder:(e,t)=>{var n=Sa(Pn(e.body),t),r=new Oe("mphantom",n),a=new Oe("mpadded",[r]);return a.setAttribute("width","0px"),a}});Be({type:"raisebox",names:["\\raisebox"],props:{numArgs:2,argTypes:["size","hbox"],allowedInText:!0},handler(e,t){var{parser:n}=e,r=wt(t[0],"size").value,a=t[1];return{type:"raisebox",mode:n.mode,dy:r,body:a}},htmlBuilder(e,t){var n=Wt(e.body,t),r=wn(e.dy,t);return Gt({positionType:"shift",positionData:-r,children:[{type:"elem",elem:n}]})},mathmlBuilder(e,t){var n=new Oe("mpadded",[an(e.body,t)]),r=e.dy.number+e.dy.unit;return n.setAttribute("voffset",r),n}});Be({type:"internal",names:["\\relax"],props:{numArgs:0,allowedInText:!0,allowedInArgument:!0},handler(e){var{parser:t}=e;return{type:"internal",mode:t.mode}}});Be({type:"rule",names:["\\rule"],props:{numArgs:2,numOptionalArgs:1,allowedInText:!0,allowedInMath:!0,argTypes:["size","size","size"]},handler(e,t,n){var{parser:r}=e,a=n[0],i=wt(t[0],"size"),o=wt(t[1],"size");return{type:"rule",mode:r.mode,shift:a&&wt(a,"size").value,width:i.value,height:o.value}},htmlBuilder(e,t){var n=Ce(["mord","rule"],[],t),r=wn(e.width,t),a=wn(e.height,t),i=e.shift?wn(e.shift,t):0;return n.style.borderRightWidth=Ie(r),n.style.borderTopWidth=Ie(a),n.style.bottom=Ie(i),n.width=r,n.height=a+i,n.depth=-i,n.maxFontSize=a*1.125*t.sizeMultiplier,n},mathmlBuilder(e,t){var n=wn(e.width,t),r=wn(e.height,t),a=e.shift?wn(e.shift,t):0,i=t.color&&t.getColor()||"black",o=new Oe("mspace");o.setAttribute("mathbackground",i),o.setAttribute("width",Ie(n)),o.setAttribute("height",Ie(r));var l=new Oe("mpadded",[o]);return a>=0?l.setAttribute("height",Ie(a)):(l.setAttribute("height",Ie(a)),l.setAttribute("depth",Ie(-a))),l.setAttribute("voffset",Ie(a)),l}});function lM(e,t,n){for(var r=Kn(e,t,!1),a=t.sizeMultiplier/n.sizeMultiplier,i=0;i<r.length;i++){var o=r[i].classes.indexOf("sizing");o<0?Array.prototype.push.apply(r[i].classes,t.sizingClasses(n)):r[i].classes[o+1]==="reset-size"+t.size&&(r[i].classes[o+1]="reset-size"+n.size),r[i].height*=a,r[i].depth*=a}return Oo(r)}var RN=["\\tiny","\\sixptsize","\\scriptsize","\\footnotesize","\\small","\\normalsize","\\large","\\Large","\\LARGE","\\huge","\\Huge"],Cie=(e,t)=>{var n=t.havingSize(e.size);return lM(e.body,n,t)};Be({type:"sizing",names:RN,props:{numArgs:0,allowedInText:!0},handler:(e,t)=>{var{breakOnTokenText:n,funcName:r,parser:a}=e,i=a.parseExpression(!1,n);return{type:"sizing",mode:a.mode,size:RN.indexOf(r)+1,body:i}},htmlBuilder:Cie,mathmlBuilder:(e,t)=>{var n=t.havingSize(e.size),r=Sa(e.body,n),a=new Oe("mstyle",r);return a.setAttribute("mathsize",Ie(n.sizeMultiplier)),a}});Be({type:"smash",names:["\\smash"],props:{numArgs:1,numOptionalArgs:1,allowedInText:!0},handler:(e,t,n)=>{var{parser:r}=e,a=!1,i=!1,o=n[0]&&wt(n[0],"ordgroup");if(o)for(var l="",u=0;u<o.body.length;++u){var d=o.body[u];if(l=Eg(d).text,l==="t")a=!0;else if(l==="b")i=!0;else{a=!1,i=!1;break}}else a=!0,i=!0;var h=t[0];return{type:"smash",mode:r.mode,body:h,smashHeight:a,smashDepth:i}},htmlBuilder:(e,t)=>{var n=Ce([],[Wt(e.body,t)]);if(!e.smashHeight&&!e.smashDepth)return n;if(e.smashHeight&&(n.height=0),e.smashDepth&&(n.depth=0),e.smashHeight&&e.smashDepth)return Ce(["mord","smash"],[n],t);if(n.children)for(var r=0;r<n.children.length;r++)e.smashHeight&&(n.children[r].height=0),e.smashDepth&&(n.children[r].depth=0);var a=Gt({positionType:"firstBaseline",children:[{type:"elem",elem:n}]});return Ce(["mord"],[a],t)},mathmlBuilder:(e,t)=>{var n=new Oe("mpadded",[an(e.body,t)]);return e.smashHeight&&n.setAttribute("height","0px"),e.smashDepth&&n.setAttribute("depth","0px"),n}});Be({type:"sqrt",names:["\\sqrt"],props:{numArgs:1,numOptionalArgs:1},handler(e,t,n){var{parser:r}=e,a=n[0],i=t[0];return{type:"sqrt",mode:r.mode,body:i,index:a}},htmlBuilder(e,t){var n=Wt(e.body,t.havingCrampedStyle());n.height===0&&(n.height=t.fontMetrics().xHeight),n=tu(n,t);var r=t.fontMetrics(),a=r.defaultRuleThickness,i=a;t.style.id<mt.TEXT.id&&(i=t.fontMetrics().xHeight);var o=a+i/4,l=n.height+n.depth+o+a,{span:u,ruleWidth:d,advanceWidth:h}=pie(l,t),f=u.height-d;f>n.height+n.depth+o&&(o=(o+f-n.height-n.depth)/2);var m=u.height-n.height-o-d;n.style.paddingLeft=Ie(h);var b=Gt({positionType:"firstBaseline",children:[{type:"elem",elem:n,wrapperClasses:["svg-align"]},{type:"kern",size:-(n.height+m)},{type:"elem",elem:u},{type:"kern",size:d}]});if(e.index){var y=t.havingStyle(mt.SCRIPTSCRIPT),v=Wt(e.index,y,t),w=.6*(b.height-b.depth),S=Gt({positionType:"shift",positionData:-w,children:[{type:"elem",elem:v}]}),k=Ce(["root"],[S]);return Ce(["mord","sqrt"],[k,b],t)}else return Ce(["mord","sqrt"],[b],t)},mathmlBuilder(e,t){var{body:n,index:r}=e;return r?new Oe("mroot",[an(n,t),an(r,t)]):new Oe("msqrt",[an(n,t)])}});var NN={display:mt.DISPLAY,text:mt.TEXT,script:mt.SCRIPT,scriptscript:mt.SCRIPTSCRIPT};Be({type:"styling",names:["\\displaystyle","\\textstyle","\\scriptstyle","\\scriptscriptstyle"],props:{numArgs:0,allowedInText:!0,primitive:!0},handler(e,t){var{breakOnTokenText:n,funcName:r,parser:a}=e,i=a.parseExpression(!0,n),o=r.slice(1,r.length-5);return{type:"styling",mode:a.mode,style:o,body:i}},htmlBuilder(e,t){var n=NN[e.style],r=t.havingStyle(n).withFont("");return lM(e.body,r,t)},mathmlBuilder(e,t){var n=NN[e.style],r=t.havingStyle(n),a=Sa(e.body,r),i=new Oe("mstyle",a),o={display:["0","true"],text:["0","false"],script:["1","false"],scriptscript:["2","false"]},l=o[e.style];return i.setAttribute("scriptlevel",l[0]),i.setAttribute("displaystyle",l[1]),i}});var Aie=function(t,n){var r=t.base;if(r)if(r.type==="op"){var a=r.limits&&(n.style.size===mt.DISPLAY.size||r.alwaysHandleSupSub);return a?wu:null}else if(r.type==="operatorname"){var i=r.alwaysHandleSupSub&&(n.style.size===mt.DISPLAY.size||r.limits);return i?sM:null}else{if(r.type==="accent")return Ro(r.base)?JS:null;if(r.type==="horizBrace"){var o=!t.sub;return o===r.isOver?aM:null}else return null}else return null};Il({type:"supsub",htmlBuilder(e,t){var n=Aie(e,t);if(n)return n(e,t);var{base:r,sup:a,sub:i}=e,o=Wt(r,t),l,u,d=t.fontMetrics(),h=0,f=0,m=r&&Ro(r);if(a){var b=t.havingStyle(t.style.sup());l=Wt(a,b,t),m||(h=o.height-b.fontMetrics().supDrop*b.sizeMultiplier/t.sizeMultiplier)}if(i){var y=t.havingStyle(t.style.sub());u=Wt(i,y,t),m||(f=o.depth+y.fontMetrics().subDrop*y.sizeMultiplier/t.sizeMultiplier)}var v;t.style===mt.DISPLAY?v=d.sup1:t.style.cramped?v=d.sup3:v=d.sup2;var w=t.sizeMultiplier,S=Ie(.5/d.ptPerEm/w),k=null;if(u){var R=e.base&&e.base.type==="op"&&e.base.name&&(e.base.name==="\\oiint"||e.base.name==="\\oiiint");(o instanceof ba||R)&&(k=Ie(-o.italic))}var I;if(l&&u){h=Math.max(h,v,l.depth+.25*d.xHeight),f=Math.max(f,d.sub2);var L=d.defaultRuleThickness,A=4*L;if(h-l.depth-(u.height-f)<A){f=A-(h-l.depth)+u.height;var M=.8*d.xHeight-(h-l.depth);M>0&&(h+=M,f-=M)}var P=[{type:"elem",elem:u,shift:f,marginRight:S,marginLeft:k},{type:"elem",elem:l,shift:-h,marginRight:S}];I=Gt({positionType:"individualShift",children:P})}else if(u){f=Math.max(f,d.sub1,u.height-.8*d.xHeight);var G=[{type:"elem",elem:u,marginLeft:k,marginRight:S}];I=Gt({positionType:"shift",positionData:f,children:G})}else if(l)h=Math.max(h,v,l.depth+.25*d.xHeight),I=Gt({positionType:"shift",positionData:-h,children:[{type:"elem",elem:l,marginRight:S}]});else throw new Error("supsub must have either sup or sub.");var B=Nx(o,"right")||"mord";return Ce([B],[o,Ce(["msupsub"],[I])],t)},mathmlBuilder(e,t){var n=!1,r,a;e.base&&e.base.type==="horizBrace"&&(a=!!e.sup,a===e.base.isOver&&(n=!0,r=e.base.isOver)),e.base&&(e.base.type==="op"||e.base.type==="operatorname")&&(e.base.parentIsSupSub=!0);var i=[an(e.base,t)];e.sub&&i.push(an(e.sub,t)),e.sup&&i.push(an(e.sup,t));var o;if(n)o=r?"mover":"munder";else if(e.sub)if(e.sup){var d=e.base;d&&d.type==="op"&&d.limits&&t.style===mt.DISPLAY||d&&d.type==="operatorname"&&d.alwaysHandleSupSub&&(t.style===mt.DISPLAY||d.limits)?o="munderover":o="msubsup"}else{var u=e.base;u&&u.type==="op"&&u.limits&&(t.style===mt.DISPLAY||u.alwaysHandleSupSub)||u&&u.type==="operatorname"&&u.alwaysHandleSupSub&&(u.limits||t.style===mt.DISPLAY)?o="munder":o="msub"}else{var l=e.base;l&&l.type==="op"&&l.limits&&(t.style===mt.DISPLAY||l.alwaysHandleSupSub)||l&&l.type==="operatorname"&&l.alwaysHandleSupSub&&(l.limits||t.style===mt.DISPLAY)?o="mover":o="msup"}return new Oe(o,i)}});Il({type:"atom",htmlBuilder(e,t){return XS(e.text,e.mode,t,["m"+e.family])},mathmlBuilder(e,t){var n=new Oe("mo",[Ha(e.text,e.mode)]);if(e.family==="bin"){var r=QS(e,t);r==="bold-italic"&&n.setAttribute("mathvariant",r)}else e.family==="punct"?n.setAttribute("separator","true"):(e.family==="open"||e.family==="close")&&n.setAttribute("stretchy","false");return n}});var cM={mi:"italic",mn:"normal",mtext:"normal"};Il({type:"mathord",htmlBuilder(e,t){return xg(e,t,"mathord")},mathmlBuilder(e,t){var n=new Oe("mi",[Ha(e.text,e.mode,t)]),r=QS(e,t)||"italic";return r!==cM[n.type]&&n.setAttribute("mathvariant",r),n}});Il({type:"textord",htmlBuilder(e,t){return xg(e,t,"textord")},mathmlBuilder(e,t){var n=Ha(e.text,e.mode,t),r=QS(e,t)||"normal",a;return e.mode==="text"?a=new Oe("mtext",[n]):/[0-9]/.test(e.text)?a=new Oe("mn",[n]):e.text==="\\prime"?a=new Oe("mo",[n]):a=new Oe("mi",[n]),r!==cM[a.type]&&a.setAttribute("mathvariant",r),a}});var kv={"\\nobreak":"nobreak","\\allowbreak":"allowbreak"},Tv={" ":{},"\\ ":{},"~":{className:"nobreak"},"\\space":{},"\\nobreakspace":{className:"nobreak"}};Il({type:"spacing",htmlBuilder(e,t){if(Tv.hasOwnProperty(e.text)){var n=Tv[e.text].className||"";if(e.mode==="text"){var r=xg(e,t,"textord");return r.classes.push(n),r}else return Ce(["mspace",n],[XS(e.text,e.mode,t)],t)}else{if(kv.hasOwnProperty(e.text))return Ce(["mspace",kv[e.text]],[],t);throw new Re('Unknown type of space "'+e.text+'"')}},mathmlBuilder(e,t){var n;if(Tv.hasOwnProperty(e.text))n=new Oe("mtext",[new Un(" ")]);else{if(kv.hasOwnProperty(e.text))return new Oe("mspace");throw new Re('Unknown type of space "'+e.text+'"')}return n}});var ON=()=>{var e=new Oe("mtd",[]);return e.setAttribute("width","50%"),e};Il({type:"tag",mathmlBuilder(e,t){var n=new Oe("mtable",[new Oe("mtr",[ON(),new Oe("mtd",[Ts(e.body,t)]),ON(),new Oe("mtd",[Ts(e.tag,t)])])]);return n.setAttribute("width","100%"),n}});var IN={"\\text":void 0,"\\textrm":"textrm","\\textsf":"textsf","\\texttt":"texttt","\\textnormal":"textrm"},LN={"\\textbf":"textbf","\\textmd":"textmd"},Rie={"\\textit":"textit","\\textup":"textup"},DN=(e,t)=>{var n=e.font;if(n){if(IN[n])return t.withTextFontFamily(IN[n]);if(LN[n])return t.withTextFontWeight(LN[n]);if(n==="\\emph")return t.fontShape==="textit"?t.withTextFontShape("textup"):t.withTextFontShape("textit")}else return t;return t.withTextFontShape(Rie[n])};Be({type:"text",names:["\\text","\\textrm","\\textsf","\\texttt","\\textnormal","\\textbf","\\textmd","\\textit","\\textup","\\emph"],props:{numArgs:1,argTypes:["text"],allowedInArgument:!0,allowedInText:!0},handler(e,t){var{parser:n,funcName:r}=e,a=t[0];return{type:"text",mode:n.mode,body:Pn(a),font:r}},htmlBuilder(e,t){var n=DN(e,t),r=Kn(e.body,n,!0);return Ce(["mord","text"],r,n)},mathmlBuilder(e,t){var n=DN(e,t);return Ts(e.body,n)}});Be({type:"underline",names:["\\underline"],props:{numArgs:1,allowedInText:!0},handler(e,t){var{parser:n}=e;return{type:"underline",mode:n.mode,body:t[0]}},htmlBuilder(e,t){var n=Wt(e.body,t),r=eu("underline-line",t),a=t.fontMetrics().defaultRuleThickness,i=Gt({positionType:"top",positionData:n.height,children:[{type:"kern",size:a},{type:"elem",elem:r},{type:"kern",size:3*a},{type:"elem",elem:n}]});return Ce(["mord","underline"],[i],t)},mathmlBuilder(e,t){var n=new Oe("mo",[new Un("‾")]);n.setAttribute("stretchy","true");var r=new Oe("munder",[an(e.body,t),n]);return r.setAttribute("accentunder","true"),r}});Be({type:"vcenter",names:["\\vcenter"],props:{numArgs:1,argTypes:["original"],allowedInText:!1},handler(e,t){var{parser:n}=e;return{type:"vcenter",mode:n.mode,body:t[0]}},htmlBuilder(e,t){var n=Wt(e.body,t),r=t.fontMetrics().axisHeight,a=.5*(n.height-r-(n.depth+r));return Gt({positionType:"shift",positionData:a,children:[{type:"elem",elem:n}]})},mathmlBuilder(e,t){return new Oe("mpadded",[an(e.body,t)],["vcenter"])}});Be({type:"verb",names:["\\verb"],props:{numArgs:0,allowedInText:!0},handler(e,t,n){throw new Re("\\verb ended by end of line instead of matching delimiter")},htmlBuilder(e,t){for(var n=MN(e),r=[],a=t.havingStyle(t.style.text()),i=0;i<n.length;i++){var o=n[i];o==="~"&&(o="\\textasciitilde"),r.push(Or(o,"Typewriter-Regular",e.mode,a,["mord","texttt"]))}return Ce(["mord","text"].concat(a.sizingClasses(t)),TD(r),a)},mathmlBuilder(e,t){var n=new Un(MN(e)),r=new Oe("mtext",[n]);return r.setAttribute("mathvariant","monospace"),r}});var MN=e=>e.body.replace(/ /g,e.star?"␣":" "),ms=RD,uM=`[ \r
	]`,Nie="\\\\[a-zA-Z@]+",Oie="\\\\[^\uD800-\uDFFF]",Iie="("+Nie+")"+uM+"*",Lie=`\\\\(
|[ \r	]+
?)[ \r	]*`,Mx="[̀-ͯ]",Die=new RegExp(Mx+"+$"),Mie="("+uM+"+)|"+(Lie+"|")+"([!-\\[\\]-‧‪-퟿豈-]"+(Mx+"*")+"|[\uD800-\uDBFF][\uDC00-\uDFFF]"+(Mx+"*")+"|\\\\verb\\*([^]).*?\\4|\\\\verb([^*a-zA-Z]).*?\\5"+("|"+Iie)+("|"+Oie+")");class BN{constructor(t,n){this.input=t,this.settings=n,this.tokenRegex=new RegExp(Mie,"g"),this.catcodes={"%":14,"~":13}}setCatcode(t,n){this.catcodes[t]=n}lex(){var t=this.input,n=this.tokenRegex.lastIndex;if(n===t.length)return new ri("EOF",new Zr(this,n,n));var r=this.tokenRegex.exec(t);if(r===null||r.index!==n)throw new Re("Unexpected character: '"+t[n]+"'",new ri(t[n],new Zr(this,n,n+1)));var a=r[6]||r[3]||(r[2]?"\\ ":" ");if(this.catcodes[a]===14){var i=t.indexOf(`
`,this.tokenRegex.lastIndex);return i===-1?(this.tokenRegex.lastIndex=t.length,this.settings.reportNonstrict("commentAtEnd","% comment has no terminating newline; LaTeX would fail because of commenting the end of math mode (e.g. $)")):this.tokenRegex.lastIndex=i+1,this.lex()}return new ri(a,new Zr(this,n,this.tokenRegex.lastIndex))}}class Bie{constructor(t,n){t===void 0&&(t={}),n===void 0&&(n={}),this.current=n,this.builtins=t,this.undefStack=[]}beginGroup(){this.undefStack.push({})}endGroup(){if(this.undefStack.length===0)throw new Re("Unbalanced namespace destruction: attempt to pop global namespace; please report this as a bug");var t=this.undefStack.pop();for(var n in t)t.hasOwnProperty(n)&&(t[n]==null?delete this.current[n]:this.current[n]=t[n])}endGroups(){for(;this.undefStack.length>0;)this.endGroup()}has(t){return this.current.hasOwnProperty(t)||this.builtins.hasOwnProperty(t)}get(t){return this.current.hasOwnProperty(t)?this.current[t]:this.builtins[t]}set(t,n,r){if(r===void 0&&(r=!1),r){for(var a=0;a<this.undefStack.length;a++)delete this.undefStack[a][t];this.undefStack.length>0&&(this.undefStack[this.undefStack.length-1][t]=n)}else{var i=this.undefStack[this.undefStack.length-1];i&&!i.hasOwnProperty(t)&&(i[t]=this.current[t])}n==null?delete this.current[t]:this.current[t]=n}}var Fie=QD;W("\\noexpand",function(e){var t=e.popToken();return e.isExpandable(t.text)&&(t.noexpand=!0,t.treatAsRelax=!0),{tokens:[t],numArgs:0}});W("\\expandafter",function(e){var t=e.popToken();return e.expandOnce(!0),{tokens:[t],numArgs:0}});W("\\@firstoftwo",function(e){var t=e.consumeArgs(2);return{tokens:t[0],numArgs:0}});W("\\@secondoftwo",function(e){var t=e.consumeArgs(2);return{tokens:t[1],numArgs:0}});W("\\@ifnextchar",function(e){var t=e.consumeArgs(3);e.consumeSpaces();var n=e.future();return t[0].length===1&&t[0][0].text===n.text?{tokens:t[1],numArgs:0}:{tokens:t[2],numArgs:0}});W("\\@ifstar","\\@ifnextchar *{\\@firstoftwo{#1}}");W("\\TextOrMath",function(e){var t=e.consumeArgs(2);return e.mode==="text"?{tokens:t[0],numArgs:0}:{tokens:t[1],numArgs:0}});var FN={0:0,1:1,2:2,3:3,4:4,5:5,6:6,7:7,8:8,9:9,a:10,A:10,b:11,B:11,c:12,C:12,d:13,D:13,e:14,E:14,f:15,F:15};W("\\char",function(e){var t=e.popToken(),n,r=0;if(t.text==="'")n=8,t=e.popToken();else if(t.text==='"')n=16,t=e.popToken();else if(t.text==="`")if(t=e.popToken(),t.text[0]==="\\")r=t.text.charCodeAt(1);else{if(t.text==="EOF")throw new Re("\\char` missing argument");r=t.text.charCodeAt(0)}else n=10;if(n){if(r=FN[t.text],r==null||r>=n)throw new Re("Invalid base-"+n+" digit "+t.text);for(var a;(a=FN[e.future().text])!=null&&a<n;)r*=n,r+=a,e.popToken()}return"\\@char{"+r+"}"});var iw=(e,t,n,r)=>{var a=e.consumeArg().tokens;if(a.length!==1)throw new Re("\\newcommand's first argument must be a macro name");var i=a[0].text,o=e.isDefined(i);if(o&&!t)throw new Re("\\newcommand{"+i+"} attempting to redefine "+(i+"; use \\renewcommand"));if(!o&&!n)throw new Re("\\renewcommand{"+i+"} when command "+i+" does not yet exist; use \\newcommand");var l=0;if(a=e.consumeArg().tokens,a.length===1&&a[0].text==="["){for(var u="",d=e.expandNextToken();d.text!=="]"&&d.text!=="EOF";)u+=d.text,d=e.expandNextToken();if(!u.match(/^\s*[0-9]+\s*$/))throw new Re("Invalid number of arguments: "+u);l=parseInt(u),a=e.consumeArg().tokens}return o&&r||e.macros.set(i,{tokens:a,numArgs:l}),""};W("\\newcommand",e=>iw(e,!1,!0,!1));W("\\renewcommand",e=>iw(e,!0,!1,!1));W("\\providecommand",e=>iw(e,!0,!0,!0));W("\\message",e=>{var t=e.consumeArgs(1)[0];return console.log(t.reverse().map(n=>n.text).join("")),""});W("\\errmessage",e=>{var t=e.consumeArgs(1)[0];return console.error(t.reverse().map(n=>n.text).join("")),""});W("\\show",e=>{var t=e.popToken(),n=t.text;return console.log(t,e.macros.get(n),ms[n],yn.math[n],yn.text[n]),""});W("\\bgroup","{");W("\\egroup","}");W("~","\\nobreakspace");W("\\lq","`");W("\\rq","'");W("\\aa","\\r a");W("\\AA","\\r A");W("\\textcopyright","\\html@mathml{\\textcircled{c}}{\\char`©}");W("\\copyright","\\TextOrMath{\\textcopyright}{\\text{\\textcopyright}}");W("\\textregistered","\\html@mathml{\\textcircled{\\scriptsize R}}{\\char`®}");W("ℬ","\\mathscr{B}");W("ℰ","\\mathscr{E}");W("ℱ","\\mathscr{F}");W("ℋ","\\mathscr{H}");W("ℐ","\\mathscr{I}");W("ℒ","\\mathscr{L}");W("ℳ","\\mathscr{M}");W("ℛ","\\mathscr{R}");W("ℭ","\\mathfrak{C}");W("ℌ","\\mathfrak{H}");W("ℨ","\\mathfrak{Z}");W("\\Bbbk","\\Bbb{k}");W("·","\\cdotp");W("\\llap","\\mathllap{\\textrm{#1}}");W("\\rlap","\\mathrlap{\\textrm{#1}}");W("\\clap","\\mathclap{\\textrm{#1}}");W("\\mathstrut","\\vphantom{(}");W("\\underbar","\\underline{\\text{#1}}");W("\\not",'\\html@mathml{\\mathrel{\\mathrlap\\@not}\\nobreak}{\\char"338}');W("\\neq","\\html@mathml{\\mathrel{\\not=}}{\\mathrel{\\char`≠}}");W("\\ne","\\neq");W("≠","\\neq");W("\\notin","\\html@mathml{\\mathrel{{\\in}\\mathllap{/\\mskip1mu}}}{\\mathrel{\\char`∉}}");W("∉","\\notin");W("≘","\\html@mathml{\\mathrel{=\\kern{-1em}\\raisebox{0.4em}{$\\scriptsize\\frown$}}}{\\mathrel{\\char`≘}}");W("≙","\\html@mathml{\\stackrel{\\tiny\\wedge}{=}}{\\mathrel{\\char`≘}}");W("≚","\\html@mathml{\\stackrel{\\tiny\\vee}{=}}{\\mathrel{\\char`≚}}");W("≛","\\html@mathml{\\stackrel{\\scriptsize\\star}{=}}{\\mathrel{\\char`≛}}");W("≝","\\html@mathml{\\stackrel{\\tiny\\mathrm{def}}{=}}{\\mathrel{\\char`≝}}");W("≞","\\html@mathml{\\stackrel{\\tiny\\mathrm{m}}{=}}{\\mathrel{\\char`≞}}");W("≟","\\html@mathml{\\stackrel{\\tiny?}{=}}{\\mathrel{\\char`≟}}");W("⟂","\\perp");W("‼","\\mathclose{!\\mkern-0.8mu!}");W("∌","\\notni");W("⌜","\\ulcorner");W("⌝","\\urcorner");W("⌞","\\llcorner");W("⌟","\\lrcorner");W("©","\\copyright");W("®","\\textregistered");W("\\ulcorner",'\\html@mathml{\\@ulcorner}{\\mathop{\\char"231c}}');W("\\urcorner",'\\html@mathml{\\@urcorner}{\\mathop{\\char"231d}}');W("\\llcorner",'\\html@mathml{\\@llcorner}{\\mathop{\\char"231e}}');W("\\lrcorner",'\\html@mathml{\\@lrcorner}{\\mathop{\\char"231f}}');W("\\vdots","{\\varvdots\\rule{0pt}{15pt}}");W("⋮","\\vdots");W("\\varGamma","\\mathit{\\Gamma}");W("\\varDelta","\\mathit{\\Delta}");W("\\varTheta","\\mathit{\\Theta}");W("\\varLambda","\\mathit{\\Lambda}");W("\\varXi","\\mathit{\\Xi}");W("\\varPi","\\mathit{\\Pi}");W("\\varSigma","\\mathit{\\Sigma}");W("\\varUpsilon","\\mathit{\\Upsilon}");W("\\varPhi","\\mathit{\\Phi}");W("\\varPsi","\\mathit{\\Psi}");W("\\varOmega","\\mathit{\\Omega}");W("\\substack","\\begin{subarray}{c}#1\\end{subarray}");W("\\colon","\\nobreak\\mskip2mu\\mathpunct{}\\mathchoice{\\mkern-3mu}{\\mkern-3mu}{}{}{:}\\mskip6mu\\relax");W("\\boxed","\\fbox{$\\displaystyle{#1}$}");W("\\iff","\\DOTSB\\;\\Longleftrightarrow\\;");W("\\implies","\\DOTSB\\;\\Longrightarrow\\;");W("\\impliedby","\\DOTSB\\;\\Longleftarrow\\;");W("\\dddot","{\\overset{\\raisebox{-0.1ex}{\\normalsize ...}}{#1}}");W("\\ddddot","{\\overset{\\raisebox{-0.1ex}{\\normalsize ....}}{#1}}");var zN={",":"\\dotsc","\\not":"\\dotsb","+":"\\dotsb","=":"\\dotsb","<":"\\dotsb",">":"\\dotsb","-":"\\dotsb","*":"\\dotsb",":":"\\dotsb","\\DOTSB":"\\dotsb","\\coprod":"\\dotsb","\\bigvee":"\\dotsb","\\bigwedge":"\\dotsb","\\biguplus":"\\dotsb","\\bigcap":"\\dotsb","\\bigcup":"\\dotsb","\\prod":"\\dotsb","\\sum":"\\dotsb","\\bigotimes":"\\dotsb","\\bigoplus":"\\dotsb","\\bigodot":"\\dotsb","\\bigsqcup":"\\dotsb","\\And":"\\dotsb","\\longrightarrow":"\\dotsb","\\Longrightarrow":"\\dotsb","\\longleftarrow":"\\dotsb","\\Longleftarrow":"\\dotsb","\\longleftrightarrow":"\\dotsb","\\Longleftrightarrow":"\\dotsb","\\mapsto":"\\dotsb","\\longmapsto":"\\dotsb","\\hookrightarrow":"\\dotsb","\\doteq":"\\dotsb","\\mathbin":"\\dotsb","\\mathrel":"\\dotsb","\\relbar":"\\dotsb","\\Relbar":"\\dotsb","\\xrightarrow":"\\dotsb","\\xleftarrow":"\\dotsb","\\DOTSI":"\\dotsi","\\int":"\\dotsi","\\oint":"\\dotsi","\\iint":"\\dotsi","\\iiint":"\\dotsi","\\iiiint":"\\dotsi","\\idotsint":"\\dotsi","\\DOTSX":"\\dotsx"},zie=new Set(["bin","rel"]);W("\\dots",function(e){var t="\\dotso",n=e.expandAfterFuture().text;return n in zN?t=zN[n]:(n.slice(0,4)==="\\not"||n in yn.math&&zie.has(yn.math[n].group))&&(t="\\dotsb"),t});var ow={")":!0,"]":!0,"\\rbrack":!0,"\\}":!0,"\\rbrace":!0,"\\rangle":!0,"\\rceil":!0,"\\rfloor":!0,"\\rgroup":!0,"\\rmoustache":!0,"\\right":!0,"\\bigr":!0,"\\biggr":!0,"\\Bigr":!0,"\\Biggr":!0,$:!0,";":!0,".":!0,",":!0};W("\\dotso",function(e){var t=e.future().text;return t in ow?"\\ldots\\,":"\\ldots"});W("\\dotsc",function(e){var t=e.future().text;return t in ow&&t!==","?"\\ldots\\,":"\\ldots"});W("\\cdots",function(e){var t=e.future().text;return t in ow?"\\@cdots\\,":"\\@cdots"});W("\\dotsb","\\cdots");W("\\dotsm","\\cdots");W("\\dotsi","\\!\\cdots");W("\\dotsx","\\ldots\\,");W("\\DOTSI","\\relax");W("\\DOTSB","\\relax");W("\\DOTSX","\\relax");W("\\tmspace","\\TextOrMath{\\kern#1#3}{\\mskip#1#2}\\relax");W("\\,","\\tmspace+{3mu}{.1667em}");W("\\thinspace","\\,");W("\\>","\\mskip{4mu}");W("\\:","\\tmspace+{4mu}{.2222em}");W("\\medspace","\\:");W("\\;","\\tmspace+{5mu}{.2777em}");W("\\thickspace","\\;");W("\\!","\\tmspace-{3mu}{.1667em}");W("\\negthinspace","\\!");W("\\negmedspace","\\tmspace-{4mu}{.2222em}");W("\\negthickspace","\\tmspace-{5mu}{.277em}");W("\\enspace","\\kern.5em ");W("\\enskip","\\hskip.5em\\relax");W("\\quad","\\hskip1em\\relax");W("\\qquad","\\hskip2em\\relax");W("\\tag","\\@ifstar\\tag@literal\\tag@paren");W("\\tag@paren","\\tag@literal{({#1})}");W("\\tag@literal",e=>{if(e.macros.get("\\df@tag"))throw new Re("Multiple \\tag");return"\\gdef\\df@tag{\\text{#1}}"});W("\\bmod","\\mathchoice{\\mskip1mu}{\\mskip1mu}{\\mskip5mu}{\\mskip5mu}\\mathbin{\\rm mod}\\mathchoice{\\mskip1mu}{\\mskip1mu}{\\mskip5mu}{\\mskip5mu}");W("\\pod","\\allowbreak\\mathchoice{\\mkern18mu}{\\mkern8mu}{\\mkern8mu}{\\mkern8mu}(#1)");W("\\pmod","\\pod{{\\rm mod}\\mkern6mu#1}");W("\\mod","\\allowbreak\\mathchoice{\\mkern18mu}{\\mkern12mu}{\\mkern12mu}{\\mkern12mu}{\\rm mod}\\,\\,#1");W("\\newline","\\\\\\relax");W("\\TeX","\\textrm{\\html@mathml{T\\kern-.1667em\\raisebox{-.5ex}{E}\\kern-.125emX}{TeX}}");var dM=Ie(Ti["Main-Regular"][84][1]-.7*Ti["Main-Regular"][65][1]);W("\\LaTeX","\\textrm{\\html@mathml{"+("L\\kern-.36em\\raisebox{"+dM+"}{\\scriptstyle A}")+"\\kern-.15em\\TeX}{LaTeX}}");W("\\KaTeX","\\textrm{\\html@mathml{"+("K\\kern-.17em\\raisebox{"+dM+"}{\\scriptstyle A}")+"\\kern-.15em\\TeX}{KaTeX}}");W("\\hspace","\\@ifstar\\@hspacer\\@hspace");W("\\@hspace","\\hskip #1\\relax");W("\\@hspacer","\\rule{0pt}{0pt}\\hskip #1\\relax");W("\\ordinarycolon",":");W("\\vcentcolon","\\mathrel{\\mathop\\ordinarycolon}");W("\\dblcolon",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-.9mu}\\vcentcolon}}{\\mathop{\\char"2237}}');W("\\coloneqq",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}=}}{\\mathop{\\char"2254}}');W("\\Coloneqq",'\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}=}}{\\mathop{\\char"2237\\char"3d}}');W("\\coloneq",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}\\mathrel{-}}}{\\mathop{\\char"3a\\char"2212}}');W("\\Coloneq",'\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}\\mathrel{-}}}{\\mathop{\\char"2237\\char"2212}}');W("\\eqqcolon",'\\html@mathml{\\mathrel{=\\mathrel{\\mkern-1.2mu}\\vcentcolon}}{\\mathop{\\char"2255}}');W("\\Eqqcolon",'\\html@mathml{\\mathrel{=\\mathrel{\\mkern-1.2mu}\\dblcolon}}{\\mathop{\\char"3d\\char"2237}}');W("\\eqcolon",'\\html@mathml{\\mathrel{\\mathrel{-}\\mathrel{\\mkern-1.2mu}\\vcentcolon}}{\\mathop{\\char"2239}}');W("\\Eqcolon",'\\html@mathml{\\mathrel{\\mathrel{-}\\mathrel{\\mkern-1.2mu}\\dblcolon}}{\\mathop{\\char"2212\\char"2237}}');W("\\colonapprox",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}\\approx}}{\\mathop{\\char"3a\\char"2248}}');W("\\Colonapprox",'\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}\\approx}}{\\mathop{\\char"2237\\char"2248}}');W("\\colonsim",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}\\sim}}{\\mathop{\\char"3a\\char"223c}}');W("\\Colonsim",'\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}\\sim}}{\\mathop{\\char"2237\\char"223c}}');W("∷","\\dblcolon");W("∹","\\eqcolon");W("≔","\\coloneqq");W("≕","\\eqqcolon");W("⩴","\\Coloneqq");W("\\ratio","\\vcentcolon");W("\\coloncolon","\\dblcolon");W("\\colonequals","\\coloneqq");W("\\coloncolonequals","\\Coloneqq");W("\\equalscolon","\\eqqcolon");W("\\equalscoloncolon","\\Eqqcolon");W("\\colonminus","\\coloneq");W("\\coloncolonminus","\\Coloneq");W("\\minuscolon","\\eqcolon");W("\\minuscoloncolon","\\Eqcolon");W("\\coloncolonapprox","\\Colonapprox");W("\\coloncolonsim","\\Colonsim");W("\\simcolon","\\mathrel{\\sim\\mathrel{\\mkern-1.2mu}\\vcentcolon}");W("\\simcoloncolon","\\mathrel{\\sim\\mathrel{\\mkern-1.2mu}\\dblcolon}");W("\\approxcolon","\\mathrel{\\approx\\mathrel{\\mkern-1.2mu}\\vcentcolon}");W("\\approxcoloncolon","\\mathrel{\\approx\\mathrel{\\mkern-1.2mu}\\dblcolon}");W("\\notni","\\html@mathml{\\not\\ni}{\\mathrel{\\char`∌}}");W("\\limsup","\\DOTSB\\operatorname*{lim\\,sup}");W("\\liminf","\\DOTSB\\operatorname*{lim\\,inf}");W("\\injlim","\\DOTSB\\operatorname*{inj\\,lim}");W("\\projlim","\\DOTSB\\operatorname*{proj\\,lim}");W("\\varlimsup","\\DOTSB\\operatorname*{\\overline{lim}}");W("\\varliminf","\\DOTSB\\operatorname*{\\underline{lim}}");W("\\varinjlim","\\DOTSB\\operatorname*{\\underrightarrow{lim}}");W("\\varprojlim","\\DOTSB\\operatorname*{\\underleftarrow{lim}}");W("\\gvertneqq","\\html@mathml{\\@gvertneqq}{≩}");W("\\lvertneqq","\\html@mathml{\\@lvertneqq}{≨}");W("\\ngeqq","\\html@mathml{\\@ngeqq}{≱}");W("\\ngeqslant","\\html@mathml{\\@ngeqslant}{≱}");W("\\nleqq","\\html@mathml{\\@nleqq}{≰}");W("\\nleqslant","\\html@mathml{\\@nleqslant}{≰}");W("\\nshortmid","\\html@mathml{\\@nshortmid}{∤}");W("\\nshortparallel","\\html@mathml{\\@nshortparallel}{∦}");W("\\nsubseteqq","\\html@mathml{\\@nsubseteqq}{⊈}");W("\\nsupseteqq","\\html@mathml{\\@nsupseteqq}{⊉}");W("\\varsubsetneq","\\html@mathml{\\@varsubsetneq}{⊊}");W("\\varsubsetneqq","\\html@mathml{\\@varsubsetneqq}{⫋}");W("\\varsupsetneq","\\html@mathml{\\@varsupsetneq}{⊋}");W("\\varsupsetneqq","\\html@mathml{\\@varsupsetneqq}{⫌}");W("\\imath","\\html@mathml{\\@imath}{ı}");W("\\jmath","\\html@mathml{\\@jmath}{ȷ}");W("\\llbracket","\\html@mathml{\\mathopen{[\\mkern-3.2mu[}}{\\mathopen{\\char`⟦}}");W("\\rrbracket","\\html@mathml{\\mathclose{]\\mkern-3.2mu]}}{\\mathclose{\\char`⟧}}");W("⟦","\\llbracket");W("⟧","\\rrbracket");W("\\lBrace","\\html@mathml{\\mathopen{\\{\\mkern-3.2mu[}}{\\mathopen{\\char`⦃}}");W("\\rBrace","\\html@mathml{\\mathclose{]\\mkern-3.2mu\\}}}{\\mathclose{\\char`⦄}}");W("⦃","\\lBrace");W("⦄","\\rBrace");W("\\minuso","\\mathbin{\\html@mathml{{\\mathrlap{\\mathchoice{\\kern{0.145em}}{\\kern{0.145em}}{\\kern{0.1015em}}{\\kern{0.0725em}}\\circ}{-}}}{\\char`⦵}}");W("⦵","\\minuso");W("\\darr","\\downarrow");W("\\dArr","\\Downarrow");W("\\Darr","\\Downarrow");W("\\lang","\\langle");W("\\rang","\\rangle");W("\\uarr","\\uparrow");W("\\uArr","\\Uparrow");W("\\Uarr","\\Uparrow");W("\\N","\\mathbb{N}");W("\\R","\\mathbb{R}");W("\\Z","\\mathbb{Z}");W("\\alef","\\aleph");W("\\alefsym","\\aleph");W("\\Alpha","\\mathrm{A}");W("\\Beta","\\mathrm{B}");W("\\bull","\\bullet");W("\\Chi","\\mathrm{X}");W("\\clubs","\\clubsuit");W("\\cnums","\\mathbb{C}");W("\\Complex","\\mathbb{C}");W("\\Dagger","\\ddagger");W("\\diamonds","\\diamondsuit");W("\\empty","\\emptyset");W("\\Epsilon","\\mathrm{E}");W("\\Eta","\\mathrm{H}");W("\\exist","\\exists");W("\\harr","\\leftrightarrow");W("\\hArr","\\Leftrightarrow");W("\\Harr","\\Leftrightarrow");W("\\hearts","\\heartsuit");W("\\image","\\Im");W("\\infin","\\infty");W("\\Iota","\\mathrm{I}");W("\\isin","\\in");W("\\Kappa","\\mathrm{K}");W("\\larr","\\leftarrow");W("\\lArr","\\Leftarrow");W("\\Larr","\\Leftarrow");W("\\lrarr","\\leftrightarrow");W("\\lrArr","\\Leftrightarrow");W("\\Lrarr","\\Leftrightarrow");W("\\Mu","\\mathrm{M}");W("\\natnums","\\mathbb{N}");W("\\Nu","\\mathrm{N}");W("\\Omicron","\\mathrm{O}");W("\\plusmn","\\pm");W("\\rarr","\\rightarrow");W("\\rArr","\\Rightarrow");W("\\Rarr","\\Rightarrow");W("\\real","\\Re");W("\\reals","\\mathbb{R}");W("\\Reals","\\mathbb{R}");W("\\Rho","\\mathrm{P}");W("\\sdot","\\cdot");W("\\sect","\\S");W("\\spades","\\spadesuit");W("\\sub","\\subset");W("\\sube","\\subseteq");W("\\supe","\\supseteq");W("\\Tau","\\mathrm{T}");W("\\thetasym","\\vartheta");W("\\weierp","\\wp");W("\\Zeta","\\mathrm{Z}");W("\\argmin","\\DOTSB\\operatorname*{arg\\,min}");W("\\argmax","\\DOTSB\\operatorname*{arg\\,max}");W("\\plim","\\DOTSB\\mathop{\\operatorname{plim}}\\limits");W("\\bra","\\mathinner{\\langle{#1}|}");W("\\ket","\\mathinner{|{#1}\\rangle}");W("\\braket","\\mathinner{\\langle{#1}\\rangle}");W("\\Bra","\\left\\langle#1\\right|");W("\\Ket","\\left|#1\\right\\rangle");var hM=e=>t=>{var n=t.consumeArg().tokens,r=t.consumeArg().tokens,a=t.consumeArg().tokens,i=t.consumeArg().tokens,o=t.macros.get("|"),l=t.macros.get("\\|");t.macros.beginGroup();var u=f=>m=>{e&&(m.macros.set("|",o),a.length&&m.macros.set("\\|",l));var b=f;if(!f&&a.length){var y=m.future();y.text==="|"&&(m.popToken(),b=!0)}return{tokens:b?a:r,numArgs:0}};t.macros.set("|",u(!1)),a.length&&t.macros.set("\\|",u(!0));var d=t.consumeArg().tokens,h=t.expandTokens([...i,...d,...n]);return t.macros.endGroup(),{tokens:h.reverse(),numArgs:0}};W("\\bra@ket",hM(!1));W("\\bra@set",hM(!0));W("\\Braket","\\bra@ket{\\left\\langle}{\\,\\middle\\vert\\,}{\\,\\middle\\vert\\,}{\\right\\rangle}");W("\\Set","\\bra@set{\\left\\{\\:}{\\;\\middle\\vert\\;}{\\;\\middle\\Vert\\;}{\\:\\right\\}}");W("\\set","\\bra@set{\\{\\,}{\\mid}{}{\\,\\}}");W("\\angln","{\\angl n}");W("\\blue","\\textcolor{##6495ed}{#1}");W("\\orange","\\textcolor{##ffa500}{#1}");W("\\pink","\\textcolor{##ff00af}{#1}");W("\\red","\\textcolor{##df0030}{#1}");W("\\green","\\textcolor{##28ae7b}{#1}");W("\\gray","\\textcolor{gray}{#1}");W("\\purple","\\textcolor{##9d38bd}{#1}");W("\\blueA","\\textcolor{##ccfaff}{#1}");W("\\blueB","\\textcolor{##80f6ff}{#1}");W("\\blueC","\\textcolor{##63d9ea}{#1}");W("\\blueD","\\textcolor{##11accd}{#1}");W("\\blueE","\\textcolor{##0c7f99}{#1}");W("\\tealA","\\textcolor{##94fff5}{#1}");W("\\tealB","\\textcolor{##26edd5}{#1}");W("\\tealC","\\textcolor{##01d1c1}{#1}");W("\\tealD","\\textcolor{##01a995}{#1}");W("\\tealE","\\textcolor{##208170}{#1}");W("\\greenA","\\textcolor{##b6ffb0}{#1}");W("\\greenB","\\textcolor{##8af281}{#1}");W("\\greenC","\\textcolor{##74cf70}{#1}");W("\\greenD","\\textcolor{##1fab54}{#1}");W("\\greenE","\\textcolor{##0d923f}{#1}");W("\\goldA","\\textcolor{##ffd0a9}{#1}");W("\\goldB","\\textcolor{##ffbb71}{#1}");W("\\goldC","\\textcolor{##ff9c39}{#1}");W("\\goldD","\\textcolor{##e07d10}{#1}");W("\\goldE","\\textcolor{##a75a05}{#1}");W("\\redA","\\textcolor{##fca9a9}{#1}");W("\\redB","\\textcolor{##ff8482}{#1}");W("\\redC","\\textcolor{##f9685d}{#1}");W("\\redD","\\textcolor{##e84d39}{#1}");W("\\redE","\\textcolor{##bc2612}{#1}");W("\\maroonA","\\textcolor{##ffbde0}{#1}");W("\\maroonB","\\textcolor{##ff92c6}{#1}");W("\\maroonC","\\textcolor{##ed5fa6}{#1}");W("\\maroonD","\\textcolor{##ca337c}{#1}");W("\\maroonE","\\textcolor{##9e034e}{#1}");W("\\purpleA","\\textcolor{##ddd7ff}{#1}");W("\\purpleB","\\textcolor{##c6b9fc}{#1}");W("\\purpleC","\\textcolor{##aa87ff}{#1}");W("\\purpleD","\\textcolor{##7854ab}{#1}");W("\\purpleE","\\textcolor{##543b78}{#1}");W("\\mintA","\\textcolor{##f5f9e8}{#1}");W("\\mintB","\\textcolor{##edf2df}{#1}");W("\\mintC","\\textcolor{##e0e5cc}{#1}");W("\\grayA","\\textcolor{##f6f7f7}{#1}");W("\\grayB","\\textcolor{##f0f1f2}{#1}");W("\\grayC","\\textcolor{##e3e5e6}{#1}");W("\\grayD","\\textcolor{##d6d8da}{#1}");W("\\grayE","\\textcolor{##babec2}{#1}");W("\\grayF","\\textcolor{##888d93}{#1}");W("\\grayG","\\textcolor{##626569}{#1}");W("\\grayH","\\textcolor{##3b3e40}{#1}");W("\\grayI","\\textcolor{##21242c}{#1}");W("\\kaBlue","\\textcolor{##314453}{#1}");W("\\kaGreen","\\textcolor{##71B307}{#1}");var pM={"^":!0,_:!0,"\\limits":!0,"\\nolimits":!0};class $ie{constructor(t,n,r){this.settings=n,this.expansionCount=0,this.feed(t),this.macros=new Bie(Fie,n.macros),this.mode=r,this.stack=[]}feed(t){this.lexer=new BN(t,this.settings)}switchMode(t){this.mode=t}beginGroup(){this.macros.beginGroup()}endGroup(){this.macros.endGroup()}endGroups(){this.macros.endGroups()}future(){return this.stack.length===0&&this.pushToken(this.lexer.lex()),this.stack[this.stack.length-1]}popToken(){return this.future(),this.stack.pop()}pushToken(t){this.stack.push(t)}pushTokens(t){this.stack.push(...t)}scanArgument(t){var n,r,a;if(t){if(this.consumeSpaces(),this.future().text!=="[")return null;n=this.popToken(),{tokens:a,end:r}=this.consumeArg(["]"])}else({tokens:a,start:n,end:r}=this.consumeArg());return this.pushToken(new ri("EOF",r.loc)),this.pushTokens(a),new ri("",Zr.range(n,r))}consumeSpaces(){for(;;){var t=this.future();if(t.text===" ")this.stack.pop();else break}}consumeArg(t){var n=[],r=t&&t.length>0;r||this.consumeSpaces();var a=this.future(),i,o=0,l=0;do{if(i=this.popToken(),n.push(i),i.text==="{")++o;else if(i.text==="}"){if(--o,o===-1)throw new Re("Extra }",i)}else if(i.text==="EOF")throw new Re("Unexpected end of input in a macro argument, expected '"+(t&&r?t[l]:"}")+"'",i);if(t&&r)if((o===0||o===1&&t[l]==="{")&&i.text===t[l]){if(++l,l===t.length){n.splice(-l,l);break}}else l=0}while(o!==0||r);return a.text==="{"&&n[n.length-1].text==="}"&&(n.pop(),n.shift()),n.reverse(),{tokens:n,start:a,end:i}}consumeArgs(t,n){if(n){if(n.length!==t+1)throw new Re("The length of delimiters doesn't match the number of args!");for(var r=n[0],a=0;a<r.length;a++){var i=this.popToken();if(r[a]!==i.text)throw new Re("Use of the macro doesn't match its definition",i)}}for(var o=[],l=0;l<t;l++)o.push(this.consumeArg(n&&n[l+1]).tokens);return o}countExpansion(t){if(this.expansionCount+=t,this.expansionCount>this.settings.maxExpand)throw new Re("Too many expansions: infinite loop or need to increase maxExpand setting")}expandOnce(t){var n=this.popToken(),r=n.text,a=n.noexpand?null:this._getExpansion(r);if(a==null||t&&a.unexpandable){if(t&&a==null&&r[0]==="\\"&&!this.isDefined(r))throw new Re("Undefined control sequence: "+r);return this.pushToken(n),!1}this.countExpansion(1);var i=a.tokens,o=this.consumeArgs(a.numArgs,a.delimiters);if(a.numArgs){i=i.slice();for(var l=i.length-1;l>=0;--l){var u=i[l];if(u.text==="#"){if(l===0)throw new Re("Incomplete placeholder at end of macro body",u);if(u=i[--l],u.text==="#")i.splice(l+1,1);else if(/^[1-9]$/.test(u.text))i.splice(l,2,...o[+u.text-1]);else throw new Re("Not a valid argument number",u)}}}return this.pushTokens(i),i.length}expandAfterFuture(){return this.expandOnce(),this.future()}expandNextToken(){for(;;)if(this.expandOnce()===!1){var t=this.stack.pop();return t.treatAsRelax&&(t.text="\\relax"),t}}expandMacro(t){return this.macros.has(t)?this.expandTokens([new ri(t)]):void 0}expandTokens(t){var n=[],r=this.stack.length;for(this.pushTokens(t);this.stack.length>r;)if(this.expandOnce(!0)===!1){var a=this.stack.pop();a.treatAsRelax&&(a.noexpand=!1,a.treatAsRelax=!1),n.push(a)}return this.countExpansion(n.length),n}expandMacroAsText(t){var n=this.expandMacro(t);return n&&n.map(r=>r.text).join("")}_getExpansion(t){var n=this.macros.get(t);if(n==null)return n;if(t.length===1){var r=this.lexer.catcodes[t];if(r!=null&&r!==13)return}var a=typeof n=="function"?n(this):n;if(typeof a=="string"){var i=0;if(a.includes("#"))for(var o=a.replace(/##/g,"");o.includes("#"+(i+1));)++i;for(var l=new BN(a,this.settings),u=[],d=l.lex();d.text!=="EOF";)u.push(d),d=l.lex();u.reverse();var h={tokens:u,numArgs:i};return h}return a}isDefined(t){return this.macros.has(t)||ms.hasOwnProperty(t)||yn.math.hasOwnProperty(t)||yn.text.hasOwnProperty(t)||pM.hasOwnProperty(t)}isExpandable(t){var n=this.macros.get(t);return n!=null?typeof n=="string"||typeof n=="function"||!n.unexpandable:ms.hasOwnProperty(t)&&!ms[t].primitive}}var $N=/^[₊₋₌₍₎₀₁₂₃₄₅₆₇₈₉ₐₑₕᵢⱼₖₗₘₙₒₚᵣₛₜᵤᵥₓᵦᵧᵨᵩᵪ]/,c0=Object.freeze({"₊":"+","₋":"-","₌":"=","₍":"(","₎":")","₀":"0","₁":"1","₂":"2","₃":"3","₄":"4","₅":"5","₆":"6","₇":"7","₈":"8","₉":"9","ₐ":"a","ₑ":"e","ₕ":"h","ᵢ":"i","ⱼ":"j","ₖ":"k","ₗ":"l","ₘ":"m","ₙ":"n","ₒ":"o","ₚ":"p","ᵣ":"r","ₛ":"s","ₜ":"t","ᵤ":"u","ᵥ":"v","ₓ":"x","ᵦ":"β","ᵧ":"γ","ᵨ":"ρ","ᵩ":"ϕ","ᵪ":"χ","⁺":"+","⁻":"-","⁼":"=","⁽":"(","⁾":")","⁰":"0","¹":"1","²":"2","³":"3","⁴":"4","⁵":"5","⁶":"6","⁷":"7","⁸":"8","⁹":"9","ᴬ":"A","ᴮ":"B","ᴰ":"D","ᴱ":"E","ᴳ":"G","ᴴ":"H","ᴵ":"I","ᴶ":"J","ᴷ":"K","ᴸ":"L","ᴹ":"M","ᴺ":"N","ᴼ":"O","ᴾ":"P","ᴿ":"R","ᵀ":"T","ᵁ":"U","ⱽ":"V","ᵂ":"W","ᵃ":"a","ᵇ":"b","ᶜ":"c","ᵈ":"d","ᵉ":"e","ᶠ":"f","ᵍ":"g",ʰ:"h","ⁱ":"i",ʲ:"j","ᵏ":"k",ˡ:"l","ᵐ":"m",ⁿ:"n","ᵒ":"o","ᵖ":"p",ʳ:"r",ˢ:"s","ᵗ":"t","ᵘ":"u","ᵛ":"v",ʷ:"w",ˣ:"x",ʸ:"y","ᶻ":"z","ᵝ":"β","ᵞ":"γ","ᵟ":"δ","ᵠ":"ϕ","ᵡ":"χ","ᶿ":"θ"}),_v={"́":{text:"\\'",math:"\\acute"},"̀":{text:"\\`",math:"\\grave"},"̈":{text:'\\"',math:"\\ddot"},"̃":{text:"\\~",math:"\\tilde"},"̄":{text:"\\=",math:"\\bar"},"̆":{text:"\\u",math:"\\breve"},"̌":{text:"\\v",math:"\\check"},"̂":{text:"\\^",math:"\\hat"},"̇":{text:"\\.",math:"\\dot"},"̊":{text:"\\r",math:"\\mathring"},"̋":{text:"\\H"},"̧":{text:"\\c"}},PN={á:"á",à:"à",ä:"ä",ǟ:"ǟ",ã:"ã",ā:"ā",ă:"ă",ắ:"ắ",ằ:"ằ",ẵ:"ẵ",ǎ:"ǎ",â:"â",ấ:"ấ",ầ:"ầ",ẫ:"ẫ",ȧ:"ȧ",ǡ:"ǡ",å:"å",ǻ:"ǻ",ḃ:"ḃ",ć:"ć",ḉ:"ḉ",č:"č",ĉ:"ĉ",ċ:"ċ",ç:"ç",ď:"ď",ḋ:"ḋ",ḑ:"ḑ",é:"é",è:"è",ë:"ë",ẽ:"ẽ",ē:"ē",ḗ:"ḗ",ḕ:"ḕ",ĕ:"ĕ",ḝ:"ḝ",ě:"ě",ê:"ê",ế:"ế",ề:"ề",ễ:"ễ",ė:"ė",ȩ:"ȩ",ḟ:"ḟ",ǵ:"ǵ",ḡ:"ḡ",ğ:"ğ",ǧ:"ǧ",ĝ:"ĝ",ġ:"ġ",ģ:"ģ",ḧ:"ḧ",ȟ:"ȟ",ĥ:"ĥ",ḣ:"ḣ",ḩ:"ḩ",í:"í",ì:"ì",ï:"ï",ḯ:"ḯ",ĩ:"ĩ",ī:"ī",ĭ:"ĭ",ǐ:"ǐ",î:"î",ǰ:"ǰ",ĵ:"ĵ",ḱ:"ḱ",ǩ:"ǩ",ķ:"ķ",ĺ:"ĺ",ľ:"ľ",ļ:"ļ",ḿ:"ḿ",ṁ:"ṁ",ń:"ń",ǹ:"ǹ",ñ:"ñ",ň:"ň",ṅ:"ṅ",ņ:"ņ",ó:"ó",ò:"ò",ö:"ö",ȫ:"ȫ",õ:"õ",ṍ:"ṍ",ṏ:"ṏ",ȭ:"ȭ",ō:"ō",ṓ:"ṓ",ṑ:"ṑ",ŏ:"ŏ",ǒ:"ǒ",ô:"ô",ố:"ố",ồ:"ồ",ỗ:"ỗ",ȯ:"ȯ",ȱ:"ȱ",ő:"ő",ṕ:"ṕ",ṗ:"ṗ",ŕ:"ŕ",ř:"ř",ṙ:"ṙ",ŗ:"ŗ",ś:"ś",ṥ:"ṥ",š:"š",ṧ:"ṧ",ŝ:"ŝ",ṡ:"ṡ",ş:"ş",ẗ:"ẗ",ť:"ť",ṫ:"ṫ",ţ:"ţ",ú:"ú",ù:"ù",ü:"ü",ǘ:"ǘ",ǜ:"ǜ",ǖ:"ǖ",ǚ:"ǚ",ũ:"ũ",ṹ:"ṹ",ū:"ū",ṻ:"ṻ",ŭ:"ŭ",ǔ:"ǔ",û:"û",ů:"ů",ű:"ű",ṽ:"ṽ",ẃ:"ẃ",ẁ:"ẁ",ẅ:"ẅ",ŵ:"ŵ",ẇ:"ẇ",ẘ:"ẘ",ẍ:"ẍ",ẋ:"ẋ",ý:"ý",ỳ:"ỳ",ÿ:"ÿ",ỹ:"ỹ",ȳ:"ȳ",ŷ:"ŷ",ẏ:"ẏ",ẙ:"ẙ",ź:"ź",ž:"ž",ẑ:"ẑ",ż:"ż",Á:"Á",À:"À",Ä:"Ä",Ǟ:"Ǟ",Ã:"Ã",Ā:"Ā",Ă:"Ă",Ắ:"Ắ",Ằ:"Ằ",Ẵ:"Ẵ",Ǎ:"Ǎ",Â:"Â",Ấ:"Ấ",Ầ:"Ầ",Ẫ:"Ẫ",Ȧ:"Ȧ",Ǡ:"Ǡ",Å:"Å",Ǻ:"Ǻ",Ḃ:"Ḃ",Ć:"Ć",Ḉ:"Ḉ",Č:"Č",Ĉ:"Ĉ",Ċ:"Ċ",Ç:"Ç",Ď:"Ď",Ḋ:"Ḋ",Ḑ:"Ḑ",É:"É",È:"È",Ë:"Ë",Ẽ:"Ẽ",Ē:"Ē",Ḗ:"Ḗ",Ḕ:"Ḕ",Ĕ:"Ĕ",Ḝ:"Ḝ",Ě:"Ě",Ê:"Ê",Ế:"Ế",Ề:"Ề",Ễ:"Ễ",Ė:"Ė",Ȩ:"Ȩ",Ḟ:"Ḟ",Ǵ:"Ǵ",Ḡ:"Ḡ",Ğ:"Ğ",Ǧ:"Ǧ",Ĝ:"Ĝ",Ġ:"Ġ",Ģ:"Ģ",Ḧ:"Ḧ",Ȟ:"Ȟ",Ĥ:"Ĥ",Ḣ:"Ḣ",Ḩ:"Ḩ",Í:"Í",Ì:"Ì",Ï:"Ï",Ḯ:"Ḯ",Ĩ:"Ĩ",Ī:"Ī",Ĭ:"Ĭ",Ǐ:"Ǐ",Î:"Î",İ:"İ",Ĵ:"Ĵ",Ḱ:"Ḱ",Ǩ:"Ǩ",Ķ:"Ķ",Ĺ:"Ĺ",Ľ:"Ľ",Ļ:"Ļ",Ḿ:"Ḿ",Ṁ:"Ṁ",Ń:"Ń",Ǹ:"Ǹ",Ñ:"Ñ",Ň:"Ň",Ṅ:"Ṅ",Ņ:"Ņ",Ó:"Ó",Ò:"Ò",Ö:"Ö",Ȫ:"Ȫ",Õ:"Õ",Ṍ:"Ṍ",Ṏ:"Ṏ",Ȭ:"Ȭ",Ō:"Ō",Ṓ:"Ṓ",Ṑ:"Ṑ",Ŏ:"Ŏ",Ǒ:"Ǒ",Ô:"Ô",Ố:"Ố",Ồ:"Ồ",Ỗ:"Ỗ",Ȯ:"Ȯ",Ȱ:"Ȱ",Ő:"Ő",Ṕ:"Ṕ",Ṗ:"Ṗ",Ŕ:"Ŕ",Ř:"Ř",Ṙ:"Ṙ",Ŗ:"Ŗ",Ś:"Ś",Ṥ:"Ṥ",Š:"Š",Ṧ:"Ṧ",Ŝ:"Ŝ",Ṡ:"Ṡ",Ş:"Ş",Ť:"Ť",Ṫ:"Ṫ",Ţ:"Ţ",Ú:"Ú",Ù:"Ù",Ü:"Ü",Ǘ:"Ǘ",Ǜ:"Ǜ",Ǖ:"Ǖ",Ǚ:"Ǚ",Ũ:"Ũ",Ṹ:"Ṹ",Ū:"Ū",Ṻ:"Ṻ",Ŭ:"Ŭ",Ǔ:"Ǔ",Û:"Û",Ů:"Ů",Ű:"Ű",Ṽ:"Ṽ",Ẃ:"Ẃ",Ẁ:"Ẁ",Ẅ:"Ẅ",Ŵ:"Ŵ",Ẇ:"Ẇ",Ẍ:"Ẍ",Ẋ:"Ẋ",Ý:"Ý",Ỳ:"Ỳ",Ÿ:"Ÿ",Ỹ:"Ỹ",Ȳ:"Ȳ",Ŷ:"Ŷ",Ẏ:"Ẏ",Ź:"Ź",Ž:"Ž",Ẑ:"Ẑ",Ż:"Ż",ά:"ά",ὰ:"ὰ",ᾱ:"ᾱ",ᾰ:"ᾰ",έ:"έ",ὲ:"ὲ",ή:"ή",ὴ:"ὴ",ί:"ί",ὶ:"ὶ",ϊ:"ϊ",ΐ:"ΐ",ῒ:"ῒ",ῑ:"ῑ",ῐ:"ῐ",ό:"ό",ὸ:"ὸ",ύ:"ύ",ὺ:"ὺ",ϋ:"ϋ",ΰ:"ΰ",ῢ:"ῢ",ῡ:"ῡ",ῠ:"ῠ",ώ:"ώ",ὼ:"ὼ",Ύ:"Ύ",Ὺ:"Ὺ",Ϋ:"Ϋ",Ῡ:"Ῡ",Ῠ:"Ῠ",Ώ:"Ώ",Ὼ:"Ὼ"};class Ag{constructor(t,n){this.mode="math",this.gullet=new $ie(t,n,this.mode),this.settings=n,this.leftrightDepth=0,this.nextToken=null}expect(t,n){if(n===void 0&&(n=!0),this.fetch().text!==t)throw new Re("Expected '"+t+"', got '"+this.fetch().text+"'",this.fetch());n&&this.consume()}consume(){this.nextToken=null}fetch(){return this.nextToken==null&&(this.nextToken=this.gullet.expandNextToken()),this.nextToken}switchMode(t){this.mode=t,this.gullet.switchMode(t)}parse(){this.settings.globalGroup||this.gullet.beginGroup(),this.settings.colorIsTextColor&&this.gullet.macros.set("\\color","\\textcolor");try{var t=this.parseExpression(!1);return this.expect("EOF"),this.settings.globalGroup||this.gullet.endGroup(),t}finally{this.gullet.endGroups()}}subparse(t){var n=this.nextToken;this.consume(),this.gullet.pushToken(new ri("}")),this.gullet.pushTokens(t);var r=this.parseExpression(!1);return this.expect("}"),this.nextToken=n,r}parseExpression(t,n){for(var r=[];;){this.mode==="math"&&this.consumeSpaces();var a=this.fetch();if(Ag.endOfExpression.has(a.text)||n&&a.text===n||t&&ms[a.text]&&ms[a.text].infix)break;var i=this.parseAtom(n);if(i){if(i.type==="internal")continue}else break;r.push(i)}return this.mode==="text"&&this.formLigatures(r),this.handleInfixNodes(r)}handleInfixNodes(t){for(var n=-1,r,a=0;a<t.length;a++){var i=t[a];if(i.type==="infix"){if(n!==-1)throw new Re("only one infix operator per group",i.token);n=a,r=i.replaceWith}}if(n!==-1&&r){var o,l,u=t.slice(0,n),d=t.slice(n+1);u.length===1&&u[0].type==="ordgroup"?o=u[0]:o={type:"ordgroup",mode:this.mode,body:u},d.length===1&&d[0].type==="ordgroup"?l=d[0]:l={type:"ordgroup",mode:this.mode,body:d};var h;return r==="\\\\abovefrac"?h=this.callFunction(r,[o,t[n],l],[]):h=this.callFunction(r,[o,l],[]),[h]}else return t}handleSupSubscript(t){var n=this.fetch(),r=n.text;this.consume(),this.consumeSpaces();var a;do{var i;a=this.parseGroup(t)}while(((i=a)==null?void 0:i.type)==="internal");if(!a)throw new Re("Expected group after '"+r+"'",n);return a}formatUnsupportedCmd(t){for(var n=[],r=0;r<t.length;r++)n.push({type:"textord",mode:"text",text:t[r]});var a={type:"text",mode:this.mode,body:n},i={type:"color",mode:this.mode,color:this.settings.errorColor,body:[a]};return i}parseAtom(t){var n=this.parseGroup("atom",t);if((n==null?void 0:n.type)==="internal"||this.mode==="text")return n;for(var r,a;;){this.consumeSpaces();var i=this.fetch();if(i.text==="\\limits"||i.text==="\\nolimits"){if(n&&n.type==="op"){var o=i.text==="\\limits";n.limits=o,n.alwaysHandleSupSub=!0}else if(n&&n.type==="operatorname")n.alwaysHandleSupSub&&(n.limits=i.text==="\\limits");else throw new Re("Limit controls must follow a math operator",i);this.consume()}else if(i.text==="^"){if(r)throw new Re("Double superscript",i);r=this.handleSupSubscript("superscript")}else if(i.text==="_"){if(a)throw new Re("Double subscript",i);a=this.handleSupSubscript("subscript")}else if(i.text==="'"){if(r)throw new Re("Double superscript",i);var l={type:"textord",mode:this.mode,text:"\\prime"},u=[l];for(this.consume();this.fetch().text==="'";)u.push(l),this.consume();this.fetch().text==="^"&&u.push(this.handleSupSubscript("superscript")),r={type:"ordgroup",mode:this.mode,body:u}}else if(c0[i.text]){var d=$N.test(i.text),h=[];for(h.push(new ri(c0[i.text])),this.consume();;){var f=this.fetch().text;if(!c0[f]||$N.test(f)!==d)break;h.unshift(new ri(c0[f])),this.consume()}var m=this.subparse(h);d?a={type:"ordgroup",mode:"math",body:m}:r={type:"ordgroup",mode:"math",body:m}}else break}return r||a?{type:"supsub",mode:this.mode,base:n,sup:r,sub:a}:n}parseFunction(t,n){var r=this.fetch(),a=r.text,i=ms[a];if(!i)return null;if(this.consume(),n&&n!=="atom"&&!i.allowedInArgument)throw new Re("Got function '"+a+"' with no arguments"+(n?" as "+n:""),r);if(this.mode==="text"&&!i.allowedInText)throw new Re("Can't use function '"+a+"' in text mode",r);if(this.mode==="math"&&i.allowedInMath===!1)throw new Re("Can't use function '"+a+"' in math mode",r);var{args:o,optArgs:l}=this.parseArguments(a,i);return this.callFunction(a,o,l,r,t)}callFunction(t,n,r,a,i){var o={funcName:t,parser:this,token:a,breakOnTokenText:i},l=ms[t];if(l&&l.handler)return l.handler(o,n,r);throw new Re("No function handler for "+t)}parseArguments(t,n){var r=n.numArgs+n.numOptionalArgs;if(r===0)return{args:[],optArgs:[]};for(var a=[],i=[],o=0;o<r;o++){var l=n.argTypes&&n.argTypes[o],u=o<n.numOptionalArgs;("primitive"in n&&n.primitive&&l==null||n.type==="sqrt"&&o===1&&i[0]==null)&&(l="primitive");var d=this.parseGroupOfType("argument to '"+t+"'",l,u);if(u)i.push(d);else if(d!=null)a.push(d);else throw new Re("Null argument, please report this as a bug")}return{args:a,optArgs:i}}parseGroupOfType(t,n,r){switch(n){case"color":return this.parseColorGroup(r);case"size":return this.parseSizeGroup(r);case"url":return this.parseUrlGroup(r);case"math":case"text":return this.parseArgumentGroup(r,n);case"hbox":{var a=this.parseArgumentGroup(r,"text");return a!=null?{type:"styling",mode:a.mode,body:[a],style:"text"}:null}case"raw":{var i=this.parseStringGroup("raw",r);return i!=null?{type:"raw",mode:"text",string:i.text}:null}case"primitive":{if(r)throw new Re("A primitive argument cannot be optional");var o=this.parseGroup(t);if(o==null)throw new Re("Expected group as "+t,this.fetch());return o}case"original":case null:case void 0:return this.parseArgumentGroup(r);default:throw new Re("Unknown group type as "+t,this.fetch())}}consumeSpaces(){for(;this.fetch().text===" ";)this.consume()}parseStringGroup(t,n){var r=this.gullet.scanArgument(n);if(r==null)return null;for(var a="",i;(i=this.fetch()).text!=="EOF";)a+=i.text,this.consume();return this.consume(),r.text=a,r}parseRegexGroup(t,n){for(var r=this.fetch(),a=r,i="",o;(o=this.fetch()).text!=="EOF"&&t.test(i+o.text);)a=o,i+=a.text,this.consume();if(i==="")throw new Re("Invalid "+n+": '"+r.text+"'",r);return r.range(a,i)}parseColorGroup(t){var n=this.parseStringGroup("color",t);if(n==null)return null;var r=/^(#[a-f0-9]{3,4}|#[a-f0-9]{6}|#[a-f0-9]{8}|[a-f0-9]{6}|[a-z]+)$/i.exec(n.text);if(!r)throw new Re("Invalid color: '"+n.text+"'",n);var a=r[0];return/^[0-9a-f]{6}$/i.test(a)&&(a="#"+a),{type:"color-token",mode:this.mode,color:a}}parseSizeGroup(t){var n,r=!1;if(this.gullet.consumeSpaces(),!t&&this.gullet.future().text!=="{"?n=this.parseRegexGroup(/^[-+]? *(?:$|\d+|\d+\.\d*|\.\d*) *[a-z]{0,2} *$/,"size"):n=this.parseStringGroup("size",t),!n)return null;!t&&n.text.length===0&&(n.text="0pt",r=!0);var a=/([-+]?) *(\d+(?:\.\d*)?|\.\d+) *([a-z]{2})/.exec(n.text);if(!a)throw new Re("Invalid size: '"+n.text+"'",n);var i={number:+(a[1]+a[2]),unit:a[3]};if(!vD(i))throw new Re("Invalid unit: '"+i.unit+"'",n);return{type:"size",mode:this.mode,value:i,isBlank:r}}parseUrlGroup(t){this.gullet.lexer.setCatcode("%",13),this.gullet.lexer.setCatcode("~",12);var n=this.parseStringGroup("url",t);if(this.gullet.lexer.setCatcode("%",14),this.gullet.lexer.setCatcode("~",13),n==null)return null;var r=n.text.replace(/\\([#$%&~_^{}])/g,"$1");return{type:"url",mode:this.mode,url:r}}parseArgumentGroup(t,n){var r=this.gullet.scanArgument(t);if(r==null)return null;var a=this.mode;n&&this.switchMode(n),this.gullet.beginGroup();var i=this.parseExpression(!1,"EOF");this.expect("EOF"),this.gullet.endGroup();var o={type:"ordgroup",mode:this.mode,loc:r.loc,body:i};return n&&this.switchMode(a),o}parseGroup(t,n){var r=this.fetch(),a=r.text,i;if(a==="{"||a==="\\begingroup"){this.consume();var o=a==="{"?"}":"\\endgroup";this.gullet.beginGroup();var l=this.parseExpression(!1,o),u=this.fetch();this.expect(o),this.gullet.endGroup(),i={type:"ordgroup",mode:this.mode,loc:Zr.range(r,u),body:l,semisimple:a==="\\begingroup"||void 0}}else if(i=this.parseFunction(n,t)||this.parseSymbol(),i==null&&a[0]==="\\"&&!pM.hasOwnProperty(a)){if(this.settings.throwOnError)throw new Re("Undefined control sequence: "+a,r);i=this.formatUnsupportedCmd(a),this.consume()}return i}formLigatures(t){for(var n=t.length-1,r=0;r<n;++r){var a=t[r];if(a.type==="textord"){var i=a.text,o=t[r+1];if(!(!o||o.type!=="textord")){if(i==="-"&&o.text==="-"){var l=t[r+2];r+1<n&&l&&l.type==="textord"&&l.text==="-"?(t.splice(r,3,{type:"textord",mode:"text",loc:Zr.range(a,l),text:"---"}),n-=2):(t.splice(r,2,{type:"textord",mode:"text",loc:Zr.range(a,o),text:"--"}),n-=1)}(i==="'"||i==="`")&&o.text===i&&(t.splice(r,2,{type:"textord",mode:"text",loc:Zr.range(a,o),text:i+i}),n-=1)}}}}parseSymbol(){var t=this.fetch(),n=t.text;if(/^\\verb[^a-zA-Z]/.test(n)){this.consume();var r=n.slice(5),a=r.charAt(0)==="*";if(a&&(r=r.slice(1)),r.length<2||r.charAt(0)!==r.slice(-1))throw new Re(`\\verb assertion failed --
                    please report what input caused this bug`);return r=r.slice(1,-1),{type:"verb",mode:"text",body:r,star:a}}PN.hasOwnProperty(n[0])&&!yn[this.mode][n[0]]&&(this.settings.strict&&this.mode==="math"&&this.settings.reportNonstrict("unicodeTextInMathMode",'Accented Unicode text character "'+n[0]+'" used in math mode',t),n=PN[n[0]]+n.slice(1));var i=Die.exec(n);i&&(n=n.substring(0,i.index),n==="i"?n="ı":n==="j"&&(n="ȷ"));var o;if(yn[this.mode][n]){this.settings.strict&&this.mode==="math"&&_x.includes(n)&&this.settings.reportNonstrict("unicodeTextInMathMode",'Latin-1/Unicode text character "'+n[0]+'" used in math mode',t);var l=yn[this.mode][n].group,u=Zr.range(t),d;if(Mae.hasOwnProperty(l)){var h=l;d={type:"atom",mode:this.mode,family:h,loc:u,text:n}}else d={type:l,mode:this.mode,loc:u,text:n};o=d}else if(n.charCodeAt(0)>=128)this.settings.strict&&(yD(n.charCodeAt(0))?this.mode==="math"&&this.settings.reportNonstrict("unicodeTextInMathMode",'Unicode text character "'+n[0]+'" used in math mode',t):this.settings.reportNonstrict("unknownSymbol",'Unrecognized Unicode character "'+n[0]+'"'+(" ("+n.charCodeAt(0)+")"),t)),o={type:"textord",mode:"text",loc:Zr.range(t),text:n};else return null;if(this.consume(),i)for(var f=0;f<i[0].length;f++){var m=i[0][f];if(!_v[m])throw new Re("Unknown accent ' "+m+"'",t);var b=_v[m][this.mode]||_v[m].text;if(!b)throw new Re("Accent "+m+" unsupported in "+this.mode+" mode",t);o={type:"accent",mode:this.mode,loc:Zr.range(t),label:b,isStretchy:!1,isShifty:!0,base:o}}return o}}Ag.endOfExpression=new Set(["}","\\endgroup","\\end","\\right","&"]);var sw=function(t,n){if(!(typeof t=="string"||t instanceof String))throw new TypeError("KaTeX can only parse string typed expression");var r=new Ag(t,n);delete r.gullet.macros.current["\\df@tag"];var a=r.parse();if(delete r.gullet.macros.current["\\current@color"],delete r.gullet.macros.current["\\color"],r.gullet.macros.get("\\df@tag")){if(!n.displayMode)throw new Re("\\tag works only in display equations");a=[{type:"tag",mode:"text",body:a,tag:r.subparse([new ri("\\df@tag")])}]}return a},lw=function(t,n,r){n.textContent="";var a=Rg(t,r).toNode();n.appendChild(a)};typeof document<"u"&&document.compatMode!=="CSS1Compat"&&(typeof console<"u"&&console.warn("Warning: KaTeX doesn't work in quirks mode. Make sure your website has a suitable doctype."),lw=function(){throw new Re("KaTeX doesn't work in quirks mode.")});var fM=function(t,n){var r=Rg(t,n).toMarkup();return r},mM=function(t,n){var r=new WS(n);return sw(t,r)},gM=function(t,n,r){if(r.throwOnError||!(t instanceof Re))throw t;var a=Ce(["katex-error"],[new ba(n)]);return a.setAttribute("title",t.toString()),a.setAttribute("style","color:"+r.errorColor),a},Rg=function(t,n){var r=new WS(n);try{var a=sw(t,r);return Zae(a,t,r)}catch(i){return gM(i,t,r)}},bM=function(t,n){var r=new WS(n);try{var a=sw(t,r);return Qae(a,t,r)}catch(i){return gM(i,t,r)}},yM="0.16.38",vM={Span:xu,Anchor:bg,SymbolNode:ba,SvgNode:To,PathNode:Es,LineNode:Tx},Bx={version:yM,render:lw,renderToString:fM,ParseError:Re,SETTINGS_SCHEMA:lm,__parse:mM,__renderToDomTree:Rg,__renderToHTMLTree:bM,__setFontMetrics:ED,__defineSymbol:C,__defineFunction:Be,__defineMacro:W,__domTree:vM};const Pie=Object.freeze(Object.defineProperty({__proto__:null,ParseError:Re,SETTINGS_SCHEMA:lm,__defineFunction:Be,__defineMacro:W,__defineSymbol:C,__domTree:vM,__parse:mM,__renderToDomTree:Rg,__renderToHTMLTree:bM,__setFontMetrics:ED,default:Bx,get render(){return lw},renderToString:fM,version:yM},Symbol.toStringTag,{value:"Module"})),Uie={},jie=[];function Hie(e){const t=e||Uie;return function(n,r){US(n,"element",function(a,i){const o=Array.isArray(a.properties.className)?a.properties.className:jie,l=o.includes("language-math"),u=o.includes("math-display"),d=o.includes("math-inline");let h=u;if(!l&&!u&&!d)return;let f=i[i.length-1],m=a;if(a.tagName==="code"&&l&&f&&f.type==="element"&&f.tagName==="pre"&&(m=f,f=i[i.length-2],h=!0),!f)return;const b=Zre(m,{whitespace:"pre"});let y;try{y=Bx.renderToString(b,{...t,displayMode:h,throwOnError:!0})}catch(w){const S=w,k=S.name.toLowerCase();r.message("Could not render math with KaTeX",{ancestors:[...i,a],cause:S,place:a.position,ruleId:k,source:"rehype-katex"});try{y=Bx.renderToString(b,{...t,displayMode:h,strict:"ignore",throwOnError:!1})}catch{y=[{type:"element",tagName:"span",properties:{className:["katex-error"],style:"color:"+(t.errorColor||"#cc0000"),title:String(w)},children:[{type:"text",value:b}]}]}}typeof y=="string"&&(y=Hre(y).children);const v=f.children.indexOf(m);return f.children.splice(v,1,...y),lD})}}function UN(e,t){const n=String(e);if(typeof t!="string")throw new TypeError("Expected character");let r=0,a=n.indexOf(t);for(;a!==-1;)r++,a=n.indexOf(t,a+t.length);return r}function Gie(e){if(typeof e!="string")throw new TypeError("Expected a string");return e.replace(/[|\\{}()[\]^$+*?.]/g,"\\$&").replace(/-/g,"\\x2d")}function qie(e,t,n){const a=np((n||{}).ignore||[]),i=Wie(t);let o=-1;for(;++o<i.length;)US(e,"text",l);function l(d,h){let f=-1,m;for(;++f<h.length;){const b=h[f],y=m?m.children:void 0;if(a(b,y?y.indexOf(b):void 0,m))return;m=b}if(m)return u(d,h)}function u(d,h){const f=h[h.length-1],m=i[o][0],b=i[o][1];let y=0;const w=f.children.indexOf(d);let S=!1,k=[];m.lastIndex=0;let R=m.exec(d.value);for(;R;){const I=R.index,L={index:R.index,input:R.input,stack:[...h,d]};let A=b(...R,L);if(typeof A=="string"&&(A=A.length>0?{type:"text",value:A}:void 0),A===!1?m.lastIndex=I+1:(y!==I&&k.push({type:"text",value:d.value.slice(y,I)}),Array.isArray(A)?k.push(...A):A&&k.push(A),y=I+R[0].length,S=!0),!m.global)break;R=m.exec(d.value)}return S?(y<d.value.length&&k.push({type:"text",value:d.value.slice(y)}),f.children.splice(w,1,...k)):k=[d],w+k.length}}function Wie(e){const t=[];if(!Array.isArray(e))throw new TypeError("Expected find and replace tuple or list of tuples");const n=!e[0]||Array.isArray(e[0])?e:[e];let r=-1;for(;++r<n.length;){const a=n[r];t.push([Vie(a[0]),Yie(a[1])])}return t}function Vie(e){return typeof e=="string"?new RegExp(Gie(e),"g"):e}function Yie(e){return typeof e=="function"?e:function(){return e}}const Cv="phrasing",Av=["autolink","link","image","label"];function Xie(){return{transforms:[noe],enter:{literalAutolink:Zie,literalAutolinkEmail:Rv,literalAutolinkHttp:Rv,literalAutolinkWww:Rv},exit:{literalAutolink:toe,literalAutolinkEmail:eoe,literalAutolinkHttp:Qie,literalAutolinkWww:Jie}}}function Kie(){return{unsafe:[{character:"@",before:"[+\\-.\\w]",after:"[\\-.\\w]",inConstruct:Cv,notInConstruct:Av},{character:".",before:"[Ww]",after:"[\\-.\\w]",inConstruct:Cv,notInConstruct:Av},{character:":",before:"[ps]",after:"\\/",inConstruct:Cv,notInConstruct:Av}]}}function Zie(e){this.enter({type:"link",title:null,url:"",children:[]},e)}function Rv(e){this.config.enter.autolinkProtocol.call(this,e)}function Qie(e){this.config.exit.autolinkProtocol.call(this,e)}function Jie(e){this.config.exit.data.call(this,e);const t=this.stack[this.stack.length-1];t.type,t.url="http://"+this.sliceSerialize(e)}function eoe(e){this.config.exit.autolinkEmail.call(this,e)}function toe(e){this.exit(e)}function noe(e){qie(e,[[/(https?:\/\/|www(?=\.))([-.\w]+)([^ \t\r\n]*)/gi,roe],[new RegExp("(?<=^|\\s|\\p{P}|\\p{S})([-.\\w+]+)@([-\\w]+(?:\\.[-\\w]+)+)","gu"),aoe]],{ignore:["link","linkReference"]})}function roe(e,t,n,r,a){let i="";if(!xM(a)||(/^w/i.test(t)&&(n=t+n,t="",i="http://"),!ioe(n)))return!1;const o=ooe(n+r);if(!o[0])return!1;const l={type:"link",title:null,url:i+t+o[0],children:[{type:"text",value:t+o[0]}]};return o[1]?[l,{type:"text",value:o[1]}]:l}function aoe(e,t,n,r){return!xM(r,!0)||/[-\d_]$/.test(n)?!1:{type:"link",title:null,url:"mailto:"+t+"@"+n,children:[{type:"text",value:t+"@"+n}]}}function ioe(e){const t=e.split(".");return!(t.length<2||t[t.length-1]&&(/_/.test(t[t.length-1])||!/[a-zA-Z\d]/.test(t[t.length-1]))||t[t.length-2]&&(/_/.test(t[t.length-2])||!/[a-zA-Z\d]/.test(t[t.length-2])))}function ooe(e){const t=/[!"&'),.:;<>?\]}]+$/.exec(e);if(!t)return[e,void 0];e=e.slice(0,t.index);let n=t[0],r=n.indexOf(")");const a=UN(e,"(");let i=UN(e,")");for(;r!==-1&&a>i;)e+=n.slice(0,r+1),n=n.slice(r+1),r=n.indexOf(")"),i++;return[e,n]}function xM(e,t){const n=e.input.charCodeAt(e.index-1);return(e.index===0||yl(n)||pg(n))&&(!t||n!==47)}SM.peek=moe;function soe(){this.buffer()}function loe(e){this.enter({type:"footnoteReference",identifier:"",label:""},e)}function coe(){this.buffer()}function uoe(e){this.enter({type:"footnoteDefinition",identifier:"",label:"",children:[]},e)}function doe(e){const t=this.resume(),n=this.stack[this.stack.length-1];n.type,n.identifier=ni(this.sliceSerialize(e)).toLowerCase(),n.label=t}function hoe(e){this.exit(e)}function poe(e){const t=this.resume(),n=this.stack[this.stack.length-1];n.type,n.identifier=ni(this.sliceSerialize(e)).toLowerCase(),n.label=t}function foe(e){this.exit(e)}function moe(){return"["}function SM(e,t,n,r){const a=n.createTracker(r);let i=a.move("[^");const o=n.enter("footnoteReference"),l=n.enter("reference");return i+=a.move(n.safe(n.associationId(e),{after:"]",before:i})),l(),o(),i+=a.move("]"),i}function goe(){return{enter:{gfmFootnoteCallString:soe,gfmFootnoteCall:loe,gfmFootnoteDefinitionLabelString:coe,gfmFootnoteDefinition:uoe},exit:{gfmFootnoteCallString:doe,gfmFootnoteCall:hoe,gfmFootnoteDefinitionLabelString:poe,gfmFootnoteDefinition:foe}}}function boe(e){let t=!1;return e&&e.firstLineBlank&&(t=!0),{handlers:{footnoteDefinition:n,footnoteReference:SM},unsafe:[{character:"[",inConstruct:["label","phrasing","reference"]}]};function n(r,a,i,o){const l=i.createTracker(o);let u=l.move("[^");const d=i.enter("footnoteDefinition"),h=i.enter("label");return u+=l.move(i.safe(i.associationId(r),{before:u,after:"]"})),h(),u+=l.move("]:"),r.children&&r.children.length>0&&(l.shift(4),u+=l.move((t?`
`:" ")+i.indentLines(i.containerFlow(r,l.current()),t?wM:yoe))),d(),u}}function yoe(e,t,n){return t===0?e:wM(e,t,n)}function wM(e,t,n){return(n?"":"    ")+e}const voe=["autolink","destinationLiteral","destinationRaw","reference","titleQuote","titleApostrophe"];EM.peek=koe;function xoe(){return{canContainEols:["delete"],enter:{strikethrough:woe},exit:{strikethrough:Eoe}}}function Soe(){return{unsafe:[{character:"~",inConstruct:"phrasing",notInConstruct:voe}],handlers:{delete:EM}}}function woe(e){this.enter({type:"delete",children:[]},e)}function Eoe(e){this.exit(e)}function EM(e,t,n,r){const a=n.createTracker(r),i=n.enter("strikethrough");let o=a.move("~~");return o+=n.containerPhrasing(e,{...a.current(),before:o,after:"~"}),o+=a.move("~~"),i(),o}function koe(){return"~"}function Toe(e){return e.length}function _oe(e,t){const n=t||{},r=(n.align||[]).concat(),a=n.stringLength||Toe,i=[],o=[],l=[],u=[];let d=0,h=-1;for(;++h<e.length;){const v=[],w=[];let S=-1;for(e[h].length>d&&(d=e[h].length);++S<e[h].length;){const k=Coe(e[h][S]);if(n.alignDelimiters!==!1){const R=a(k);w[S]=R,(u[S]===void 0||R>u[S])&&(u[S]=R)}v.push(k)}o[h]=v,l[h]=w}let f=-1;if(typeof r=="object"&&"length"in r)for(;++f<d;)i[f]=jN(r[f]);else{const v=jN(r);for(;++f<d;)i[f]=v}f=-1;const m=[],b=[];for(;++f<d;){const v=i[f];let w="",S="";v===99?(w=":",S=":"):v===108?w=":":v===114&&(S=":");let k=n.alignDelimiters===!1?1:Math.max(1,u[f]-w.length-S.length);const R=w+"-".repeat(k)+S;n.alignDelimiters!==!1&&(k=w.length+k+S.length,k>u[f]&&(u[f]=k),b[f]=k),m[f]=R}o.splice(1,0,m),l.splice(1,0,b),h=-1;const y=[];for(;++h<o.length;){const v=o[h],w=l[h];f=-1;const S=[];for(;++f<d;){const k=v[f]||"";let R="",I="";if(n.alignDelimiters!==!1){const L=u[f]-(w[f]||0),A=i[f];A===114?R=" ".repeat(L):A===99?L%2?(R=" ".repeat(L/2+.5),I=" ".repeat(L/2-.5)):(R=" ".repeat(L/2),I=R):I=" ".repeat(L)}n.delimiterStart!==!1&&!f&&S.push("|"),n.padding!==!1&&!(n.alignDelimiters===!1&&k==="")&&(n.delimiterStart!==!1||f)&&S.push(" "),n.alignDelimiters!==!1&&S.push(R),S.push(k),n.alignDelimiters!==!1&&S.push(I),n.padding!==!1&&S.push(" "),(n.delimiterEnd!==!1||f!==d-1)&&S.push("|")}y.push(n.delimiterEnd===!1?S.join("").replace(/ +$/,""):S.join(""))}return y.join(`
`)}function Coe(e){return e==null?"":String(e)}function jN(e){const t=typeof e=="string"?e.codePointAt(0):0;return t===67||t===99?99:t===76||t===108?108:t===82||t===114?114:0}function Aoe(e,t,n,r){const a=n.enter("blockquote"),i=n.createTracker(r);i.move("> "),i.shift(2);const o=n.indentLines(n.containerFlow(e,i.current()),Roe);return a(),o}function Roe(e,t,n){return">"+(n?"":" ")+e}function Noe(e,t){return HN(e,t.inConstruct,!0)&&!HN(e,t.notInConstruct,!1)}function HN(e,t,n){if(typeof t=="string"&&(t=[t]),!t||t.length===0)return n;let r=-1;for(;++r<t.length;)if(e.includes(t[r]))return!0;return!1}function GN(e,t,n,r){let a=-1;for(;++a<n.unsafe.length;)if(n.unsafe[a].character===`
`&&Noe(n.stack,n.unsafe[a]))return/[ \t]/.test(r.before)?"":" ";return`\\
`}function kM(e,t){const n=String(e);let r=n.indexOf(t),a=r,i=0,o=0;if(typeof t!="string")throw new TypeError("Expected substring");for(;r!==-1;)r===a?++i>o&&(o=i):i=1,a=r+t.length,r=n.indexOf(t,a);return o}function Ooe(e,t){return!!(t.options.fences===!1&&e.value&&!e.lang&&/[^ \r\n]/.test(e.value)&&!/^[\t ]*(?:[\r\n]|$)|(?:^|[\r\n])[\t ]*$/.test(e.value))}function Ioe(e){const t=e.options.fence||"`";if(t!=="`"&&t!=="~")throw new Error("Cannot serialize code with `"+t+"` for `options.fence`, expected `` ` `` or `~`");return t}function Loe(e,t,n,r){const a=Ioe(n),i=e.value||"",o=a==="`"?"GraveAccent":"Tilde";if(Ooe(e,n)){const f=n.enter("codeIndented"),m=n.indentLines(i,Doe);return f(),m}const l=n.createTracker(r),u=a.repeat(Math.max(kM(i,a)+1,3)),d=n.enter("codeFenced");let h=l.move(u);if(e.lang){const f=n.enter(`codeFencedLang${o}`);h+=l.move(n.safe(e.lang,{before:h,after:" ",encode:["`"],...l.current()})),f()}if(e.lang&&e.meta){const f=n.enter(`codeFencedMeta${o}`);h+=l.move(" "),h+=l.move(n.safe(e.meta,{before:h,after:`
`,encode:["`"],...l.current()})),f()}return h+=l.move(`
`),i&&(h+=l.move(i+`
`)),h+=l.move(u),d(),h}function Doe(e,t,n){return(n?"":"    ")+e}function cw(e){const t=e.options.quote||'"';if(t!=='"'&&t!=="'")throw new Error("Cannot serialize title with `"+t+"` for `options.quote`, expected `\"`, or `'`");return t}function Moe(e,t,n,r){const a=cw(n),i=a==='"'?"Quote":"Apostrophe",o=n.enter("definition");let l=n.enter("label");const u=n.createTracker(r);let d=u.move("[");return d+=u.move(n.safe(n.associationId(e),{before:d,after:"]",...u.current()})),d+=u.move("]: "),l(),!e.url||/[\0- \u007F]/.test(e.url)?(l=n.enter("destinationLiteral"),d+=u.move("<"),d+=u.move(n.safe(e.url,{before:d,after:">",...u.current()})),d+=u.move(">")):(l=n.enter("destinationRaw"),d+=u.move(n.safe(e.url,{before:d,after:e.title?" ":`
`,...u.current()}))),l(),e.title&&(l=n.enter(`title${i}`),d+=u.move(" "+a),d+=u.move(n.safe(e.title,{before:d,after:a,...u.current()})),d+=u.move(a),l()),o(),d}function Boe(e){const t=e.options.emphasis||"*";if(t!=="*"&&t!=="_")throw new Error("Cannot serialize emphasis with `"+t+"` for `options.emphasis`, expected `*`, or `_`");return t}function Rh(e){return"&#x"+e.toString(16).toUpperCase()+";"}function fm(e,t,n){const r=Qc(e),a=Qc(t);return r===void 0?a===void 0?n==="_"?{inside:!0,outside:!0}:{inside:!1,outside:!1}:a===1?{inside:!0,outside:!0}:{inside:!1,outside:!0}:r===1?a===void 0?{inside:!1,outside:!1}:a===1?{inside:!0,outside:!0}:{inside:!1,outside:!1}:a===void 0?{inside:!1,outside:!1}:a===1?{inside:!0,outside:!1}:{inside:!1,outside:!1}}TM.peek=Foe;function TM(e,t,n,r){const a=Boe(n),i=n.enter("emphasis"),o=n.createTracker(r),l=o.move(a);let u=o.move(n.containerPhrasing(e,{after:a,before:l,...o.current()}));const d=u.charCodeAt(0),h=fm(r.before.charCodeAt(r.before.length-1),d,a);h.inside&&(u=Rh(d)+u.slice(1));const f=u.charCodeAt(u.length-1),m=fm(r.after.charCodeAt(0),f,a);m.inside&&(u=u.slice(0,-1)+Rh(f));const b=o.move(a);return i(),n.attentionEncodeSurroundingInfo={after:m.outside,before:h.outside},l+u+b}function Foe(e,t,n){return n.options.emphasis||"*"}function zoe(e,t){let n=!1;return jS(e,function(r){if("value"in r&&/\r?\n|\r/.test(r.value)||r.type==="break")return n=!0,bx}),!!((!e.depth||e.depth<3)&&MS(e)&&(t.options.setext||n))}function $oe(e,t,n,r){const a=Math.max(Math.min(6,e.depth||1),1),i=n.createTracker(r);if(zoe(e,n)){const h=n.enter("headingSetext"),f=n.enter("phrasing"),m=n.containerPhrasing(e,{...i.current(),before:`
`,after:`
`});return f(),h(),m+`
`+(a===1?"=":"-").repeat(m.length-(Math.max(m.lastIndexOf("\r"),m.lastIndexOf(`
`))+1))}const o="#".repeat(a),l=n.enter("headingAtx"),u=n.enter("phrasing");i.move(o+" ");let d=n.containerPhrasing(e,{before:"# ",after:`
`,...i.current()});return/^[\t ]/.test(d)&&(d=Rh(d.charCodeAt(0))+d.slice(1)),d=d?o+" "+d:o,n.options.closeAtx&&(d+=" "+o),u(),l(),d}_M.peek=Poe;function _M(e){return e.value||""}function Poe(){return"<"}CM.peek=Uoe;function CM(e,t,n,r){const a=cw(n),i=a==='"'?"Quote":"Apostrophe",o=n.enter("image");let l=n.enter("label");const u=n.createTracker(r);let d=u.move("![");return d+=u.move(n.safe(e.alt,{before:d,after:"]",...u.current()})),d+=u.move("]("),l(),!e.url&&e.title||/[\0- \u007F]/.test(e.url)?(l=n.enter("destinationLiteral"),d+=u.move("<"),d+=u.move(n.safe(e.url,{before:d,after:">",...u.current()})),d+=u.move(">")):(l=n.enter("destinationRaw"),d+=u.move(n.safe(e.url,{before:d,after:e.title?" ":")",...u.current()}))),l(),e.title&&(l=n.enter(`title${i}`),d+=u.move(" "+a),d+=u.move(n.safe(e.title,{before:d,after:a,...u.current()})),d+=u.move(a),l()),d+=u.move(")"),o(),d}function Uoe(){return"!"}AM.peek=joe;function AM(e,t,n,r){const a=e.referenceType,i=n.enter("imageReference");let o=n.enter("label");const l=n.createTracker(r);let u=l.move("![");const d=n.safe(e.alt,{before:u,after:"]",...l.current()});u+=l.move(d+"]["),o();const h=n.stack;n.stack=[],o=n.enter("reference");const f=n.safe(n.associationId(e),{before:u,after:"]",...l.current()});return o(),n.stack=h,i(),a==="full"||!d||d!==f?u+=l.move(f+"]"):a==="shortcut"?u=u.slice(0,-1):u+=l.move("]"),u}function joe(){return"!"}RM.peek=Hoe;function RM(e,t,n){let r=e.value||"",a="`",i=-1;for(;new RegExp("(^|[^`])"+a+"([^`]|$)").test(r);)a+="`";for(/[^ \r\n]/.test(r)&&(/^[ \r\n]/.test(r)&&/[ \r\n]$/.test(r)||/^`|`$/.test(r))&&(r=" "+r+" ");++i<n.unsafe.length;){const o=n.unsafe[i],l=n.compilePattern(o);let u;if(o.atBreak)for(;u=l.exec(r);){let d=u.index;r.charCodeAt(d)===10&&r.charCodeAt(d-1)===13&&d--,r=r.slice(0,d)+" "+r.slice(u.index+1)}}return a+r+a}function Hoe(){return"`"}function NM(e,t){const n=MS(e);return!!(!t.options.resourceLink&&e.url&&!e.title&&e.children&&e.children.length===1&&e.children[0].type==="text"&&(n===e.url||"mailto:"+n===e.url)&&/^[a-z][a-z+.-]+:/i.test(e.url)&&!/[\0- <>\u007F]/.test(e.url))}OM.peek=Goe;function OM(e,t,n,r){const a=cw(n),i=a==='"'?"Quote":"Apostrophe",o=n.createTracker(r);let l,u;if(NM(e,n)){const h=n.stack;n.stack=[],l=n.enter("autolink");let f=o.move("<");return f+=o.move(n.containerPhrasing(e,{before:f,after:">",...o.current()})),f+=o.move(">"),l(),n.stack=h,f}l=n.enter("link"),u=n.enter("label");let d=o.move("[");return d+=o.move(n.containerPhrasing(e,{before:d,after:"](",...o.current()})),d+=o.move("]("),u(),!e.url&&e.title||/[\0- \u007F]/.test(e.url)?(u=n.enter("destinationLiteral"),d+=o.move("<"),d+=o.move(n.safe(e.url,{before:d,after:">",...o.current()})),d+=o.move(">")):(u=n.enter("destinationRaw"),d+=o.move(n.safe(e.url,{before:d,after:e.title?" ":")",...o.current()}))),u(),e.title&&(u=n.enter(`title${i}`),d+=o.move(" "+a),d+=o.move(n.safe(e.title,{before:d,after:a,...o.current()})),d+=o.move(a),u()),d+=o.move(")"),l(),d}function Goe(e,t,n){return NM(e,n)?"<":"["}IM.peek=qoe;function IM(e,t,n,r){const a=e.referenceType,i=n.enter("linkReference");let o=n.enter("label");const l=n.createTracker(r);let u=l.move("[");const d=n.containerPhrasing(e,{before:u,after:"]",...l.current()});u+=l.move(d+"]["),o();const h=n.stack;n.stack=[],o=n.enter("reference");const f=n.safe(n.associationId(e),{before:u,after:"]",...l.current()});return o(),n.stack=h,i(),a==="full"||!d||d!==f?u+=l.move(f+"]"):a==="shortcut"?u=u.slice(0,-1):u+=l.move("]"),u}function qoe(){return"["}function uw(e){const t=e.options.bullet||"*";if(t!=="*"&&t!=="+"&&t!=="-")throw new Error("Cannot serialize items with `"+t+"` for `options.bullet`, expected `*`, `+`, or `-`");return t}function Woe(e){const t=uw(e),n=e.options.bulletOther;if(!n)return t==="*"?"-":"*";if(n!=="*"&&n!=="+"&&n!=="-")throw new Error("Cannot serialize items with `"+n+"` for `options.bulletOther`, expected `*`, `+`, or `-`");if(n===t)throw new Error("Expected `bullet` (`"+t+"`) and `bulletOther` (`"+n+"`) to be different");return n}function Voe(e){const t=e.options.bulletOrdered||".";if(t!=="."&&t!==")")throw new Error("Cannot serialize items with `"+t+"` for `options.bulletOrdered`, expected `.` or `)`");return t}function LM(e){const t=e.options.rule||"*";if(t!=="*"&&t!=="-"&&t!=="_")throw new Error("Cannot serialize rules with `"+t+"` for `options.rule`, expected `*`, `-`, or `_`");return t}function Yoe(e,t,n,r){const a=n.enter("list"),i=n.bulletCurrent;let o=e.ordered?Voe(n):uw(n);const l=e.ordered?o==="."?")":".":Woe(n);let u=t&&n.bulletLastUsed?o===n.bulletLastUsed:!1;if(!e.ordered){const h=e.children?e.children[0]:void 0;if((o==="*"||o==="-")&&h&&(!h.children||!h.children[0])&&n.stack[n.stack.length-1]==="list"&&n.stack[n.stack.length-2]==="listItem"&&n.stack[n.stack.length-3]==="list"&&n.stack[n.stack.length-4]==="listItem"&&n.indexStack[n.indexStack.length-1]===0&&n.indexStack[n.indexStack.length-2]===0&&n.indexStack[n.indexStack.length-3]===0&&(u=!0),LM(n)===o&&h){let f=-1;for(;++f<e.children.length;){const m=e.children[f];if(m&&m.type==="listItem"&&m.children&&m.children[0]&&m.children[0].type==="thematicBreak"){u=!0;break}}}}u&&(o=l),n.bulletCurrent=o;const d=n.containerFlow(e,r);return n.bulletLastUsed=o,n.bulletCurrent=i,a(),d}function Xoe(e){const t=e.options.listItemIndent||"one";if(t!=="tab"&&t!=="one"&&t!=="mixed")throw new Error("Cannot serialize items with `"+t+"` for `options.listItemIndent`, expected `tab`, `one`, or `mixed`");return t}function Koe(e,t,n,r){const a=Xoe(n);let i=n.bulletCurrent||uw(n);t&&t.type==="list"&&t.ordered&&(i=(typeof t.start=="number"&&t.start>-1?t.start:1)+(n.options.incrementListMarker===!1?0:t.children.indexOf(e))+i);let o=i.length+1;(a==="tab"||a==="mixed"&&(t&&t.type==="list"&&t.spread||e.spread))&&(o=Math.ceil(o/4)*4);const l=n.createTracker(r);l.move(i+" ".repeat(o-i.length)),l.shift(o);const u=n.enter("listItem"),d=n.indentLines(n.containerFlow(e,l.current()),h);return u(),d;function h(f,m,b){return m?(b?"":" ".repeat(o))+f:(b?i:i+" ".repeat(o-i.length))+f}}function Zoe(e,t,n,r){const a=n.enter("paragraph"),i=n.enter("phrasing"),o=n.containerPhrasing(e,r);return i(),a(),o}const Qoe=np(["break","delete","emphasis","footnote","footnoteReference","image","imageReference","inlineCode","inlineMath","link","linkReference","mdxJsxTextElement","mdxTextExpression","strong","text","textDirective"]);function Joe(e,t,n,r){return(e.children.some(function(o){return Qoe(o)})?n.containerPhrasing:n.containerFlow).call(n,e,r)}function ese(e){const t=e.options.strong||"*";if(t!=="*"&&t!=="_")throw new Error("Cannot serialize strong with `"+t+"` for `options.strong`, expected `*`, or `_`");return t}DM.peek=tse;function DM(e,t,n,r){const a=ese(n),i=n.enter("strong"),o=n.createTracker(r),l=o.move(a+a);let u=o.move(n.containerPhrasing(e,{after:a,before:l,...o.current()}));const d=u.charCodeAt(0),h=fm(r.before.charCodeAt(r.before.length-1),d,a);h.inside&&(u=Rh(d)+u.slice(1));const f=u.charCodeAt(u.length-1),m=fm(r.after.charCodeAt(0),f,a);m.inside&&(u=u.slice(0,-1)+Rh(f));const b=o.move(a+a);return i(),n.attentionEncodeSurroundingInfo={after:m.outside,before:h.outside},l+u+b}function tse(e,t,n){return n.options.strong||"*"}function nse(e,t,n,r){return n.safe(e.value,r)}function rse(e){const t=e.options.ruleRepetition||3;if(t<3)throw new Error("Cannot serialize rules with repetition `"+t+"` for `options.ruleRepetition`, expected `3` or more");return t}function ase(e,t,n){const r=(LM(n)+(n.options.ruleSpaces?" ":"")).repeat(rse(n));return n.options.ruleSpaces?r.slice(0,-1):r}const MM={blockquote:Aoe,break:GN,code:Loe,definition:Moe,emphasis:TM,hardBreak:GN,heading:$oe,html:_M,image:CM,imageReference:AM,inlineCode:RM,link:OM,linkReference:IM,list:Yoe,listItem:Koe,paragraph:Zoe,root:Joe,strong:DM,text:nse,thematicBreak:ase};function ise(){return{enter:{table:ose,tableData:qN,tableHeader:qN,tableRow:lse},exit:{codeText:cse,table:sse,tableData:Nv,tableHeader:Nv,tableRow:Nv}}}function ose(e){const t=e._align;this.enter({type:"table",align:t.map(function(n){return n==="none"?null:n}),children:[]},e),this.data.inTable=!0}function sse(e){this.exit(e),this.data.inTable=void 0}function lse(e){this.enter({type:"tableRow",children:[]},e)}function Nv(e){this.exit(e)}function qN(e){this.enter({type:"tableCell",children:[]},e)}function cse(e){let t=this.resume();this.data.inTable&&(t=t.replace(/\\([\\|])/g,use));const n=this.stack[this.stack.length-1];n.type,n.value=t,this.exit(e)}function use(e,t){return t==="|"?t:e}function dse(e){const t=e||{},n=t.tableCellPadding,r=t.tablePipeAlign,a=t.stringLength,i=n?" ":"|";return{unsafe:[{character:"\r",inConstruct:"tableCell"},{character:`
`,inConstruct:"tableCell"},{atBreak:!0,character:"|",after:"[	 :-]"},{character:"|",inConstruct:"tableCell"},{atBreak:!0,character:":",after:"-"},{atBreak:!0,character:"-",after:"[:|-]"}],handlers:{inlineCode:m,table:o,tableCell:u,tableRow:l}};function o(b,y,v,w){return d(h(b,v,w),b.align)}function l(b,y,v,w){const S=f(b,v,w),k=d([S]);return k.slice(0,k.indexOf(`
`))}function u(b,y,v,w){const S=v.enter("tableCell"),k=v.enter("phrasing"),R=v.containerPhrasing(b,{...w,before:i,after:i});return k(),S(),R}function d(b,y){return _oe(b,{align:y,alignDelimiters:r,padding:n,stringLength:a})}function h(b,y,v){const w=b.children;let S=-1;const k=[],R=y.enter("table");for(;++S<w.length;)k[S]=f(w[S],y,v);return R(),k}function f(b,y,v){const w=b.children;let S=-1;const k=[],R=y.enter("tableRow");for(;++S<w.length;)k[S]=u(w[S],b,y,v);return R(),k}function m(b,y,v){let w=MM.inlineCode(b,y,v);return v.stack.includes("tableCell")&&(w=w.replace(/\|/g,"\\$&")),w}}function hse(){return{exit:{taskListCheckValueChecked:WN,taskListCheckValueUnchecked:WN,paragraph:fse}}}function pse(){return{unsafe:[{atBreak:!0,character:"-",after:"[:|-]"}],handlers:{listItem:mse}}}function WN(e){const t=this.stack[this.stack.length-2];t.type,t.checked=e.type==="taskListCheckValueChecked"}function fse(e){const t=this.stack[this.stack.length-2];if(t&&t.type==="listItem"&&typeof t.checked=="boolean"){const n=this.stack[this.stack.length-1];n.type;const r=n.children[0];if(r&&r.type==="text"){const a=t.children;let i=-1,o;for(;++i<a.length;){const l=a[i];if(l.type==="paragraph"){o=l;break}}o===n&&(r.value=r.value.slice(1),r.value.length===0?n.children.shift():n.position&&r.position&&typeof r.position.start.offset=="number"&&(r.position.start.column++,r.position.start.offset++,n.position.start=Object.assign({},r.position.start)))}}this.exit(e)}function mse(e,t,n,r){const a=e.children[0],i=typeof e.checked=="boolean"&&a&&a.type==="paragraph",o="["+(e.checked?"x":" ")+"] ",l=n.createTracker(r);i&&l.move(o);let u=MM.listItem(e,t,n,{...r,...l.current()});return i&&(u=u.replace(/^(?:[*+-]|\d+\.)([\r\n]| {1,3})/,d)),u;function d(h){return h+o}}function gse(){return[Xie(),goe(),xoe(),ise(),hse()]}function bse(e){return{extensions:[Kie(),boe(e),Soe(),dse(e),pse()]}}const yse={tokenize:kse,partial:!0},BM={tokenize:Tse,partial:!0},FM={tokenize:_se,partial:!0},zM={tokenize:Cse,partial:!0},vse={tokenize:Ase,partial:!0},$M={name:"wwwAutolink",tokenize:wse,previous:UM},PM={name:"protocolAutolink",tokenize:Ese,previous:jM},Io={name:"emailAutolink",tokenize:Sse,previous:HM},zi={};function xse(){return{text:zi}}let al=48;for(;al<123;)zi[al]=Io,al++,al===58?al=65:al===91&&(al=97);zi[43]=Io;zi[45]=Io;zi[46]=Io;zi[95]=Io;zi[72]=[Io,PM];zi[104]=[Io,PM];zi[87]=[Io,$M];zi[119]=[Io,$M];function Sse(e,t,n){const r=this;let a,i;return o;function o(f){return!Fx(f)||!HM.call(r,r.previous)||dw(r.events)?n(f):(e.enter("literalAutolink"),e.enter("literalAutolinkEmail"),l(f))}function l(f){return Fx(f)?(e.consume(f),l):f===64?(e.consume(f),u):n(f)}function u(f){return f===46?e.check(vse,h,d)(f):f===45||f===95||mr(f)?(i=!0,e.consume(f),u):h(f)}function d(f){return e.consume(f),a=!0,u}function h(f){return i&&a&&Ir(r.previous)?(e.exit("literalAutolinkEmail"),e.exit("literalAutolink"),t(f)):n(f)}}function wse(e,t,n){const r=this;return a;function a(o){return o!==87&&o!==119||!UM.call(r,r.previous)||dw(r.events)?n(o):(e.enter("literalAutolink"),e.enter("literalAutolinkWww"),e.check(yse,e.attempt(BM,e.attempt(FM,i),n),n)(o))}function i(o){return e.exit("literalAutolinkWww"),e.exit("literalAutolink"),t(o)}}function Ese(e,t,n){const r=this;let a="",i=!1;return o;function o(f){return(f===72||f===104)&&jM.call(r,r.previous)&&!dw(r.events)?(e.enter("literalAutolink"),e.enter("literalAutolinkHttp"),a+=String.fromCodePoint(f),e.consume(f),l):n(f)}function l(f){if(Ir(f)&&a.length<5)return a+=String.fromCodePoint(f),e.consume(f),l;if(f===58){const m=a.toLowerCase();if(m==="http"||m==="https")return e.consume(f),u}return n(f)}function u(f){return f===47?(e.consume(f),i?d:(i=!0,u)):n(f)}function d(f){return f===null||im(f)||rn(f)||yl(f)||pg(f)?n(f):e.attempt(BM,e.attempt(FM,h),n)(f)}function h(f){return e.exit("literalAutolinkHttp"),e.exit("literalAutolink"),t(f)}}function kse(e,t,n){let r=0;return a;function a(o){return(o===87||o===119)&&r<3?(r++,e.consume(o),a):o===46&&r===3?(e.consume(o),i):n(o)}function i(o){return o===null?n(o):t(o)}}function Tse(e,t,n){let r,a,i;return o;function o(d){return d===46||d===95?e.check(zM,u,l)(d):d===null||rn(d)||yl(d)||d!==45&&pg(d)?u(d):(i=!0,e.consume(d),o)}function l(d){return d===95?r=!0:(a=r,r=void 0),e.consume(d),o}function u(d){return a||r||!i?n(d):t(d)}}function _se(e,t){let n=0,r=0;return a;function a(o){return o===40?(n++,e.consume(o),a):o===41&&r<n?i(o):o===33||o===34||o===38||o===39||o===41||o===42||o===44||o===46||o===58||o===59||o===60||o===63||o===93||o===95||o===126?e.check(zM,t,i)(o):o===null||rn(o)||yl(o)?t(o):(e.consume(o),a)}function i(o){return o===41&&r++,e.consume(o),a}}function Cse(e,t,n){return r;function r(l){return l===33||l===34||l===39||l===41||l===42||l===44||l===46||l===58||l===59||l===63||l===95||l===126?(e.consume(l),r):l===38?(e.consume(l),i):l===93?(e.consume(l),a):l===60||l===null||rn(l)||yl(l)?t(l):n(l)}function a(l){return l===null||l===40||l===91||rn(l)||yl(l)?t(l):r(l)}function i(l){return Ir(l)?o(l):n(l)}function o(l){return l===59?(e.consume(l),r):Ir(l)?(e.consume(l),o):n(l)}}function Ase(e,t,n){return r;function r(i){return e.consume(i),a}function a(i){return mr(i)?n(i):t(i)}}function UM(e){return e===null||e===40||e===42||e===95||e===91||e===93||e===126||rn(e)}function jM(e){return!Ir(e)}function HM(e){return!(e===47||Fx(e))}function Fx(e){return e===43||e===45||e===46||e===95||mr(e)}function dw(e){let t=e.length,n=!1;for(;t--;){const r=e[t][1];if((r.type==="labelLink"||r.type==="labelImage")&&!r._balanced){n=!0;break}if(r._gfmAutolinkLiteralWalkedInto){n=!1;break}}return e.length>0&&!n&&(e[e.length-1][1]._gfmAutolinkLiteralWalkedInto=!0),n}const Rse={tokenize:Fse,partial:!0};function Nse(){return{document:{91:{name:"gfmFootnoteDefinition",tokenize:Dse,continuation:{tokenize:Mse},exit:Bse}},text:{91:{name:"gfmFootnoteCall",tokenize:Lse},93:{name:"gfmPotentialFootnoteCall",add:"after",tokenize:Ose,resolveTo:Ise}}}}function Ose(e,t,n){const r=this;let a=r.events.length;const i=r.parser.gfmFootnotes||(r.parser.gfmFootnotes=[]);let o;for(;a--;){const u=r.events[a][1];if(u.type==="labelImage"){o=u;break}if(u.type==="gfmFootnoteCall"||u.type==="labelLink"||u.type==="label"||u.type==="image"||u.type==="link")break}return l;function l(u){if(!o||!o._balanced)return n(u);const d=ni(r.sliceSerialize({start:o.end,end:r.now()}));return d.codePointAt(0)!==94||!i.includes(d.slice(1))?n(u):(e.enter("gfmFootnoteCallLabelMarker"),e.consume(u),e.exit("gfmFootnoteCallLabelMarker"),t(u))}}function Ise(e,t){let n=e.length;for(;n--;)if(e[n][1].type==="labelImage"&&e[n][0]==="enter"){e[n][1];break}e[n+1][1].type="data",e[n+3][1].type="gfmFootnoteCallLabelMarker";const r={type:"gfmFootnoteCall",start:Object.assign({},e[n+3][1].start),end:Object.assign({},e[e.length-1][1].end)},a={type:"gfmFootnoteCallMarker",start:Object.assign({},e[n+3][1].end),end:Object.assign({},e[n+3][1].end)};a.end.column++,a.end.offset++,a.end._bufferIndex++;const i={type:"gfmFootnoteCallString",start:Object.assign({},a.end),end:Object.assign({},e[e.length-1][1].start)},o={type:"chunkString",contentType:"string",start:Object.assign({},i.start),end:Object.assign({},i.end)},l=[e[n+1],e[n+2],["enter",r,t],e[n+3],e[n+4],["enter",a,t],["exit",a,t],["enter",i,t],["enter",o,t],["exit",o,t],["exit",i,t],e[e.length-2],e[e.length-1],["exit",r,t]];return e.splice(n,e.length-n+1,...l),e}function Lse(e,t,n){const r=this,a=r.parser.gfmFootnotes||(r.parser.gfmFootnotes=[]);let i=0,o;return l;function l(f){return e.enter("gfmFootnoteCall"),e.enter("gfmFootnoteCallLabelMarker"),e.consume(f),e.exit("gfmFootnoteCallLabelMarker"),u}function u(f){return f!==94?n(f):(e.enter("gfmFootnoteCallMarker"),e.consume(f),e.exit("gfmFootnoteCallMarker"),e.enter("gfmFootnoteCallString"),e.enter("chunkString").contentType="string",d)}function d(f){if(i>999||f===93&&!o||f===null||f===91||rn(f))return n(f);if(f===93){e.exit("chunkString");const m=e.exit("gfmFootnoteCallString");return a.includes(ni(r.sliceSerialize(m)))?(e.enter("gfmFootnoteCallLabelMarker"),e.consume(f),e.exit("gfmFootnoteCallLabelMarker"),e.exit("gfmFootnoteCall"),t):n(f)}return rn(f)||(o=!0),i++,e.consume(f),f===92?h:d}function h(f){return f===91||f===92||f===93?(e.consume(f),i++,d):d(f)}}function Dse(e,t,n){const r=this,a=r.parser.gfmFootnotes||(r.parser.gfmFootnotes=[]);let i,o=0,l;return u;function u(y){return e.enter("gfmFootnoteDefinition")._container=!0,e.enter("gfmFootnoteDefinitionLabel"),e.enter("gfmFootnoteDefinitionLabelMarker"),e.consume(y),e.exit("gfmFootnoteDefinitionLabelMarker"),d}function d(y){return y===94?(e.enter("gfmFootnoteDefinitionMarker"),e.consume(y),e.exit("gfmFootnoteDefinitionMarker"),e.enter("gfmFootnoteDefinitionLabelString"),e.enter("chunkString").contentType="string",h):n(y)}function h(y){if(o>999||y===93&&!l||y===null||y===91||rn(y))return n(y);if(y===93){e.exit("chunkString");const v=e.exit("gfmFootnoteDefinitionLabelString");return i=ni(r.sliceSerialize(v)),e.enter("gfmFootnoteDefinitionLabelMarker"),e.consume(y),e.exit("gfmFootnoteDefinitionLabelMarker"),e.exit("gfmFootnoteDefinitionLabel"),m}return rn(y)||(l=!0),o++,e.consume(y),y===92?f:h}function f(y){return y===91||y===92||y===93?(e.consume(y),o++,h):h(y)}function m(y){return y===58?(e.enter("definitionMarker"),e.consume(y),e.exit("definitionMarker"),a.includes(i)||a.push(i),At(e,b,"gfmFootnoteDefinitionWhitespace")):n(y)}function b(y){return t(y)}}function Mse(e,t,n){return e.check(tp,t,e.attempt(Rse,t,n))}function Bse(e){e.exit("gfmFootnoteDefinition")}function Fse(e,t,n){const r=this;return At(e,a,"gfmFootnoteDefinitionIndent",5);function a(i){const o=r.events[r.events.length-1];return o&&o[1].type==="gfmFootnoteDefinitionIndent"&&o[2].sliceSerialize(o[1],!0).length===4?t(i):n(i)}}function zse(e){let n=(e||{}).singleTilde;const r={name:"strikethrough",tokenize:i,resolveAll:a};return n==null&&(n=!0),{text:{126:r},insideSpan:{null:[r]},attentionMarkers:{null:[126]}};function a(o,l){let u=-1;for(;++u<o.length;)if(o[u][0]==="enter"&&o[u][1].type==="strikethroughSequenceTemporary"&&o[u][1]._close){let d=u;for(;d--;)if(o[d][0]==="exit"&&o[d][1].type==="strikethroughSequenceTemporary"&&o[d][1]._open&&o[u][1].end.offset-o[u][1].start.offset===o[d][1].end.offset-o[d][1].start.offset){o[u][1].type="strikethroughSequence",o[d][1].type="strikethroughSequence";const h={type:"strikethrough",start:Object.assign({},o[d][1].start),end:Object.assign({},o[u][1].end)},f={type:"strikethroughText",start:Object.assign({},o[d][1].end),end:Object.assign({},o[u][1].start)},m=[["enter",h,l],["enter",o[d][1],l],["exit",o[d][1],l],["enter",f,l]],b=l.parser.constructs.insideSpan.null;b&&ma(m,m.length,0,fg(b,o.slice(d+1,u),l)),ma(m,m.length,0,[["exit",f,l],["enter",o[u][1],l],["exit",o[u][1],l],["exit",h,l]]),ma(o,d-1,u-d+3,m),u=d+m.length-2;break}}for(u=-1;++u<o.length;)o[u][1].type==="strikethroughSequenceTemporary"&&(o[u][1].type="data");return o}function i(o,l,u){const d=this.previous,h=this.events;let f=0;return m;function m(y){return d===126&&h[h.length-1][1].type!=="characterEscape"?u(y):(o.enter("strikethroughSequenceTemporary"),b(y))}function b(y){const v=Qc(d);if(y===126)return f>1?u(y):(o.consume(y),f++,b);if(f<2&&!n)return u(y);const w=o.exit("strikethroughSequenceTemporary"),S=Qc(y);return w._open=!S||S===2&&!!v,w._close=!v||v===2&&!!S,l(y)}}}class $se{constructor(){this.map=[]}add(t,n,r){Pse(this,t,n,r)}consume(t){if(this.map.sort(function(i,o){return i[0]-o[0]}),this.map.length===0)return;let n=this.map.length;const r=[];for(;n>0;)n-=1,r.push(t.slice(this.map[n][0]+this.map[n][1]),this.map[n][2]),t.length=this.map[n][0];r.push(t.slice()),t.length=0;let a=r.pop();for(;a;){for(const i of a)t.push(i);a=r.pop()}this.map.length=0}}function Pse(e,t,n,r){let a=0;if(!(n===0&&r.length===0)){for(;a<e.map.length;){if(e.map[a][0]===t){e.map[a][1]+=n,e.map[a][2].push(...r);return}a+=1}e.map.push([t,n,r])}}function Use(e,t){let n=!1;const r=[];for(;t<e.length;){const a=e[t];if(n){if(a[0]==="enter")a[1].type==="tableContent"&&r.push(e[t+1][1].type==="tableDelimiterMarker"?"left":"none");else if(a[1].type==="tableContent"){if(e[t-1][1].type==="tableDelimiterMarker"){const i=r.length-1;r[i]=r[i]==="left"?"center":"right"}}else if(a[1].type==="tableDelimiterRow")break}else a[0]==="enter"&&a[1].type==="tableDelimiterRow"&&(n=!0);t+=1}return r}function jse(){return{flow:{null:{name:"table",tokenize:Hse,resolveAll:Gse}}}}function Hse(e,t,n){const r=this;let a=0,i=0,o;return l;function l(B){let H=r.events.length-1;for(;H>-1;){const q=r.events[H][1].type;if(q==="lineEnding"||q==="linePrefix")H--;else break}const Z=H>-1?r.events[H][1].type:null,V=Z==="tableHead"||Z==="tableRow"?A:u;return V===A&&r.parser.lazy[r.now().line]?n(B):V(B)}function u(B){return e.enter("tableHead"),e.enter("tableRow"),d(B)}function d(B){return B===124||(o=!0,i+=1),h(B)}function h(B){return B===null?n(B):Je(B)?i>1?(i=0,r.interrupt=!0,e.exit("tableRow"),e.enter("lineEnding"),e.consume(B),e.exit("lineEnding"),b):n(B):Ot(B)?At(e,h,"whitespace")(B):(i+=1,o&&(o=!1,a+=1),B===124?(e.enter("tableCellDivider"),e.consume(B),e.exit("tableCellDivider"),o=!0,h):(e.enter("data"),f(B)))}function f(B){return B===null||B===124||rn(B)?(e.exit("data"),h(B)):(e.consume(B),B===92?m:f)}function m(B){return B===92||B===124?(e.consume(B),f):f(B)}function b(B){return r.interrupt=!1,r.parser.lazy[r.now().line]?n(B):(e.enter("tableDelimiterRow"),o=!1,Ot(B)?At(e,y,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(B):y(B))}function y(B){return B===45||B===58?w(B):B===124?(o=!0,e.enter("tableCellDivider"),e.consume(B),e.exit("tableCellDivider"),v):L(B)}function v(B){return Ot(B)?At(e,w,"whitespace")(B):w(B)}function w(B){return B===58?(i+=1,o=!0,e.enter("tableDelimiterMarker"),e.consume(B),e.exit("tableDelimiterMarker"),S):B===45?(i+=1,S(B)):B===null||Je(B)?I(B):L(B)}function S(B){return B===45?(e.enter("tableDelimiterFiller"),k(B)):L(B)}function k(B){return B===45?(e.consume(B),k):B===58?(o=!0,e.exit("tableDelimiterFiller"),e.enter("tableDelimiterMarker"),e.consume(B),e.exit("tableDelimiterMarker"),R):(e.exit("tableDelimiterFiller"),R(B))}function R(B){return Ot(B)?At(e,I,"whitespace")(B):I(B)}function I(B){return B===124?y(B):B===null||Je(B)?!o||a!==i?L(B):(e.exit("tableDelimiterRow"),e.exit("tableHead"),t(B)):L(B)}function L(B){return n(B)}function A(B){return e.enter("tableRow"),M(B)}function M(B){return B===124?(e.enter("tableCellDivider"),e.consume(B),e.exit("tableCellDivider"),M):B===null||Je(B)?(e.exit("tableRow"),t(B)):Ot(B)?At(e,M,"whitespace")(B):(e.enter("data"),P(B))}function P(B){return B===null||B===124||rn(B)?(e.exit("data"),M(B)):(e.consume(B),B===92?G:P)}function G(B){return B===92||B===124?(e.consume(B),P):P(B)}}function Gse(e,t){let n=-1,r=!0,a=0,i=[0,0,0,0],o=[0,0,0,0],l=!1,u=0,d,h,f;const m=new $se;for(;++n<e.length;){const b=e[n],y=b[1];b[0]==="enter"?y.type==="tableHead"?(l=!1,u!==0&&(VN(m,t,u,d,h),h=void 0,u=0),d={type:"table",start:Object.assign({},y.start),end:Object.assign({},y.end)},m.add(n,0,[["enter",d,t]])):y.type==="tableRow"||y.type==="tableDelimiterRow"?(r=!0,f=void 0,i=[0,0,0,0],o=[0,n+1,0,0],l&&(l=!1,h={type:"tableBody",start:Object.assign({},y.start),end:Object.assign({},y.end)},m.add(n,0,[["enter",h,t]])),a=y.type==="tableDelimiterRow"?2:h?3:1):a&&(y.type==="data"||y.type==="tableDelimiterMarker"||y.type==="tableDelimiterFiller")?(r=!1,o[2]===0&&(i[1]!==0&&(o[0]=o[1],f=u0(m,t,i,a,void 0,f),i=[0,0,0,0]),o[2]=n)):y.type==="tableCellDivider"&&(r?r=!1:(i[1]!==0&&(o[0]=o[1],f=u0(m,t,i,a,void 0,f)),i=o,o=[i[1],n,0,0])):y.type==="tableHead"?(l=!0,u=n):y.type==="tableRow"||y.type==="tableDelimiterRow"?(u=n,i[1]!==0?(o[0]=o[1],f=u0(m,t,i,a,n,f)):o[1]!==0&&(f=u0(m,t,o,a,n,f)),a=0):a&&(y.type==="data"||y.type==="tableDelimiterMarker"||y.type==="tableDelimiterFiller")&&(o[3]=n)}for(u!==0&&VN(m,t,u,d,h),m.consume(t.events),n=-1;++n<t.events.length;){const b=t.events[n];b[0]==="enter"&&b[1].type==="table"&&(b[1]._align=Use(t.events,n))}return e}function u0(e,t,n,r,a,i){const o=r===1?"tableHeader":r===2?"tableDelimiter":"tableData",l="tableContent";n[0]!==0&&(i.end=Object.assign({},Rc(t.events,n[0])),e.add(n[0],0,[["exit",i,t]]));const u=Rc(t.events,n[1]);if(i={type:o,start:Object.assign({},u),end:Object.assign({},u)},e.add(n[1],0,[["enter",i,t]]),n[2]!==0){const d=Rc(t.events,n[2]),h=Rc(t.events,n[3]),f={type:l,start:Object.assign({},d),end:Object.assign({},h)};if(e.add(n[2],0,[["enter",f,t]]),r!==2){const m=t.events[n[2]],b=t.events[n[3]];if(m[1].end=Object.assign({},b[1].end),m[1].type="chunkText",m[1].contentType="text",n[3]>n[2]+1){const y=n[2]+1,v=n[3]-n[2]-1;e.add(y,v,[])}}e.add(n[3]+1,0,[["exit",f,t]])}return a!==void 0&&(i.end=Object.assign({},Rc(t.events,a)),e.add(a,0,[["exit",i,t]]),i=void 0),i}function VN(e,t,n,r,a){const i=[],o=Rc(t.events,n);a&&(a.end=Object.assign({},o),i.push(["exit",a,t])),r.end=Object.assign({},o),i.push(["exit",r,t]),e.add(n+1,0,i)}function Rc(e,t){const n=e[t],r=n[0]==="enter"?"start":"end";return n[1][r]}const qse={name:"tasklistCheck",tokenize:Vse};function Wse(){return{text:{91:qse}}}function Vse(e,t,n){const r=this;return a;function a(u){return r.previous!==null||!r._gfmTasklistFirstContentOfListItem?n(u):(e.enter("taskListCheck"),e.enter("taskListCheckMarker"),e.consume(u),e.exit("taskListCheckMarker"),i)}function i(u){return rn(u)?(e.enter("taskListCheckValueUnchecked"),e.consume(u),e.exit("taskListCheckValueUnchecked"),o):u===88||u===120?(e.enter("taskListCheckValueChecked"),e.consume(u),e.exit("taskListCheckValueChecked"),o):n(u)}function o(u){return u===93?(e.enter("taskListCheckMarker"),e.consume(u),e.exit("taskListCheckMarker"),e.exit("taskListCheck"),l):n(u)}function l(u){return Je(u)?t(u):Ot(u)?e.check({tokenize:Yse},t,n)(u):n(u)}}function Yse(e,t,n){return At(e,r,"whitespace");function r(a){return a===null?n(a):t(a)}}function Xse(e){return HL([xse(),Nse(),zse(e),jse(),Wse()])}const Kse={};function Zse(e){const t=this,n=e||Kse,r=t.data(),a=r.micromarkExtensions||(r.micromarkExtensions=[]),i=r.fromMarkdownExtensions||(r.fromMarkdownExtensions=[]),o=r.toMarkdownExtensions||(r.toMarkdownExtensions=[]);a.push(Xse(n)),i.push(gse()),o.push(bse(n))}function Qse(){return{enter:{mathFlow:e,mathFlowFenceMeta:t,mathText:i},exit:{mathFlow:a,mathFlowFence:r,mathFlowFenceMeta:n,mathFlowValue:l,mathText:o,mathTextData:l}};function e(u){const d={type:"element",tagName:"code",properties:{className:["language-math","math-display"]},children:[]};this.enter({type:"math",meta:null,value:"",data:{hName:"pre",hChildren:[d]}},u)}function t(){this.buffer()}function n(){const u=this.resume(),d=this.stack[this.stack.length-1];d.type,d.meta=u}function r(){this.data.mathFlowInside||(this.buffer(),this.data.mathFlowInside=!0)}function a(u){const d=this.resume().replace(/^(\r?\n|\r)|(\r?\n|\r)$/g,""),h=this.stack[this.stack.length-1];h.type,this.exit(u),h.value=d;const f=h.data.hChildren[0];f.type,f.tagName,f.children.push({type:"text",value:d}),this.data.mathFlowInside=void 0}function i(u){this.enter({type:"inlineMath",value:"",data:{hName:"code",hProperties:{className:["language-math","math-inline"]},hChildren:[]}},u),this.buffer()}function o(u){const d=this.resume(),h=this.stack[this.stack.length-1];h.type,this.exit(u),h.value=d,h.data.hChildren.push({type:"text",value:d})}function l(u){this.config.enter.data.call(this,u),this.config.exit.data.call(this,u)}}function Jse(e){let t=(e||{}).singleDollarTextMath;return t==null&&(t=!0),r.peek=a,{unsafe:[{character:"\r",inConstruct:"mathFlowMeta"},{character:`
`,inConstruct:"mathFlowMeta"},{character:"$",after:t?void 0:"\\$",inConstruct:"phrasing"},{character:"$",inConstruct:"mathFlowMeta"},{atBreak:!0,character:"$",after:"\\$"}],handlers:{math:n,inlineMath:r}};function n(i,o,l,u){const d=i.value||"",h=l.createTracker(u),f="$".repeat(Math.max(kM(d,"$")+1,2)),m=l.enter("mathFlow");let b=h.move(f);if(i.meta){const y=l.enter("mathFlowMeta");b+=h.move(l.safe(i.meta,{after:`
`,before:b,encode:["$"],...h.current()})),y()}return b+=h.move(`
`),d&&(b+=h.move(d+`
`)),b+=h.move(f),m(),b}function r(i,o,l){let u=i.value||"",d=1;for(t||d++;new RegExp("(^|[^$])"+"\\$".repeat(d)+"([^$]|$)").test(u);)d++;const h="$".repeat(d);/[^ \r\n]/.test(u)&&(/^[ \r\n]/.test(u)&&/[ \r\n]$/.test(u)||/^\$|\$$/.test(u))&&(u=" "+u+" ");let f=-1;for(;++f<l.unsafe.length;){const m=l.unsafe[f];if(!m.atBreak)continue;const b=l.compilePattern(m);let y;for(;y=b.exec(u);){let v=y.index;u.codePointAt(v)===10&&u.codePointAt(v-1)===13&&v--,u=u.slice(0,v)+" "+u.slice(y.index+1)}}return h+u+h}function a(){return"$"}}const ele={tokenize:tle,concrete:!0,name:"mathFlow"},YN={tokenize:nle,partial:!0};function tle(e,t,n){const r=this,a=r.events[r.events.length-1],i=a&&a[1].type==="linePrefix"?a[2].sliceSerialize(a[1],!0).length:0;let o=0;return l;function l(k){return e.enter("mathFlow"),e.enter("mathFlowFence"),e.enter("mathFlowFenceSequence"),u(k)}function u(k){return k===36?(e.consume(k),o++,u):o<2?n(k):(e.exit("mathFlowFenceSequence"),At(e,d,"whitespace")(k))}function d(k){return k===null||Je(k)?f(k):(e.enter("mathFlowFenceMeta"),e.enter("chunkString",{contentType:"string"}),h(k))}function h(k){return k===null||Je(k)?(e.exit("chunkString"),e.exit("mathFlowFenceMeta"),f(k)):k===36?n(k):(e.consume(k),h)}function f(k){return e.exit("mathFlowFence"),r.interrupt?t(k):e.attempt(YN,m,w)(k)}function m(k){return e.attempt({tokenize:S,partial:!0},w,b)(k)}function b(k){return(i?At(e,y,"linePrefix",i+1):y)(k)}function y(k){return k===null?w(k):Je(k)?e.attempt(YN,m,w)(k):(e.enter("mathFlowValue"),v(k))}function v(k){return k===null||Je(k)?(e.exit("mathFlowValue"),y(k)):(e.consume(k),v)}function w(k){return e.exit("mathFlow"),t(k)}function S(k,R,I){let L=0;return At(k,A,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4);function A(G){return k.enter("mathFlowFence"),k.enter("mathFlowFenceSequence"),M(G)}function M(G){return G===36?(L++,k.consume(G),M):L<o?I(G):(k.exit("mathFlowFenceSequence"),At(k,P,"whitespace")(G))}function P(G){return G===null||Je(G)?(k.exit("mathFlowFence"),R(G)):I(G)}}}function nle(e,t,n){const r=this;return a;function a(o){return o===null?t(o):(e.enter("lineEnding"),e.consume(o),e.exit("lineEnding"),i)}function i(o){return r.parser.lazy[r.now().line]?n(o):t(o)}}function rle(e){let n=(e||{}).singleDollarTextMath;return n==null&&(n=!0),{tokenize:r,resolve:ale,previous:ile,name:"mathText"};function r(a,i,o){let l=0,u,d;return h;function h(v){return a.enter("mathText"),a.enter("mathTextSequence"),f(v)}function f(v){return v===36?(a.consume(v),l++,f):l<2&&!n?o(v):(a.exit("mathTextSequence"),m(v))}function m(v){return v===null?o(v):v===36?(d=a.enter("mathTextSequence"),u=0,y(v)):v===32?(a.enter("space"),a.consume(v),a.exit("space"),m):Je(v)?(a.enter("lineEnding"),a.consume(v),a.exit("lineEnding"),m):(a.enter("mathTextData"),b(v))}function b(v){return v===null||v===32||v===36||Je(v)?(a.exit("mathTextData"),m(v)):(a.consume(v),b)}function y(v){return v===36?(a.consume(v),u++,y):u===l?(a.exit("mathTextSequence"),a.exit("mathText"),i(v)):(d.type="mathTextData",b(v))}}}function ale(e){let t=e.length-4,n=3,r,a;if((e[n][1].type==="lineEnding"||e[n][1].type==="space")&&(e[t][1].type==="lineEnding"||e[t][1].type==="space")){for(r=n;++r<t;)if(e[r][1].type==="mathTextData"){e[t][1].type="mathTextPadding",e[n][1].type="mathTextPadding",n+=2,t-=2;break}}for(r=n-1,t++;++r<=t;)a===void 0?r!==t&&e[r][1].type!=="lineEnding"&&(a=r):(r===t||e[r][1].type==="lineEnding")&&(e[a][1].type="mathTextData",r!==a+2&&(e[a][1].end=e[r-1][1].end,e.splice(a+2,r-a-2),t-=r-a-2,r=a+2),a=void 0);return e}function ile(e){return e!==36||this.events[this.events.length-1][1].type==="characterEscape"}function ole(e){return{flow:{36:ele},text:{36:rle(e)}}}const sle={};function lle(e){const t=this,n=e||sle,r=t.data(),a=r.micromarkExtensions||(r.micromarkExtensions=[]),i=r.fromMarkdownExtensions||(r.fromMarkdownExtensions=[]),o=r.toMarkdownExtensions||(r.toMarkdownExtensions=[]);a.push(ole(n)),i.push(Qse()),o.push(Jse(n))}function cle(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)!==-1)continue;n[r]=e[r]}return n}function ule(e,t){if(e==null)return{};var n,r,a=cle(e,t);if(Object.getOwnPropertySymbols){var i=Object.getOwnPropertySymbols(e);for(r=0;r<i.length;r++)n=i[r],t.indexOf(n)===-1&&{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}function zx(e,t){(t==null||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}function dle(e){if(Array.isArray(e))return zx(e)}function hle(e){if(typeof Symbol<"u"&&e[Symbol.iterator]!=null||e["@@iterator"]!=null)return Array.from(e)}function ple(e,t){if(e){if(typeof e=="string")return zx(e,t);var n={}.toString.call(e).slice(8,-1);return n==="Object"&&e.constructor&&(n=e.constructor.name),n==="Map"||n==="Set"?Array.from(e):n==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?zx(e,t):void 0}}function fle(){throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function $x(e){return dle(e)||hle(e)||ple(e)||fle()}function Nh(e){"@babel/helpers - typeof";return Nh=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(t){return typeof t}:function(t){return t&&typeof Symbol=="function"&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},Nh(e)}function mle(e,t){if(Nh(e)!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(Nh(r)!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function gle(e){var t=mle(e,"string");return Nh(t)=="symbol"?t:t+""}function GM(e,t,n){return(t=gle(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function Px(){return Px=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},Px.apply(null,arguments)}function XN(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function Ic(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?XN(Object(n),!0).forEach(function(r){GM(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):XN(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function ble(e){var t=e.length;if(t===0||t===1)return e;if(t===2)return[e[0],e[1],"".concat(e[0],".").concat(e[1]),"".concat(e[1],".").concat(e[0])];if(t===3)return[e[0],e[1],e[2],"".concat(e[0],".").concat(e[1]),"".concat(e[0],".").concat(e[2]),"".concat(e[1],".").concat(e[0]),"".concat(e[1],".").concat(e[2]),"".concat(e[2],".").concat(e[0]),"".concat(e[2],".").concat(e[1]),"".concat(e[0],".").concat(e[1],".").concat(e[2]),"".concat(e[0],".").concat(e[2],".").concat(e[1]),"".concat(e[1],".").concat(e[0],".").concat(e[2]),"".concat(e[1],".").concat(e[2],".").concat(e[0]),"".concat(e[2],".").concat(e[0],".").concat(e[1]),"".concat(e[2],".").concat(e[1],".").concat(e[0])];if(t>=4)return[e[0],e[1],e[2],e[3],"".concat(e[0],".").concat(e[1]),"".concat(e[0],".").concat(e[2]),"".concat(e[0],".").concat(e[3]),"".concat(e[1],".").concat(e[0]),"".concat(e[1],".").concat(e[2]),"".concat(e[1],".").concat(e[3]),"".concat(e[2],".").concat(e[0]),"".concat(e[2],".").concat(e[1]),"".concat(e[2],".").concat(e[3]),"".concat(e[3],".").concat(e[0]),"".concat(e[3],".").concat(e[1]),"".concat(e[3],".").concat(e[2]),"".concat(e[0],".").concat(e[1],".").concat(e[2]),"".concat(e[0],".").concat(e[1],".").concat(e[3]),"".concat(e[0],".").concat(e[2],".").concat(e[1]),"".concat(e[0],".").concat(e[2],".").concat(e[3]),"".concat(e[0],".").concat(e[3],".").concat(e[1]),"".concat(e[0],".").concat(e[3],".").concat(e[2]),"".concat(e[1],".").concat(e[0],".").concat(e[2]),"".concat(e[1],".").concat(e[0],".").concat(e[3]),"".concat(e[1],".").concat(e[2],".").concat(e[0]),"".concat(e[1],".").concat(e[2],".").concat(e[3]),"".concat(e[1],".").concat(e[3],".").concat(e[0]),"".concat(e[1],".").concat(e[3],".").concat(e[2]),"".concat(e[2],".").concat(e[0],".").concat(e[1]),"".concat(e[2],".").concat(e[0],".").concat(e[3]),"".concat(e[2],".").concat(e[1],".").concat(e[0]),"".concat(e[2],".").concat(e[1],".").concat(e[3]),"".concat(e[2],".").concat(e[3],".").concat(e[0]),"".concat(e[2],".").concat(e[3],".").concat(e[1]),"".concat(e[3],".").concat(e[0],".").concat(e[1]),"".concat(e[3],".").concat(e[0],".").concat(e[2]),"".concat(e[3],".").concat(e[1],".").concat(e[0]),"".concat(e[3],".").concat(e[1],".").concat(e[2]),"".concat(e[3],".").concat(e[2],".").concat(e[0]),"".concat(e[3],".").concat(e[2],".").concat(e[1]),"".concat(e[0],".").concat(e[1],".").concat(e[2],".").concat(e[3]),"".concat(e[0],".").concat(e[1],".").concat(e[3],".").concat(e[2]),"".concat(e[0],".").concat(e[2],".").concat(e[1],".").concat(e[3]),"".concat(e[0],".").concat(e[2],".").concat(e[3],".").concat(e[1]),"".concat(e[0],".").concat(e[3],".").concat(e[1],".").concat(e[2]),"".concat(e[0],".").concat(e[3],".").concat(e[2],".").concat(e[1]),"".concat(e[1],".").concat(e[0],".").concat(e[2],".").concat(e[3]),"".concat(e[1],".").concat(e[0],".").concat(e[3],".").concat(e[2]),"".concat(e[1],".").concat(e[2],".").concat(e[0],".").concat(e[3]),"".concat(e[1],".").concat(e[2],".").concat(e[3],".").concat(e[0]),"".concat(e[1],".").concat(e[3],".").concat(e[0],".").concat(e[2]),"".concat(e[1],".").concat(e[3],".").concat(e[2],".").concat(e[0]),"".concat(e[2],".").concat(e[0],".").concat(e[1],".").concat(e[3]),"".concat(e[2],".").concat(e[0],".").concat(e[3],".").concat(e[1]),"".concat(e[2],".").concat(e[1],".").concat(e[0],".").concat(e[3]),"".concat(e[2],".").concat(e[1],".").concat(e[3],".").concat(e[0]),"".concat(e[2],".").concat(e[3],".").concat(e[0],".").concat(e[1]),"".concat(e[2],".").concat(e[3],".").concat(e[1],".").concat(e[0]),"".concat(e[3],".").concat(e[0],".").concat(e[1],".").concat(e[2]),"".concat(e[3],".").concat(e[0],".").concat(e[2],".").concat(e[1]),"".concat(e[3],".").concat(e[1],".").concat(e[0],".").concat(e[2]),"".concat(e[3],".").concat(e[1],".").concat(e[2],".").concat(e[0]),"".concat(e[3],".").concat(e[2],".").concat(e[0],".").concat(e[1]),"".concat(e[3],".").concat(e[2],".").concat(e[1],".").concat(e[0])]}var Ov={};function yle(e){if(e.length===0||e.length===1)return e;var t=e.join(".");return Ov[t]||(Ov[t]=ble(e)),Ov[t]}function vle(e){var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},n=arguments.length>2?arguments[2]:void 0,r=e.filter(function(i){return i!=="token"}),a=yle(r);return a.reduce(function(i,o){return Ic(Ic({},i),n[o])},t)}function KN(e){return e.join(" ")}function xle(e,t){var n=0;return function(r){return n+=1,r.map(function(a,i){return qM({node:a,stylesheet:e,useInlineStyles:t,key:"code-segment-".concat(n,"-").concat(i)})})}}function qM(e){var t=e.node,n=e.stylesheet,r=e.style,a=r===void 0?{}:r,i=e.useInlineStyles,o=e.key,l=t.properties,u=t.type,d=t.tagName,h=t.value;if(u==="text")return h;if(d){var f=xle(n,i),m;if(!i)m=Ic(Ic({},l),{},{className:KN(l.className)});else{var b=Object.keys(n).reduce(function(S,k){return k.split(".").forEach(function(R){S.includes(R)||S.push(R)}),S},[]),y=l.className&&l.className.includes("token")?["token"]:[],v=l.className&&y.concat(l.className.filter(function(S){return!b.includes(S)}));m=Ic(Ic({},l),{},{className:KN(v)||void 0,style:vle(l.className,Object.assign({},l.style,a),n)})}var w=f(t.children);return fr.createElement(d,Px({key:o},m),w)}}const Sle=(function(e,t){var n=e.listLanguages();return n.indexOf(t)!==-1});var wle=["language","children","style","customStyle","codeTagProps","useInlineStyles","showLineNumbers","showInlineLineNumbers","startingLineNumber","lineNumberContainerStyle","lineNumberStyle","wrapLines","wrapLongLines","lineProps","renderer","PreTag","CodeTag","code","astGenerator"];function ZN(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function gs(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?ZN(Object(n),!0).forEach(function(r){GM(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):ZN(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}var Ele=/\n/g;function kle(e){return e.match(Ele)}function Tle(e){var t=e.lines,n=e.startingLineNumber,r=e.style;return t.map(function(a,i){var o=i+n;return fr.createElement("span",{key:"line-".concat(i),className:"react-syntax-highlighter-line-number",style:typeof r=="function"?r(o):r},"".concat(o,`
`))})}function _le(e){var t=e.codeString,n=e.codeStyle,r=e.containerStyle,a=r===void 0?{float:"left",paddingRight:"10px"}:r,i=e.numberStyle,o=i===void 0?{}:i,l=e.startingLineNumber;return fr.createElement("code",{style:Object.assign({},n,a)},Tle({lines:t.replace(/\n$/,"").split(`
`),style:o,startingLineNumber:l}))}function Cle(e){return"".concat(e.toString().length,".25em")}function WM(e,t){return{type:"element",tagName:"span",properties:{key:"line-number--".concat(e),className:["comment","linenumber","react-syntax-highlighter-line-number"],style:t},children:[{type:"text",value:e}]}}function VM(e,t,n){var r={display:"inline-block",minWidth:Cle(n),paddingRight:"1em",textAlign:"right",userSelect:"none"},a=typeof e=="function"?e(t):e,i=gs(gs({},r),a);return i}function L0(e){var t=e.children,n=e.lineNumber,r=e.lineNumberStyle,a=e.largestLineNumber,i=e.showInlineLineNumbers,o=e.lineProps,l=o===void 0?{}:o,u=e.className,d=u===void 0?[]:u,h=e.showLineNumbers,f=e.wrapLongLines,m=e.wrapLines,b=m===void 0?!1:m,y=b?gs({},typeof l=="function"?l(n):l):{};if(y.className=y.className?[].concat($x(y.className.trim().split(/\s+/)),$x(d)):d,n&&i){var v=VM(r,n,a);t.unshift(WM(n,v))}return f&h&&(y.style=gs({display:"flex"},y.style)),{type:"element",tagName:"span",properties:y,children:t}}function YM(e){var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:[],n=arguments.length>2&&arguments[2]!==void 0?arguments[2]:[];e.length===void 0&&(e=[e]);for(var r=0;r<e.length;r++){var a=e[r];if(a.type==="text")n.push(L0({children:[a],className:$x(new Set(t))}));else if(a.children){var i,o=t.concat(((i=a.properties)===null||i===void 0?void 0:i.className)||[]);YM(a.children,o).forEach(function(l){return n.push(l)})}}return n}function Ale(e,t,n,r,a,i,o,l,u){var d,h=YM(e.value),f=[],m=-1,b=0;function y(L,A){var M=arguments.length>2&&arguments[2]!==void 0?arguments[2]:[];return L0({children:L,lineNumber:A,lineNumberStyle:l,largestLineNumber:o,showInlineLineNumbers:a,lineProps:n,className:M,showLineNumbers:r,wrapLongLines:u,wrapLines:t})}function v(L,A){if(r&&A&&a){var M=VM(l,A,o);L.unshift(WM(A,M))}return L}function w(L,A){var M=arguments.length>2&&arguments[2]!==void 0?arguments[2]:[];return t||M.length>0?y(L,A,M):v(L,A)}for(var S=function(){var A=h[b],M=A.children[0].value,P=kle(M);if(P){var G=M.split(`
`);G.forEach(function(B,H){var Z=r&&f.length+i,V={type:"text",value:"".concat(B,`
`)};if(H===0){var q=h.slice(m+1,b).concat(L0({children:[V],className:A.properties.className})),X=w(q,Z);f.push(X)}else if(H===G.length-1){var $=h[b+1]&&h[b+1].children&&h[b+1].children[0],Q={type:"text",value:"".concat(B)};if($){var J=L0({children:[Q],className:A.properties.className});h.splice(b+1,0,J)}else{var ie=[Q],F=w(ie,Z,A.properties.className);f.push(F)}}else{var Y=[V],oe=w(Y,Z,A.properties.className);f.push(oe)}}),m=b}b++};b<h.length;)S();if(m!==h.length-1){var k=h.slice(m+1,h.length);if(k&&k.length){var R=r&&f.length+i,I=w(k,R);f.push(I)}}return t?f:(d=[]).concat.apply(d,f)}function Rle(e){var t=e.rows,n=e.stylesheet,r=e.useInlineStyles;return t.map(function(a,i){return qM({node:a,stylesheet:n,useInlineStyles:r,key:"code-segment-".concat(i)})})}function XM(e){return e&&typeof e.highlightAuto<"u"}function Nle(e){var t=e.astGenerator,n=e.language,r=e.code,a=e.defaultCodeValue;if(XM(t)){var i=Sle(t,n);return n==="text"?{value:a,language:"text"}:i?t.highlight(n,r):t.highlightAuto(r)}try{return n&&n!=="text"?{value:t.highlight(r,n)}:{value:a}}catch{return{value:a}}}function Ole(e,t){return function(r){var a,i,o=r.language,l=r.children,u=r.style,d=u===void 0?t:u,h=r.customStyle,f=h===void 0?{}:h,m=r.codeTagProps,b=m===void 0?{className:o?"language-".concat(o):void 0,style:gs(gs({},d['code[class*="language-"]']),d['code[class*="language-'.concat(o,'"]')])}:m,y=r.useInlineStyles,v=y===void 0?!0:y,w=r.showLineNumbers,S=w===void 0?!1:w,k=r.showInlineLineNumbers,R=k===void 0?!0:k,I=r.startingLineNumber,L=I===void 0?1:I,A=r.lineNumberContainerStyle,M=r.lineNumberStyle,P=M===void 0?{}:M,G=r.wrapLines,B=r.wrapLongLines,H=B===void 0?!1:B,Z=r.lineProps,V=Z===void 0?{}:Z,q=r.renderer,X=r.PreTag,$=X===void 0?"pre":X,Q=r.CodeTag,J=Q===void 0?"code":Q,ie=r.code,F=ie===void 0?(Array.isArray(l)?l[0]:l)||"":ie,Y=r.astGenerator,oe=ule(r,wle);Y=Y||e;var U=S?fr.createElement(_le,{containerStyle:A,codeStyle:b.style||{},numberStyle:P,startingLineNumber:L,codeString:F}):null,be=d.hljs||d['pre[class*="language-"]']||{backgroundColor:"#fff"},ge=XM(Y)?"hljs":"prismjs",fe=v?Object.assign({},oe,{style:Object.assign({},be,f)}):Object.assign({},oe,{className:oe.className?"".concat(ge," ").concat(oe.className):ge,style:Object.assign({},f)});if(H?b.style=gs({whiteSpace:"pre-wrap"},b.style):b.style=gs({whiteSpace:"pre"},b.style),!Y)return fr.createElement($,fe,U,fr.createElement(J,b,F));(G===void 0&&q||H)&&(G=!0),q=q||Rle;var Ee=[{type:"text",value:F}],Ae=Nle({astGenerator:Y,language:o,code:F,defaultCodeValue:Ee});Ae.language===null&&(Ae.value=Ee);var ve=(a=(i=F.match(/\n/g))===null||i===void 0?void 0:i.length)!==null&&a!==void 0?a:0,De=L+ve,Le=Ale(Ae,G,V,S,R,L,De,P,H);return fr.createElement($,fe,fr.createElement(J,b,!R&&U,q({rows:Le,stylesheet:d,useInlineStyles:v})))}}const Ile="modulepreload",Lle=function(e){return"/"+e},QN={},Ut=function(t,n,r){let a=Promise.resolve();if(n&&n.length>0){let o=function(d){return Promise.all(d.map(h=>Promise.resolve(h).then(f=>({status:"fulfilled",value:f}),f=>({status:"rejected",reason:f}))))};document.getElementsByTagName("link");const l=document.querySelector("meta[property=csp-nonce]"),u=(l==null?void 0:l.nonce)||(l==null?void 0:l.getAttribute("nonce"));a=o(n.map(d=>{if(d=Lle(d),d in QN)return;QN[d]=!0;const h=d.endsWith(".css"),f=h?'[rel="stylesheet"]':"";if(document.querySelector(`link[href="${d}"]${f}`))return;const m=document.createElement("link");if(m.rel=h?"stylesheet":Ile,h||(m.as="script"),m.crossOrigin="",m.href=d,u&&m.setAttribute("nonce",u),document.head.appendChild(m),h)return new Promise((b,y)=>{m.addEventListener("load",b),m.addEventListener("error",()=>y(new Error(`Unable to preload CSS for ${d}`)))})}))}function i(o){const l=new Event("vite:preloadError",{cancelable:!0});if(l.payload=o,window.dispatchEvent(l),!l.defaultPrevented)throw o}return a.then(o=>{for(const l of o||[])l.status==="rejected"&&i(l.reason);return t().catch(i)})},Dle=["abap","abnf","actionscript","ada","agda","al","antlr4","apacheconf","apex","apl","applescript","aql","arduino","arff","armasm","arturo","asciidoc","asm6502","asmatmel","aspnet","autohotkey","autoit","avisynth","avro-idl","awk","bash","basic","batch","bbcode","bbj","bicep","birb","bison","bnf","bqn","brainfuck","brightscript","bro","bsl","c","cfscript","chaiscript","cil","cilkc","cilkcpp","clike","clojure","cmake","cobol","coffeescript","concurnas","cooklang","coq","cpp","crystal","csharp","cshtml","csp","css-extras","css","csv","cue","cypher","d","dart","dataweave","dax","dhall","diff","django","dns-zone-file","docker","dot","ebnf","editorconfig","eiffel","ejs","elixir","elm","erb","erlang","etlua","excel-formula","factor","false","firestore-security-rules","flow","fortran","fsharp","ftl","gap","gcode","gdscript","gedcom","gettext","gherkin","git","glsl","gml","gn","go-module","go","gradle","graphql","groovy","haml","handlebars","haskell","haxe","hcl","hlsl","hoon","hpkp","hsts","http","ichigojam","icon","icu-message-format","idris","iecst","ignore","inform7","ini","io","j","java","javadoc","javadoclike","javascript","javastacktrace","jexl","jolie","jq","js-extras","js-templates","jsdoc","json","json5","jsonp","jsstacktrace","jsx","julia","keepalived","keyman","kotlin","kumir","kusto","latex","latte","less","lilypond","linker-script","liquid","lisp","livescript","llvm","log","lolcode","lua","magma","makefile","markdown","markup-templating","markup","mata","matlab","maxscript","mel","mermaid","metafont","mizar","mongodb","monkey","moonscript","n1ql","n4js","nand2tetris-hdl","naniscript","nasm","neon","nevod","nginx","nim","nix","nsis","objectivec","ocaml","odin","opencl","openqasm","oz","parigp","parser","pascal","pascaligo","pcaxis","peoplecode","perl","php-extras","php","phpdoc","plant-uml","plsql","powerquery","powershell","processing","prolog","promql","properties","protobuf","psl","pug","puppet","pure","purebasic","purescript","python","q","qml","qore","qsharp","r","racket","reason","regex","rego","renpy","rescript","rest","rip","roboconf","robotframework","ruby","rust","sas","sass","scala","scheme","scss","shell-session","smali","smalltalk","smarty","sml","solidity","solution-file","soy","sparql","splunk-spl","sqf","sql","squirrel","stan","stata","stylus","supercollider","swift","systemd","t4-cs","t4-templating","t4-vb","tap","tcl","textile","toml","tremor","tsx","tt2","turtle","twig","typescript","typoscript","unrealscript","uorazor","uri","v","vala","vbnet","velocity","verilog","vhdl","vim","visual-basic","warpscript","wasm","web-idl","wgsl","wiki","wolfram","wren","xeora","xml-doc","xojo","xquery","yaml","yang","zig"],Mle=["AElig","AMP","Aacute","Acirc","Agrave","Aring","Atilde","Auml","COPY","Ccedil","ETH","Eacute","Ecirc","Egrave","Euml","GT","Iacute","Icirc","Igrave","Iuml","LT","Ntilde","Oacute","Ocirc","Ograve","Oslash","Otilde","Ouml","QUOT","REG","THORN","Uacute","Ucirc","Ugrave","Uuml","Yacute","aacute","acirc","acute","aelig","agrave","amp","aring","atilde","auml","brvbar","ccedil","cedil","cent","copy","curren","deg","divide","eacute","ecirc","egrave","eth","euml","frac12","frac14","frac34","gt","iacute","icirc","iexcl","igrave","iquest","iuml","laquo","lt","macr","micro","middot","nbsp","not","ntilde","oacute","ocirc","ograve","ordf","ordm","oslash","otilde","ouml","para","plusmn","pound","quot","raquo","reg","sect","shy","sup1","sup2","sup3","szlig","thorn","times","uacute","ucirc","ugrave","uml","uuml","yacute","yen","yuml"],JN={0:"�",128:"€",130:"‚",131:"ƒ",132:"„",133:"…",134:"†",135:"‡",136:"ˆ",137:"‰",138:"Š",139:"‹",140:"Œ",142:"Ž",145:"‘",146:"’",147:"“",148:"”",149:"•",150:"–",151:"—",152:"˜",153:"™",154:"š",155:"›",156:"œ",158:"ž",159:"Ÿ"};function KM(e){const t=typeof e=="string"?e.charCodeAt(0):e;return t>=48&&t<=57}function Ble(e){const t=typeof e=="string"?e.charCodeAt(0):e;return t>=97&&t<=102||t>=65&&t<=70||t>=48&&t<=57}function Fle(e){const t=typeof e=="string"?e.charCodeAt(0):e;return t>=97&&t<=122||t>=65&&t<=90}function e7(e){return Fle(e)||KM(e)}const zle=["","Named character references must be terminated by a semicolon","Numeric character references must be terminated by a semicolon","Named character references cannot be empty","Numeric character references cannot be empty","Named character references must be known","Numeric character references cannot be disallowed","Numeric character references cannot be outside the permissible Unicode range"];function $le(e,t){const n={},r=typeof n.additional=="string"?n.additional.charCodeAt(0):n.additional,a=[];let i=0,o=-1,l="",u,d;n.position&&("start"in n.position||"indent"in n.position?(d=n.position.indent,u=n.position.start):u=n.position);let h=(u?u.line:0)||1,f=(u?u.column:0)||1,m=y(),b;for(i--;++i<=e.length;)if(b===10&&(f=(d?d[o]:0)||1),b=e.charCodeAt(i),b===38){const S=e.charCodeAt(i+1);if(S===9||S===10||S===12||S===32||S===38||S===60||Number.isNaN(S)||r&&S===r){l+=String.fromCharCode(b),f++;continue}const k=i+1;let R=k,I=k,L;if(S===35){I=++R;const V=e.charCodeAt(I);V===88||V===120?(L="hexadecimal",I=++R):L="decimal"}else L="named";let A="",M="",P="";const G=L==="named"?e7:L==="decimal"?KM:Ble;for(I--;++I<=e.length;){const V=e.charCodeAt(I);if(!G(V))break;P+=String.fromCharCode(V),L==="named"&&Mle.includes(P)&&(A=P,M=_h(P))}let B=e.charCodeAt(I)===59;if(B){I++;const V=L==="named"?_h(P):!1;V&&(A=P,M=V)}let H=1+I-k,Z="";if(!(!B&&n.nonTerminated===!1))if(!P)L!=="named"&&v(4,H);else if(L==="named"){if(B&&!M)v(5,1);else if(A!==P&&(I=R+A.length,H=1+I-R,B=!1),!B){const V=A?1:3;if(n.attribute){const q=e.charCodeAt(I);q===61?(v(V,H),M=""):e7(q)?M="":v(V,H)}else v(V,H)}Z=M}else{B||v(2,H);let V=Number.parseInt(P,L==="hexadecimal"?16:10);if(Ple(V))v(7,H),Z="�";else if(V in JN)v(6,H),Z=JN[V];else{let q="";Ule(V)&&v(6,H),V>65535&&(V-=65536,q+=String.fromCharCode(V>>>10|55296),V=56320|V&1023),Z=q+String.fromCharCode(V)}}if(Z){w(),m=y(),i=I-1,f+=I-k+1,a.push(Z);const V=y();V.offset++,n.reference&&n.reference.call(n.referenceContext||void 0,Z,{start:m,end:V},e.slice(k-1,I)),m=V}else P=e.slice(k-1,I),l+=P,f+=P.length,i=I-1}else b===10&&(h++,o++,f=0),Number.isNaN(b)?w():(l+=String.fromCharCode(b),f++);return a.join("");function y(){return{line:h,column:f,offset:i+((u?u.offset:0)||0)}}function v(S,k){let R;n.warning&&(R=y(),R.column+=k,R.offset+=k,n.warning.call(n.warningContext||void 0,zle[S],R,S))}function w(){l&&(a.push(l),n.text&&n.text.call(n.textContext||void 0,l,{start:m,end:y()}),l="")}}function Ple(e){return e>=55296&&e<=57343||e>1114111}function Ule(e){return e>=1&&e<=8||e===11||e>=13&&e<=31||e>=127&&e<=159||e>=64976&&e<=65007||(e&65535)===65535||(e&65535)===65534}var jle=0,d0={},Jn={util:{type:function(e){return Object.prototype.toString.call(e).slice(8,-1)},objId:function(e){return e.__id||Object.defineProperty(e,"__id",{value:++jle}),e.__id},clone:function e(t,n){n=n||{};var r,a;switch(Jn.util.type(t)){case"Object":if(a=Jn.util.objId(t),n[a])return n[a];r={},n[a]=r;for(var i in t)t.hasOwnProperty(i)&&(r[i]=e(t[i],n));return r;case"Array":return a=Jn.util.objId(t),n[a]?n[a]:(r=[],n[a]=r,t.forEach(function(o,l){r[l]=e(o,n)}),r);default:return t}}},languages:{plain:d0,plaintext:d0,text:d0,txt:d0,extend:function(e,t){var n=Jn.util.clone(Jn.languages[e]);for(var r in t)n[r]=t[r];return n},insertBefore:function(e,t,n,r){r=r||Jn.languages;var a=r[e],i={};for(var o in a)if(a.hasOwnProperty(o)){if(o==t)for(var l in n)n.hasOwnProperty(l)&&(i[l]=n[l]);n.hasOwnProperty(o)||(i[o]=a[o])}var u=r[e];return r[e]=i,Jn.languages.DFS(Jn.languages,function(d,h){h===u&&d!=e&&(this[d]=i)}),i},DFS:function e(t,n,r,a){a=a||{};var i=Jn.util.objId;for(var o in t)if(t.hasOwnProperty(o)){n.call(t,o,t[o],r||o);var l=t[o],u=Jn.util.type(l);u==="Object"&&!a[i(l)]?(a[i(l)]=!0,e(l,n,null,a)):u==="Array"&&!a[i(l)]&&(a[i(l)]=!0,e(l,n,o,a))}}},plugins:{},highlight:function(e,t,n){var r={code:e,grammar:t,language:n};if(Jn.hooks.run("before-tokenize",r),!r.grammar)throw new Error('The language "'+r.language+'" has no grammar.');return r.tokens=Jn.tokenize(r.code,r.grammar),Jn.hooks.run("after-tokenize",r),dh.stringify(Jn.util.encode(r.tokens),r.language)},tokenize:function(e,t){var n=t.rest;if(n){for(var r in n)t[r]=n[r];delete t.rest}var a=new Hle;return D0(a,a.head,e),ZM(e,a,t,a.head,0),qle(a)},hooks:{all:{},add:function(e,t){var n=Jn.hooks.all;n[e]=n[e]||[],n[e].push(t)},run:function(e,t){var n=Jn.hooks.all[e];if(!(!n||!n.length))for(var r=0,a;a=n[r++];)a(t)}},Token:dh};function dh(e,t,n,r){this.type=e,this.content=t,this.alias=n,this.length=(r||"").length|0}function t7(e,t,n,r){e.lastIndex=t;var a=e.exec(n);if(a&&r&&a[1]){var i=a[1].length;a.index+=i,a[0]=a[0].slice(i)}return a}function ZM(e,t,n,r,a,i){for(var o in n)if(!(!n.hasOwnProperty(o)||!n[o])){var l=n[o];l=Array.isArray(l)?l:[l];for(var u=0;u<l.length;++u){if(i&&i.cause==o+","+u)return;var d=l[u],h=d.inside,f=!!d.lookbehind,m=!!d.greedy,b=d.alias;if(m&&!d.pattern.global){var y=d.pattern.toString().match(/[imsuy]*$/)[0];d.pattern=RegExp(d.pattern.source,y+"g")}for(var v=d.pattern||d,w=r.next,S=a;w!==t.tail&&!(i&&S>=i.reach);S+=w.value.length,w=w.next){var k=w.value;if(t.length>e.length)return;if(!(k instanceof dh)){var R=1,I;if(m){if(I=t7(v,S,e,f),!I||I.index>=e.length)break;var P=I.index,L=I.index+I[0].length,A=S;for(A+=w.value.length;P>=A;)w=w.next,A+=w.value.length;if(A-=w.value.length,S=A,w.value instanceof dh)continue;for(var M=w;M!==t.tail&&(A<L||typeof M.value=="string");M=M.next)R++,A+=M.value.length;R--,k=e.slice(S,A),I.index-=S}else if(I=t7(v,0,k,f),!I)continue;var P=I.index,G=I[0],B=k.slice(0,P),H=k.slice(P+G.length),Z=S+k.length;i&&Z>i.reach&&(i.reach=Z);var V=w.prev;B&&(V=D0(t,V,B),S+=B.length),Gle(t,V,R);var q=new dh(o,h?Jn.tokenize(G,h):G,b,G);if(w=D0(t,V,q),H&&D0(t,w,H),R>1){var X={cause:o+","+u,reach:Z};ZM(e,t,n,w.prev,S,X),i&&X.reach>i.reach&&(i.reach=X.reach)}}}}}}function Hle(){var e={value:null,prev:null,next:null},t={value:null,prev:e,next:null};e.next=t,this.head=e,this.tail=t,this.length=0}function D0(e,t,n){var r=t.next,a={value:n,prev:t,next:r};return t.next=a,r.prev=a,e.length++,a}function Gle(e,t,n){for(var r=t.next,a=0;a<n&&r!==e.tail;a++)r=r.next;t.next=r,r.prev=t,e.length-=a}function qle(e){for(var t=[],n=e.head.next;n!==e.tail;)t.push(n.value),n=n.next;return t}const QM=Jn;function JM(){}JM.prototype=QM;const K=new JM;K.highlight=Wle;K.register=Vle;K.alias=Yle;K.registered=Xle;K.listLanguages=Kle;K.util.encode=Zle;K.Token.stringify=Ux;function Wle(e,t){if(typeof e!="string")throw new TypeError("Expected `string` for `value`, got `"+e+"`");let n,r;if(t&&typeof t=="object")n=t;else{if(r=t,typeof r!="string")throw new TypeError("Expected `string` for `name`, got `"+r+"`");if(Object.hasOwn(K.languages,r))n=K.languages[r];else throw new Error("Unknown language: `"+r+"` is not registered")}return{type:"root",children:QM.highlight.call(K,e,n,r)}}function Vle(e){if(typeof e!="function"||!e.displayName)throw new Error("Expected `function` for `syntax`, got `"+e+"`");Object.hasOwn(K.languages,e.displayName)||e(K)}function Yle(e,t){const n=K.languages;let r={};typeof e=="string"?t&&(r[e]=t):r=e;let a;for(a in r)if(Object.hasOwn(r,a)){const i=r[a],o=typeof i=="string"?[i]:i;let l=-1;for(;++l<o.length;)n[o[l]]=n[a]}}function Xle(e){if(typeof e!="string")throw new TypeError("Expected `string` for `aliasOrLanguage`, got `"+e+"`");return Object.hasOwn(K.languages,e)}function Kle(){const e=K.languages,t=[];let n;for(n in e)Object.hasOwn(e,n)&&typeof e[n]=="object"&&t.push(n);return t}function Ux(e,t){if(typeof e=="string")return{type:"text",value:e};if(Array.isArray(e)){const r=[];let a=-1;for(;++a<e.length;)e[a]!==null&&e[a]!==void 0&&e[a]!==""&&r.push(Ux(e[a],t));return r}const n={attributes:{},classes:["token",e.type],content:Ux(e.content,t),language:t,tag:"span",type:e.type};return e.alias&&n.classes.push(...typeof e.alias=="string"?[e.alias]:e.alias),K.hooks.run("wrap",n),dD(n.tag+"."+n.classes.join("."),Qle(n.attributes),n.content)}function Zle(e){return e}function Qle(e){let t;for(t in e)Object.hasOwn(e,t)&&(e[t]=$le(e[t]));return e}const Jle={'code[class*="language-"]':{color:"black",background:"none",textShadow:"0 1px white",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"black",background:"#f5f2f0",textShadow:"0 1px white",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto"},'pre[class*="language-"]::-moz-selection':{textShadow:"none",background:"#b3d4fc"},'pre[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#b3d4fc"},'code[class*="language-"]::-moz-selection':{textShadow:"none",background:"#b3d4fc"},'code[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#b3d4fc"},'pre[class*="language-"]::selection':{textShadow:"none",background:"#b3d4fc"},'pre[class*="language-"] ::selection':{textShadow:"none",background:"#b3d4fc"},'code[class*="language-"]::selection':{textShadow:"none",background:"#b3d4fc"},'code[class*="language-"] ::selection':{textShadow:"none",background:"#b3d4fc"},':not(pre) > code[class*="language-"]':{background:"#f5f2f0",padding:".1em",borderRadius:".3em",whiteSpace:"normal"},comment:{color:"slategray"},prolog:{color:"slategray"},doctype:{color:"slategray"},cdata:{color:"slategray"},punctuation:{color:"#999"},namespace:{Opacity:".7"},property:{color:"#905"},tag:{color:"#905"},boolean:{color:"#905"},number:{color:"#905"},constant:{color:"#905"},symbol:{color:"#905"},deleted:{color:"#905"},selector:{color:"#690"},"attr-name":{color:"#690"},string:{color:"#690"},char:{color:"#690"},builtin:{color:"#690"},inserted:{color:"#690"},operator:{color:"#9a6e3a",background:"hsla(0, 0%, 100%, .5)"},entity:{color:"#9a6e3a",background:"hsla(0, 0%, 100%, .5)",cursor:"help"},url:{color:"#9a6e3a",background:"hsla(0, 0%, 100%, .5)"},".language-css .token.string":{color:"#9a6e3a",background:"hsla(0, 0%, 100%, .5)"},".style .token.string":{color:"#9a6e3a",background:"hsla(0, 0%, 100%, .5)"},atrule:{color:"#07a"},"attr-value":{color:"#07a"},keyword:{color:"#07a"},function:{color:"#DD4A68"},"class-name":{color:"#DD4A68"},regex:{color:"#e90"},important:{color:"#e90",fontWeight:"bold"},variable:{color:"#e90"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"}};cr.displayName="markup";cr.aliases=["atom","html","mathml","rss","ssml","svg","xml"];function cr(e){e.languages.markup={comment:{pattern:/<!--(?:(?!<!--)[\s\S])*?-->/,greedy:!0},prolog:{pattern:/<\?[\s\S]+?\?>/,greedy:!0},doctype:{pattern:/<!DOCTYPE(?:[^>"'[\]]|"[^"]*"|'[^']*')+(?:\[(?:[^<"'\]]|"[^"]*"|'[^']*'|<(?!!--)|<!--(?:[^-]|-(?!->))*-->)*\]\s*)?>/i,greedy:!0,inside:{"internal-subset":{pattern:/(^[^\[]*\[)[\s\S]+(?=\]>$)/,lookbehind:!0,greedy:!0,inside:null},string:{pattern:/"[^"]*"|'[^']*'/,greedy:!0},punctuation:/^<!|>$|[[\]]/,"doctype-tag":/^DOCTYPE/i,name:/[^\s<>'"]+/}},cdata:{pattern:/<!\[CDATA\[[\s\S]*?\]\]>/i,greedy:!0},tag:{pattern:/<\/?(?!\d)[^\s>\/=$<%]+(?:\s(?:\s*[^\s>\/=]+(?:\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+(?=[\s>]))|(?=[\s/>])))+)?\s*\/?>/,greedy:!0,inside:{tag:{pattern:/^<\/?[^\s>\/]+/,inside:{punctuation:/^<\/?/,namespace:/^[^\s>\/:]+:/}},"special-attr":[],"attr-value":{pattern:/=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+)/,inside:{punctuation:[{pattern:/^=/,alias:"attr-equals"},{pattern:/^(\s*)["']|["']$/,lookbehind:!0}]}},punctuation:/\/?>/,"attr-name":{pattern:/[^\s>\/]+/,inside:{namespace:/^[^\s>\/:]+:/}}}},entity:[{pattern:/&[\da-z]{1,8};/i,alias:"named-entity"},/&#x?[\da-f]{1,8};/i]},e.languages.markup.tag.inside["attr-value"].inside.entity=e.languages.markup.entity,e.languages.markup.doctype.inside["internal-subset"].inside=e.languages.markup,e.hooks.add("wrap",function(t){t.type==="entity"&&(t.attributes.title=t.content.value.replace(/&amp;/,"&"))}),Object.defineProperty(e.languages.markup.tag,"addInlined",{value:function(n,r){var a={};a["language-"+r]={pattern:/(^<!\[CDATA\[)[\s\S]+?(?=\]\]>$)/i,lookbehind:!0,inside:e.languages[r]},a.cdata=/^<!\[CDATA\[|\]\]>$/i;var i={"included-cdata":{pattern:/<!\[CDATA\[[\s\S]*?\]\]>/i,inside:a}};i["language-"+r]={pattern:/[\s\S]+/,inside:e.languages[r]};var o={};o[n]={pattern:RegExp(/(<__[^>]*>)(?:<!\[CDATA\[(?:[^\]]|\](?!\]>))*\]\]>|(?!<!\[CDATA\[)[\s\S])*?(?=<\/__>)/.source.replace(/__/g,function(){return n}),"i"),lookbehind:!0,greedy:!0,inside:i},e.languages.insertBefore("markup","cdata",o)}}),Object.defineProperty(e.languages.markup.tag,"addAttribute",{value:function(t,n){e.languages.markup.tag.inside["special-attr"].push({pattern:RegExp(/(^|["'\s])/.source+"(?:"+t+")"+/\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+(?=[\s>]))/.source,"i"),lookbehind:!0,inside:{"attr-name":/^[^\s=]+/,"attr-value":{pattern:/=[\s\S]+/,inside:{value:{pattern:/(^=\s*(["']|(?!["'])))\S[\s\S]*(?=\2$)/,lookbehind:!0,alias:[n,"language-"+n],inside:e.languages[n]},punctuation:[{pattern:/^=/,alias:"attr-equals"},/"|'/]}}}})}}),e.languages.html=e.languages.markup,e.languages.mathml=e.languages.markup,e.languages.svg=e.languages.markup,e.languages.xml=e.languages.extend("markup",{}),e.languages.ssml=e.languages.xml,e.languages.atom=e.languages.xml,e.languages.rss=e.languages.xml}Ll.displayName="css";Ll.aliases=[];function Ll(e){(function(t){var n=/(?:"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"|'(?:\\(?:\r\n|[\s\S])|[^'\\\r\n])*')/;t.languages.css={comment:/\/\*[\s\S]*?\*\//,atrule:{pattern:RegExp("@[\\w-](?:"+/[^;{\s"']|\s+(?!\s)/.source+"|"+n.source+")*?"+/(?:;|(?=\s*\{))/.source),inside:{rule:/^@[\w-]+/,"selector-function-argument":{pattern:/(\bselector\s*\(\s*(?![\s)]))(?:[^()\s]|\s+(?![\s)])|\((?:[^()]|\([^()]*\))*\))+(?=\s*\))/,lookbehind:!0,alias:"selector"},keyword:{pattern:/(^|[^\w-])(?:and|not|only|or)(?![\w-])/,lookbehind:!0}}},url:{pattern:RegExp("\\burl\\((?:"+n.source+"|"+/(?:[^\\\r\n()"']|\\[\s\S])*/.source+")\\)","i"),greedy:!0,inside:{function:/^url/i,punctuation:/^\(|\)$/,string:{pattern:RegExp("^"+n.source+"$"),alias:"url"}}},selector:{pattern:RegExp(`(^|[{}\\s])[^{}\\s](?:[^{};"'\\s]|\\s+(?![\\s{])|`+n.source+")*(?=\\s*\\{)"),lookbehind:!0},string:{pattern:n,greedy:!0},property:{pattern:/(^|[^-\w\xA0-\uFFFF])(?!\s)[-_a-z\xA0-\uFFFF](?:(?!\s)[-\w\xA0-\uFFFF])*(?=\s*:)/i,lookbehind:!0},important:/!important\b/i,function:{pattern:/(^|[^-a-z0-9])[-a-z0-9]+(?=\()/i,lookbehind:!0},punctuation:/[(){};:,]/},t.languages.css.atrule.inside.rest=t.languages.css;var r=t.languages.markup;r&&(r.tag.addInlined("style","css"),r.tag.addAttribute("style","css"))})(e)}Mt.displayName="clike";Mt.aliases=[];function Mt(e){e.languages.clike={comment:[{pattern:/(^|[^\\])\/\*[\s\S]*?(?:\*\/|$)/,lookbehind:!0,greedy:!0},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0,greedy:!0}],string:{pattern:/(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,greedy:!0},"class-name":{pattern:/(\b(?:class|extends|implements|instanceof|interface|new|trait)\s+|\bcatch\s+\()[\w.\\]+/i,lookbehind:!0,inside:{punctuation:/[.\\]/}},keyword:/\b(?:break|catch|continue|do|else|finally|for|function|if|in|instanceof|new|null|return|throw|try|while)\b/,boolean:/\b(?:false|true)\b/,function:/\b\w+(?=\()/,number:/\b0x[\da-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?/i,operator:/[<>]=?|[!=]=?=?|--?|\+\+?|&&?|\|\|?|[?*/~^%]/,punctuation:/[{}[\];(),.:]/}}hw.displayName="regex";hw.aliases=[];function hw(e){(function(t){var n={pattern:/\\[\\(){}[\]^$+*?|.]/,alias:"escape"},r=/\\(?:x[\da-fA-F]{2}|u[\da-fA-F]{4}|u\{[\da-fA-F]+\}|0[0-7]{0,2}|[123][0-7]{2}|c[a-zA-Z]|.)/,a={pattern:/\.|\\[wsd]|\\p\{[^{}]+\}/i,alias:"class-name"},i={pattern:/\\[wsd]|\\p\{[^{}]+\}/i,alias:"class-name"},o="(?:[^\\\\-]|"+r.source+")",l=RegExp(o+"-"+o),u={pattern:/(<|')[^<>']+(?=[>']$)/,lookbehind:!0,alias:"variable"};t.languages.regex={"char-class":{pattern:/((?:^|[^\\])(?:\\\\)*)\[(?:[^\\\]]|\\[\s\S])*\]/,lookbehind:!0,inside:{"char-class-negation":{pattern:/(^\[)\^/,lookbehind:!0,alias:"operator"},"char-class-punctuation":{pattern:/^\[|\]$/,alias:"punctuation"},range:{pattern:l,inside:{escape:r,"range-punctuation":{pattern:/-/,alias:"operator"}}},"special-escape":n,"char-set":i,escape:r}},"special-escape":n,"char-set":a,backreference:[{pattern:/\\(?![123][0-7]{2})[1-9]/,alias:"keyword"},{pattern:/\\k<[^<>']+>/,alias:"keyword",inside:{"group-name":u}}],anchor:{pattern:/[$^]|\\[ABbGZz]/,alias:"function"},escape:r,group:[{pattern:/\((?:\?(?:<[^<>']+>|'[^<>']+'|[>:]|<?[=!]|[idmnsuxU]+(?:-[idmnsuxU]+)?:?))?/,alias:"punctuation",inside:{"group-name":u}},{pattern:/\)/,alias:"punctuation"}],quantifier:{pattern:/(?:[+*?]|\{\d+(?:,\d*)?\})[?+]?/,alias:"number"},alternation:{pattern:/\|/,alias:"keyword"}}})(e)}wr.displayName="javascript";wr.aliases=["js"];function wr(e){e.register(Mt),e.languages.javascript=e.languages.extend("clike",{"class-name":[e.languages.clike["class-name"],{pattern:/(^|[^$\w\xA0-\uFFFF])(?!\s)[_$A-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\.(?:constructor|prototype))/,lookbehind:!0}],keyword:[{pattern:/((?:^|\})\s*)catch\b/,lookbehind:!0},{pattern:/(^|[^.]|\.\.\.\s*)\b(?:as|assert(?=\s*\{)|async(?=\s*(?:function\b|\(|[$\w\xA0-\uFFFF]|$))|await|break|case|class|const|continue|debugger|default|delete|do|else|enum|export|extends|finally(?=\s*(?:\{|$))|for|from(?=\s*(?:['"]|$))|function|(?:get|set)(?=\s*(?:[#\[$\w\xA0-\uFFFF]|$))|if|implements|import|in|instanceof|interface|let|new|null|of|package|private|protected|public|return|static|super|switch|this|throw|try|typeof|undefined|var|void|while|with|yield)\b/,lookbehind:!0}],function:/#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*(?:\.\s*(?:apply|bind|call)\s*)?\()/,number:{pattern:RegExp(/(^|[^\w$])/.source+"(?:"+(/NaN|Infinity/.source+"|"+/0[bB][01]+(?:_[01]+)*n?/.source+"|"+/0[oO][0-7]+(?:_[0-7]+)*n?/.source+"|"+/0[xX][\dA-Fa-f]+(?:_[\dA-Fa-f]+)*n?/.source+"|"+/\d+(?:_\d+)*n/.source+"|"+/(?:\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\.\d+(?:_\d+)*)(?:[Ee][+-]?\d+(?:_\d+)*)?/.source)+")"+/(?![\w$])/.source),lookbehind:!0},operator:/--|\+\+|\*\*=?|=>|&&=?|\|\|=?|[!=]==|<<=?|>>>?=?|[-+*/%&|^!=<>]=?|\.{3}|\?\?=?|\?\.?|[~:]/}),e.languages.javascript["class-name"][0].pattern=/(\b(?:class|extends|implements|instanceof|interface|new)\s+)[\w.\\]+/,e.languages.insertBefore("javascript","keyword",{regex:{pattern:RegExp(/((?:^|[^$\w\xA0-\uFFFF."'\])\s]|\b(?:return|yield))\s*)/.source+/\//.source+"(?:"+/(?:\[(?:[^\]\\\r\n]|\\.)*\]|\\.|[^/\\\[\r\n])+\/[dgimyus]{0,7}/.source+"|"+/(?:\[(?:[^[\]\\\r\n]|\\.|\[(?:[^[\]\\\r\n]|\\.|\[(?:[^[\]\\\r\n]|\\.)*\])*\])*\]|\\.|[^/\\\[\r\n])+\/[dgimyus]{0,7}v[dgimyus]{0,7}/.source+")"+/(?=(?:\s|\/\*(?:[^*]|\*(?!\/))*\*\/)*(?:$|[\r\n,.;:})\]]|\/\/))/.source),lookbehind:!0,greedy:!0,inside:{"regex-source":{pattern:/^(\/)[\s\S]+(?=\/[a-z]*$)/,lookbehind:!0,alias:"language-regex",inside:e.languages.regex},"regex-delimiter":/^\/|\/$/,"regex-flags":/^[a-z]+$/}},"function-variable":{pattern:/#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*[=:]\s*(?:async\s*)?(?:\bfunction\b|(?:\((?:[^()]|\([^()]*\))*\)|(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)\s*=>))/,alias:"function"},parameter:[{pattern:/(function(?:\s+(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)?\s*\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\))/,lookbehind:!0,inside:e.languages.javascript},{pattern:/(^|[^$\w\xA0-\uFFFF])(?!\s)[_$a-z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*=>)/i,lookbehind:!0,inside:e.languages.javascript},{pattern:/(\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\)\s*=>)/,lookbehind:!0,inside:e.languages.javascript},{pattern:/((?:\b|\s|^)(?!(?:as|async|await|break|case|catch|class|const|continue|debugger|default|delete|do|else|enum|export|extends|finally|for|from|function|get|if|implements|import|in|instanceof|interface|let|new|null|of|package|private|protected|public|return|set|static|super|switch|this|throw|try|typeof|undefined|var|void|while|with|yield)(?![$\w\xA0-\uFFFF]))(?:(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*\s*)\(\s*|\]\s*\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\)\s*\{)/,lookbehind:!0,inside:e.languages.javascript}],constant:/\b[A-Z](?:[A-Z_]|\dx?)*\b/}),e.languages.insertBefore("javascript","string",{hashbang:{pattern:/^#!.*/,greedy:!0,alias:"comment"},"template-string":{pattern:/`(?:\\[\s\S]|\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}|(?!\$\{)[^\\`])*`/,greedy:!0,inside:{"template-punctuation":{pattern:/^`|`$/,alias:"string"},interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}/,lookbehind:!0,inside:{"interpolation-punctuation":{pattern:/^\$\{|\}$/,alias:"punctuation"},rest:e.languages.javascript}},string:/[\s\S]+/}},"string-property":{pattern:/((?:^|[,{])[ \t]*)(["'])(?:\\(?:\r\n|[\s\S])|(?!\2)[^\\\r\n])*\2(?=\s*:)/m,lookbehind:!0,greedy:!0,alias:"property"}}),e.languages.insertBefore("javascript","operator",{"literal-property":{pattern:/((?:^|[,{])[ \t]*)(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*:)/m,lookbehind:!0,alias:"property"}}),e.languages.markup&&(e.languages.markup.tag.addInlined("script","javascript"),e.languages.markup.tag.addAttribute(/on(?:abort|blur|change|click|composition(?:end|start|update)|dblclick|error|focus(?:in|out)?|key(?:down|up)|load|mouse(?:down|enter|leave|move|out|over|up)|reset|resize|scroll|select|slotchange|submit|unload|wheel)/.source,"javascript")),e.languages.js=e.languages.javascript}pw.displayName="abap";pw.aliases=[];function pw(e){e.languages.abap={comment:/^\*.*/m,string:/(`|')(?:\\.|(?!\1)[^\\\r\n])*\1/,"string-template":{pattern:/([|}])(?:\\.|[^\\|{\r\n])*(?=[|{])/,lookbehind:!0,alias:"string"},"eol-comment":{pattern:/(^|\s)".*/m,lookbehind:!0,alias:"comment"},keyword:{pattern:/(\s|\.|^)(?:\*-INPUT|\?TO|ABAP-SOURCE|ABBREVIATED|ABS|ABSTRACT|ACCEPT|ACCEPTING|ACCESSPOLICY|ACCORDING|ACOS|ACTIVATION|ACTUAL|ADD|ADD-CORRESPONDING|ADJACENT|AFTER|ALIAS|ALIASES|ALIGN|ALL|ALLOCATE|ALPHA|ANALYSIS|ANALYZER|AND|ANY|APPEND|APPENDAGE|APPENDING|APPLICATION|ARCHIVE|AREA|ARITHMETIC|AS|ASCENDING|ASIN|ASPECT|ASSERT|ASSIGN|ASSIGNED|ASSIGNING|ASSOCIATION|ASYNCHRONOUS|AT|ATAN|ATTRIBUTES|AUTHORITY|AUTHORITY-CHECK|AVG|BACK|BACKGROUND|BACKUP|BACKWARD|BADI|BASE|BEFORE|BEGIN|BETWEEN|BIG|BINARY|BINDING|BIT|BIT-AND|BIT-NOT|BIT-OR|BIT-XOR|BLACK|BLANK|BLANKS|BLOB|BLOCK|BLOCKS|BLUE|BOUND|BOUNDARIES|BOUNDS|BOXED|BREAK-POINT|BT|BUFFER|BY|BYPASSING|BYTE|BYTE-CA|BYTE-CN|BYTE-CO|BYTE-CS|BYTE-NA|BYTE-NS|BYTE-ORDER|C|CA|CALL|CALLING|CASE|CAST|CASTING|CATCH|CEIL|CENTER|CENTERED|CHAIN|CHAIN-INPUT|CHAIN-REQUEST|CHANGE|CHANGING|CHANNELS|CHAR-TO-HEX|CHARACTER|CHARLEN|CHECK|CHECKBOX|CIRCULAR|CI_|CLASS|CLASS-CODING|CLASS-DATA|CLASS-EVENTS|CLASS-METHODS|CLASS-POOL|CLEANUP|CLEAR|CLIENT|CLOB|CLOCK|CLOSE|CN|CNT|CO|COALESCE|CODE|CODING|COLLECT|COLOR|COLUMN|COLUMNS|COL_BACKGROUND|COL_GROUP|COL_HEADING|COL_KEY|COL_NEGATIVE|COL_NORMAL|COL_POSITIVE|COL_TOTAL|COMMENT|COMMENTS|COMMIT|COMMON|COMMUNICATION|COMPARING|COMPONENT|COMPONENTS|COMPRESSION|COMPUTE|CONCAT|CONCATENATE|COND|CONDENSE|CONDITION|CONNECT|CONNECTION|CONSTANTS|CONTEXT|CONTEXTS|CONTINUE|CONTROL|CONTROLS|CONV|CONVERSION|CONVERT|COPIES|COPY|CORRESPONDING|COS|COSH|COUNT|COUNTRY|COVER|CP|CPI|CREATE|CREATING|CRITICAL|CS|CURRENCY|CURRENCY_CONVERSION|CURRENT|CURSOR|CURSOR-SELECTION|CUSTOMER|CUSTOMER-FUNCTION|DANGEROUS|DATA|DATABASE|DATAINFO|DATASET|DATE|DAYLIGHT|DBMAXLEN|DD\/MM\/YY|DD\/MM\/YYYY|DDMMYY|DEALLOCATE|DECIMALS|DECIMAL_SHIFT|DECLARATIONS|DEEP|DEFAULT|DEFERRED|DEFINE|DEFINING|DEFINITION|DELETE|DELETING|DEMAND|DEPARTMENT|DESCENDING|DESCRIBE|DESTINATION|DETAIL|DIALOG|DIRECTORY|DISCONNECT|DISPLAY|DISPLAY-MODE|DISTANCE|DISTINCT|DIV|DIVIDE|DIVIDE-CORRESPONDING|DIVISION|DO|DUMMY|DUPLICATE|DUPLICATES|DURATION|DURING|DYNAMIC|DYNPRO|E|EACH|EDIT|EDITOR-CALL|ELSE|ELSEIF|EMPTY|ENABLED|ENABLING|ENCODING|END|END-ENHANCEMENT-SECTION|END-LINES|END-OF-DEFINITION|END-OF-FILE|END-OF-PAGE|END-OF-SELECTION|ENDAT|ENDCASE|ENDCATCH|ENDCHAIN|ENDCLASS|ENDDO|ENDENHANCEMENT|ENDEXEC|ENDFOR|ENDFORM|ENDFUNCTION|ENDIAN|ENDIF|ENDING|ENDINTERFACE|ENDLOOP|ENDMETHOD|ENDMODULE|ENDON|ENDPROVIDE|ENDSELECT|ENDTRY|ENDWHILE|ENGINEERING|ENHANCEMENT|ENHANCEMENT-POINT|ENHANCEMENT-SECTION|ENHANCEMENTS|ENTRIES|ENTRY|ENVIRONMENT|EQ|EQUAL|EQUIV|ERRORMESSAGE|ERRORS|ESCAPE|ESCAPING|EVENT|EVENTS|EXACT|EXCEPT|EXCEPTION|EXCEPTION-TABLE|EXCEPTIONS|EXCLUDE|EXCLUDING|EXEC|EXECUTE|EXISTS|EXIT|EXIT-COMMAND|EXP|EXPAND|EXPANDING|EXPIRATION|EXPLICIT|EXPONENT|EXPORT|EXPORTING|EXTEND|EXTENDED|EXTENSION|EXTRACT|FAIL|FETCH|FIELD|FIELD-GROUPS|FIELD-SYMBOL|FIELD-SYMBOLS|FIELDS|FILE|FILTER|FILTER-TABLE|FILTERS|FINAL|FIND|FIRST|FIRST-LINE|FIXED-POINT|FKEQ|FKGE|FLOOR|FLUSH|FONT|FOR|FORM|FORMAT|FORWARD|FOUND|FRAC|FRAME|FRAMES|FREE|FRIENDS|FROM|FUNCTION|FUNCTION-POOL|FUNCTIONALITY|FURTHER|GAPS|GE|GENERATE|GET|GIVING|GKEQ|GKGE|GLOBAL|GRANT|GREATER|GREEN|GROUP|GROUPS|GT|HANDLE|HANDLER|HARMLESS|HASHED|HAVING|HDB|HEAD-LINES|HEADER|HEADERS|HEADING|HELP-ID|HELP-REQUEST|HIDE|HIGH|HINT|HOLD|HOTSPOT|I|ICON|ID|IDENTIFICATION|IDENTIFIER|IDS|IF|IGNORE|IGNORING|IMMEDIATELY|IMPLEMENTATION|IMPLEMENTATIONS|IMPLEMENTED|IMPLICIT|IMPORT|IMPORTING|IN|INACTIVE|INCL|INCLUDE|INCLUDES|INCLUDING|INCREMENT|INDEX|INDEX-LINE|INFOTYPES|INHERITING|INIT|INITIAL|INITIALIZATION|INNER|INOUT|INPUT|INSERT|INSTANCES|INTENSIFIED|INTERFACE|INTERFACE-POOL|INTERFACES|INTERNAL|INTERVALS|INTO|INVERSE|INVERTED-DATE|IS|ISO|ITERATOR|ITNO|JOB|JOIN|KEEP|KEEPING|KERNEL|KEY|KEYS|KEYWORDS|KIND|LANGUAGE|LAST|LATE|LAYOUT|LE|LEADING|LEAVE|LEFT|LEFT-JUSTIFIED|LEFTPLUS|LEFTSPACE|LEGACY|LENGTH|LESS|LET|LEVEL|LEVELS|LIKE|LINE|LINE-COUNT|LINE-SELECTION|LINE-SIZE|LINEFEED|LINES|LIST|LIST-PROCESSING|LISTBOX|LITTLE|LLANG|LOAD|LOAD-OF-PROGRAM|LOB|LOCAL|LOCALE|LOCATOR|LOG|LOG-POINT|LOG10|LOGFILE|LOGICAL|LONG|LOOP|LOW|LOWER|LPAD|LPI|LT|M|MAIL|MAIN|MAJOR-ID|MAPPING|MARGIN|MARK|MASK|MATCH|MATCHCODE|MAX|MAXIMUM|MEDIUM|MEMBERS|MEMORY|MESH|MESSAGE|MESSAGE-ID|MESSAGES|MESSAGING|METHOD|METHODS|MIN|MINIMUM|MINOR-ID|MM\/DD\/YY|MM\/DD\/YYYY|MMDDYY|MOD|MODE|MODIF|MODIFIER|MODIFY|MODULE|MOVE|MOVE-CORRESPONDING|MULTIPLY|MULTIPLY-CORRESPONDING|NA|NAME|NAMETAB|NATIVE|NB|NE|NESTED|NESTING|NEW|NEW-LINE|NEW-PAGE|NEW-SECTION|NEXT|NO|NO-DISPLAY|NO-EXTENSION|NO-GAP|NO-GAPS|NO-GROUPING|NO-HEADING|NO-SCROLLING|NO-SIGN|NO-TITLE|NO-TOPOFPAGE|NO-ZERO|NODE|NODES|NON-UNICODE|NON-UNIQUE|NOT|NP|NS|NULL|NUMBER|NUMOFCHAR|O|OBJECT|OBJECTS|OBLIGATORY|OCCURRENCE|OCCURRENCES|OCCURS|OF|OFF|OFFSET|OLE|ON|ONLY|OPEN|OPTION|OPTIONAL|OPTIONS|OR|ORDER|OTHER|OTHERS|OUT|OUTER|OUTPUT|OUTPUT-LENGTH|OVERFLOW|OVERLAY|PACK|PACKAGE|PAD|PADDING|PAGE|PAGES|PARAMETER|PARAMETER-TABLE|PARAMETERS|PART|PARTIALLY|PATTERN|PERCENTAGE|PERFORM|PERFORMING|PERSON|PF|PF-STATUS|PINK|PLACES|POOL|POSITION|POS_HIGH|POS_LOW|PRAGMAS|PRECOMPILED|PREFERRED|PRESERVING|PRIMARY|PRINT|PRINT-CONTROL|PRIORITY|PRIVATE|PROCEDURE|PROCESS|PROGRAM|PROPERTY|PROTECTED|PROVIDE|PUBLIC|PUSHBUTTON|PUT|QUEUE-ONLY|QUICKINFO|RADIOBUTTON|RAISE|RAISING|RANGE|RANGES|RAW|READ|READ-ONLY|READER|RECEIVE|RECEIVED|RECEIVER|RECEIVING|RED|REDEFINITION|REDUCE|REDUCED|REF|REFERENCE|REFRESH|REGEX|REJECT|REMOTE|RENAMING|REPLACE|REPLACEMENT|REPLACING|REPORT|REQUEST|REQUESTED|RESERVE|RESET|RESOLUTION|RESPECTING|RESPONSIBLE|RESULT|RESULTS|RESUMABLE|RESUME|RETRY|RETURN|RETURNCODE|RETURNING|RIGHT|RIGHT-JUSTIFIED|RIGHTPLUS|RIGHTSPACE|RISK|RMC_COMMUNICATION_FAILURE|RMC_INVALID_STATUS|RMC_SYSTEM_FAILURE|ROLE|ROLLBACK|ROUND|ROWS|RTTI|RUN|SAP|SAP-SPOOL|SAVING|SCALE_PRESERVING|SCALE_PRESERVING_SCIENTIFIC|SCAN|SCIENTIFIC|SCIENTIFIC_WITH_LEADING_ZERO|SCREEN|SCROLL|SCROLL-BOUNDARY|SCROLLING|SEARCH|SECONDARY|SECONDS|SECTION|SELECT|SELECT-OPTIONS|SELECTION|SELECTION-SCREEN|SELECTION-SET|SELECTION-SETS|SELECTION-TABLE|SELECTIONS|SELECTOR|SEND|SEPARATE|SEPARATED|SET|SHARED|SHIFT|SHORT|SHORTDUMP-ID|SIGN|SIGN_AS_POSTFIX|SIMPLE|SIN|SINGLE|SINH|SIZE|SKIP|SKIPPING|SMART|SOME|SORT|SORTABLE|SORTED|SOURCE|SPACE|SPECIFIED|SPLIT|SPOOL|SPOTS|SQL|SQLSCRIPT|SQRT|STABLE|STAMP|STANDARD|START-OF-SELECTION|STARTING|STATE|STATEMENT|STATEMENTS|STATIC|STATICS|STATUSINFO|STEP-LOOP|STOP|STRLEN|STRUCTURE|STRUCTURES|STYLE|SUBKEY|SUBMATCHES|SUBMIT|SUBROUTINE|SUBSCREEN|SUBSTRING|SUBTRACT|SUBTRACT-CORRESPONDING|SUFFIX|SUM|SUMMARY|SUMMING|SUPPLIED|SUPPLY|SUPPRESS|SWITCH|SWITCHSTATES|SYMBOL|SYNCPOINTS|SYNTAX|SYNTAX-CHECK|SYNTAX-TRACE|SYSTEM-CALL|SYSTEM-EXCEPTIONS|SYSTEM-EXIT|TAB|TABBED|TABLE|TABLES|TABLEVIEW|TABSTRIP|TAN|TANH|TARGET|TASK|TASKS|TEST|TESTING|TEXT|TEXTPOOL|THEN|THROW|TIME|TIMES|TIMESTAMP|TIMEZONE|TITLE|TITLE-LINES|TITLEBAR|TO|TOKENIZATION|TOKENS|TOP-LINES|TOP-OF-PAGE|TRACE-FILE|TRACE-TABLE|TRAILING|TRANSACTION|TRANSFER|TRANSFORMATION|TRANSLATE|TRANSPORTING|TRMAC|TRUNC|TRUNCATE|TRUNCATION|TRY|TYPE|TYPE-POOL|TYPE-POOLS|TYPES|ULINE|UNASSIGN|UNDER|UNICODE|UNION|UNIQUE|UNIT|UNIT_CONVERSION|UNIX|UNPACK|UNTIL|UNWIND|UP|UPDATE|UPPER|USER|USER-COMMAND|USING|UTF-8|VALID|VALUE|VALUE-REQUEST|VALUES|VARY|VARYING|VERIFICATION-MESSAGE|VERSION|VIA|VIEW|VISIBLE|WAIT|WARNING|WHEN|WHENEVER|WHERE|WHILE|WIDTH|WINDOW|WINDOWS|WITH|WITH-HEADING|WITH-TITLE|WITHOUT|WORD|WORK|WRITE|WRITER|X|XML|XOR|XSD|XSTRLEN|YELLOW|YES|YYMMDD|Z|ZERO|ZONE)(?![\w-])/i,lookbehind:!0},number:/\b\d+\b/,operator:{pattern:/(\s)(?:\*\*?|<[=>]?|>=?|\?=|[-+\/=])(?=\s)/,lookbehind:!0},"string-operator":{pattern:/(\s)&&?(?=\s)/,lookbehind:!0,alias:"keyword"},"token-operator":[{pattern:/(\w)(?:->?|=>|[~|{}])(?=\w)/,lookbehind:!0,alias:"punctuation"},{pattern:/[|{}]/,alias:"punctuation"}],punctuation:/[,.:()]/}}fw.displayName="abnf";fw.aliases=[];function fw(e){(function(t){var n="(?:ALPHA|BIT|CHAR|CR|CRLF|CTL|DIGIT|DQUOTE|HEXDIG|HTAB|LF|LWSP|OCTET|SP|VCHAR|WSP)";t.languages.abnf={comment:/;.*/,string:{pattern:/(?:%[is])?"[^"\n\r]*"/,greedy:!0,inside:{punctuation:/^%[is]/}},range:{pattern:/%(?:b[01]+-[01]+|d\d+-\d+|x[A-F\d]+-[A-F\d]+)/i,alias:"number"},terminal:{pattern:/%(?:b[01]+(?:\.[01]+)*|d\d+(?:\.\d+)*|x[A-F\d]+(?:\.[A-F\d]+)*)/i,alias:"number"},repetition:{pattern:/(^|[^\w-])(?:\d*\*\d*|\d+)/,lookbehind:!0,alias:"operator"},definition:{pattern:/(^[ \t]*)(?:[a-z][\w-]*|<[^<>\r\n]*>)(?=\s*=)/m,lookbehind:!0,alias:"keyword",inside:{punctuation:/<|>/}},"core-rule":{pattern:RegExp("(?:(^|[^<\\w-])"+n+"|<"+n+">)(?![\\w-])","i"),lookbehind:!0,alias:["rule","constant"],inside:{punctuation:/<|>/}},rule:{pattern:/(^|[^<\w-])[a-z][\w-]*|<[^<>\r\n]*>/i,lookbehind:!0,inside:{punctuation:/<|>/}},operator:/=\/?|\//,punctuation:/[()\[\]]/}})(e)}mw.displayName="actionscript";mw.aliases=[];function mw(e){e.register(wr),e.languages.actionscript=e.languages.extend("javascript",{keyword:/\b(?:as|break|case|catch|class|const|default|delete|do|dynamic|each|else|extends|final|finally|for|function|get|if|implements|import|in|include|instanceof|interface|internal|is|namespace|native|new|null|override|package|private|protected|public|return|set|static|super|switch|this|throw|try|typeof|use|var|void|while|with)\b/,operator:/\+\+|--|(?:[+\-*\/%^]|&&?|\|\|?|<<?|>>?>?|[!=]=?)=?|[~?@]/}),e.languages.actionscript["class-name"].alias="function",delete e.languages.actionscript.parameter,delete e.languages.actionscript["literal-property"],e.languages.markup&&e.languages.insertBefore("actionscript","string",{xml:{pattern:/(^|[^.])<\/?\w+(?:\s+[^\s>\/=]+=("|')(?:\\[\s\S]|(?!\2)[^\\])*\2)*\s*\/?>/,lookbehind:!0,inside:e.languages.markup}})}gw.displayName="ada";gw.aliases=[];function gw(e){e.languages.ada={comment:/--.*/,string:/"(?:""|[^"\r\f\n])*"/,number:[{pattern:/\b\d(?:_?\d)*#[\dA-F](?:_?[\dA-F])*(?:\.[\dA-F](?:_?[\dA-F])*)?#(?:E[+-]?\d(?:_?\d)*)?/i},{pattern:/\b\d(?:_?\d)*(?:\.\d(?:_?\d)*)?(?:E[+-]?\d(?:_?\d)*)?\b/i}],attribute:{pattern:/\b'\w+/,alias:"attr-name"},keyword:/\b(?:abort|abs|abstract|accept|access|aliased|all|and|array|at|begin|body|case|constant|declare|delay|delta|digits|do|else|elsif|end|entry|exception|exit|for|function|generic|goto|if|in|interface|is|limited|loop|mod|new|not|null|of|or|others|out|overriding|package|pragma|private|procedure|protected|raise|range|record|rem|renames|requeue|return|reverse|select|separate|some|subtype|synchronized|tagged|task|terminate|then|type|until|use|when|while|with|xor)\b/i,boolean:/\b(?:false|true)\b/i,operator:/<[=>]?|>=?|=>?|:=|\/=?|\*\*?|[&+-]/,punctuation:/\.\.?|[,;():]/,char:/'.'/,variable:/\b[a-z](?:\w)*\b/i}}bw.displayName="agda";bw.aliases=[];function bw(e){(function(t){t.languages.agda={comment:/\{-[\s\S]*?(?:-\}|$)|--.*/,string:{pattern:/"(?:\\(?:\r\n|[\s\S])|[^\\\r\n"])*"/,greedy:!0},punctuation:/[(){}⦃⦄.;@]/,"class-name":{pattern:/((?:data|record) +)\S+/,lookbehind:!0},function:{pattern:/(^[ \t]*)(?!\s)[^:\r\n]+(?=:)/m,lookbehind:!0},operator:{pattern:/(^\s*|\s)(?:[=|:∀→λ\\?_]|->)(?=\s)/,lookbehind:!0},keyword:/\b(?:Set|abstract|constructor|data|eta-equality|field|forall|hiding|import|in|inductive|infix|infixl|infixr|instance|let|macro|module|mutual|no-eta-equality|open|overlap|pattern|postulate|primitive|private|public|quote|quoteContext|quoteGoal|quoteTerm|record|renaming|rewrite|syntax|tactic|unquote|unquoteDecl|unquoteDef|using|variable|where|with)\b/}})(e)}yw.displayName="al";yw.aliases=[];function yw(e){e.languages.al={comment:/\/\/.*|\/\*[\s\S]*?\*\//,string:{pattern:/'(?:''|[^'\r\n])*'(?!')|"(?:""|[^"\r\n])*"(?!")/,greedy:!0},function:{pattern:/(\b(?:event|procedure|trigger)\s+|(?:^|[^.])\.\s*)[a-z_]\w*(?=\s*\()/i,lookbehind:!0},keyword:[/\b(?:array|asserterror|begin|break|case|do|downto|else|end|event|exit|for|foreach|function|if|implements|in|indataset|interface|internal|local|of|procedure|program|protected|repeat|runonclient|securityfiltering|suppressdispose|temporary|then|to|trigger|until|var|while|with|withevents)\b/i,/\b(?:action|actions|addafter|addbefore|addfirst|addlast|area|assembly|chartpart|codeunit|column|controladdin|cuegroup|customizes|dataitem|dataset|dotnet|elements|enum|enumextension|extends|field|fieldattribute|fieldelement|fieldgroup|fieldgroups|fields|filter|fixed|grid|group|key|keys|label|labels|layout|modify|moveafter|movebefore|movefirst|movelast|page|pagecustomization|pageextension|part|profile|query|repeater|report|requestpage|schema|separator|systempart|table|tableelement|tableextension|textattribute|textelement|type|usercontrol|value|xmlport)\b/i],number:/\b(?:0x[\da-f]+|(?:\d+(?:\.\d*)?|\.\d+)(?:e[+-]?\d+)?)(?:F|LL?|U(?:LL?)?)?\b/i,boolean:/\b(?:false|true)\b/i,variable:/\b(?:Curr(?:FieldNo|Page|Report)|x?Rec|RequestOptionsPage)\b/,"class-name":/\b(?:automation|biginteger|bigtext|blob|boolean|byte|char|clienttype|code|completiontriggererrorlevel|connectiontype|database|dataclassification|datascope|date|dateformula|datetime|decimal|defaultlayout|dialog|dictionary|dotnetassembly|dotnettypedeclaration|duration|errorinfo|errortype|executioncontext|executionmode|fieldclass|fieldref|fieldtype|file|filterpagebuilder|guid|httpclient|httpcontent|httpheaders|httprequestmessage|httpresponsemessage|instream|integer|joker|jsonarray|jsonobject|jsontoken|jsonvalue|keyref|list|moduledependencyinfo|moduleinfo|none|notification|notificationscope|objecttype|option|outstream|pageresult|record|recordid|recordref|reportformat|securityfilter|sessionsettings|tableconnectiontype|tablefilter|testaction|testfield|testfilterfield|testpage|testpermissions|testrequestpage|text|textbuilder|textconst|textencoding|time|transactionmodel|transactiontype|variant|verbosity|version|view|views|webserviceactioncontext|webserviceactionresultcode|xmlattribute|xmlattributecollection|xmlcdata|xmlcomment|xmldeclaration|xmldocument|xmldocumenttype|xmlelement|xmlnamespacemanager|xmlnametable|xmlnode|xmlnodelist|xmlprocessinginstruction|xmlreadoptions|xmltext|xmlwriteoptions)\b/i,operator:/\.\.|:[=:]|[-+*/]=?|<>|[<>]=?|=|\b(?:and|div|mod|not|or|xor)\b/i,punctuation:/[()\[\]{}:.;,]/}}vw.displayName="antlr4";vw.aliases=["g4"];function vw(e){e.languages.antlr4={comment:/\/\/.*|\/\*[\s\S]*?(?:\*\/|$)/,string:{pattern:/'(?:\\.|[^\\'\r\n])*'/,greedy:!0},"character-class":{pattern:/\[(?:\\.|[^\\\]\r\n])*\]/,greedy:!0,alias:"regex",inside:{range:{pattern:/([^[]|(?:^|[^\\])(?:\\\\)*\\\[)-(?!\])/,lookbehind:!0,alias:"punctuation"},escape:/\\(?:u(?:[a-fA-F\d]{4}|\{[a-fA-F\d]+\})|[pP]\{[=\w-]+\}|[^\r\nupP])/,punctuation:/[\[\]]/}},action:{pattern:/\{(?:[^{}]|\{(?:[^{}]|\{(?:[^{}]|\{[^{}]*\})*\})*\})*\}/,greedy:!0,inside:{content:{pattern:/(\{)[\s\S]+(?=\})/,lookbehind:!0},punctuation:/[{}]/}},command:{pattern:/(->\s*(?!\s))(?:\s*(?:,\s*)?\b[a-z]\w*(?:\s*\([^()\r\n]*\))?)+(?=\s*;)/i,lookbehind:!0,inside:{function:/\b\w+(?=\s*(?:[,(]|$))/,punctuation:/[,()]/}},annotation:{pattern:/@\w+(?:::\w+)*/,alias:"keyword"},label:{pattern:/#[ \t]*\w+/,alias:"punctuation"},keyword:/\b(?:catch|channels|finally|fragment|grammar|import|lexer|locals|mode|options|parser|returns|throws|tokens)\b/,definition:[{pattern:/\b[a-z]\w*(?=\s*:)/,alias:["rule","class-name"]},{pattern:/\b[A-Z]\w*(?=\s*:)/,alias:["token","constant"]}],constant:/\b[A-Z][A-Z_]*\b/,operator:/\.\.|->|[|~]|[*+?]\??/,punctuation:/[;:()=]/},e.languages.g4=e.languages.antlr4}xw.displayName="apacheconf";xw.aliases=[];function xw(e){e.languages.apacheconf={comment:/#.*/,"directive-inline":{pattern:/(^[\t ]*)\b(?:AcceptFilter|AcceptPathInfo|AccessFileName|Action|Add(?:Alt|AltByEncoding|AltByType|Charset|DefaultCharset|Description|Encoding|Handler|Icon|IconByEncoding|IconByType|InputFilter|Language|ModuleInfo|OutputFilter|OutputFilterByType|Type)|Alias|AliasMatch|Allow(?:CONNECT|EncodedSlashes|Methods|Override|OverrideList)?|Anonymous(?:_LogEmail|_MustGiveEmail|_NoUserID|_VerifyEmail)?|AsyncRequestWorkerFactor|Auth(?:BasicAuthoritative|BasicFake|BasicProvider|BasicUseDigestAlgorithm|DBDUserPWQuery|DBDUserRealmQuery|DBMGroupFile|DBMType|DBMUserFile|Digest(?:Algorithm|Domain|NonceLifetime|Provider|Qop|ShmemSize)|Form(?:Authoritative|Body|DisableNoStore|FakeBasicAuth|Location|LoginRequiredLocation|LoginSuccessLocation|LogoutLocation|Method|Mimetype|Password|Provider|SitePassphrase|Size|Username)|GroupFile|LDAP(?:AuthorizePrefix|BindAuthoritative|BindDN|BindPassword|CharsetConfig|CompareAsUser|CompareDNOnServer|DereferenceAliases|GroupAttribute|GroupAttributeIsDN|InitialBindAsUser|InitialBindPattern|MaxSubGroupDepth|RemoteUserAttribute|RemoteUserIsDN|SearchAsUser|SubGroupAttribute|SubGroupClass|Url)|Merging|Name|nCache(?:Context|Enable|ProvideFor|SOCache|Timeout)|nzFcgiCheckAuthnProvider|nzFcgiDefineProvider|Type|UserFile|zDBDLoginToReferer|zDBDQuery|zDBDRedirectQuery|zDBMType|zSendForbiddenOnFailure)|BalancerGrowth|BalancerInherit|BalancerMember|BalancerPersist|BrowserMatch|BrowserMatchNoCase|BufferedLogs|BufferSize|Cache(?:DefaultExpire|DetailHeader|DirLength|DirLevels|Disable|Enable|File|Header|IgnoreCacheControl|IgnoreHeaders|IgnoreNoLastMod|IgnoreQueryString|IgnoreURLSessionIdentifiers|KeyBaseURL|LastModifiedFactor|Lock|LockMaxAge|LockPath|MaxExpire|MaxFileSize|MinExpire|MinFileSize|NegotiatedDocs|QuickHandler|ReadSize|ReadTime|Root|Socache(?:MaxSize|MaxTime|MinTime|ReadSize|ReadTime)?|StaleOnError|StoreExpired|StoreNoStore|StorePrivate)|CGIDScriptTimeout|CGIMapExtension|CharsetDefault|CharsetOptions|CharsetSourceEnc|CheckCaseOnly|CheckSpelling|ChrootDir|ContentDigest|CookieDomain|CookieExpires|CookieName|CookieStyle|CookieTracking|CoreDumpDirectory|CustomLog|Dav|DavDepthInfinity|DavGenericLockDB|DavLockDB|DavMinTimeout|DBDExptime|DBDInitSQL|DBDKeep|DBDMax|DBDMin|DBDParams|DBDPersist|DBDPrepareSQL|DBDriver|DefaultIcon|DefaultLanguage|DefaultRuntimeDir|DefaultType|Define|Deflate(?:BufferSize|CompressionLevel|FilterNote|InflateLimitRequestBody|InflateRatio(?:Burst|Limit)|MemLevel|WindowSize)|Deny|DirectoryCheckHandler|DirectoryIndex|DirectoryIndexRedirect|DirectorySlash|DocumentRoot|DTracePrivileges|DumpIOInput|DumpIOOutput|EnableExceptionHook|EnableMMAP|EnableSendfile|Error|ErrorDocument|ErrorLog|ErrorLogFormat|Example|ExpiresActive|ExpiresByType|ExpiresDefault|ExtendedStatus|ExtFilterDefine|ExtFilterOptions|FallbackResource|FileETag|FilterChain|FilterDeclare|FilterProtocol|FilterProvider|FilterTrace|ForceLanguagePriority|ForceType|ForensicLog|GprofDir|GracefulShutdownTimeout|Group|Header|HeaderName|Heartbeat(?:Address|Listen|MaxServers|Storage)|HostnameLookups|IdentityCheck|IdentityCheckTimeout|ImapBase|ImapDefault|ImapMenu|Include|IncludeOptional|Index(?:HeadInsert|Ignore|IgnoreReset|Options|OrderDefault|StyleSheet)|InputSed|ISAPI(?:AppendLogToErrors|AppendLogToQuery|CacheFile|FakeAsync|LogNotSupported|ReadAheadBuffer)|KeepAlive|KeepAliveTimeout|KeptBodySize|LanguagePriority|LDAP(?:CacheEntries|CacheTTL|ConnectionPoolTTL|ConnectionTimeout|LibraryDebug|OpCacheEntries|OpCacheTTL|ReferralHopLimit|Referrals|Retries|RetryDelay|SharedCacheFile|SharedCacheSize|Timeout|TrustedClientCert|TrustedGlobalCert|TrustedMode|VerifyServerCert)|Limit(?:InternalRecursion|Request(?:Body|Fields|FieldSize|Line)|XMLRequestBody)|Listen|ListenBackLog|LoadFile|LoadModule|LogFormat|LogLevel|LogMessage|LuaAuthzProvider|LuaCodeCache|Lua(?:Hook(?:AccessChecker|AuthChecker|CheckUserID|Fixups|InsertFilter|Log|MapToStorage|TranslateName|TypeChecker)|Inherit|InputFilter|MapHandler|OutputFilter|PackageCPath|PackagePath|QuickHandler|Root|Scope)|Max(?:ConnectionsPerChild|KeepAliveRequests|MemFree|RangeOverlaps|RangeReversals|Ranges|RequestWorkers|SpareServers|SpareThreads|Threads)|MergeTrailers|MetaDir|MetaFiles|MetaSuffix|MimeMagicFile|MinSpareServers|MinSpareThreads|MMapFile|ModemStandard|ModMimeUsePathInfo|MultiviewsMatch|Mutex|NameVirtualHost|NoProxy|NWSSLTrustedCerts|NWSSLUpgradeable|Options|Order|OutputSed|PassEnv|PidFile|PrivilegesMode|Protocol|ProtocolEcho|Proxy(?:AddHeaders|BadHeader|Block|Domain|ErrorOverride|ExpressDBMFile|ExpressDBMType|ExpressEnable|FtpDirCharset|FtpEscapeWildcards|FtpListOnWildcard|HTML(?:BufSize|CharsetOut|DocType|Enable|Events|Extended|Fixups|Interp|Links|Meta|StripComments|URLMap)|IOBufferSize|MaxForwards|Pass(?:Inherit|InterpolateEnv|Match|Reverse|ReverseCookieDomain|ReverseCookiePath)?|PreserveHost|ReceiveBufferSize|Remote|RemoteMatch|Requests|SCGIInternalRedirect|SCGISendfile|Set|SourceAddress|Status|Timeout|Via)|ReadmeName|ReceiveBufferSize|Redirect|RedirectMatch|RedirectPermanent|RedirectTemp|ReflectorHeader|RemoteIP(?:Header|InternalProxy|InternalProxyList|ProxiesHeader|TrustedProxy|TrustedProxyList)|RemoveCharset|RemoveEncoding|RemoveHandler|RemoveInputFilter|RemoveLanguage|RemoveOutputFilter|RemoveType|RequestHeader|RequestReadTimeout|Require|Rewrite(?:Base|Cond|Engine|Map|Options|Rule)|RLimitCPU|RLimitMEM|RLimitNPROC|Satisfy|ScoreBoardFile|Script(?:Alias|AliasMatch|InterpreterSource|Log|LogBuffer|LogLength|Sock)?|SecureListen|SeeRequestTail|SendBufferSize|Server(?:Admin|Alias|Limit|Name|Path|Root|Signature|Tokens)|Session(?:Cookie(?:Name|Name2|Remove)|Crypto(?:Cipher|Driver|Passphrase|PassphraseFile)|DBD(?:CookieName|CookieName2|CookieRemove|DeleteLabel|InsertLabel|PerUser|SelectLabel|UpdateLabel)|Env|Exclude|Header|Include|MaxAge)?|SetEnv|SetEnvIf|SetEnvIfExpr|SetEnvIfNoCase|SetHandler|SetInputFilter|SetOutputFilter|SSIEndTag|SSIErrorMsg|SSIETag|SSILastModified|SSILegacyExprParser|SSIStartTag|SSITimeFormat|SSIUndefinedEcho|SSL(?:CACertificateFile|CACertificatePath|CADNRequestFile|CADNRequestPath|CARevocationCheck|CARevocationFile|CARevocationPath|CertificateChainFile|CertificateFile|CertificateKeyFile|CipherSuite|Compression|CryptoDevice|Engine|FIPS|HonorCipherOrder|InsecureRenegotiation|OCSP(?:DefaultResponder|Enable|OverrideResponder|ResponderTimeout|ResponseMaxAge|ResponseTimeSkew|UseRequestNonce)|OpenSSLConfCmd|Options|PassPhraseDialog|Protocol|Proxy(?:CACertificateFile|CACertificatePath|CARevocation(?:Check|File|Path)|CheckPeer(?:CN|Expire|Name)|CipherSuite|Engine|MachineCertificate(?:ChainFile|File|Path)|Protocol|Verify|VerifyDepth)|RandomSeed|RenegBufferSize|Require|RequireSSL|Session(?:Cache|CacheTimeout|TicketKeyFile|Tickets)|SRPUnknownUserSeed|SRPVerifierFile|Stapling(?:Cache|ErrorCacheTimeout|FakeTryLater|ForceURL|ResponderTimeout|ResponseMaxAge|ResponseTimeSkew|ReturnResponderErrors|StandardCacheTimeout)|StrictSNIVHostCheck|UserName|UseStapling|VerifyClient|VerifyDepth)|StartServers|StartThreads|Substitute|Suexec|SuexecUserGroup|ThreadLimit|ThreadsPerChild|ThreadStackSize|TimeOut|TraceEnable|TransferLog|TypesConfig|UnDefine|UndefMacro|UnsetEnv|Use|UseCanonicalName|UseCanonicalPhysicalPort|User|UserDir|VHostCGIMode|VHostCGIPrivs|VHostGroup|VHostPrivs|VHostSecure|VHostUser|Virtual(?:DocumentRoot|ScriptAlias)(?:IP)?|WatchdogInterval|XBitHack|xml2EncAlias|xml2EncDefault|xml2StartParse)\b/im,lookbehind:!0,alias:"property"},"directive-block":{pattern:/<\/?\b(?:Auth[nz]ProviderAlias|Directory|DirectoryMatch|Else|ElseIf|Files|FilesMatch|If|IfDefine|IfModule|IfVersion|Limit|LimitExcept|Location|LocationMatch|Macro|Proxy|Require(?:All|Any|None)|VirtualHost)\b.*>/i,inside:{"directive-block":{pattern:/^<\/?\w+/,inside:{punctuation:/^<\/?/},alias:"tag"},"directive-block-parameter":{pattern:/.*[^>]/,inside:{punctuation:/:/,string:{pattern:/("|').*\1/,inside:{variable:/[$%]\{?(?:\w\.?[-+:]?)+\}?/}}},alias:"attr-value"},punctuation:/>/},alias:"tag"},"directive-flags":{pattern:/\[(?:[\w=],?)+\]/,alias:"keyword"},string:{pattern:/("|').*\1/,inside:{variable:/[$%]\{?(?:\w\.?[-+:]?)+\}?/}},variable:/[$%]\{?(?:\w\.?[-+:]?)+\}?/,regex:/\^?.*\$|\^.*\$?/}}ip.displayName="sql";ip.aliases=[];function ip(e){e.languages.sql={comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?\*\/|(?:--|\/\/|#).*)/,lookbehind:!0},variable:[{pattern:/@(["'`])(?:\\[\s\S]|(?!\1)[^\\])+\1/,greedy:!0},/@[\w.$]+/],string:{pattern:/(^|[^@\\])("|')(?:\\[\s\S]|(?!\2)[^\\]|\2\2)*\2/,greedy:!0,lookbehind:!0},identifier:{pattern:/(^|[^@\\])`(?:\\[\s\S]|[^`\\]|``)*`/,greedy:!0,lookbehind:!0,inside:{punctuation:/^`|`$/}},function:/\b(?:AVG|COUNT|FIRST|FORMAT|LAST|LCASE|LEN|MAX|MID|MIN|MOD|NOW|ROUND|SUM|UCASE)(?=\s*\()/i,keyword:/\b(?:ACTION|ADD|AFTER|ALGORITHM|ALL|ALTER|ANALYZE|ANY|APPLY|AS|ASC|AUTHORIZATION|AUTO_INCREMENT|BACKUP|BDB|BEGIN|BERKELEYDB|BIGINT|BINARY|BIT|BLOB|BOOL|BOOLEAN|BREAK|BROWSE|BTREE|BULK|BY|CALL|CASCADED?|CASE|CHAIN|CHAR(?:ACTER|SET)?|CHECK(?:POINT)?|CLOSE|CLUSTERED|COALESCE|COLLATE|COLUMNS?|COMMENT|COMMIT(?:TED)?|COMPUTE|CONNECT|CONSISTENT|CONSTRAINT|CONTAINS(?:TABLE)?|CONTINUE|CONVERT|CREATE|CROSS|CURRENT(?:_DATE|_TIME|_TIMESTAMP|_USER)?|CURSOR|CYCLE|DATA(?:BASES?)?|DATE(?:TIME)?|DAY|DBCC|DEALLOCATE|DEC|DECIMAL|DECLARE|DEFAULT|DEFINER|DELAYED|DELETE|DELIMITERS?|DENY|DESC|DESCRIBE|DETERMINISTIC|DISABLE|DISCARD|DISK|DISTINCT|DISTINCTROW|DISTRIBUTED|DO|DOUBLE|DROP|DUMMY|DUMP(?:FILE)?|DUPLICATE|ELSE(?:IF)?|ENABLE|ENCLOSED|END|ENGINE|ENUM|ERRLVL|ERRORS|ESCAPED?|EXCEPT|EXEC(?:UTE)?|EXISTS|EXIT|EXPLAIN|EXTENDED|FETCH|FIELDS|FILE|FILLFACTOR|FIRST|FIXED|FLOAT|FOLLOWING|FOR(?: EACH ROW)?|FORCE|FOREIGN|FREETEXT(?:TABLE)?|FROM|FULL|FUNCTION|GEOMETRY(?:COLLECTION)?|GLOBAL|GOTO|GRANT|GROUP|HANDLER|HASH|HAVING|HOLDLOCK|HOUR|IDENTITY(?:COL|_INSERT)?|IF|IGNORE|IMPORT|INDEX|INFILE|INNER|INNODB|INOUT|INSERT|INT|INTEGER|INTERSECT|INTERVAL|INTO|INVOKER|ISOLATION|ITERATE|JOIN|KEYS?|KILL|LANGUAGE|LAST|LEAVE|LEFT|LEVEL|LIMIT|LINENO|LINES|LINESTRING|LOAD|LOCAL|LOCK|LONG(?:BLOB|TEXT)|LOOP|MATCH(?:ED)?|MEDIUM(?:BLOB|INT|TEXT)|MERGE|MIDDLEINT|MINUTE|MODE|MODIFIES|MODIFY|MONTH|MULTI(?:LINESTRING|POINT|POLYGON)|NATIONAL|NATURAL|NCHAR|NEXT|NO|NONCLUSTERED|NULLIF|NUMERIC|OFF?|OFFSETS?|ON|OPEN(?:DATASOURCE|QUERY|ROWSET)?|OPTIMIZE|OPTION(?:ALLY)?|ORDER|OUT(?:ER|FILE)?|OVER|PARTIAL|PARTITION|PERCENT|PIVOT|PLAN|POINT|POLYGON|PRECEDING|PRECISION|PREPARE|PREV|PRIMARY|PRINT|PRIVILEGES|PROC(?:EDURE)?|PUBLIC|PURGE|QUICK|RAISERROR|READS?|REAL|RECONFIGURE|REFERENCES|RELEASE|RENAME|REPEAT(?:ABLE)?|REPLACE|REPLICATION|REQUIRE|RESIGNAL|RESTORE|RESTRICT|RETURN(?:ING|S)?|REVOKE|RIGHT|ROLLBACK|ROUTINE|ROW(?:COUNT|GUIDCOL|S)?|RTREE|RULE|SAVE(?:POINT)?|SCHEMA|SECOND|SELECT|SERIAL(?:IZABLE)?|SESSION(?:_USER)?|SET(?:USER)?|SHARE|SHOW|SHUTDOWN|SIMPLE|SMALLINT|SNAPSHOT|SOME|SONAME|SQL|START(?:ING)?|STATISTICS|STATUS|STRIPED|SYSTEM_USER|TABLES?|TABLESPACE|TEMP(?:ORARY|TABLE)?|TERMINATED|TEXT(?:SIZE)?|THEN|TIME(?:STAMP)?|TINY(?:BLOB|INT|TEXT)|TOP?|TRAN(?:SACTIONS?)?|TRIGGER|TRUNCATE|TSEQUAL|TYPES?|UNBOUNDED|UNCOMMITTED|UNDEFINED|UNION|UNIQUE|UNLOCK|UNPIVOT|UNSIGNED|UPDATE(?:TEXT)?|USAGE|USE|USER|USING|VALUES?|VAR(?:BINARY|CHAR|CHARACTER|YING)|VIEW|WAITFOR|WARNINGS|WHEN|WHERE|WHILE|WITH(?: ROLLUP|IN)?|WORK|WRITE(?:TEXT)?|YEAR)\b/i,boolean:/\b(?:FALSE|NULL|TRUE)\b/i,number:/\b0x[\da-f]+\b|\b\d+(?:\.\d*)?|\B\.\d+\b/i,operator:/[-+*\/=%^~]|&&?|\|\|?|!=?|<(?:=>?|<|>)?|>[>=]?|\b(?:AND|BETWEEN|DIV|ILIKE|IN|IS|LIKE|NOT|OR|REGEXP|RLIKE|SOUNDS LIKE|XOR)\b/i,punctuation:/[;[\]()`,.]/}}Sw.displayName="apex";Sw.aliases=[];function Sw(e){e.register(Mt),e.register(ip),(function(t){var n=/\b(?:(?:after|before)(?=\s+[a-z])|abstract|activate|and|any|array|as|asc|autonomous|begin|bigdecimal|blob|boolean|break|bulk|by|byte|case|cast|catch|char|class|collect|commit|const|continue|currency|date|datetime|decimal|default|delete|desc|do|double|else|end|enum|exception|exit|export|extends|final|finally|float|for|from|get(?=\s*[{};])|global|goto|group|having|hint|if|implements|import|in|inner|insert|instanceof|int|integer|interface|into|join|like|limit|list|long|loop|map|merge|new|not|null|nulls|number|object|of|on|or|outer|override|package|parallel|pragma|private|protected|public|retrieve|return|rollback|select|set|short|sObject|sort|static|string|super|switch|synchronized|system|testmethod|then|this|throw|time|transaction|transient|trigger|try|undelete|update|upsert|using|virtual|void|webservice|when|where|while|(?:inherited|with|without)\s+sharing)\b/i,r=/\b(?:(?=[a-z_]\w*\s*[<\[])|(?!<keyword>))[A-Z_]\w*(?:\s*\.\s*[A-Z_]\w*)*\b(?:\s*(?:\[\s*\]|<(?:[^<>]|<(?:[^<>]|<[^<>]*>)*>)*>))*/.source.replace(/<keyword>/g,function(){return n.source});function a(o){return RegExp(o.replace(/<CLASS-NAME>/g,function(){return r}),"i")}var i={keyword:n,punctuation:/[()\[\]{};,:.<>]/};t.languages.apex={comment:t.languages.clike.comment,string:t.languages.clike.string,sql:{pattern:/((?:[=,({:]|\breturn)\s*)\[[^\[\]]*\]/i,lookbehind:!0,greedy:!0,alias:"language-sql",inside:t.languages.sql},annotation:{pattern:/@\w+\b/,alias:"punctuation"},"class-name":[{pattern:a(/(\b(?:class|enum|extends|implements|instanceof|interface|new|trigger\s+\w+\s+on)\s+)<CLASS-NAME>/.source),lookbehind:!0,inside:i},{pattern:a(/(\(\s*)<CLASS-NAME>(?=\s*\)\s*[\w(])/.source),lookbehind:!0,inside:i},{pattern:a(/<CLASS-NAME>(?=\s*\w+\s*[;=,(){:])/.source),inside:i}],trigger:{pattern:/(\btrigger\s+)\w+\b/i,lookbehind:!0,alias:"class-name"},keyword:n,function:/\b[a-z_]\w*(?=\s*\()/i,boolean:/\b(?:false|true)\b/i,number:/(?:\B\.\d+|\b\d+(?:\.\d+|L)?)\b/i,operator:/[!=](?:==?)?|\?\.?|&&|\|\||--|\+\+|[-+*/^&|]=?|:|<<?=?|>{1,3}=?/,punctuation:/[()\[\]{};,.]/}})(e)}ww.displayName="apl";ww.aliases=[];function ww(e){e.languages.apl={comment:/(?:⍝|#[! ]).*$/m,string:{pattern:/'(?:[^'\r\n]|'')*'/,greedy:!0},number:/¯?(?:\d*\.?\b\d+(?:e[+¯]?\d+)?|¯|∞)(?:j¯?(?:(?:\d+(?:\.\d+)?|\.\d+)(?:e[+¯]?\d+)?|¯|∞))?/i,statement:/:[A-Z][a-z][A-Za-z]*\b/,"system-function":{pattern:/⎕[A-Z]+/i,alias:"function"},constant:/[⍬⌾#⎕⍞]/,function:/[-+×÷⌈⌊∣|⍳⍸?*⍟○!⌹<≤=>≥≠≡≢∊⍷∪∩~∨∧⍱⍲⍴,⍪⌽⊖⍉↑↓⊂⊃⊆⊇⌷⍋⍒⊤⊥⍕⍎⊣⊢⍁⍂≈⍯↗¤→]/,"monadic-operator":{pattern:/[\\\/⌿⍀¨⍨⌶&∥]/,alias:"operator"},"dyadic-operator":{pattern:/[.⍣⍠⍤∘⌸@⌺⍥]/,alias:"operator"},assignment:{pattern:/←/,alias:"keyword"},punctuation:/[\[;\]()◇⋄]/,dfn:{pattern:/[{}⍺⍵⍶⍹∇⍫:]/,alias:"builtin"}}}Ew.displayName="applescript";Ew.aliases=[];function Ew(e){e.languages.applescript={comment:[/\(\*(?:\(\*(?:[^*]|\*(?!\)))*\*\)|(?!\(\*)[\s\S])*?\*\)/,/--.+/,/#.+/],string:/"(?:\\.|[^"\\\r\n])*"/,number:/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e-?\d+)?\b/i,operator:[/[&=≠≤≥*+\-\/÷^]|[<>]=?/,/\b(?:(?:begin|end|start)s? with|(?:contains?|(?:does not|doesn't) contain)|(?:is|isn't|is not) (?:contained by|in)|(?:(?:is|isn't|is not) )?(?:greater|less) than(?: or equal)?(?: to)?|(?:comes|(?:does not|doesn't) come) (?:after|before)|(?:is|isn't|is not) equal(?: to)?|(?:(?:does not|doesn't) equal|equal to|equals|is not|isn't)|(?:a )?(?:ref(?: to)?|reference to)|(?:and|as|div|mod|not|or))\b/],keyword:/\b(?:about|above|after|against|apart from|around|aside from|at|back|before|beginning|behind|below|beneath|beside|between|but|by|considering|continue|copy|does|eighth|else|end|equal|error|every|exit|false|fifth|first|for|fourth|from|front|get|given|global|if|ignoring|in|instead of|into|is|it|its|last|local|me|middle|my|ninth|of|on|onto|out of|over|prop|property|put|repeat|return|returning|second|set|seventh|since|sixth|some|tell|tenth|that|the|then|third|through|thru|timeout|times|to|transaction|true|try|until|where|while|whose|with|without)\b/,"class-name":/\b(?:POSIX file|RGB color|alias|application|boolean|centimeters|centimetres|class|constant|cubic centimeters|cubic centimetres|cubic feet|cubic inches|cubic meters|cubic metres|cubic yards|date|degrees Celsius|degrees Fahrenheit|degrees Kelvin|feet|file|gallons|grams|inches|integer|kilograms|kilometers|kilometres|list|liters|litres|meters|metres|miles|number|ounces|pounds|quarts|real|record|reference|script|square feet|square kilometers|square kilometres|square meters|square metres|square miles|square yards|text|yards)\b/,punctuation:/[{}():,¬«»《》]/}}kw.displayName="aql";kw.aliases=[];function kw(e){e.languages.aql={comment:/\/\/.*|\/\*[\s\S]*?\*\//,property:{pattern:/([{,]\s*)(?:(?!\d)\w+|(["'´`])(?:(?!\2)[^\\\r\n]|\\.)*\2)(?=\s*:)/,lookbehind:!0,greedy:!0},string:{pattern:/(["'])(?:(?!\1)[^\\\r\n]|\\.)*\1/,greedy:!0},identifier:{pattern:/([´`])(?:(?!\1)[^\\\r\n]|\\.)*\1/,greedy:!0},variable:/@@?\w+/,keyword:[{pattern:/(\bWITH\s+)COUNT(?=\s+INTO\b)/i,lookbehind:!0},/\b(?:AGGREGATE|ALL|AND|ANY|ASC|COLLECT|DESC|DISTINCT|FILTER|FOR|GRAPH|IN|INBOUND|INSERT|INTO|K_PATHS|K_SHORTEST_PATHS|LET|LIKE|LIMIT|NONE|NOT|NULL|OR|OUTBOUND|REMOVE|REPLACE|RETURN|SHORTEST_PATH|SORT|UPDATE|UPSERT|WINDOW|WITH)\b/i,{pattern:/(^|[^\w.[])(?:KEEP|PRUNE|SEARCH|TO)\b/i,lookbehind:!0},{pattern:/(^|[^\w.[])(?:CURRENT|NEW|OLD)\b/,lookbehind:!0},{pattern:/\bOPTIONS(?=\s*\{)/i}],function:/\b(?!\d)\w+(?=\s*\()/,boolean:/\b(?:false|true)\b/i,range:{pattern:/\.\./,alias:"operator"},number:[/\b0b[01]+/i,/\b0x[0-9a-f]+/i,/(?:\B\.\d+|\b(?:0|[1-9]\d*)(?:\.\d+)?)(?:e[+-]?\d+)?/i],operator:/\*{2,}|[=!]~|[!=<>]=?|&&|\|\||[-+*/%]/,punctuation:/::|[?.:,;()[\]{}]/}}$i.displayName="c";$i.aliases=[];function $i(e){e.register(Mt),e.languages.c=e.languages.extend("clike",{comment:{pattern:/\/\/(?:[^\r\n\\]|\\(?:\r\n?|\n|(?![\r\n])))*|\/\*[\s\S]*?(?:\*\/|$)/,greedy:!0},string:{pattern:/"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"/,greedy:!0},"class-name":{pattern:/(\b(?:enum|struct)\s+(?:__attribute__\s*\(\([\s\S]*?\)\)\s*)?)\w+|\b[a-z]\w*_t\b/,lookbehind:!0},keyword:/\b(?:_Alignas|_Alignof|_Atomic|_Bool|_Complex|_Generic|_Imaginary|_Noreturn|_Static_assert|_Thread_local|__attribute__|asm|auto|break|case|char|const|continue|default|do|double|else|enum|extern|float|for|goto|if|inline|int|long|register|return|short|signed|sizeof|static|struct|switch|typedef|typeof|union|unsigned|void|volatile|while)\b/,function:/\b[a-z_]\w*(?=\s*\()/i,number:/(?:\b0x(?:[\da-f]+(?:\.[\da-f]*)?|\.[\da-f]+)(?:p[+-]?\d+)?|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?)[ful]{0,4}/i,operator:/>>=?|<<=?|->|([-+&|:])\1|[?:~]|[-+*/%&|^!=<>]=?/}),e.languages.insertBefore("c","string",{char:{pattern:/'(?:\\(?:\r\n|[\s\S])|[^'\\\r\n]){0,32}'/,greedy:!0}}),e.languages.insertBefore("c","string",{macro:{pattern:/(^[\t ]*)#\s*[a-z](?:[^\r\n\\/]|\/(?!\*)|\/\*(?:[^*]|\*(?!\/))*\*\/|\\(?:\r\n|[\s\S]))*/im,lookbehind:!0,greedy:!0,alias:"property",inside:{string:[{pattern:/^(#\s*include\s*)<[^>]+>/,lookbehind:!0},e.languages.c.string],char:e.languages.c.char,comment:e.languages.c.comment,"macro-name":[{pattern:/(^#\s*define\s+)\w+\b(?!\()/i,lookbehind:!0},{pattern:/(^#\s*define\s+)\w+\b(?=\()/i,lookbehind:!0,alias:"function"}],directive:{pattern:/^(#\s*)[a-z]+/,lookbehind:!0,alias:"keyword"},"directive-hash":/^#/,punctuation:/##|\\(?=[\r\n])/,expression:{pattern:/\S[\s\S]*/,inside:e.languages.c}}}}),e.languages.insertBefore("c","function",{constant:/\b(?:EOF|NULL|SEEK_CUR|SEEK_END|SEEK_SET|__DATE__|__FILE__|__LINE__|__TIMESTAMP__|__TIME__|__func__|stderr|stdin|stdout)\b/}),delete e.languages.c.boolean}Eu.displayName="cpp";Eu.aliases=[];function Eu(e){e.register($i),(function(t){var n=/\b(?:alignas|alignof|asm|auto|bool|break|case|catch|char|char16_t|char32_t|char8_t|class|co_await|co_return|co_yield|compl|concept|const|const_cast|consteval|constexpr|constinit|continue|decltype|default|delete|do|double|dynamic_cast|else|enum|explicit|export|extern|final|float|for|friend|goto|if|import|inline|int|int16_t|int32_t|int64_t|int8_t|long|module|mutable|namespace|new|noexcept|nullptr|operator|override|private|protected|public|register|reinterpret_cast|requires|return|short|signed|sizeof|static|static_assert|static_cast|struct|switch|template|this|thread_local|throw|try|typedef|typeid|typename|uint16_t|uint32_t|uint64_t|uint8_t|union|unsigned|using|virtual|void|volatile|wchar_t|while)\b/,r=/\b(?!<keyword>)\w+(?:\s*\.\s*\w+)*\b/.source.replace(/<keyword>/g,function(){return n.source});t.languages.cpp=t.languages.extend("c",{"class-name":[{pattern:RegExp(/(\b(?:class|concept|enum|struct|typename)\s+)(?!<keyword>)\w+/.source.replace(/<keyword>/g,function(){return n.source})),lookbehind:!0},/\b[A-Z]\w*(?=\s*::\s*\w+\s*\()/,/\b[A-Z_]\w*(?=\s*::\s*~\w+\s*\()/i,/\b\w+(?=\s*<(?:[^<>]|<(?:[^<>]|<[^<>]*>)*>)*>\s*::\s*\w+\s*\()/],keyword:n,number:{pattern:/(?:\b0b[01']+|\b0x(?:[\da-f']+(?:\.[\da-f']*)?|\.[\da-f']+)(?:p[+-]?[\d']+)?|(?:\b[\d']+(?:\.[\d']*)?|\B\.[\d']+)(?:e[+-]?[\d']+)?)[ful]{0,4}/i,greedy:!0},operator:/>>=?|<<=?|->|--|\+\+|&&|\|\||[?:~]|<=>|[-+*/%&|^!=<>]=?|\b(?:and|and_eq|bitand|bitor|not|not_eq|or|or_eq|xor|xor_eq)\b/,boolean:/\b(?:false|true)\b/}),t.languages.insertBefore("cpp","string",{module:{pattern:RegExp(/(\b(?:import|module)\s+)/.source+"(?:"+/"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"|<[^<>\r\n]*>/.source+"|"+/<mod-name>(?:\s*:\s*<mod-name>)?|:\s*<mod-name>/.source.replace(/<mod-name>/g,function(){return r})+")"),lookbehind:!0,greedy:!0,inside:{string:/^[<"][\s\S]+/,operator:/:/,punctuation:/\./}},"raw-string":{pattern:/R"([^()\\ ]{0,16})\([\s\S]*?\)\1"/,alias:"string",greedy:!0}}),t.languages.insertBefore("cpp","keyword",{"generic-function":{pattern:/\b(?!operator\b)[a-z_]\w*\s*<(?:[^<>]|<[^<>]*>)*>(?=\s*\()/i,inside:{function:/^\w+/,generic:{pattern:/<[\s\S]+/,alias:"class-name",inside:t.languages.cpp}}}}),t.languages.insertBefore("cpp","operator",{"double-colon":{pattern:/::/,alias:"punctuation"}}),t.languages.insertBefore("cpp","class-name",{"base-clause":{pattern:/(\b(?:class|struct)\s+\w+\s*:\s*)[^;{}"'\s]+(?:\s+[^;{}"'\s]+)*(?=\s*[;{])/,lookbehind:!0,greedy:!0,inside:t.languages.extend("cpp",{})}}),t.languages.insertBefore("inside","double-colon",{"class-name":/\b[a-z_]\w*\b(?!\s*::)/i},t.languages.cpp["base-clause"])})(e)}Tw.displayName="arduino";Tw.aliases=["ino"];function Tw(e){e.register(Eu),e.languages.arduino=e.languages.extend("cpp",{keyword:/\b(?:String|array|bool|boolean|break|byte|case|catch|continue|default|do|double|else|finally|for|function|goto|if|in|instanceof|int|integer|long|loop|new|null|return|setup|string|switch|throw|try|void|while|word)\b/,constant:/\b(?:ANALOG_MESSAGE|DEFAULT|DIGITAL_MESSAGE|EXTERNAL|FIRMATA_STRING|HIGH|INPUT|INPUT_PULLUP|INTERNAL|INTERNAL1V1|INTERNAL2V56|LED_BUILTIN|LOW|OUTPUT|REPORT_ANALOG|REPORT_DIGITAL|SET_PIN_MODE|SYSEX_START|SYSTEM_RESET)\b/,builtin:/\b(?:Audio|BSSID|Bridge|Client|Console|EEPROM|Esplora|EsploraTFT|Ethernet|EthernetClient|EthernetServer|EthernetUDP|File|FileIO|FileSystem|Firmata|GPRS|GSM|GSMBand|GSMClient|GSMModem|GSMPIN|GSMScanner|GSMServer|GSMVoiceCall|GSM_SMS|HttpClient|IPAddress|IRread|Keyboard|KeyboardController|LiquidCrystal|LiquidCrystal_I2C|Mailbox|Mouse|MouseController|PImage|Process|RSSI|RobotControl|RobotMotor|SD|SPI|SSID|Scheduler|Serial|Server|Servo|SoftwareSerial|Stepper|Stream|TFT|Task|USBHost|WiFi|WiFiClient|WiFiServer|WiFiUDP|Wire|YunClient|YunServer|abs|addParameter|analogRead|analogReadResolution|analogReference|analogWrite|analogWriteResolution|answerCall|attach|attachGPRS|attachInterrupt|attached|autoscroll|available|background|beep|begin|beginPacket|beginSD|beginSMS|beginSpeaker|beginTFT|beginTransmission|beginWrite|bit|bitClear|bitRead|bitSet|bitWrite|blink|blinkVersion|buffer|changePIN|checkPIN|checkPUK|checkReg|circle|cityNameRead|cityNameWrite|clear|clearScreen|click|close|compassRead|config|connect|connected|constrain|cos|countryNameRead|countryNameWrite|createChar|cursor|debugPrint|delay|delayMicroseconds|detach|detachInterrupt|digitalRead|digitalWrite|disconnect|display|displayLogos|drawBMP|drawCompass|encryptionType|end|endPacket|endSMS|endTransmission|endWrite|exists|exitValue|fill|find|findUntil|flush|gatewayIP|get|getAsynchronously|getBand|getButton|getCurrentCarrier|getIMEI|getKey|getModifiers|getOemKey|getPINUsed|getResult|getSignalStrength|getSocket|getVoiceCallStatus|getXChange|getYChange|hangCall|height|highByte|home|image|interrupts|isActionDone|isDirectory|isListening|isPIN|isPressed|isValid|keyPressed|keyReleased|keyboardRead|knobRead|leftToRight|line|lineFollowConfig|listen|listenOnLocalhost|loadImage|localIP|lowByte|macAddress|maintain|map|max|messageAvailable|micros|millis|min|mkdir|motorsStop|motorsWrite|mouseDragged|mouseMoved|mousePressed|mouseReleased|move|noAutoscroll|noBlink|noBuffer|noCursor|noDisplay|noFill|noInterrupts|noListenOnLocalhost|noStroke|noTone|onReceive|onRequest|open|openNextFile|overflow|parseCommand|parseFloat|parseInt|parsePacket|pauseMode|peek|pinMode|playFile|playMelody|point|pointTo|position|pow|prepare|press|print|printFirmwareVersion|printVersion|println|process|processInput|pulseIn|put|random|randomSeed|read|readAccelerometer|readBlue|readButton|readBytes|readBytesUntil|readGreen|readJoystickButton|readJoystickSwitch|readJoystickX|readJoystickY|readLightSensor|readMessage|readMicrophone|readNetworks|readRed|readSlider|readString|readStringUntil|readTemperature|ready|rect|release|releaseAll|remoteIP|remoteNumber|remotePort|remove|requestFrom|retrieveCallingNumber|rewindDirectory|rightToLeft|rmdir|robotNameRead|robotNameWrite|run|runAsynchronously|runShellCommand|runShellCommandAsynchronously|running|scanNetworks|scrollDisplayLeft|scrollDisplayRight|seek|sendAnalog|sendDigitalPortPair|sendDigitalPorts|sendString|sendSysex|serialEvent|setBand|setBitOrder|setClockDivider|setCursor|setDNS|setDataMode|setFirmwareVersion|setMode|setPINUsed|setSpeed|setTextSize|setTimeout|shiftIn|shiftOut|shutdown|sin|size|sqrt|startLoop|step|stop|stroke|subnetMask|switchPIN|tan|tempoWrite|text|tone|transfer|tuneWrite|turn|updateIR|userNameRead|userNameWrite|voiceCall|waitContinue|width|write|writeBlue|writeGreen|writeJSON|writeMessage|writeMicroseconds|writeRGB|writeRed|yield)\b/}),e.languages.ino=e.languages.arduino}_w.displayName="arff";_w.aliases=[];function _w(e){e.languages.arff={comment:/%.*/,string:{pattern:/(["'])(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0},keyword:/@(?:attribute|data|end|relation)\b/i,number:/\b\d+(?:\.\d+)?\b/,punctuation:/[{},]/}}Cw.displayName="armasm";Cw.aliases=["arm-asm"];function Cw(e){e.languages.armasm={comment:{pattern:/;.*/,greedy:!0},string:{pattern:/"(?:[^"\r\n]|"")*"/,greedy:!0,inside:{variable:{pattern:/((?:^|[^$])(?:\${2})*)\$\w+/,lookbehind:!0}}},char:{pattern:/'(?:[^'\r\n]{0,4}|'')'/,greedy:!0},"version-symbol":{pattern:/\|[\w@]+\|/,greedy:!0,alias:"property"},boolean:/\b(?:FALSE|TRUE)\b/,directive:{pattern:/\b(?:ALIAS|ALIGN|AREA|ARM|ASSERT|ATTR|CN|CODE|CODE16|CODE32|COMMON|CP|DATA|DCB|DCD|DCDO|DCDU|DCFD|DCFDU|DCI|DCQ|DCQU|DCW|DCWU|DN|ELIF|ELSE|END|ENDFUNC|ENDIF|ENDP|ENTRY|EQU|EXPORT|EXPORTAS|EXTERN|FIELD|FILL|FN|FUNCTION|GBLA|GBLL|GBLS|GET|GLOBAL|IF|IMPORT|INCBIN|INCLUDE|INFO|KEEP|LCLA|LCLL|LCLS|LTORG|MACRO|MAP|MEND|MEXIT|NOFP|OPT|PRESERVE8|PROC|QN|READONLY|RELOC|REQUIRE|REQUIRE8|RLIST|ROUT|SETA|SETL|SETS|SN|SPACE|SUBT|THUMB|THUMBX|TTL|WEND|WHILE)\b/,alias:"property"},instruction:{pattern:/((?:^|(?:^|[^\\])(?:\r\n?|\n))[ \t]*(?:(?:[A-Z][A-Z0-9_]*[a-z]\w*|[a-z]\w*|\d+)[ \t]+)?)\b[A-Z.]+\b/,lookbehind:!0,alias:"keyword"},variable:/\$\w+/,number:/(?:\b[2-9]_\d+|(?:\b\d+(?:\.\d+)?|\B\.\d+)(?:e-?\d+)?|\b0(?:[fd]_|x)[0-9a-f]+|&[0-9a-f]+)\b/i,register:{pattern:/\b(?:r\d|lr)\b/,alias:"symbol"},operator:/<>|<<|>>|&&|\|\||[=!<>/]=?|[+\-*%#?&|^]|:[A-Z]+:/,punctuation:/[()[\],]/},e.languages["arm-asm"]=e.languages.armasm}Ng.displayName="bash";Ng.aliases=["sh","shell"];function Ng(e){(function(t){var n="\\b(?:BASH|BASHOPTS|BASH_ALIASES|BASH_ARGC|BASH_ARGV|BASH_CMDS|BASH_COMPLETION_COMPAT_DIR|BASH_LINENO|BASH_REMATCH|BASH_SOURCE|BASH_VERSINFO|BASH_VERSION|COLORTERM|COLUMNS|COMP_WORDBREAKS|DBUS_SESSION_BUS_ADDRESS|DEFAULTS_PATH|DESKTOP_SESSION|DIRSTACK|DISPLAY|EUID|GDMSESSION|GDM_LANG|GNOME_KEYRING_CONTROL|GNOME_KEYRING_PID|GPG_AGENT_INFO|GROUPS|HISTCONTROL|HISTFILE|HISTFILESIZE|HISTSIZE|HOME|HOSTNAME|HOSTTYPE|IFS|INSTANCE|JOB|LANG|LANGUAGE|LC_ADDRESS|LC_ALL|LC_IDENTIFICATION|LC_MEASUREMENT|LC_MONETARY|LC_NAME|LC_NUMERIC|LC_PAPER|LC_TELEPHONE|LC_TIME|LESSCLOSE|LESSOPEN|LINES|LOGNAME|LS_COLORS|MACHTYPE|MAILCHECK|MANDATORY_PATH|NO_AT_BRIDGE|OLDPWD|OPTERR|OPTIND|ORBIT_SOCKETDIR|OSTYPE|PAPERSIZE|PATH|PIPESTATUS|PPID|PS1|PS2|PS3|PS4|PWD|RANDOM|REPLY|SECONDS|SELINUX_INIT|SESSION|SESSIONTYPE|SESSION_MANAGER|SHELL|SHELLOPTS|SHLVL|SSH_AUTH_SOCK|TERM|UID|UPSTART_EVENTS|UPSTART_INSTANCE|UPSTART_JOB|UPSTART_SESSION|USER|WINDOWID|XAUTHORITY|XDG_CONFIG_DIRS|XDG_CURRENT_DESKTOP|XDG_DATA_DIRS|XDG_GREETER_DATA_DIR|XDG_MENU_PREFIX|XDG_RUNTIME_DIR|XDG_SEAT|XDG_SEAT_PATH|XDG_SESSION_DESKTOP|XDG_SESSION_ID|XDG_SESSION_PATH|XDG_SESSION_TYPE|XDG_VTNR|XMODIFIERS)\\b",r={pattern:/(^(["']?)\w+\2)[ \t]+\S.*/,lookbehind:!0,alias:"punctuation",inside:null},a={bash:r,environment:{pattern:RegExp("\\$"+n),alias:"constant"},variable:[{pattern:/\$?\(\([\s\S]+?\)\)/,greedy:!0,inside:{variable:[{pattern:/(^\$\(\([\s\S]+)\)\)/,lookbehind:!0},/^\$\(\(/],number:/\b0x[\dA-Fa-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee]-?\d+)?/,operator:/--|\+\+|\*\*=?|<<=?|>>=?|&&|\|\||[=!+\-*/%<>^&|]=?|[?~:]/,punctuation:/\(\(?|\)\)?|,|;/}},{pattern:/\$\((?:\([^)]+\)|[^()])+\)|`[^`]+`/,greedy:!0,inside:{variable:/^\$\(|^`|\)$|`$/}},{pattern:/\$\{[^}]+\}/,greedy:!0,inside:{operator:/:[-=?+]?|[!\/]|##?|%%?|\^\^?|,,?/,punctuation:/[\[\]]/,environment:{pattern:RegExp("(\\{)"+n),lookbehind:!0,alias:"constant"}}},/\$(?:\w+|[#?*!@$])/],entity:/\\(?:[abceEfnrtv\\"]|O?[0-7]{1,3}|U[0-9a-fA-F]{8}|u[0-9a-fA-F]{4}|x[0-9a-fA-F]{1,2})/};t.languages.bash={shebang:{pattern:/^#!\s*\/.*/,alias:"important"},comment:{pattern:/(^|[^"{\\$])#.*/,lookbehind:!0},"function-name":[{pattern:/(\bfunction\s+)[\w-]+(?=(?:\s*\(?:\s*\))?\s*\{)/,lookbehind:!0,alias:"function"},{pattern:/\b[\w-]+(?=\s*\(\s*\)\s*\{)/,alias:"function"}],"for-or-select":{pattern:/(\b(?:for|select)\s+)\w+(?=\s+in\s)/,alias:"variable",lookbehind:!0},"assign-left":{pattern:/(^|[\s;|&]|[<>]\()\w+(?:\.\w+)*(?=\+?=)/,inside:{environment:{pattern:RegExp("(^|[\\s;|&]|[<>]\\()"+n),lookbehind:!0,alias:"constant"}},alias:"variable",lookbehind:!0},parameter:{pattern:/(^|\s)-{1,2}(?:\w+:[+-]?)?\w+(?:\.\w+)*(?=[=\s]|$)/,alias:"variable",lookbehind:!0},string:[{pattern:/((?:^|[^<])<<-?\s*)(\w+)\s[\s\S]*?(?:\r?\n|\r)\2/,lookbehind:!0,greedy:!0,inside:a},{pattern:/((?:^|[^<])<<-?\s*)(["'])(\w+)\2\s[\s\S]*?(?:\r?\n|\r)\3/,lookbehind:!0,greedy:!0,inside:{bash:r}},{pattern:/(^|[^\\](?:\\\\)*)"(?:\\[\s\S]|\$\([^)]+\)|\$(?!\()|`[^`]+`|[^"\\`$])*"/,lookbehind:!0,greedy:!0,inside:a},{pattern:/(^|[^$\\])'[^']*'/,lookbehind:!0,greedy:!0},{pattern:/\$'(?:[^'\\]|\\[\s\S])*'/,greedy:!0,inside:{entity:a.entity}}],environment:{pattern:RegExp("\\$?"+n),alias:"constant"},variable:a.variable,function:{pattern:/(^|[\s;|&]|[<>]\()(?:add|apropos|apt|apt-cache|apt-get|aptitude|aspell|automysqlbackup|awk|basename|bash|bc|bconsole|bg|bzip2|cal|cargo|cat|cfdisk|chgrp|chkconfig|chmod|chown|chroot|cksum|clear|cmp|column|comm|composer|cp|cron|crontab|csplit|curl|cut|date|dc|dd|ddrescue|debootstrap|df|diff|diff3|dig|dir|dircolors|dirname|dirs|dmesg|docker|docker-compose|du|egrep|eject|env|ethtool|expand|expect|expr|fdformat|fdisk|fg|fgrep|file|find|fmt|fold|format|free|fsck|ftp|fuser|gawk|git|gparted|grep|groupadd|groupdel|groupmod|groups|grub-mkconfig|gzip|halt|head|hg|history|host|hostname|htop|iconv|id|ifconfig|ifdown|ifup|import|install|ip|java|jobs|join|kill|killall|less|link|ln|locate|logname|logrotate|look|lpc|lpr|lprint|lprintd|lprintq|lprm|ls|lsof|lynx|make|man|mc|mdadm|mkconfig|mkdir|mke2fs|mkfifo|mkfs|mkisofs|mknod|mkswap|mmv|more|most|mount|mtools|mtr|mutt|mv|nano|nc|netstat|nice|nl|node|nohup|notify-send|npm|nslookup|op|open|parted|passwd|paste|pathchk|ping|pkill|pnpm|podman|podman-compose|popd|pr|printcap|printenv|ps|pushd|pv|quota|quotacheck|quotactl|ram|rar|rcp|reboot|remsync|rename|renice|rev|rm|rmdir|rpm|rsync|scp|screen|sdiff|sed|sendmail|seq|service|sftp|sh|shellcheck|shuf|shutdown|sleep|slocate|sort|split|ssh|stat|strace|su|sudo|sum|suspend|swapon|sync|sysctl|tac|tail|tar|tee|time|timeout|top|touch|tr|traceroute|tsort|tty|umount|uname|unexpand|uniq|units|unrar|unshar|unzip|update-grub|uptime|useradd|userdel|usermod|users|uudecode|uuencode|v|vcpkg|vdir|vi|vim|virsh|vmstat|wait|watch|wc|wget|whereis|which|who|whoami|write|xargs|xdg-open|yarn|yes|zenity|zip|zsh|zypper)(?=$|[)\s;|&])/,lookbehind:!0},keyword:{pattern:/(^|[\s;|&]|[<>]\()(?:case|do|done|elif|else|esac|fi|for|function|if|in|select|then|until|while)(?=$|[)\s;|&])/,lookbehind:!0},builtin:{pattern:/(^|[\s;|&]|[<>]\()(?:\.|:|alias|bind|break|builtin|caller|cd|command|continue|declare|echo|enable|eval|exec|exit|export|getopts|hash|help|let|local|logout|mapfile|printf|pwd|read|readarray|readonly|return|set|shift|shopt|source|test|times|trap|type|typeset|ulimit|umask|unalias|unset)(?=$|[)\s;|&])/,lookbehind:!0,alias:"class-name"},boolean:{pattern:/(^|[\s;|&]|[<>]\()(?:false|true)(?=$|[)\s;|&])/,lookbehind:!0},"file-descriptor":{pattern:/\B&\d\b/,alias:"important"},operator:{pattern:/\d?<>|>\||\+=|=[=~]?|!=?|<<[<-]?|[&\d]?>>|\d[<>]&?|[<>][&=]?|&[>&]?|\|[&|]?/,inside:{"file-descriptor":{pattern:/^\d/,alias:"important"}}},punctuation:/\$?\(\(?|\)\)?|\.\.|[{}[\];\\]/,number:{pattern:/(^|\s)(?:[1-9]\d*|0)(?:[.,]\d+)?\b/,lookbehind:!0}},r.inside=t.languages.bash;for(var i=["comment","function-name","for-or-select","assign-left","parameter","string","environment","function","keyword","builtin","boolean","file-descriptor","operator","punctuation","number"],o=a.variable[1].inside,l=0;l<i.length;l++)o[i[l]]=t.languages.bash[i[l]];t.languages.sh=t.languages.bash,t.languages.shell=t.languages.bash})(e)}Og.displayName="yaml";Og.aliases=["yml"];function Og(e){(function(t){var n=/[*&][^\s[\]{},]+/,r=/!(?:<[\w\-%#;/?:@&=+$,.!~*'()[\]]+>|(?:[a-zA-Z\d-]*!)?[\w\-%#;/?:@&=+$.~*'()]+)?/,a="(?:"+r.source+"(?:[ 	]+"+n.source+")?|"+n.source+"(?:[ 	]+"+r.source+")?)",i=/(?:[^\s\x00-\x08\x0e-\x1f!"#%&'*,\-:>?@[\]`{|}\x7f-\x84\x86-\x9f\ud800-\udfff\ufffe\uffff]|[?:-]<PLAIN>)(?:[ \t]*(?:(?![#:])<PLAIN>|:<PLAIN>))*/.source.replace(/<PLAIN>/g,function(){return/[^\s\x00-\x08\x0e-\x1f,[\]{}\x7f-\x84\x86-\x9f\ud800-\udfff\ufffe\uffff]/.source}),o=/"(?:[^"\\\r\n]|\\.)*"|'(?:[^'\\\r\n]|\\.)*'/.source;function l(u,d){d=(d||"").replace(/m/g,"")+"m";var h=/([:\-,[{]\s*(?:\s<<prop>>[ \t]+)?)(?:<<value>>)(?=[ \t]*(?:$|,|\]|\}|(?:[\r\n]\s*)?#))/.source.replace(/<<prop>>/g,function(){return a}).replace(/<<value>>/g,function(){return u});return RegExp(h,d)}t.languages.yaml={scalar:{pattern:RegExp(/([\-:]\s*(?:\s<<prop>>[ \t]+)?[|>])[ \t]*(?:((?:\r?\n|\r)[ \t]+)\S[^\r\n]*(?:\2[^\r\n]+)*)/.source.replace(/<<prop>>/g,function(){return a})),lookbehind:!0,alias:"string"},comment:/#.*/,key:{pattern:RegExp(/((?:^|[:\-,[{\r\n?])[ \t]*(?:<<prop>>[ \t]+)?)<<key>>(?=\s*:\s)/.source.replace(/<<prop>>/g,function(){return a}).replace(/<<key>>/g,function(){return"(?:"+i+"|"+o+")"})),lookbehind:!0,greedy:!0,alias:"atrule"},directive:{pattern:/(^[ \t]*)%.+/m,lookbehind:!0,alias:"important"},datetime:{pattern:l(/\d{4}-\d\d?-\d\d?(?:[tT]|[ \t]+)\d\d?:\d{2}:\d{2}(?:\.\d*)?(?:[ \t]*(?:Z|[-+]\d\d?(?::\d{2})?))?|\d{4}-\d{2}-\d{2}|\d\d?:\d{2}(?::\d{2}(?:\.\d*)?)?/.source),lookbehind:!0,alias:"number"},boolean:{pattern:l(/false|true/.source,"i"),lookbehind:!0,alias:"important"},null:{pattern:l(/null|~/.source,"i"),lookbehind:!0,alias:"important"},string:{pattern:l(o),lookbehind:!0,greedy:!0},number:{pattern:l(/[+-]?(?:0x[\da-f]+|0o[0-7]+|(?:\d+(?:\.\d*)?|\.\d+)(?:e[+-]?\d+)?|\.inf|\.nan)/.source,"i"),lookbehind:!0},tag:r,important:n,punctuation:/---|[:[\]{}\-,|>?]|\.\.\./},t.languages.yml=t.languages.yaml})(e)}Aw.displayName="markdown";Aw.aliases=["md"];function Aw(e){e.register(cr),(function(t){var n=/(?:\\.|[^\\\n\r]|(?:\n|\r\n?)(?![\r\n]))/.source;function r(l){return l=l.replace(/<inner>/g,function(){return n}),RegExp(/((?:^|[^\\])(?:\\{2})*)/.source+"(?:"+l+")")}var a=/(?:\\.|``(?:[^`\r\n]|`(?!`))+``|`[^`\r\n]+`|[^\\|\r\n`])+/.source,i=/\|?__(?:\|__)+\|?(?:(?:\n|\r\n?)|(?![\s\S]))/.source.replace(/__/g,function(){return a}),o=/\|?[ \t]*:?-{3,}:?[ \t]*(?:\|[ \t]*:?-{3,}:?[ \t]*)+\|?(?:\n|\r\n?)/.source;t.languages.markdown=t.languages.extend("markup",{}),t.languages.insertBefore("markdown","prolog",{"front-matter-block":{pattern:/(^(?:\s*[\r\n])?)---(?!.)[\s\S]*?[\r\n]---(?!.)/,lookbehind:!0,greedy:!0,inside:{punctuation:/^---|---$/,"front-matter":{pattern:/\S+(?:\s+\S+)*/,alias:["yaml","language-yaml"],inside:t.languages.yaml}}},blockquote:{pattern:/^>(?:[\t ]*>)*/m,alias:"punctuation"},table:{pattern:RegExp("^"+i+o+"(?:"+i+")*","m"),inside:{"table-data-rows":{pattern:RegExp("^("+i+o+")(?:"+i+")*$"),lookbehind:!0,inside:{"table-data":{pattern:RegExp(a),inside:t.languages.markdown},punctuation:/\|/}},"table-line":{pattern:RegExp("^("+i+")"+o+"$"),lookbehind:!0,inside:{punctuation:/\||:?-{3,}:?/}},"table-header-row":{pattern:RegExp("^"+i+"$"),inside:{"table-header":{pattern:RegExp(a),alias:"important",inside:t.languages.markdown},punctuation:/\|/}}}},code:[{pattern:/((?:^|\n)[ \t]*\n|(?:^|\r\n?)[ \t]*\r\n?)(?: {4}|\t).+(?:(?:\n|\r\n?)(?: {4}|\t).+)*/,lookbehind:!0,alias:"keyword"},{pattern:/^```[\s\S]*?^```$/m,greedy:!0,inside:{"code-block":{pattern:/^(```.*(?:\n|\r\n?))[\s\S]+?(?=(?:\n|\r\n?)^```$)/m,lookbehind:!0},"code-language":{pattern:/^(```).+/,lookbehind:!0},punctuation:/```/}}],title:[{pattern:/\S.*(?:\n|\r\n?)(?:==+|--+)(?=[ \t]*$)/m,alias:"important",inside:{punctuation:/==+$|--+$/}},{pattern:/(^\s*)#.+/m,lookbehind:!0,alias:"important",inside:{punctuation:/^#+|#+$/}}],hr:{pattern:/(^\s*)([*-])(?:[\t ]*\2){2,}(?=\s*$)/m,lookbehind:!0,alias:"punctuation"},list:{pattern:/(^\s*)(?:[*+-]|\d+\.)(?=[\t ].)/m,lookbehind:!0,alias:"punctuation"},"url-reference":{pattern:/!?\[[^\]]+\]:[\t ]+(?:\S+|<(?:\\.|[^>\\])+>)(?:[\t ]+(?:"(?:\\.|[^"\\])*"|'(?:\\.|[^'\\])*'|\((?:\\.|[^)\\])*\)))?/,inside:{variable:{pattern:/^(!?\[)[^\]]+/,lookbehind:!0},string:/(?:"(?:\\.|[^"\\])*"|'(?:\\.|[^'\\])*'|\((?:\\.|[^)\\])*\))$/,punctuation:/^[\[\]!:]|[<>]/},alias:"url"},bold:{pattern:r(/\b__(?:(?!_)<inner>|_(?:(?!_)<inner>)+_)+__\b|\*\*(?:(?!\*)<inner>|\*(?:(?!\*)<inner>)+\*)+\*\*/.source),lookbehind:!0,greedy:!0,inside:{content:{pattern:/(^..)[\s\S]+(?=..$)/,lookbehind:!0,inside:{}},punctuation:/\*\*|__/}},italic:{pattern:r(/\b_(?:(?!_)<inner>|__(?:(?!_)<inner>)+__)+_\b|\*(?:(?!\*)<inner>|\*\*(?:(?!\*)<inner>)+\*\*)+\*/.source),lookbehind:!0,greedy:!0,inside:{content:{pattern:/(^.)[\s\S]+(?=.$)/,lookbehind:!0,inside:{}},punctuation:/[*_]/}},strike:{pattern:r(/(~~?)(?:(?!~)<inner>)+\2/.source),lookbehind:!0,greedy:!0,inside:{content:{pattern:/(^~~?)[\s\S]+(?=\1$)/,lookbehind:!0,inside:{}},punctuation:/~~?/}},"code-snippet":{pattern:/(^|[^\\`])(?:``[^`\r\n]+(?:`[^`\r\n]+)*``(?!`)|`[^`\r\n]+`(?!`))/,lookbehind:!0,greedy:!0,alias:["code","keyword"]},url:{pattern:r(/!?\[(?:(?!\])<inner>)+\](?:\([^\s)]+(?:[\t ]+"(?:\\.|[^"\\])*")?\)|[ \t]?\[(?:(?!\])<inner>)+\])/.source),lookbehind:!0,greedy:!0,inside:{operator:/^!/,content:{pattern:/(^\[)[^\]]+(?=\])/,lookbehind:!0,inside:{}},variable:{pattern:/(^\][ \t]?\[)[^\]]+(?=\]$)/,lookbehind:!0},url:{pattern:/(^\]\()[^\s)]+/,lookbehind:!0},string:{pattern:/(^[ \t]+)"(?:\\.|[^"\\])*"(?=\)$)/,lookbehind:!0}}}}),["url","bold","italic","strike"].forEach(function(l){["url","bold","italic","strike","code-snippet"].forEach(function(u){l!==u&&(t.languages.markdown[l].inside.content.inside[u]=t.languages.markdown[u])})}),t.hooks.add("after-tokenize",function(l){if(l.language!=="markdown"&&l.language!=="md")return;function u(d){if(!(!d||typeof d=="string"))for(var h=0,f=d.length;h<f;h++){var m=d[h];if(m.type!=="code"){u(m.content);continue}var b=m.content[1],y=m.content[3];if(b&&y&&b.type==="code-language"&&y.type==="code-block"&&typeof b.content=="string"){var v=b.content.replace(/\b#/g,"sharp").replace(/\b\+\+/g,"pp");v=(/[a-z][\w-]*/i.exec(v)||[""])[0].toLowerCase();var w="language-"+v;y.alias?typeof y.alias=="string"?y.alias=[y.alias,w]:y.alias.push(w):y.alias=[w]}}}u(l.tokens)}),t.hooks.add("wrap",function(l){if(l.type==="code-block"){for(var u="",d=0,h=l.classes.length;d<h;d++){var f=l.classes[d],m=/language-(.+)/.exec(f);if(m){u=m[1];break}}var b=t.languages[u];if(b)l.content=t.highlight(l.content.value,b,u);else if(u&&u!=="none"&&t.plugins.autoloader){var y="md-"+new Date().valueOf()+"-"+Math.floor(Math.random()*1e16);l.attributes.id=y,t.plugins.autoloader.loadLanguages(u,function(){var v=document.getElementById(y);v&&(v.innerHTML=t.highlight(v.textContent,t.languages[u],u))})}}}),RegExp(t.languages.markup.tag.pattern.source,"gi"),t.languages.md=t.languages.markdown})(e)}Rw.displayName="arturo";Rw.aliases=["art"];function Rw(e){(function(t){var n=function(r,a){return{pattern:RegExp(/\{!/.source+"(?:"+(a||r)+")"+/$[\s\S]*\}/.source,"m"),greedy:!0,inside:{embedded:{pattern:/(^\{!\w+\b)[\s\S]+(?=\}$)/,lookbehind:!0,alias:"language-"+r,inside:t.languages[r]},string:/[\s\S]+/}}};t.languages.arturo={comment:{pattern:/;.*/,greedy:!0},character:{pattern:/`.`/,alias:"char",greedy:!0},number:{pattern:/\b\d+(?:\.\d+(?:\.\d+(?:-[\w+-]+)?)?)?\b/},string:{pattern:/"(?:[^"\\\r\n]|\\.)*"/,greedy:!0},regex:{pattern:/\{\/.*?\/\}/,greedy:!0},"html-string":n("html"),"css-string":n("css"),"js-string":n("js"),"md-string":n("md"),"sql-string":n("sql"),"sh-string":n("shell","sh"),multistring:{pattern:/».*|\{:[\s\S]*?:\}|\{[\s\S]*?\}|^-{6}$[\s\S]*/m,alias:"string",greedy:!0},label:{pattern:/\w+\b\??:/,alias:"property"},literal:{pattern:/'(?:\w+\b\??:?)/,alias:"constant"},type:{pattern:/:(?:\w+\b\??:?)/,alias:"class-name"},color:/#\w+/,predicate:{pattern:/\b(?:all|and|any|ascii|attr|attribute|attributeLabel|binary|block|char|contains|database|date|dictionary|empty|equal|even|every|exists|false|floating|function|greater|greaterOrEqual|if|in|inline|integer|is|key|label|leap|less|lessOrEqual|literal|logical|lower|nand|negative|nor|not|notEqual|null|numeric|odd|or|path|pathLabel|positive|prefix|prime|regex|same|set|some|sorted|standalone|string|subset|suffix|superset|symbol|symbolLiteral|true|try|type|unless|upper|when|whitespace|word|xnor|xor|zero)\?/,alias:"keyword"},"builtin-function":{pattern:/\b(?:abs|acos|acosh|acsec|acsech|actan|actanh|add|after|alert|alias|and|angle|append|arg|args|arity|array|as|asec|asech|asin|asinh|atan|atan2|atanh|attr|attrs|average|before|benchmark|blend|break|call|capitalize|case|ceil|chop|clear|clip|close|color|combine|conj|continue|copy|cos|cosh|crc|csec|csech|ctan|ctanh|cursor|darken|dec|decode|define|delete|desaturate|deviation|dialog|dictionary|difference|digest|digits|div|do|download|drop|dup|e|else|empty|encode|ensure|env|escape|execute|exit|exp|extend|extract|factors|fdiv|filter|first|flatten|floor|fold|from|function|gamma|gcd|get|goto|hash|hypot|if|inc|indent|index|infinity|info|input|insert|inspect|intersection|invert|jaro|join|keys|kurtosis|last|let|levenshtein|lighten|list|ln|log|loop|lower|mail|map|match|max|median|min|mod|module|mul|nand|neg|new|nor|normalize|not|now|null|open|or|outdent|pad|palette|panic|path|pause|permissions|permutate|pi|pop|popup|pow|powerset|powmod|prefix|print|prints|process|product|query|random|range|read|relative|remove|rename|render|repeat|replace|request|return|reverse|round|sample|saturate|script|sec|sech|select|serve|set|shl|shr|shuffle|sin|sinh|size|skewness|slice|sort|spin|split|sqrt|squeeze|stack|strip|sub|suffix|sum|switch|symbols|symlink|sys|take|tan|tanh|terminal|terminate|to|truncate|try|type|unclip|union|unique|unless|until|unzip|upper|values|var|variance|volume|webview|while|with|wordwrap|write|xnor|xor|zip)\b/,alias:"keyword"},sugar:{pattern:/->|=>|\||::/,alias:"operator"},punctuation:/[()[\],]/,symbol:{pattern:/<:|-:|ø|@|#|\+|\||\*|\$|---|-|%|\/|\.\.|\^|~|=|<|>|\\/},boolean:{pattern:/\b(?:false|maybe|true)\b/}},t.languages.art=t.languages.arturo})(e)}Nw.displayName="asciidoc";Nw.aliases=["adoc"];function Nw(e){(function(t){var n={pattern:/(^[ \t]*)\[(?!\[)(?:(["'$`])(?:(?!\2)[^\\]|\\.)*\2|\[(?:[^\[\]\\]|\\.)*\]|[^\[\]\\"'$`]|\\.)*\]/m,lookbehind:!0,inside:{quoted:{pattern:/([$`])(?:(?!\1)[^\\]|\\.)*\1/,inside:{punctuation:/^[$`]|[$`]$/}},interpreted:{pattern:/'(?:[^'\\]|\\.)*'/,inside:{punctuation:/^'|'$/}},string:/"(?:[^"\\]|\\.)*"/,variable:/\w+(?==)/,punctuation:/^\[|\]$|,/,operator:/=/,"attr-value":/(?!^\s+$).+/}},r=t.languages.asciidoc={"comment-block":{pattern:/^(\/{4,})$[\s\S]*?^\1/m,alias:"comment"},table:{pattern:/^\|={3,}(?:(?:\r?\n|\r(?!\n)).*)*?(?:\r?\n|\r)\|={3,}$/m,inside:{specifiers:{pattern:/(?:(?:(?:\d+(?:\.\d+)?|\.\d+)[+*](?:[<^>](?:\.[<^>])?|\.[<^>])?|[<^>](?:\.[<^>])?|\.[<^>])[a-z]*|[a-z]+)(?=\|)/,alias:"attr-value"},punctuation:{pattern:/(^|[^\\])[|!]=*/,lookbehind:!0}}},"passthrough-block":{pattern:/^(\+{4,})$[\s\S]*?^\1$/m,inside:{punctuation:/^\++|\++$/}},"literal-block":{pattern:/^(-{4,}|\.{4,})$[\s\S]*?^\1$/m,inside:{punctuation:/^(?:-+|\.+)|(?:-+|\.+)$/}},"other-block":{pattern:/^(--|\*{4,}|_{4,}|={4,})$[\s\S]*?^\1$/m,inside:{punctuation:/^(?:-+|\*+|_+|=+)|(?:-+|\*+|_+|=+)$/}},"list-punctuation":{pattern:/(^[ \t]*)(?:-|\*{1,5}|\.{1,5}|(?:[a-z]|\d+)\.|[xvi]+\))(?= )/im,lookbehind:!0,alias:"punctuation"},"list-label":{pattern:/(^[ \t]*)[a-z\d].+(?::{2,4}|;;)(?=\s)/im,lookbehind:!0,alias:"symbol"},"indented-block":{pattern:/((\r?\n|\r)\2)([ \t]+)\S.*(?:(?:\r?\n|\r)\3.+)*(?=\2{2}|$)/,lookbehind:!0},comment:/^\/\/.*/m,title:{pattern:/^.+(?:\r?\n|\r)(?:={3,}|-{3,}|~{3,}|\^{3,}|\+{3,})$|^={1,5} .+|^\.(?![\s.]).*/m,alias:"important",inside:{punctuation:/^(?:\.|=+)|(?:=+|-+|~+|\^+|\++)$/}},"attribute-entry":{pattern:/^:[^:\r\n]+:(?: .*?(?: \+(?:\r?\n|\r).*?)*)?$/m,alias:"tag"},attributes:n,hr:{pattern:/^'{3,}$/m,alias:"punctuation"},"page-break":{pattern:/^<{3,}$/m,alias:"punctuation"},admonition:{pattern:/^(?:CAUTION|IMPORTANT|NOTE|TIP|WARNING):/m,alias:"keyword"},callout:[{pattern:/(^[ \t]*)<?\d*>/m,lookbehind:!0,alias:"symbol"},{pattern:/<\d+>/,alias:"symbol"}],macro:{pattern:/\b[a-z\d][a-z\d-]*::?(?:[^\s\[\]]*\[(?:[^\]\\"']|(["'])(?:(?!\1)[^\\]|\\.)*\1|\\.)*\])/,inside:{function:/^[a-z\d-]+(?=:)/,punctuation:/^::?/,attributes:{pattern:/(?:\[(?:[^\]\\"']|(["'])(?:(?!\1)[^\\]|\\.)*\1|\\.)*\])/,inside:n.inside}}},inline:{pattern:/(^|[^\\])(?:(?:\B\[(?:[^\]\\"']|(["'])(?:(?!\2)[^\\]|\\.)*\2|\\.)*\])?(?:\b_(?!\s)(?: _|[^_\\\r\n]|\\.)+(?:(?:\r?\n|\r)(?: _|[^_\\\r\n]|\\.)+)*_\b|\B``(?!\s).+?(?:(?:\r?\n|\r).+?)*''\B|\B`(?!\s)(?:[^`'\s]|\s+\S)+['`]\B|\B(['*+#])(?!\s)(?: \3|(?!\3)[^\\\r\n]|\\.)+(?:(?:\r?\n|\r)(?: \3|(?!\3)[^\\\r\n]|\\.)+)*\3\B)|(?:\[(?:[^\]\\"']|(["'])(?:(?!\4)[^\\]|\\.)*\4|\\.)*\])?(?:(__|\*\*|\+\+\+?|##|\$\$|[~^]).+?(?:(?:\r?\n|\r).+?)*\5|\{[^}\r\n]+\}|\[\[\[?.+?(?:(?:\r?\n|\r).+?)*\]?\]\]|<<.+?(?:(?:\r?\n|\r).+?)*>>|\(\(\(?.+?(?:(?:\r?\n|\r).+?)*\)?\)\)))/m,lookbehind:!0,inside:{attributes:n,url:{pattern:/^(?:\[\[\[?.+?\]?\]\]|<<.+?>>)$/,inside:{punctuation:/^(?:\[\[\[?|<<)|(?:\]\]\]?|>>)$/}},"attribute-ref":{pattern:/^\{.+\}$/,inside:{variable:{pattern:/(^\{)[a-z\d,+_-]+/,lookbehind:!0},operator:/^[=?!#%@$]|!(?=[:}])/,punctuation:/^\{|\}$|::?/}},italic:{pattern:/^(['_])[\s\S]+\1$/,inside:{punctuation:/^(?:''?|__?)|(?:''?|__?)$/}},bold:{pattern:/^\*[\s\S]+\*$/,inside:{punctuation:/^\*\*?|\*\*?$/}},punctuation:/^(?:``?|\+{1,3}|##?|\$\$|[~^]|\(\(\(?)|(?:''?|\+{1,3}|##?|\$\$|[~^`]|\)?\)\))$/}},replacement:{pattern:/\((?:C|R|TM)\)/,alias:"builtin"},entity:/&#?[\da-z]{1,8};/i,"line-continuation":{pattern:/(^| )\+$/m,lookbehind:!0,alias:"punctuation"}};function a(i){i=i.split(" ");for(var o={},l=0,u=i.length;l<u;l++)o[i[l]]=r[i[l]];return o}n.inside.interpreted.inside.rest=a("macro inline replacement entity"),r["passthrough-block"].inside.rest=a("macro"),r["literal-block"].inside.rest=a("callout"),r.table.inside.rest=a("comment-block passthrough-block literal-block other-block list-punctuation indented-block comment title attribute-entry attributes hr page-break admonition list-label callout macro inline replacement entity line-continuation"),r["other-block"].inside.rest=a("table list-punctuation indented-block comment attribute-entry attributes hr page-break admonition list-label macro inline replacement entity line-continuation"),r.title.inside.rest=a("macro inline replacement entity"),t.hooks.add("wrap",function(i){i.type==="entity"&&(i.attributes.title=i.content.value.replace(/&amp;/,"&"))}),t.languages.adoc=t.languages.asciidoc})(e)}ku.displayName="csharp";ku.aliases=["cs","dotnet"];function ku(e){e.register(Mt),(function(t){function n(F,Y){return F.replace(/<<(\d+)>>/g,function(oe,U){return"(?:"+Y[+U]+")"})}function r(F,Y,oe){return RegExp(n(F,Y),"")}function a(F,Y){for(var oe=0;oe<Y;oe++)F=F.replace(/<<self>>/g,function(){return"(?:"+F+")"});return F.replace(/<<self>>/g,"[^\\s\\S]")}var i={type:"bool byte char decimal double dynamic float int long object sbyte short string uint ulong ushort var void",typeDeclaration:"class enum interface record struct",contextual:"add alias and ascending async await by descending from(?=\\s*(?:\\w|$)) get global group into init(?=\\s*;) join let nameof not notnull on or orderby partial remove select set unmanaged value when where with(?=\\s*{)",other:"abstract as base break case catch checked const continue default delegate do else event explicit extern finally fixed for foreach goto if implicit in internal is lock namespace new null operator out override params private protected public readonly ref return sealed sizeof stackalloc static switch this throw try typeof unchecked unsafe using virtual volatile while yield"};function o(F){return"\\b(?:"+F.trim().replace(/ /g,"|")+")\\b"}var l=o(i.typeDeclaration),u=RegExp(o(i.type+" "+i.typeDeclaration+" "+i.contextual+" "+i.other)),d=o(i.typeDeclaration+" "+i.contextual+" "+i.other),h=o(i.type+" "+i.typeDeclaration+" "+i.other),f=a(/<(?:[^<>;=+\-*/%&|^]|<<self>>)*>/.source,2),m=a(/\((?:[^()]|<<self>>)*\)/.source,2),b=/@?\b[A-Za-z_]\w*\b/.source,y=n(/<<0>>(?:\s*<<1>>)?/.source,[b,f]),v=n(/(?!<<0>>)<<1>>(?:\s*\.\s*<<1>>)*/.source,[d,y]),w=/\[\s*(?:,\s*)*\]/.source,S=n(/<<0>>(?:\s*(?:\?\s*)?<<1>>)*(?:\s*\?)?/.source,[v,w]),k=n(/[^,()<>[\];=+\-*/%&|^]|<<0>>|<<1>>|<<2>>/.source,[f,m,w]),R=n(/\(<<0>>+(?:,<<0>>+)+\)/.source,[k]),I=n(/(?:<<0>>|<<1>>)(?:\s*(?:\?\s*)?<<2>>)*(?:\s*\?)?/.source,[R,v,w]),L={keyword:u,punctuation:/[<>()?,.:[\]]/},A=/'(?:[^\r\n'\\]|\\.|\\[Uux][\da-fA-F]{1,8})'/.source,M=/"(?:\\.|[^\\"\r\n])*"/.source,P=/@"(?:""|\\[\s\S]|[^\\"])*"(?!")/.source;t.languages.csharp=t.languages.extend("clike",{string:[{pattern:r(/(^|[^$\\])<<0>>/.source,[P]),lookbehind:!0,greedy:!0},{pattern:r(/(^|[^@$\\])<<0>>/.source,[M]),lookbehind:!0,greedy:!0}],"class-name":[{pattern:r(/(\busing\s+static\s+)<<0>>(?=\s*;)/.source,[v]),lookbehind:!0,inside:L},{pattern:r(/(\busing\s+<<0>>\s*=\s*)<<1>>(?=\s*;)/.source,[b,I]),lookbehind:!0,inside:L},{pattern:r(/(\busing\s+)<<0>>(?=\s*=)/.source,[b]),lookbehind:!0},{pattern:r(/(\b<<0>>\s+)<<1>>/.source,[l,y]),lookbehind:!0,inside:L},{pattern:r(/(\bcatch\s*\(\s*)<<0>>/.source,[v]),lookbehind:!0,inside:L},{pattern:r(/(\bwhere\s+)<<0>>/.source,[b]),lookbehind:!0},{pattern:r(/(\b(?:is(?:\s+not)?|as)\s+)<<0>>/.source,[S]),lookbehind:!0,inside:L},{pattern:r(/\b<<0>>(?=\s+(?!<<1>>|with\s*\{)<<2>>(?:\s*[=,;:{)\]]|\s+(?:in|when)\b))/.source,[I,h,b]),inside:L}],keyword:u,number:/(?:\b0(?:x[\da-f_]*[\da-f]|b[01_]*[01])|(?:\B\.\d+(?:_+\d+)*|\b\d+(?:_+\d+)*(?:\.\d+(?:_+\d+)*)?)(?:e[-+]?\d+(?:_+\d+)*)?)(?:[dflmu]|lu|ul)?\b/i,operator:/>>=?|<<=?|[-=]>|([-+&|])\1|~|\?\?=?|[-+*/%&|^!=<>]=?/,punctuation:/\?\.?|::|[{}[\];(),.:]/}),t.languages.insertBefore("csharp","number",{range:{pattern:/\.\./,alias:"operator"}}),t.languages.insertBefore("csharp","punctuation",{"named-parameter":{pattern:r(/([(,]\s*)<<0>>(?=\s*:)/.source,[b]),lookbehind:!0,alias:"punctuation"}}),t.languages.insertBefore("csharp","class-name",{namespace:{pattern:r(/(\b(?:namespace|using)\s+)<<0>>(?:\s*\.\s*<<0>>)*(?=\s*[;{])/.source,[b]),lookbehind:!0,inside:{punctuation:/\./}},"type-expression":{pattern:r(/(\b(?:default|sizeof|typeof)\s*\(\s*(?!\s))(?:[^()\s]|\s(?!\s)|<<0>>)*(?=\s*\))/.source,[m]),lookbehind:!0,alias:"class-name",inside:L},"return-type":{pattern:r(/<<0>>(?=\s+(?:<<1>>\s*(?:=>|[({]|\.\s*this\s*\[)|this\s*\[))/.source,[I,v]),inside:L,alias:"class-name"},"constructor-invocation":{pattern:r(/(\bnew\s+)<<0>>(?=\s*[[({])/.source,[I]),lookbehind:!0,inside:L,alias:"class-name"},"generic-method":{pattern:r(/<<0>>\s*<<1>>(?=\s*\()/.source,[b,f]),inside:{function:r(/^<<0>>/.source,[b]),generic:{pattern:RegExp(f),alias:"class-name",inside:L}}},"type-list":{pattern:r(/\b((?:<<0>>\s+<<1>>|record\s+<<1>>\s*<<5>>|where\s+<<2>>)\s*:\s*)(?:<<3>>|<<4>>|<<1>>\s*<<5>>|<<6>>)(?:\s*,\s*(?:<<3>>|<<4>>|<<6>>))*(?=\s*(?:where|[{;]|=>|$))/.source,[l,y,b,I,u.source,m,/\bnew\s*\(\s*\)/.source]),lookbehind:!0,inside:{"record-arguments":{pattern:r(/(^(?!new\s*\()<<0>>\s*)<<1>>/.source,[y,m]),lookbehind:!0,greedy:!0,inside:t.languages.csharp},keyword:u,"class-name":{pattern:RegExp(I),greedy:!0,inside:L},punctuation:/[,()]/}},preprocessor:{pattern:/(^[\t ]*)#.*/m,lookbehind:!0,alias:"property",inside:{directive:{pattern:/(#)\b(?:define|elif|else|endif|endregion|error|if|line|nullable|pragma|region|undef|warning)\b/,lookbehind:!0,alias:"keyword"}}}});var G=M+"|"+A,B=n(/\/(?![*/])|\/\/[^\r\n]*[\r\n]|\/\*(?:[^*]|\*(?!\/))*\*\/|<<0>>/.source,[G]),H=a(n(/[^"'/()]|<<0>>|\(<<self>>*\)/.source,[B]),2),Z=/\b(?:assembly|event|field|method|module|param|property|return|type)\b/.source,V=n(/<<0>>(?:\s*\(<<1>>*\))?/.source,[v,H]);t.languages.insertBefore("csharp","class-name",{attribute:{pattern:r(/((?:^|[^\s\w>)?])\s*\[\s*)(?:<<0>>\s*:\s*)?<<1>>(?:\s*,\s*<<1>>)*(?=\s*\])/.source,[Z,V]),lookbehind:!0,greedy:!0,inside:{target:{pattern:r(/^<<0>>(?=\s*:)/.source,[Z]),alias:"keyword"},"attribute-arguments":{pattern:r(/\(<<0>>*\)/.source,[H]),inside:t.languages.csharp},"class-name":{pattern:RegExp(v),inside:{punctuation:/\./}},punctuation:/[:,]/}}});var q=/:[^}\r\n]+/.source,X=a(n(/[^"'/()]|<<0>>|\(<<self>>*\)/.source,[B]),2),$=n(/\{(?!\{)(?:(?![}:])<<0>>)*<<1>>?\}/.source,[X,q]),Q=a(n(/[^"'/()]|\/(?!\*)|\/\*(?:[^*]|\*(?!\/))*\*\/|<<0>>|\(<<self>>*\)/.source,[G]),2),J=n(/\{(?!\{)(?:(?![}:])<<0>>)*<<1>>?\}/.source,[Q,q]);function ie(F,Y){return{interpolation:{pattern:r(/((?:^|[^{])(?:\{\{)*)<<0>>/.source,[F]),lookbehind:!0,inside:{"format-string":{pattern:r(/(^\{(?:(?![}:])<<0>>)*)<<1>>(?=\}$)/.source,[Y,q]),lookbehind:!0,inside:{punctuation:/^:/}},punctuation:/^\{|\}$/,expression:{pattern:/[\s\S]+/,alias:"language-csharp",inside:t.languages.csharp}}},string:/[\s\S]+/}}t.languages.insertBefore("csharp","string",{"interpolation-string":[{pattern:r(/(^|[^\\])(?:\$@|@\$)"(?:""|\\[\s\S]|\{\{|<<0>>|[^\\{"])*"/.source,[$]),lookbehind:!0,greedy:!0,inside:ie($,X)},{pattern:r(/(^|[^@\\])\$"(?:\\.|\{\{|<<0>>|[^\\"{])*"/.source,[J]),lookbehind:!0,greedy:!0,inside:ie(J,Q)}],char:{pattern:RegExp(A),greedy:!0}}),t.languages.dotnet=t.languages.cs=t.languages.csharp})(e)}Ow.displayName="aspnet";Ow.aliases=[];function Ow(e){e.register(ku),e.register(cr),e.languages.aspnet=e.languages.extend("markup",{"page-directive":{pattern:/<%\s*@.*%>/,alias:"tag",inside:{"page-directive":{pattern:/<%\s*@\s*(?:Assembly|Control|Implements|Import|Master(?:Type)?|OutputCache|Page|PreviousPageType|Reference|Register)?|%>/i,alias:"tag"},rest:e.languages.markup.tag.inside}},directive:{pattern:/<%.*%>/,alias:"tag",inside:{directive:{pattern:/<%\s*?[$=%#:]{0,2}|%>/,alias:"tag"},rest:e.languages.csharp}}}),e.languages.aspnet.tag.pattern=/<(?!%)\/?[^\s>\/]+(?:\s+[^\s>\/=]+(?:=(?:("|')(?:\\[\s\S]|(?!\1)[^\\])*\1|[^\s'">=]+))?)*\s*\/?>/,e.languages.insertBefore("inside","punctuation",{directive:e.languages.aspnet.directive},e.languages.aspnet.tag.inside["attr-value"]),e.languages.insertBefore("aspnet","comment",{"asp-comment":{pattern:/<%--[\s\S]*?--%>/,alias:["asp","comment"]}}),e.languages.insertBefore("aspnet",e.languages.javascript?"script":"tag",{"asp-script":{pattern:/(<script(?=.*runat=['"]?server\b)[^>]*>)[\s\S]*?(?=<\/script>)/i,lookbehind:!0,alias:["asp","script"],inside:e.languages.csharp||{}}})}Iw.displayName="asm6502";Iw.aliases=[];function Iw(e){e.languages.asm6502={comment:/;.*/,directive:{pattern:/\.\w+(?= )/,alias:"property"},string:/(["'`])(?:\\.|(?!\1)[^\\\r\n])*\1/,"op-code":{pattern:/\b(?:ADC|AND|ASL|BCC|BCS|BEQ|BIT|BMI|BNE|BPL|BRK|BVC|BVS|CLC|CLD|CLI|CLV|CMP|CPX|CPY|DEC|DEX|DEY|EOR|INC|INX|INY|JMP|JSR|LDA|LDX|LDY|LSR|NOP|ORA|PHA|PHP|PLA|PLP|ROL|ROR|RTI|RTS|SBC|SEC|SED|SEI|STA|STX|STY|TAX|TAY|TSX|TXA|TXS|TYA|adc|and|asl|bcc|bcs|beq|bit|bmi|bne|bpl|brk|bvc|bvs|clc|cld|cli|clv|cmp|cpx|cpy|dec|dex|dey|eor|inc|inx|iny|jmp|jsr|lda|ldx|ldy|lsr|nop|ora|pha|php|pla|plp|rol|ror|rti|rts|sbc|sec|sed|sei|sta|stx|sty|tax|tay|tsx|txa|txs|tya)\b/,alias:"keyword"},"hex-number":{pattern:/#?\$[\da-f]{1,4}\b/i,alias:"number"},"binary-number":{pattern:/#?%[01]+\b/,alias:"number"},"decimal-number":{pattern:/#?\b\d+\b/,alias:"number"},register:{pattern:/\b[xya]\b/i,alias:"variable"},punctuation:/[(),:]/}}Lw.displayName="asmatmel";Lw.aliases=[];function Lw(e){e.languages.asmatmel={comment:{pattern:/;.*/,greedy:!0},string:{pattern:/(["'`])(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0},constant:/\b(?:PORT[A-Z]|DDR[A-Z]|(?:DD|P)[A-Z](?:\d|[0-2]\d|3[01]))\b/,directive:{pattern:/\.\w+(?= )/,alias:"property"},"r-register":{pattern:/\br(?:\d|[12]\d|3[01])\b/,alias:"variable"},"op-code":{pattern:/\b(?:ADC|ADD|ADIW|AND|ANDI|ASR|BCLR|BLD|BRBC|BRBS|BRCC|BRCS|BREAK|BREQ|BRGE|BRHC|BRHS|BRID|BRIE|BRLO|BRLT|BRMI|BRNE|BRPL|BRSH|BRTC|BRTS|BRVC|BRVS|BSET|BST|CALL|CBI|CBR|CLC|CLH|CLI|CLN|CLR|CLS|CLT|CLV|CLZ|COM|CP|CPC|CPI|CPSE|DEC|DES|EICALL|EIJMP|ELPM|EOR|FMUL|FMULS|FMULSU|ICALL|IJMP|IN|INC|JMP|LAC|LAS|LAT|LD|LD[A-Za-z0-9]|LPM|LSL|LSR|MOV|MOVW|MUL|MULS|MULSU|NEG|NOP|OR|ORI|OUT|POP|PUSH|RCALL|RET|RETI|RJMP|ROL|ROR|SBC|SBCI|SBI|SBIC|SBIS|SBIW|SBR|SBRC|SBRS|SEC|SEH|SEI|SEN|SER|SES|SET|SEV|SEZ|SLEEP|SPM|ST|ST[A-Z0-9]|SUB|SUBI|SWAP|TST|WDR|XCH|adc|add|adiw|and|andi|asr|bclr|bld|brbc|brbs|brcc|brcs|break|breq|brge|brhc|brhs|brid|brie|brlo|brlt|brmi|brne|brpl|brsh|brtc|brts|brvc|brvs|bset|bst|call|cbi|cbr|clc|clh|cli|cln|clr|cls|clt|clv|clz|com|cp|cpc|cpi|cpse|dec|des|eicall|eijmp|elpm|eor|fmul|fmuls|fmulsu|icall|ijmp|in|inc|jmp|lac|las|lat|ld|ld[a-z0-9]|lpm|lsl|lsr|mov|movw|mul|muls|mulsu|neg|nop|or|ori|out|pop|push|rcall|ret|reti|rjmp|rol|ror|sbc|sbci|sbi|sbic|sbis|sbiw|sbr|sbrc|sbrs|sec|seh|sei|sen|ser|ses|set|sev|sez|sleep|spm|st|st[a-zA-Z0-9]|sub|subi|swap|tst|wdr|xch)\b/,alias:"keyword"},"hex-number":{pattern:/#?\$[\da-f]{2,4}\b/i,alias:"number"},"binary-number":{pattern:/#?%[01]+\b/,alias:"number"},"decimal-number":{pattern:/#?\b\d+\b/,alias:"number"},register:{pattern:/\b[acznvshtixy]\b/i,alias:"variable"},operator:/>>=?|<<=?|&[&=]?|\|[\|=]?|[-+*/%^!=<>?]=?/,punctuation:/[(),:]/}}Dw.displayName="autohotkey";Dw.aliases=[];function Dw(e){e.languages.autohotkey={comment:[{pattern:/(^|\s);.*/,lookbehind:!0},{pattern:/(^[\t ]*)\/\*(?:[\r\n](?![ \t]*\*\/)|[^\r\n])*(?:[\r\n][ \t]*\*\/)?/m,lookbehind:!0,greedy:!0}],tag:{pattern:/^([ \t]*)[^\s,`":]+(?=:[ \t]*$)/m,lookbehind:!0},string:/"(?:[^"\n\r]|"")*"/,variable:/%\w+%/,number:/\b0x[\dA-Fa-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee]-?\d+)?/,operator:/\?|\/\/?=?|:=|\|[=|]?|&[=&]?|\+[=+]?|-[=-]?|\*[=*]?|<(?:<=?|>|=)?|>>?=?|[.^!=~]=?|\b(?:AND|NOT|OR)\b/,boolean:/\b(?:false|true)\b/,command:{pattern:/\b(?:AutoTrim|BlockInput|Break|Click|ClipWait|Continue|Control|ControlClick|ControlFocus|ControlGet|ControlGetFocus|ControlGetPos|ControlGetText|ControlMove|ControlSend|ControlSendRaw|ControlSetText|CoordMode|Critical|DetectHiddenText|DetectHiddenWindows|Drive|DriveGet|DriveSpaceFree|EnvAdd|EnvDiv|EnvGet|EnvMult|EnvSet|EnvSub|EnvUpdate|Exit|ExitApp|FileAppend|FileCopy|FileCopyDir|FileCreateDir|FileCreateShortcut|FileDelete|FileEncoding|FileGetAttrib|FileGetShortcut|FileGetSize|FileGetTime|FileGetVersion|FileInstall|FileMove|FileMoveDir|FileRead|FileReadLine|FileRecycle|FileRecycleEmpty|FileRemoveDir|FileSelectFile|FileSelectFolder|FileSetAttrib|FileSetTime|FormatTime|GetKeyState|Gosub|Goto|GroupActivate|GroupAdd|GroupClose|GroupDeactivate|Gui|GuiControl|GuiControlGet|Hotkey|ImageSearch|IniDelete|IniRead|IniWrite|Input|InputBox|KeyWait|ListHotkeys|ListLines|ListVars|Loop|Menu|MouseClick|MouseClickDrag|MouseGetPos|MouseMove|MsgBox|OnExit|OutputDebug|Pause|PixelGetColor|PixelSearch|PostMessage|Process|Progress|Random|RegDelete|RegRead|RegWrite|Reload|Repeat|Return|Run|RunAs|RunWait|Send|SendEvent|SendInput|SendMessage|SendMode|SendPlay|SendRaw|SetBatchLines|SetCapslockState|SetControlDelay|SetDefaultMouseSpeed|SetEnv|SetFormat|SetKeyDelay|SetMouseDelay|SetNumlockState|SetRegView|SetScrollLockState|SetStoreCapslockMode|SetTimer|SetTitleMatchMode|SetWinDelay|SetWorkingDir|Shutdown|Sleep|Sort|SoundBeep|SoundGet|SoundGetWaveVolume|SoundPlay|SoundSet|SoundSetWaveVolume|SplashImage|SplashTextOff|SplashTextOn|SplitPath|StatusBarGetText|StatusBarWait|StringCaseSense|StringGetPos|StringLeft|StringLen|StringLower|StringMid|StringReplace|StringRight|StringSplit|StringTrimLeft|StringTrimRight|StringUpper|Suspend|SysGet|Thread|ToolTip|Transform|TrayTip|URLDownloadToFile|WinActivate|WinActivateBottom|WinClose|WinGet|WinGetActiveStats|WinGetActiveTitle|WinGetClass|WinGetPos|WinGetText|WinGetTitle|WinHide|WinKill|WinMaximize|WinMenuSelectItem|WinMinimize|WinMinimizeAll|WinMinimizeAllUndo|WinMove|WinRestore|WinSet|WinSetTitle|WinShow|WinWait|WinWaitActive|WinWaitClose|WinWaitNotActive)\b/i,alias:"selector"},constant:/\b(?:a_ahkpath|a_ahkversion|a_appdata|a_appdatacommon|a_autotrim|a_batchlines|a_caretx|a_carety|a_computername|a_controldelay|a_cursor|a_dd|a_ddd|a_dddd|a_defaultmousespeed|a_desktop|a_desktopcommon|a_detecthiddentext|a_detecthiddenwindows|a_endchar|a_eventinfo|a_exitreason|a_fileencoding|a_formatfloat|a_formatinteger|a_gui|a_guicontrol|a_guicontrolevent|a_guievent|a_guiheight|a_guiwidth|a_guix|a_guiy|a_hour|a_iconfile|a_iconhidden|a_iconnumber|a_icontip|a_index|a_ipaddress1|a_ipaddress2|a_ipaddress3|a_ipaddress4|a_is64bitos|a_isadmin|a_iscompiled|a_iscritical|a_ispaused|a_issuspended|a_isunicode|a_keydelay|a_language|a_lasterror|a_linefile|a_linenumber|a_loopfield|a_loopfileattrib|a_loopfiledir|a_loopfileext|a_loopfilefullpath|a_loopfilelongpath|a_loopfilename|a_loopfileshortname|a_loopfileshortpath|a_loopfilesize|a_loopfilesizekb|a_loopfilesizemb|a_loopfiletimeaccessed|a_loopfiletimecreated|a_loopfiletimemodified|a_loopreadline|a_loopregkey|a_loopregname|a_loopregsubkey|a_loopregtimemodified|a_loopregtype|a_mday|a_min|a_mm|a_mmm|a_mmmm|a_mon|a_mousedelay|a_msec|a_mydocuments|a_now|a_nowutc|a_numbatchlines|a_ostype|a_osversion|a_priorhotkey|a_priorkey|a_programfiles|a_programs|a_programscommon|a_ptrsize|a_regview|a_screendpi|a_screenheight|a_screenwidth|a_scriptdir|a_scriptfullpath|a_scripthwnd|a_scriptname|a_sec|a_space|a_startmenu|a_startmenucommon|a_startup|a_startupcommon|a_stringcasesense|a_tab|a_temp|a_thisfunc|a_thishotkey|a_thislabel|a_thismenu|a_thismenuitem|a_thismenuitempos|a_tickcount|a_timeidle|a_timeidlephysical|a_timesincepriorhotkey|a_timesincethishotkey|a_titlematchmode|a_titlematchmodespeed|a_username|a_wday|a_windelay|a_windir|a_workingdir|a_yday|a_year|a_yweek|a_yyyy|clipboard|clipboardall|comspec|errorlevel|programfiles)\b/i,builtin:/\b(?:abs|acos|asc|asin|atan|ceil|chr|class|comobjactive|comobjarray|comobjconnect|comobjcreate|comobjerror|comobjflags|comobjget|comobjquery|comobjtype|comobjvalue|cos|dllcall|exp|fileexist|Fileopen|floor|format|il_add|il_create|il_destroy|instr|isfunc|islabel|IsObject|ln|log|ltrim|lv_add|lv_delete|lv_deletecol|lv_getcount|lv_getnext|lv_gettext|lv_insert|lv_insertcol|lv_modify|lv_modifycol|lv_setimagelist|mod|numget|numput|onmessage|regexmatch|regexreplace|registercallback|round|rtrim|sb_seticon|sb_setparts|sb_settext|sin|sqrt|strlen|strreplace|strsplit|substr|tan|tv_add|tv_delete|tv_get|tv_getchild|tv_getcount|tv_getnext|tv_getparent|tv_getprev|tv_getselection|tv_gettext|tv_modify|varsetcapacity|winactive|winexist|__Call|__Get|__New|__Set)\b/i,symbol:/\b(?:alt|altdown|altup|appskey|backspace|browser_back|browser_favorites|browser_forward|browser_home|browser_refresh|browser_search|browser_stop|bs|capslock|ctrl|ctrlbreak|ctrldown|ctrlup|del|delete|down|end|enter|esc|escape|f1|f10|f11|f12|f13|f14|f15|f16|f17|f18|f19|f2|f20|f21|f22|f23|f24|f3|f4|f5|f6|f7|f8|f9|home|ins|insert|joy1|joy10|joy11|joy12|joy13|joy14|joy15|joy16|joy17|joy18|joy19|joy2|joy20|joy21|joy22|joy23|joy24|joy25|joy26|joy27|joy28|joy29|joy3|joy30|joy31|joy32|joy4|joy5|joy6|joy7|joy8|joy9|joyaxes|joybuttons|joyinfo|joyname|joypov|joyr|joyu|joyv|joyx|joyy|joyz|lalt|launch_app1|launch_app2|launch_mail|launch_media|lbutton|lcontrol|lctrl|left|lshift|lwin|lwindown|lwinup|mbutton|media_next|media_play_pause|media_prev|media_stop|numlock|numpad0|numpad1|numpad2|numpad3|numpad4|numpad5|numpad6|numpad7|numpad8|numpad9|numpadadd|numpadclear|numpaddel|numpaddiv|numpaddot|numpaddown|numpadend|numpadenter|numpadhome|numpadins|numpadleft|numpadmult|numpadpgdn|numpadpgup|numpadright|numpadsub|numpadup|pgdn|pgup|printscreen|ralt|rbutton|rcontrol|rctrl|right|rshift|rwin|rwindown|rwinup|scrolllock|shift|shiftdown|shiftup|space|tab|up|volume_down|volume_mute|volume_up|wheeldown|wheelleft|wheelright|wheelup|xbutton1|xbutton2)\b/i,directive:{pattern:/#[a-z]+\b/i,alias:"important"},keyword:/\b(?:Abort|AboveNormal|Add|ahk_class|ahk_exe|ahk_group|ahk_id|ahk_pid|All|Alnum|Alpha|AltSubmit|AltTab|AltTabAndMenu|AltTabMenu|AltTabMenuDismiss|AlwaysOnTop|AutoSize|Background|BackgroundTrans|BelowNormal|between|BitAnd|BitNot|BitOr|BitShiftLeft|BitShiftRight|BitXOr|Bold|Border|Button|ByRef|Catch|Checkbox|Checked|CheckedGray|Choose|ChooseString|Close|Color|ComboBox|Contains|ControlList|Count|Date|DateTime|Days|DDL|Default|DeleteAll|Delimiter|Deref|Destroy|Digit|Disable|Disabled|DropDownList|Edit|Eject|Else|Enable|Enabled|Error|Exist|Expand|ExStyle|FileSystem|Finally|First|Flash|Float|FloatFast|Focus|Font|for|global|Grid|Group|GroupBox|GuiClose|GuiContextMenu|GuiDropFiles|GuiEscape|GuiSize|Hdr|Hidden|Hide|High|HKCC|HKCR|HKCU|HKEY_CLASSES_ROOT|HKEY_CURRENT_CONFIG|HKEY_CURRENT_USER|HKEY_LOCAL_MACHINE|HKEY_USERS|HKLM|HKU|Hours|HScroll|Icon|IconSmall|ID|IDLast|If|IfEqual|IfExist|IfGreater|IfGreaterOrEqual|IfInString|IfLess|IfLessOrEqual|IfMsgBox|IfNotEqual|IfNotExist|IfNotInString|IfWinActive|IfWinExist|IfWinNotActive|IfWinNotExist|Ignore|ImageList|in|Integer|IntegerFast|Interrupt|is|italic|Join|Label|LastFound|LastFoundExist|Limit|Lines|List|ListBox|ListView|local|Lock|Logoff|Low|Lower|Lowercase|MainWindow|Margin|Maximize|MaximizeBox|MaxSize|Minimize|MinimizeBox|MinMax|MinSize|Minutes|MonthCal|Mouse|Move|Multi|NA|No|NoActivate|NoDefault|NoHide|NoIcon|NoMainWindow|norm|Normal|NoSort|NoSortHdr|NoStandard|Not|NoTab|NoTimers|Number|Off|Ok|On|OwnDialogs|Owner|Parse|Password|Picture|Pixel|Pos|Pow|Priority|ProcessName|Radio|Range|Read|ReadOnly|Realtime|Redraw|Region|REG_BINARY|REG_DWORD|REG_EXPAND_SZ|REG_MULTI_SZ|REG_SZ|Relative|Rename|Report|Resize|Restore|Retry|RGB|Screen|Seconds|Section|Serial|SetLabel|ShiftAltTab|Show|Single|Slider|SortDesc|Standard|static|Status|StatusBar|StatusCD|strike|Style|Submit|SysMenu|Tab2|TabStop|Text|Theme|Throw|Tile|ToggleCheck|ToggleEnable|ToolWindow|Top|Topmost|TransColor|Transparent|Tray|TreeView|Try|TryAgain|Type|UnCheck|underline|Unicode|Unlock|Until|UpDown|Upper|Uppercase|UseErrorLevel|Vis|VisFirst|Visible|VScroll|Wait|WaitClose|WantCtrlA|WantF2|WantReturn|While|Wrap|Xdigit|xm|xp|xs|Yes|ym|yp|ys)\b/i,function:/[^(); \t,\n+*\-=?>:\\\/<&%\[\]]+(?=\()/,punctuation:/[{}[\]():,]/}}Mw.displayName="autoit";Mw.aliases=[];function Mw(e){e.languages.autoit={comment:[/;.*/,{pattern:/(^[\t ]*)#(?:comments-start|cs)[\s\S]*?^[ \t]*#(?:ce|comments-end)/m,lookbehind:!0}],url:{pattern:/(^[\t ]*#include\s+)(?:<[^\r\n>]+>|"[^\r\n"]+")/m,lookbehind:!0},string:{pattern:/(["'])(?:\1\1|(?!\1)[^\r\n])*\1/,greedy:!0,inside:{variable:/([%$@])\w+\1/}},directive:{pattern:/(^[\t ]*)#[\w-]+/m,lookbehind:!0,alias:"keyword"},function:/\b\w+(?=\()/,variable:/[$@]\w+/,keyword:/\b(?:Case|Const|Continue(?:Case|Loop)|Default|Dim|Do|Else(?:If)?|End(?:Func|If|Select|Switch|With)|Enum|Exit(?:Loop)?|For|Func|Global|If|In|Local|Next|Null|ReDim|Select|Static|Step|Switch|Then|To|Until|Volatile|WEnd|While|With)\b/i,number:/\b(?:0x[\da-f]+|\d+(?:\.\d+)?(?:e[+-]?\d+)?)\b/i,boolean:/\b(?:False|True)\b/i,operator:/<[=>]?|[-+*\/=&>]=?|[?^]|\b(?:And|Not|Or)\b/i,punctuation:/[\[\]().,:]/}}Bw.displayName="avisynth";Bw.aliases=["avs"];function Bw(e){(function(t){function n(d,h){return d.replace(/<<(\d+)>>/g,function(f,m){return h[+m]})}function r(d,h,f){return RegExp(n(d,h),f)}var a=/bool|clip|float|int|string|val/.source,i=[/is(?:bool|clip|float|int|string)|defined|(?:(?:internal)?function|var)?exists?/.source,/apply|assert|default|eval|import|nop|select|undefined/.source,/opt_(?:allowfloataudio|avipadscanlines|dwchannelmask|enable_(?:b64a|planartopackedrgb|v210|y3_10_10|y3_10_16)|usewaveextensible|vdubplanarhack)|set(?:cachemode|maxcpu|memorymax|planarlegacyalignment|workingdir)/.source,/hex(?:value)?|value/.source,/abs|ceil|continued(?:denominator|numerator)?|exp|floor|fmod|frac|log(?:10)?|max|min|muldiv|pi|pow|rand|round|sign|spline|sqrt/.source,/a?sinh?|a?cosh?|a?tan[2h]?/.source,/(?:bit(?:and|not|x?or|[lr]?shift[aslu]?|sh[lr]|sa[lr]|[lr]rotatel?|ro[rl]|te?st|set(?:count)?|cl(?:ea)?r|ch(?:an)?ge?))/.source,/average(?:[bgr]|chroma[uv]|luma)|(?:[rgb]|chroma[uv]|luma|rgb|[yuv](?=difference(?:fromprevious|tonext)))difference(?:fromprevious|tonext)?|[yuvrgb]plane(?:median|min|max|minmaxdifference)/.source,/getprocessinfo|logmsg|script(?:dir(?:utf8)?|file(?:utf8)?|name(?:utf8)?)|setlogparams/.source,/chr|(?:fill|find|left|mid|replace|rev|right)str|format|[lu]case|ord|str(?:cmpi?|fromutf8|len|toutf8)|time|trim(?:all|left|right)/.source,/isversionorgreater|version(?:number|string)/.source,/buildpixeltype|colorspacenametopixeltype/.source,/addautoloaddir|on(?:cpu|cuda)|prefetch|setfiltermtmode/.source].join("|"),o=[/has(?:audio|video)/.source,/height|width/.source,/frame(?:count|rate)|framerate(?:denominator|numerator)/.source,/getparity|is(?:field|frame)based/.source,/bitspercomponent|componentsize|hasalpha|is(?:planar(?:rgba?)?|interleaved|rgb(?:24|32|48|64)?|y(?:8|u(?:va?|y2))?|yv(?:12|16|24|411)|420|422|444|packedrgb)|numcomponents|pixeltype/.source,/audio(?:bits|channels|duration|length(?:[fs]|hi|lo)?|rate)|isaudio(?:float|int)/.source].join("|"),l=[/avi(?:file)?source|directshowsource|image(?:reader|source|sourceanim)|opendmlsource|segmented(?:avisource|directshowsource)|wavsource/.source,/coloryuv|convertbacktoyuy2|convertto(?:RGB(?:24|32|48|64)|(?:planar)?RGBA?|Y8?|YV(?:12|16|24|411)|YUVA?(?:411|420|422|444)|YUY2)|fixluminance|gr[ae]yscale|invert|levels|limiter|mergea?rgb|merge(?:chroma|luma)|rgbadjust|show(?:alpha|blue|green|red)|swapuv|tweak|[uv]toy8?|ytouv/.source,/(?:colorkey|reset)mask|layer|mask(?:hs)?|merge|overlay|subtract/.source,/addborders|(?:bicubic|bilinear|blackman|gauss|lanczos4|lanczos|point|sinc|spline(?:16|36|64))resize|crop(?:bottom)?|flip(?:horizontal|vertical)|(?:horizontal|vertical)?reduceby2|letterbox|skewrows|turn(?:180|left|right)/.source,/blur|fixbrokenchromaupsampling|generalconvolution|(?:spatial|temporal)soften|sharpen/.source,/trim|(?:un)?alignedsplice|(?:assume|assumescaled|change|convert)FPS|(?:delete|duplicate)frame|dissolve|fade(?:in|io|out)[02]?|freezeframe|interleave|loop|reverse|select(?:even|odd|(?:range)?every)/.source,/assume[bt]ff|assume(?:field|frame)based|bob|complementparity|doubleweave|peculiarblend|pulldown|separate(?:columns|fields|rows)|swapfields|weave(?:columns|rows)?/.source,/amplify(?:db)?|assumesamplerate|audiodub(?:ex)?|audiotrim|convertaudioto(?:(?:8|16|24|32)bit|float)|converttomono|delayaudio|ensurevbrmp3sync|get(?:left|right)?channel|kill(?:audio|video)|mergechannels|mixaudio|monotostereo|normalize|resampleaudio|ssrc|supereq|timestretch/.source,/animate|applyrange|conditional(?:filter|reader|select)|frameevaluate|scriptclip|tcp(?:server|source)|writefile(?:end|if|start)?/.source,/imagewriter/.source,/blackness|blankclip|colorbars(?:hd)?|compare|dumpfiltergraph|echo|histogram|info|messageclip|preroll|setgraphanalysis|show(?:framenumber|smpte|time)|showfiveversions|stack(?:horizontal|vertical)|subtitle|tone|version/.source].join("|"),u=[i,o,l].join("|");t.languages.avisynth={comment:[{pattern:/(^|[^\\])\[\*(?:[^\[*]|\[(?!\*)|\*(?!\])|\[\*(?:[^\[*]|\[(?!\*)|\*(?!\]))*\*\])*\*\]/,lookbehind:!0,greedy:!0},{pattern:/(^|[^\\])\/\*[\s\S]*?(?:\*\/|$)/,lookbehind:!0,greedy:!0},{pattern:/(^|[^\\$])#.*/,lookbehind:!0,greedy:!0}],argument:{pattern:r(/\b(?:<<0>>)\s+("?)\w+\1/.source,[a],"i"),inside:{keyword:/^\w+/}},"argument-label":{pattern:/([,(][\s\\]*)\w+\s*=(?!=)/,lookbehind:!0,inside:{"argument-name":{pattern:/^\w+/,alias:"punctuation"},punctuation:/=$/}},string:[{pattern:/"""[\s\S]*?"""/,greedy:!0},{pattern:/"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"/,greedy:!0,inside:{constant:{pattern:/\b(?:DEFAULT_MT_MODE|(?:MAINSCRIPT|PROGRAM|SCRIPT)DIR|(?:MACHINE|USER)_(?:CLASSIC|PLUS)_PLUGINS)\b/}}}],variable:/\b(?:last)\b/i,boolean:/\b(?:false|no|true|yes)\b/i,keyword:/\b(?:catch|else|for|function|global|if|return|try|while|__END__)\b/i,constant:/\bMT_(?:MULTI_INSTANCE|NICE_FILTER|SERIALIZED|SPECIAL_MT)\b/,"builtin-function":{pattern:r(/\b(?:<<0>>)\b/.source,[u],"i"),alias:"function"},"type-cast":{pattern:r(/\b(?:<<0>>)(?=\s*\()/.source,[a],"i"),alias:"keyword"},function:{pattern:/\b[a-z_]\w*(?=\s*\()|(\.)[a-z_]\w*\b/i,lookbehind:!0},"line-continuation":{pattern:/(^[ \t]*)\\|\\(?=[ \t]*$)/m,lookbehind:!0,alias:"punctuation"},number:/\B\$(?:[\da-f]{6}|[\da-f]{8})\b|(?:(?:\b|\B-)\d+(?:\.\d*)?\b|\B\.\d+\b)/i,operator:/\+\+?|[!=<>]=?|&&|\|\||[?:*/%-]/,punctuation:/[{}\[\]();,.]/},t.languages.avs=t.languages.avisynth})(e)}Fw.displayName="avro-idl";Fw.aliases=["avdl"];function Fw(e){e.languages["avro-idl"]={comment:{pattern:/\/\/.*|\/\*[\s\S]*?\*\//,greedy:!0},string:{pattern:/(^|[^\\])"(?:[^\r\n"\\]|\\.)*"/,lookbehind:!0,greedy:!0},annotation:{pattern:/@(?:[$\w.-]|`[^\r\n`]+`)+/,greedy:!0,alias:"function"},"function-identifier":{pattern:/`[^\r\n`]+`(?=\s*\()/,greedy:!0,alias:"function"},identifier:{pattern:/`[^\r\n`]+`/,greedy:!0},"class-name":{pattern:/(\b(?:enum|error|protocol|record|throws)\b\s+)[$\w]+/,lookbehind:!0,greedy:!0},keyword:/\b(?:array|boolean|bytes|date|decimal|double|enum|error|false|fixed|float|idl|import|int|local_timestamp_ms|long|map|null|oneway|protocol|record|schema|string|throws|time_ms|timestamp_ms|true|union|uuid|void)\b/,function:/\b[a-z_]\w*(?=\s*\()/i,number:[{pattern:/(^|[^\w.])-?(?:(?:\d+(?:\.\d*)?|\.\d+)(?:e[+-]?\d+)?|0x(?:[a-f0-9]+(?:\.[a-f0-9]*)?|\.[a-f0-9]+)(?:p[+-]?\d+)?)[dfl]?(?![\w.])/i,lookbehind:!0},/-?\b(?:Infinity|NaN)\b/],operator:/=/,punctuation:/[()\[\]{}<>.:,;-]/},e.languages.avdl=e.languages["avro-idl"]}zw.displayName="awk";zw.aliases=["gawk"];function zw(e){e.languages.awk={hashbang:{pattern:/^#!.*/,greedy:!0,alias:"comment"},comment:{pattern:/#.*/,greedy:!0},string:{pattern:/(^|[^\\])"(?:[^\\"\r\n]|\\.)*"/,lookbehind:!0,greedy:!0},regex:{pattern:/((?:^|[^\w\s)])\s*)\/(?:[^\/\\\r\n]|\\.)*\//,lookbehind:!0,greedy:!0},variable:/\$\w+/,keyword:/\b(?:BEGIN|BEGINFILE|END|ENDFILE|break|case|continue|default|delete|do|else|exit|for|function|getline|if|in|next|nextfile|printf?|return|switch|while)\b|@(?:include|load)\b/,function:/\b[a-z_]\w*(?=\s*\()/i,number:/\b(?:\d+(?:\.\d+)?(?:e[+-]?\d+)?|0x[a-fA-F0-9]+)\b/,operator:/--|\+\+|!?~|>&|>>|<<|(?:\*\*|[<>!=+\-*/%^])=?|&&|\|[|&]|[?:]/,punctuation:/[()[\]{},;]/},e.languages.gawk=e.languages.awk}Ig.displayName="basic";Ig.aliases=[];function Ig(e){e.languages.basic={comment:{pattern:/(?:!|REM\b).+/i,inside:{keyword:/^REM/i}},string:{pattern:/"(?:""|[!#$%&'()*,\/:;<=>?^\w +\-.])*"/,greedy:!0},number:/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:E[+-]?\d+)?/i,keyword:/\b(?:AS|BEEP|BLOAD|BSAVE|CALL(?: ABSOLUTE)?|CASE|CHAIN|CHDIR|CLEAR|CLOSE|CLS|COM|COMMON|CONST|DATA|DECLARE|DEF(?: FN| SEG|DBL|INT|LNG|SNG|STR)|DIM|DO|DOUBLE|ELSE|ELSEIF|END|ENVIRON|ERASE|ERROR|EXIT|FIELD|FILES|FOR|FUNCTION|GET|GOSUB|GOTO|IF|INPUT|INTEGER|IOCTL|KEY|KILL|LINE INPUT|LOCATE|LOCK|LONG|LOOP|LSET|MKDIR|NAME|NEXT|OFF|ON(?: COM| ERROR| KEY| TIMER)?|OPEN|OPTION BASE|OUT|POKE|PUT|READ|REDIM|REM|RESTORE|RESUME|RETURN|RMDIR|RSET|RUN|SELECT CASE|SHARED|SHELL|SINGLE|SLEEP|STATIC|STEP|STOP|STRING|SUB|SWAP|SYSTEM|THEN|TIMER|TO|TROFF|TRON|TYPE|UNLOCK|UNTIL|USING|VIEW PRINT|WAIT|WEND|WHILE|WRITE)(?:\$|\b)/i,function:/\b(?:ABS|ACCESS|ACOS|ANGLE|AREA|ARITHMETIC|ARRAY|ASIN|ASK|AT|ATN|BASE|BEGIN|BREAK|CAUSE|CEIL|CHR|CLIP|COLLATE|COLOR|CON|COS|COSH|COT|CSC|DATE|DATUM|DEBUG|DECIMAL|DEF|DEG|DEGREES|DELETE|DET|DEVICE|DISPLAY|DOT|ELAPSED|EPS|ERASABLE|EXLINE|EXP|EXTERNAL|EXTYPE|FILETYPE|FIXED|FP|GO|GRAPH|HANDLER|IDN|IMAGE|IN|INT|INTERNAL|IP|IS|KEYED|LBOUND|LCASE|LEFT|LEN|LENGTH|LET|LINE|LINES|LOG|LOG10|LOG2|LTRIM|MARGIN|MAT|MAX|MAXNUM|MID|MIN|MISSING|MOD|NATIVE|NUL|NUMERIC|OF|OPTION|ORD|ORGANIZATION|OUTIN|OUTPUT|PI|POINT|POINTER|POINTS|POS|PRINT|PROGRAM|PROMPT|RAD|RADIANS|RANDOMIZE|RECORD|RECSIZE|RECTYPE|RELATIVE|REMAINDER|REPEAT|REST|RETRY|REWRITE|RIGHT|RND|ROUND|RTRIM|SAME|SEC|SELECT|SEQUENTIAL|SET|SETTER|SGN|SIN|SINH|SIZE|SKIP|SQR|STANDARD|STATUS|STR|STREAM|STYLE|TAB|TAN|TANH|TEMPLATE|TEXT|THERE|TIME|TIMEOUT|TRACE|TRANSFORM|TRUNCATE|UBOUND|UCASE|USE|VAL|VARIABLE|VIEWPORT|WHEN|WINDOW|WITH|ZER|ZONEWIDTH)(?:\$|\b)/i,operator:/<[=>]?|>=?|[+\-*\/^=&]|\b(?:AND|EQV|IMP|NOT|OR|XOR)\b/i,punctuation:/[,;:()]/}}$w.displayName="batch";$w.aliases=[];function $w(e){(function(t){var n=/%%?[~:\w]+%?|!\S+!/,r={pattern:/\/[a-z?]+(?=[ :]|$):?|-[a-z]\b|--[a-z-]+\b/im,alias:"attr-name",inside:{punctuation:/:/}},a=/"(?:[\\"]"|[^"])*"(?!")/,i=/(?:\b|-)\d+\b/;t.languages.batch={comment:[/^::.*/m,{pattern:/((?:^|[&(])[ \t]*)rem\b(?:[^^&)\r\n]|\^(?:\r\n|[\s\S]))*/im,lookbehind:!0}],label:{pattern:/^:.*/m,alias:"property"},command:[{pattern:/((?:^|[&(])[ \t]*)for(?: \/[a-z?](?:[ :](?:"[^"]*"|[^\s"/]\S*))?)* \S+ in \([^)]+\) do/im,lookbehind:!0,inside:{keyword:/\b(?:do|in)\b|^for\b/i,string:a,parameter:r,variable:n,number:i,punctuation:/[()',]/}},{pattern:/((?:^|[&(])[ \t]*)if(?: \/[a-z?](?:[ :](?:"[^"]*"|[^\s"/]\S*))?)* (?:not )?(?:cmdextversion \d+|defined \w+|errorlevel \d+|exist \S+|(?:"[^"]*"|(?!")(?:(?!==)\S)+)?(?:==| (?:equ|geq|gtr|leq|lss|neq) )(?:"[^"]*"|[^\s"]\S*))/im,lookbehind:!0,inside:{keyword:/\b(?:cmdextversion|defined|errorlevel|exist|not)\b|^if\b/i,string:a,parameter:r,variable:n,number:i,operator:/\^|==|\b(?:equ|geq|gtr|leq|lss|neq)\b/i}},{pattern:/((?:^|[&()])[ \t]*)else\b/im,lookbehind:!0,inside:{keyword:/^else\b/i}},{pattern:/((?:^|[&(])[ \t]*)set(?: \/[a-z](?:[ :](?:"[^"]*"|[^\s"/]\S*))?)* (?:[^^&)\r\n]|\^(?:\r\n|[\s\S]))*/im,lookbehind:!0,inside:{keyword:/^set\b/i,string:a,parameter:r,variable:[n,/\w+(?=(?:[*\/%+\-&^|]|<<|>>)?=)/],number:i,operator:/[*\/%+\-&^|]=?|<<=?|>>=?|[!~_=]/,punctuation:/[()',]/}},{pattern:/((?:^|[&(])[ \t]*@?)\w+\b(?:"(?:[\\"]"|[^"])*"(?!")|[^"^&)\r\n]|\^(?:\r\n|[\s\S]))*/m,lookbehind:!0,inside:{keyword:/^\w+\b/,string:a,parameter:r,label:{pattern:/(^\s*):\S+/m,lookbehind:!0,alias:"property"},variable:n,number:i,operator:/\^/}}],operator:/[&@]/,punctuation:/[()']/}})(e)}Pw.displayName="bbcode";Pw.aliases=["shortcode"];function Pw(e){e.languages.bbcode={tag:{pattern:/\[\/?[^\s=\]]+(?:\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'"\]=]+))?(?:\s+[^\s=\]]+\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'"\]=]+))*\s*\]/,inside:{tag:{pattern:/^\[\/?[^\s=\]]+/,inside:{punctuation:/^\[\/?/}},"attr-value":{pattern:/=\s*(?:"[^"]*"|'[^']*'|[^\s'"\]=]+)/,inside:{punctuation:[/^=/,{pattern:/^(\s*)["']|["']$/,lookbehind:!0}]}},punctuation:/\]/,"attr-name":/[^\s=\]]+/}}},e.languages.shortcode=e.languages.bbcode}Uw.displayName="bbj";Uw.aliases=[];function Uw(e){(function(t){t.languages.bbj={comment:{pattern:/(^|[^\\:])rem\s+.*/i,lookbehind:!0,greedy:!0},string:{pattern:/(['"])(?:(?!\1|\\).|\\.)*\1/,greedy:!0},number:/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:E[+-]?\d+)?/i,keyword:/\b(?:abstract|all|argc|begin|bye|callback|case|chn|class|classend|ctl|day|declare|delete|dim|dom|dread|dsz|else|end|endif|err|exitto|extends|fi|field|for|from|gosub|goto|if|implements|interface|interfaceend|iol|iolist|let|list|load|method|methodend|methodret|on|opts|pfx|print|private|process_events|protected|psz|public|read|read_resource|release|remove_callback|repeat|restore|return|rev|seterr|setesc|sqlchn|sqlunt|ssn|start|static|swend|switch|sys|then|tim|unt|until|use|void|wend|where|while)\b/i,function:/\b\w+(?=\()/,boolean:/\b(?:BBjAPI\.TRUE|BBjAPI\.FALSE)\b/i,operator:/<[=>]?|>=?|[+\-*\/^=&]|\b(?:and|not|or|xor)\b/i,punctuation:/[.,;:()]/}})(e)}jw.displayName="bicep";jw.aliases=[];function jw(e){e.languages.bicep={comment:[{pattern:/(^|[^\\])\/\*[\s\S]*?(?:\*\/|$)/,lookbehind:!0,greedy:!0},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0,greedy:!0}],property:[{pattern:/([\r\n][ \t]*)[a-z_]\w*(?=[ \t]*:)/i,lookbehind:!0},{pattern:/([\r\n][ \t]*)'(?:\\.|\$(?!\{)|[^'\\\r\n$])*'(?=[ \t]*:)/,lookbehind:!0,greedy:!0}],string:[{pattern:/'''[^'][\s\S]*?'''/,greedy:!0},{pattern:/(^|[^\\'])'(?:\\.|\$(?!\{)|[^'\\\r\n$])*'/,lookbehind:!0,greedy:!0}],"interpolated-string":{pattern:/(^|[^\\'])'(?:\\.|\$(?:(?!\{)|\{[^{}\r\n]*\})|[^'\\\r\n$])*'/,lookbehind:!0,greedy:!0,inside:{interpolation:{pattern:/\$\{[^{}\r\n]*\}/,inside:{expression:{pattern:/(^\$\{)[\s\S]+(?=\}$)/,lookbehind:!0},punctuation:/^\$\{|\}$/}},string:/[\s\S]+/}},datatype:{pattern:/(\b(?:output|param)\b[ \t]+\w+[ \t]+)\w+\b/,lookbehind:!0,alias:"class-name"},boolean:/\b(?:false|true)\b/,keyword:/\b(?:existing|for|if|in|module|null|output|param|resource|targetScope|var)\b/,decorator:/@\w+\b/,function:/\b[a-z_]\w*(?=[ \t]*\()/i,number:/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:E[+-]?\d+)?/i,operator:/--|\+\+|\*\*=?|=>|&&=?|\|\|=?|[!=]==|<<=?|>>>?=?|[-+*/%&|^!=<>]=?|\.{3}|\?\?=?|\?\.?|[~:]/,punctuation:/[{}[\];(),.:]/},e.languages.bicep["interpolated-string"].inside.interpolation.inside.expression.inside=e.languages.bicep}Hw.displayName="birb";Hw.aliases=[];function Hw(e){e.register(Mt),e.languages.birb=e.languages.extend("clike",{string:{pattern:/r?("|')(?:\\.|(?!\1)[^\\])*\1/,greedy:!0},"class-name":[/\b[A-Z](?:[\d_]*[a-zA-Z]\w*)?\b/,/\b(?:[A-Z]\w*|(?!(?:var|void)\b)[a-z]\w*)(?=\s+\w+\s*[;,=()])/],keyword:/\b(?:assert|break|case|class|const|default|else|enum|final|follows|for|grab|if|nest|new|next|noSeeb|return|static|switch|throw|var|void|while)\b/,operator:/\+\+|--|&&|\|\||<<=?|>>=?|~(?:\/=?)?|[+\-*\/%&^|=!<>]=?|\?|:/,variable:/\b[a-z_]\w*\b/}),e.languages.insertBefore("birb","function",{metadata:{pattern:/<\w+>/,greedy:!0,alias:"symbol"}})}Gw.displayName="bison";Gw.aliases=[];function Gw(e){e.register($i),e.languages.bison=e.languages.extend("c",{}),e.languages.insertBefore("bison","comment",{bison:{pattern:/^(?:[^%]|%(?!%))*%%[\s\S]*?%%/,inside:{c:{pattern:/%\{[\s\S]*?%\}|\{(?:\{[^}]*\}|[^{}])*\}/,inside:{delimiter:{pattern:/^%?\{|%?\}$/,alias:"punctuation"},"bison-variable":{pattern:/[$@](?:<[^\s>]+>)?[\w$]+/,alias:"variable",inside:{punctuation:/<|>/}},rest:e.languages.c}},comment:e.languages.c.comment,string:e.languages.c.string,property:/\S+(?=:)/,keyword:/%\w+/,number:{pattern:/(^|[^@])\b(?:0x[\da-f]+|\d+)/i,lookbehind:!0},punctuation:/%[%?]|[|:;\[\]<>]/}}})}qw.displayName="bnf";qw.aliases=["rbnf"];function qw(e){e.languages.bnf={string:{pattern:/"[^\r\n"]*"|'[^\r\n']*'/},definition:{pattern:/<[^<>\r\n\t]+>(?=\s*::=)/,alias:["rule","keyword"],inside:{punctuation:/^<|>$/}},rule:{pattern:/<[^<>\r\n\t]+>/,inside:{punctuation:/^<|>$/}},operator:/::=|[|()[\]{}*+?]|\.{3}/},e.languages.rbnf=e.languages.bnf}Ww.displayName="bqn";Ww.aliases=[];function Ww(e){e.languages.bqn={shebang:{pattern:/^#![ \t]*\/.*/,alias:"important",greedy:!0},comment:{pattern:/#.*/,greedy:!0},"string-literal":{pattern:/"(?:[^"]|"")*"/,greedy:!0,alias:"string"},"character-literal":{pattern:/'(?:[\s\S]|[\uD800-\uDBFF][\uDC00-\uDFFF])'/,greedy:!0,alias:"char"},function:/•[\w¯.∞π]+[\w¯.∞π]*/,"dot-notation-on-brackets":{pattern:/\{(?=.*\}\.)|\}\./,alias:"namespace"},"special-name":{pattern:/(?:𝕨|𝕩|𝕗|𝕘|𝕤|𝕣|𝕎|𝕏|𝔽|𝔾|𝕊|_𝕣_|_𝕣)/,alias:"keyword"},"dot-notation-on-name":{pattern:/[A-Za-z_][\w¯∞π]*\./,alias:"namespace"},"word-number-scientific":{pattern:/\d+(?:\.\d+)?[eE]¯?\d+/,alias:"number"},"word-name":{pattern:/[A-Za-z_][\w¯∞π]*/,alias:"symbol"},"word-number":{pattern:/[¯∞π]?(?:\d*\.?\b\d+(?:e[+¯]?\d+|E[+¯]?\d+)?|¯|∞|π)(?:j¯?(?:(?:\d+(?:\.\d+)?|\.\d+)(?:e[+¯]?\d+|E[+¯]?\d+)?|¯|∞|π))?/,alias:"number"},"null-literal":{pattern:/@/,alias:"char"},"primitive-functions":{pattern:/[-+×÷⋆√⌊⌈|¬∧∨<>≠=≤≥≡≢⊣⊢⥊∾≍⋈↑↓↕«»⌽⍉/⍋⍒⊏⊑⊐⊒∊⍷⊔!]/,alias:"operator"},"primitive-1-operators":{pattern:/[`˜˘¨⁼⌜´˝˙]/,alias:"operator"},"primitive-2-operators":{pattern:/[∘⊸⟜○⌾⎉⚇⍟⊘◶⎊]/,alias:"operator"},punctuation:/[←⇐↩(){}⟨⟩[\]‿·⋄,.;:?]/}}Vw.displayName="brainfuck";Vw.aliases=[];function Vw(e){e.languages.brainfuck={pointer:{pattern:/<|>/,alias:"keyword"},increment:{pattern:/\+/,alias:"inserted"},decrement:{pattern:/-/,alias:"deleted"},branching:{pattern:/\[|\]/,alias:"important"},operator:/[.,]/,comment:/\S+/}}Yw.displayName="brightscript";Yw.aliases=[];function Yw(e){e.languages.brightscript={comment:/(?:\brem|').*/i,"directive-statement":{pattern:/(^[\t ]*)#(?:const|else(?:[\t ]+if)?|end[\t ]+if|error|if).*/im,lookbehind:!0,alias:"property",inside:{"error-message":{pattern:/(^#error).+/,lookbehind:!0},directive:{pattern:/^#(?:const|else(?:[\t ]+if)?|end[\t ]+if|error|if)/,alias:"keyword"},expression:{pattern:/[\s\S]+/,inside:null}}},property:{pattern:/([\r\n{,][\t ]*)(?:(?!\d)\w+|"(?:[^"\r\n]|"")*"(?!"))(?=[ \t]*:)/,lookbehind:!0,greedy:!0},string:{pattern:/"(?:[^"\r\n]|"")*"(?!")/,greedy:!0},"class-name":{pattern:/(\bAs[\t ]+)\w+/i,lookbehind:!0},keyword:/\b(?:As|Dim|Each|Else|Elseif|End|Exit|For|Function|Goto|If|In|Print|Return|Step|Stop|Sub|Then|To|While)\b/i,boolean:/\b(?:false|true)\b/i,function:/\b(?!\d)\w+(?=[\t ]*\()/,number:/(?:\b\d+(?:\.\d+)?(?:[ed][+-]\d+)?|&h[a-f\d]+)\b[%&!#]?/i,operator:/--|\+\+|>>=?|<<=?|<>|[-+*/\\<>]=?|[:^=?]|\b(?:and|mod|not|or)\b/i,punctuation:/[.,;()[\]{}]/,constant:/\b(?:LINE_NUM)\b/i},e.languages.brightscript["directive-statement"].inside.expression.inside=e.languages.brightscript}Xw.displayName="bro";Xw.aliases=[];function Xw(e){e.languages.bro={comment:{pattern:/(^|[^\\$])#.*/,lookbehind:!0,inside:{italic:/\b(?:FIXME|TODO|XXX)\b/}},string:{pattern:/(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,greedy:!0},boolean:/\b[TF]\b/,function:{pattern:/(\b(?:event|function|hook)[ \t]+)\w+(?:::\w+)?/,lookbehind:!0},builtin:/(?:@(?:load(?:-(?:plugin|sigs))?|unload|prefixes|ifn?def|else|(?:end)?if|DIR|FILENAME))|(?:&?(?:add_func|create_expire|default|delete_func|encrypt|error_handler|expire_func|group|log|mergeable|optional|persistent|priority|raw_output|read_expire|redef|rotate_interval|rotate_size|synchronized|type_column|write_expire))/,constant:{pattern:/(\bconst[ \t]+)\w+/i,lookbehind:!0},keyword:/\b(?:add|addr|alarm|any|bool|break|const|continue|count|delete|double|else|enum|event|export|file|for|function|global|hook|if|in|int|interval|local|module|next|of|opaque|pattern|port|print|record|return|schedule|set|string|subnet|table|time|timeout|using|vector|when)\b/,operator:/--?|\+\+?|!=?=?|<=?|>=?|==?=?|&&|\|\|?|\?|\*|\/|~|\^|%/,number:/\b0x[\da-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?/i,punctuation:/[{}[\];(),.:]/}}Kw.displayName="bsl";Kw.aliases=["oscript"];function Kw(e){e.languages.bsl={comment:/\/\/.*/,string:[{pattern:/"(?:[^"]|"")*"(?!")/,greedy:!0},{pattern:/'(?:[^'\r\n\\]|\\.)*'/}],keyword:[{pattern:/(^|[^\w\u0400-\u0484\u0487-\u052f\u1d2b\u1d78\u2de0-\u2dff\ua640-\ua69f\ufe2e\ufe2f])(?:пока|для|новый|прервать|попытка|исключение|вызватьисключение|иначе|конецпопытки|неопределено|функция|перем|возврат|конецфункции|если|иначеесли|процедура|конецпроцедуры|тогда|знач|экспорт|конецесли|из|каждого|истина|ложь|по|цикл|конеццикла|выполнить)(?![\w\u0400-\u0484\u0487-\u052f\u1d2b\u1d78\u2de0-\u2dff\ua640-\ua69f\ufe2e\ufe2f])/i,lookbehind:!0},{pattern:/\b(?:break|do|each|else|elseif|enddo|endfunction|endif|endprocedure|endtry|except|execute|export|false|for|function|if|in|new|null|procedure|raise|return|then|to|true|try|undefined|val|var|while)\b/i}],number:{pattern:/(^(?=\d)|[^\w\u0400-\u0484\u0487-\u052f\u1d2b\u1d78\u2de0-\u2dff\ua640-\ua69f\ufe2e\ufe2f])(?:\d+(?:\.\d*)?|\.\d+)(?:E[+-]?\d+)?/i,lookbehind:!0},operator:[/[<>+\-*/]=?|[%=]/,{pattern:/(^|[^\w\u0400-\u0484\u0487-\u052f\u1d2b\u1d78\u2de0-\u2dff\ua640-\ua69f\ufe2e\ufe2f])(?:и|или|не)(?![\w\u0400-\u0484\u0487-\u052f\u1d2b\u1d78\u2de0-\u2dff\ua640-\ua69f\ufe2e\ufe2f])/i,lookbehind:!0},{pattern:/\b(?:and|not|or)\b/i}],punctuation:/\(\.|\.\)|[()\[\]:;,.]/,directive:[{pattern:/^([ \t]*)&.*/m,lookbehind:!0,greedy:!0,alias:"important"},{pattern:/^([ \t]*)#.*/gm,lookbehind:!0,greedy:!0,alias:"important"}]},e.languages.oscript=e.languages.bsl}Zw.displayName="cfscript";Zw.aliases=["cfc"];function Zw(e){e.register(Mt),e.languages.cfscript=e.languages.extend("clike",{comment:[{pattern:/(^|[^\\])\/\*[\s\S]*?(?:\*\/|$)/,lookbehind:!0,inside:{annotation:{pattern:/(?:^|[^.])@[\w\.]+/,alias:"punctuation"}}},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0,greedy:!0}],keyword:/\b(?:abstract|break|catch|component|continue|default|do|else|extends|final|finally|for|function|if|in|include|package|private|property|public|remote|required|rethrow|return|static|switch|throw|try|var|while|xml)\b(?!\s*=)/,operator:[/\+\+|--|&&|\|\||::|=>|[!=]==|[-+*/%&|^!=<>]=?|\?(?:\.|:)?|:/,/\b(?:and|contains|eq|equal|eqv|gt|gte|imp|is|lt|lte|mod|not|or|xor)\b/],scope:{pattern:/\b(?:application|arguments|cgi|client|cookie|local|session|super|this|variables)\b/,alias:"global"},type:{pattern:/\b(?:any|array|binary|boolean|date|guid|numeric|query|string|struct|uuid|void|xml)\b/,alias:"builtin"}}),e.languages.insertBefore("cfscript","keyword",{"function-variable":{pattern:/[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*[=:]\s*(?:\bfunction\b|(?:\((?:[^()]|\([^()]*\))*\)|(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)\s*=>))/,alias:"function"}}),delete e.languages.cfscript["class-name"],e.languages.cfc=e.languages.cfscript}Qw.displayName="chaiscript";Qw.aliases=[];function Qw(e){e.register(Mt),e.register(Eu),e.languages.chaiscript=e.languages.extend("clike",{string:{pattern:/(^|[^\\])'(?:[^'\\]|\\[\s\S])*'/,lookbehind:!0,greedy:!0},"class-name":[{pattern:/(\bclass\s+)\w+/,lookbehind:!0},{pattern:/(\b(?:attr|def)\s+)\w+(?=\s*::)/,lookbehind:!0}],keyword:/\b(?:attr|auto|break|case|catch|class|continue|def|default|else|finally|for|fun|global|if|return|switch|this|try|var|while)\b/,number:[e.languages.cpp.number,/\b(?:Infinity|NaN)\b/],operator:/>>=?|<<=?|\|\||&&|:[:=]?|--|\+\+|[=!<>+\-*/%|&^]=?|[?~]|`[^`\r\n]{1,4}`/}),e.languages.insertBefore("chaiscript","operator",{"parameter-type":{pattern:/([,(]\s*)\w+(?=\s+\w)/,lookbehind:!0,alias:"class-name"}}),e.languages.insertBefore("chaiscript","string",{"string-interpolation":{pattern:/(^|[^\\])"(?:[^"$\\]|\\[\s\S]|\$(?!\{)|\$\{(?:[^{}]|\{(?:[^{}]|\{[^{}]*\})*\})*\})*"/,lookbehind:!0,greedy:!0,inside:{interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\$\{(?:[^{}]|\{(?:[^{}]|\{[^{}]*\})*\})*\}/,lookbehind:!0,inside:{"interpolation-expression":{pattern:/(^\$\{)[\s\S]+(?=\}$)/,lookbehind:!0,inside:e.languages.chaiscript},"interpolation-punctuation":{pattern:/^\$\{|\}$/,alias:"punctuation"}}},string:/[\s\S]+/}}})}Jw.displayName="cil";Jw.aliases=[];function Jw(e){e.languages.cil={comment:/\/\/.*/,string:{pattern:/(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,greedy:!0},directive:{pattern:/(^|\W)\.[a-z]+(?=\s)/,lookbehind:!0,alias:"class-name"},variable:/\[[\w\.]+\]/,keyword:/\b(?:abstract|ansi|assembly|auto|autochar|beforefieldinit|bool|bstr|byvalstr|catch|char|cil|class|currency|date|decimal|default|enum|error|explicit|extends|extern|famandassem|family|famorassem|final(?:ly)?|float32|float64|hidebysig|u?int(?:8|16|32|64)?|iant|idispatch|implements|import|initonly|instance|interface|iunknown|literal|lpstr|lpstruct|lptstr|lpwstr|managed|method|native(?:Type)?|nested|newslot|object(?:ref)?|pinvokeimpl|private|privatescope|public|reqsecobj|rtspecialname|runtime|sealed|sequential|serializable|specialname|static|string|struct|syschar|tbstr|unicode|unmanagedexp|unsigned|value(?:type)?|variant|virtual|void)\b/,function:/\b(?:(?:constrained|no|readonly|tail|unaligned|volatile)\.)?(?:conv\.(?:[iu][1248]?|ovf\.[iu][1248]?(?:\.un)?|r\.un|r4|r8)|ldc\.(?:i4(?:\.\d+|\.[mM]1|\.s)?|i8|r4|r8)|ldelem(?:\.[iu][1248]?|\.r[48]|\.ref|a)?|ldind\.(?:[iu][1248]?|r[48]|ref)|stelem\.?(?:i[1248]?|r[48]|ref)?|stind\.(?:i[1248]?|r[48]|ref)?|end(?:fault|filter|finally)|ldarg(?:\.[0-3s]|a(?:\.s)?)?|ldloc(?:\.\d+|\.s)?|sub(?:\.ovf(?:\.un)?)?|mul(?:\.ovf(?:\.un)?)?|add(?:\.ovf(?:\.un)?)?|stloc(?:\.[0-3s])?|refany(?:type|val)|blt(?:\.un)?(?:\.s)?|ble(?:\.un)?(?:\.s)?|bgt(?:\.un)?(?:\.s)?|bge(?:\.un)?(?:\.s)?|unbox(?:\.any)?|init(?:blk|obj)|call(?:i|virt)?|brfalse(?:\.s)?|bne\.un(?:\.s)?|ldloca(?:\.s)?|brzero(?:\.s)?|brtrue(?:\.s)?|brnull(?:\.s)?|brinst(?:\.s)?|starg(?:\.s)?|leave(?:\.s)?|shr(?:\.un)?|rem(?:\.un)?|div(?:\.un)?|clt(?:\.un)?|alignment|castclass|ldvirtftn|beq(?:\.s)?|ckfinite|ldsflda|ldtoken|localloc|mkrefany|rethrow|cgt\.un|arglist|switch|stsfld|sizeof|newobj|newarr|ldsfld|ldnull|ldflda|isinst|throw|stobj|stfld|ldstr|ldobj|ldlen|ldftn|ldfld|cpobj|cpblk|break|br\.s|xor|shl|ret|pop|not|nop|neg|jmp|dup|cgt|ceq|box|and|or|br)\b/,boolean:/\b(?:false|true)\b/,number:/\b-?(?:0x[0-9a-f]+|\d+)(?:\.[0-9a-f]+)?\b/i,punctuation:/[{}[\];(),:=]|IL_[0-9A-Za-z]+/}}eE.displayName="cilkc";eE.aliases=["cilk-c"];function eE(e){e.register($i),e.languages.cilkc=e.languages.insertBefore("c","function",{"parallel-keyword":{pattern:/\bcilk_(?:for|reducer|s(?:cope|pawn|ync))\b/,alias:"keyword"}}),e.languages["cilk-c"]=e.languages.cilkc}tE.displayName="cilkcpp";tE.aliases=["cilk","cilk-cpp"];function tE(e){e.register(Eu),e.languages.cilkcpp=e.languages.insertBefore("cpp","function",{"parallel-keyword":{pattern:/\bcilk_(?:for|reducer|s(?:cope|pawn|ync))\b/,alias:"keyword"}}),e.languages["cilk-cpp"]=e.languages.cilkcpp,e.languages.cilk=e.languages.cilkcpp}nE.displayName="clojure";nE.aliases=[];function nE(e){e.languages.clojure={comment:{pattern:/;.*/,greedy:!0},string:{pattern:/"(?:[^"\\]|\\.)*"/,greedy:!0},char:/\\\w+/,symbol:{pattern:/(^|[\s()\[\]{},])::?[\w*+!?'<>=/.-]+/,lookbehind:!0},keyword:{pattern:/(\()(?:-|->|->>|\.|\.\.|\*|\/|\+|<|<=|=|==|>|>=|accessor|agent|agent-errors|aget|alength|all-ns|alter|and|append-child|apply|array-map|aset|aset-boolean|aset-byte|aset-char|aset-double|aset-float|aset-int|aset-long|aset-short|assert|assoc|await|await-for|bean|binding|bit-and|bit-not|bit-or|bit-shift-left|bit-shift-right|bit-xor|boolean|branch\?|butlast|byte|cast|char|children|class|clear-agent-errors|comment|commute|comp|comparator|complement|concat|cond|conj|cons|constantly|construct-proxy|contains\?|count|create-ns|create-struct|cycle|dec|declare|def|def-|definline|definterface|defmacro|defmethod|defmulti|defn|defn-|defonce|defproject|defprotocol|defrecord|defstruct|deftype|deref|difference|disj|dissoc|distinct|do|doall|doc|dorun|doseq|dosync|dotimes|doto|double|down|drop|drop-while|edit|end\?|ensure|eval|every\?|false\?|ffirst|file-seq|filter|find|find-doc|find-ns|find-var|first|float|flush|fn|fnseq|for|frest|gensym|get|get-proxy-class|hash-map|hash-set|identical\?|identity|if|if-let|if-not|import|in-ns|inc|index|insert-child|insert-left|insert-right|inspect-table|inspect-tree|instance\?|int|interleave|intersection|into|into-array|iterate|join|key|keys|keyword|keyword\?|last|lazy-cat|lazy-cons|left|lefts|let|line-seq|list|list\*|load|load-file|locking|long|loop|macroexpand|macroexpand-1|make-array|make-node|map|map-invert|map\?|mapcat|max|max-key|memfn|merge|merge-with|meta|min|min-key|monitor-enter|name|namespace|neg\?|new|newline|next|nil\?|node|not|not-any\?|not-every\?|not=|ns|ns-imports|ns-interns|ns-map|ns-name|ns-publics|ns-refers|ns-resolve|ns-unmap|nth|nthrest|or|parse|partial|path|peek|pop|pos\?|pr|pr-str|print|print-str|println|println-str|prn|prn-str|project|proxy|proxy-mappings|quot|quote|rand|rand-int|range|re-find|re-groups|re-matcher|re-matches|re-pattern|re-seq|read|read-line|recur|reduce|ref|ref-set|refer|rem|remove|remove-method|remove-ns|rename|rename-keys|repeat|replace|replicate|resolve|rest|resultset-seq|reverse|rfirst|right|rights|root|rrest|rseq|second|select|select-keys|send|send-off|seq|seq-zip|seq\?|set|set!|short|slurp|some|sort|sort-by|sorted-map|sorted-map-by|sorted-set|special-symbol\?|split-at|split-with|str|string\?|struct|struct-map|subs|subvec|symbol|symbol\?|sync|take|take-nth|take-while|test|throw|time|to-array|to-array-2d|tree-seq|true\?|try|union|up|update-proxy|val|vals|var|var-get|var-set|var\?|vector|vector-zip|vector\?|when|when-first|when-let|when-not|with-local-vars|with-meta|with-open|with-out-str|xml-seq|xml-zip|zero\?|zipmap|zipper)(?=[\s)]|$)/,lookbehind:!0},boolean:/\b(?:false|nil|true)\b/,number:{pattern:/(^|[^\w$@])(?:\d+(?:[/.]\d+)?(?:e[+-]?\d+)?|0x[a-f0-9]+|[1-9]\d?r[a-z0-9]+)[lmn]?(?![\w$@])/i,lookbehind:!0},function:{pattern:/((?:^|[^'])\()[\w*+!?'<>=/.-]+(?=[\s)]|$)/,lookbehind:!0},operator:/[#@^`~]/,punctuation:/[{}\[\](),]/}}rE.displayName="cmake";rE.aliases=[];function rE(e){e.languages.cmake={comment:/#.*/,string:{pattern:/"(?:[^\\"]|\\.)*"/,greedy:!0,inside:{interpolation:{pattern:/\$\{(?:[^{}$]|\$\{[^{}$]*\})*\}/,inside:{punctuation:/\$\{|\}/,variable:/\w+/}}}},variable:/\b(?:CMAKE_\w+|\w+_(?:(?:BINARY|SOURCE)_DIR|DESCRIPTION|HOMEPAGE_URL|ROOT|VERSION(?:_MAJOR|_MINOR|_PATCH|_TWEAK)?)|(?:ANDROID|APPLE|BORLAND|BUILD_SHARED_LIBS|CACHE|CPACK_(?:ABSOLUTE_DESTINATION_FILES|COMPONENT_INCLUDE_TOPLEVEL_DIRECTORY|ERROR_ON_ABSOLUTE_INSTALL_DESTINATION|INCLUDE_TOPLEVEL_DIRECTORY|INSTALL_DEFAULT_DIRECTORY_PERMISSIONS|INSTALL_SCRIPT|PACKAGING_INSTALL_PREFIX|SET_DESTDIR|WARN_ON_ABSOLUTE_INSTALL_DESTINATION)|CTEST_(?:BINARY_DIRECTORY|BUILD_COMMAND|BUILD_NAME|BZR_COMMAND|BZR_UPDATE_OPTIONS|CHANGE_ID|CHECKOUT_COMMAND|CONFIGURATION_TYPE|CONFIGURE_COMMAND|COVERAGE_COMMAND|COVERAGE_EXTRA_FLAGS|CURL_OPTIONS|CUSTOM_(?:COVERAGE_EXCLUDE|ERROR_EXCEPTION|ERROR_MATCH|ERROR_POST_CONTEXT|ERROR_PRE_CONTEXT|MAXIMUM_FAILED_TEST_OUTPUT_SIZE|MAXIMUM_NUMBER_OF_(?:ERRORS|WARNINGS)|MAXIMUM_PASSED_TEST_OUTPUT_SIZE|MEMCHECK_IGNORE|POST_MEMCHECK|POST_TEST|PRE_MEMCHECK|PRE_TEST|TESTS_IGNORE|WARNING_EXCEPTION|WARNING_MATCH)|CVS_CHECKOUT|CVS_COMMAND|CVS_UPDATE_OPTIONS|DROP_LOCATION|DROP_METHOD|DROP_SITE|DROP_SITE_CDASH|DROP_SITE_PASSWORD|DROP_SITE_USER|EXTRA_COVERAGE_GLOB|GIT_COMMAND|GIT_INIT_SUBMODULES|GIT_UPDATE_CUSTOM|GIT_UPDATE_OPTIONS|HG_COMMAND|HG_UPDATE_OPTIONS|LABELS_FOR_SUBPROJECTS|MEMORYCHECK_(?:COMMAND|COMMAND_OPTIONS|SANITIZER_OPTIONS|SUPPRESSIONS_FILE|TYPE)|NIGHTLY_START_TIME|P4_CLIENT|P4_COMMAND|P4_OPTIONS|P4_UPDATE_OPTIONS|RUN_CURRENT_SCRIPT|SCP_COMMAND|SITE|SOURCE_DIRECTORY|SUBMIT_URL|SVN_COMMAND|SVN_OPTIONS|SVN_UPDATE_OPTIONS|TEST_LOAD|TEST_TIMEOUT|TRIGGER_SITE|UPDATE_COMMAND|UPDATE_OPTIONS|UPDATE_VERSION_ONLY|USE_LAUNCHERS)|CYGWIN|ENV|EXECUTABLE_OUTPUT_PATH|GHS-MULTI|IOS|LIBRARY_OUTPUT_PATH|MINGW|MSVC(?:10|11|12|14|60|70|71|80|90|_IDE|_TOOLSET_VERSION|_VERSION)?|MSYS|PROJECT_NAME|UNIX|WIN32|WINCE|WINDOWS_PHONE|WINDOWS_STORE|XCODE))\b/,property:/\b(?:cxx_\w+|(?:ARCHIVE_OUTPUT_(?:DIRECTORY|NAME)|COMPILE_DEFINITIONS|COMPILE_PDB_NAME|COMPILE_PDB_OUTPUT_DIRECTORY|EXCLUDE_FROM_DEFAULT_BUILD|IMPORTED_(?:IMPLIB|LIBNAME|LINK_DEPENDENT_LIBRARIES|LINK_INTERFACE_LANGUAGES|LINK_INTERFACE_LIBRARIES|LINK_INTERFACE_MULTIPLICITY|LOCATION|NO_SONAME|OBJECTS|SONAME)|INTERPROCEDURAL_OPTIMIZATION|LIBRARY_OUTPUT_DIRECTORY|LIBRARY_OUTPUT_NAME|LINK_FLAGS|LINK_INTERFACE_LIBRARIES|LINK_INTERFACE_MULTIPLICITY|LOCATION|MAP_IMPORTED_CONFIG|OSX_ARCHITECTURES|OUTPUT_NAME|PDB_NAME|PDB_OUTPUT_DIRECTORY|RUNTIME_OUTPUT_DIRECTORY|RUNTIME_OUTPUT_NAME|STATIC_LIBRARY_FLAGS|VS_CSHARP|VS_DOTNET_REFERENCEPROP|VS_DOTNET_REFERENCE|VS_GLOBAL_SECTION_POST|VS_GLOBAL_SECTION_PRE|VS_GLOBAL|XCODE_ATTRIBUTE)_\w+|\w+_(?:CLANG_TIDY|COMPILER_LAUNCHER|CPPCHECK|CPPLINT|INCLUDE_WHAT_YOU_USE|OUTPUT_NAME|POSTFIX|VISIBILITY_PRESET)|ABSTRACT|ADDITIONAL_MAKE_CLEAN_FILES|ADVANCED|ALIASED_TARGET|ALLOW_DUPLICATE_CUSTOM_TARGETS|ANDROID_(?:ANT_ADDITIONAL_OPTIONS|API|API_MIN|ARCH|ASSETS_DIRECTORIES|GUI|JAR_DEPENDENCIES|NATIVE_LIB_DEPENDENCIES|NATIVE_LIB_DIRECTORIES|PROCESS_MAX|PROGUARD|PROGUARD_CONFIG_PATH|SECURE_PROPS_PATH|SKIP_ANT_STEP|STL_TYPE)|ARCHIVE_OUTPUT_DIRECTORY|ATTACHED_FILES|ATTACHED_FILES_ON_FAIL|AUTOGEN_(?:BUILD_DIR|ORIGIN_DEPENDS|PARALLEL|SOURCE_GROUP|TARGETS_FOLDER|TARGET_DEPENDS)|AUTOMOC|AUTOMOC_(?:COMPILER_PREDEFINES|DEPEND_FILTERS|EXECUTABLE|MACRO_NAMES|MOC_OPTIONS|SOURCE_GROUP|TARGETS_FOLDER)|AUTORCC|AUTORCC_EXECUTABLE|AUTORCC_OPTIONS|AUTORCC_SOURCE_GROUP|AUTOUIC|AUTOUIC_EXECUTABLE|AUTOUIC_OPTIONS|AUTOUIC_SEARCH_PATHS|BINARY_DIR|BUILDSYSTEM_TARGETS|BUILD_RPATH|BUILD_RPATH_USE_ORIGIN|BUILD_WITH_INSTALL_NAME_DIR|BUILD_WITH_INSTALL_RPATH|BUNDLE|BUNDLE_EXTENSION|CACHE_VARIABLES|CLEAN_NO_CUSTOM|COMMON_LANGUAGE_RUNTIME|COMPATIBLE_INTERFACE_(?:BOOL|NUMBER_MAX|NUMBER_MIN|STRING)|COMPILE_(?:DEFINITIONS|FEATURES|FLAGS|OPTIONS|PDB_NAME|PDB_OUTPUT_DIRECTORY)|COST|CPACK_DESKTOP_SHORTCUTS|CPACK_NEVER_OVERWRITE|CPACK_PERMANENT|CPACK_STARTUP_SHORTCUTS|CPACK_START_MENU_SHORTCUTS|CPACK_WIX_ACL|CROSSCOMPILING_EMULATOR|CUDA_EXTENSIONS|CUDA_PTX_COMPILATION|CUDA_RESOLVE_DEVICE_SYMBOLS|CUDA_SEPARABLE_COMPILATION|CUDA_STANDARD|CUDA_STANDARD_REQUIRED|CXX_EXTENSIONS|CXX_STANDARD|CXX_STANDARD_REQUIRED|C_EXTENSIONS|C_STANDARD|C_STANDARD_REQUIRED|DEBUG_CONFIGURATIONS|DEFINE_SYMBOL|DEFINITIONS|DEPENDS|DEPLOYMENT_ADDITIONAL_FILES|DEPLOYMENT_REMOTE_DIRECTORY|DISABLED|DISABLED_FEATURES|ECLIPSE_EXTRA_CPROJECT_CONTENTS|ECLIPSE_EXTRA_NATURES|ENABLED_FEATURES|ENABLED_LANGUAGES|ENABLE_EXPORTS|ENVIRONMENT|EXCLUDE_FROM_ALL|EXCLUDE_FROM_DEFAULT_BUILD|EXPORT_NAME|EXPORT_PROPERTIES|EXTERNAL_OBJECT|EchoString|FAIL_REGULAR_EXPRESSION|FIND_LIBRARY_USE_LIB32_PATHS|FIND_LIBRARY_USE_LIB64_PATHS|FIND_LIBRARY_USE_LIBX32_PATHS|FIND_LIBRARY_USE_OPENBSD_VERSIONING|FIXTURES_CLEANUP|FIXTURES_REQUIRED|FIXTURES_SETUP|FOLDER|FRAMEWORK|Fortran_FORMAT|Fortran_MODULE_DIRECTORY|GENERATED|GENERATOR_FILE_NAME|GENERATOR_IS_MULTI_CONFIG|GHS_INTEGRITY_APP|GHS_NO_SOURCE_GROUP_FILE|GLOBAL_DEPENDS_DEBUG_MODE|GLOBAL_DEPENDS_NO_CYCLES|GNUtoMS|HAS_CXX|HEADER_FILE_ONLY|HELPSTRING|IMPLICIT_DEPENDS_INCLUDE_TRANSFORM|IMPORTED|IMPORTED_(?:COMMON_LANGUAGE_RUNTIME|CONFIGURATIONS|GLOBAL|IMPLIB|LIBNAME|LINK_DEPENDENT_LIBRARIES|LINK_INTERFACE_(?:LANGUAGES|LIBRARIES|MULTIPLICITY)|LOCATION|NO_SONAME|OBJECTS|SONAME)|IMPORT_PREFIX|IMPORT_SUFFIX|INCLUDE_DIRECTORIES|INCLUDE_REGULAR_EXPRESSION|INSTALL_NAME_DIR|INSTALL_RPATH|INSTALL_RPATH_USE_LINK_PATH|INTERFACE_(?:AUTOUIC_OPTIONS|COMPILE_DEFINITIONS|COMPILE_FEATURES|COMPILE_OPTIONS|INCLUDE_DIRECTORIES|LINK_DEPENDS|LINK_DIRECTORIES|LINK_LIBRARIES|LINK_OPTIONS|POSITION_INDEPENDENT_CODE|SOURCES|SYSTEM_INCLUDE_DIRECTORIES)|INTERPROCEDURAL_OPTIMIZATION|IN_TRY_COMPILE|IOS_INSTALL_COMBINED|JOB_POOLS|JOB_POOL_COMPILE|JOB_POOL_LINK|KEEP_EXTENSION|LABELS|LANGUAGE|LIBRARY_OUTPUT_DIRECTORY|LINKER_LANGUAGE|LINK_(?:DEPENDS|DEPENDS_NO_SHARED|DIRECTORIES|FLAGS|INTERFACE_LIBRARIES|INTERFACE_MULTIPLICITY|LIBRARIES|OPTIONS|SEARCH_END_STATIC|SEARCH_START_STATIC|WHAT_YOU_USE)|LISTFILE_STACK|LOCATION|MACOSX_BUNDLE|MACOSX_BUNDLE_INFO_PLIST|MACOSX_FRAMEWORK_INFO_PLIST|MACOSX_PACKAGE_LOCATION|MACOSX_RPATH|MACROS|MANUALLY_ADDED_DEPENDENCIES|MEASUREMENT|MODIFIED|NAME|NO_SONAME|NO_SYSTEM_FROM_IMPORTED|OBJECT_DEPENDS|OBJECT_OUTPUTS|OSX_ARCHITECTURES|OUTPUT_NAME|PACKAGES_FOUND|PACKAGES_NOT_FOUND|PARENT_DIRECTORY|PASS_REGULAR_EXPRESSION|PDB_NAME|PDB_OUTPUT_DIRECTORY|POSITION_INDEPENDENT_CODE|POST_INSTALL_SCRIPT|PREDEFINED_TARGETS_FOLDER|PREFIX|PRE_INSTALL_SCRIPT|PRIVATE_HEADER|PROCESSORS|PROCESSOR_AFFINITY|PROJECT_LABEL|PUBLIC_HEADER|REPORT_UNDEFINED_PROPERTIES|REQUIRED_FILES|RESOURCE|RESOURCE_LOCK|RULE_LAUNCH_COMPILE|RULE_LAUNCH_CUSTOM|RULE_LAUNCH_LINK|RULE_MESSAGES|RUNTIME_OUTPUT_DIRECTORY|RUN_SERIAL|SKIP_AUTOGEN|SKIP_AUTOMOC|SKIP_AUTORCC|SKIP_AUTOUIC|SKIP_BUILD_RPATH|SKIP_RETURN_CODE|SOURCES|SOURCE_DIR|SOVERSION|STATIC_LIBRARY_FLAGS|STATIC_LIBRARY_OPTIONS|STRINGS|SUBDIRECTORIES|SUFFIX|SYMBOLIC|TARGET_ARCHIVES_MAY_BE_SHARED_LIBS|TARGET_MESSAGES|TARGET_SUPPORTS_SHARED_LIBS|TESTS|TEST_INCLUDE_FILE|TEST_INCLUDE_FILES|TIMEOUT|TIMEOUT_AFTER_MATCH|TYPE|USE_FOLDERS|VALUE|VARIABLES|VERSION|VISIBILITY_INLINES_HIDDEN|VS_(?:CONFIGURATION_TYPE|COPY_TO_OUT_DIR|DEBUGGER_(?:COMMAND|COMMAND_ARGUMENTS|ENVIRONMENT|WORKING_DIRECTORY)|DEPLOYMENT_CONTENT|DEPLOYMENT_LOCATION|DOTNET_REFERENCES|DOTNET_REFERENCES_COPY_LOCAL|INCLUDE_IN_VSIX|IOT_STARTUP_TASK|KEYWORD|RESOURCE_GENERATOR|SCC_AUXPATH|SCC_LOCALPATH|SCC_PROJECTNAME|SCC_PROVIDER|SDK_REFERENCES|SHADER_(?:DISABLE_OPTIMIZATIONS|ENABLE_DEBUG|ENTRYPOINT|FLAGS|MODEL|OBJECT_FILE_NAME|OUTPUT_HEADER_FILE|TYPE|VARIABLE_NAME)|STARTUP_PROJECT|TOOL_OVERRIDE|USER_PROPS|WINRT_COMPONENT|WINRT_EXTENSIONS|WINRT_REFERENCES|XAML_TYPE)|WILL_FAIL|WIN32_EXECUTABLE|WINDOWS_EXPORT_ALL_SYMBOLS|WORKING_DIRECTORY|WRAP_EXCLUDE|XCODE_(?:EMIT_EFFECTIVE_PLATFORM_NAME|EXPLICIT_FILE_TYPE|FILE_ATTRIBUTES|LAST_KNOWN_FILE_TYPE|PRODUCT_TYPE|SCHEME_(?:ADDRESS_SANITIZER|ADDRESS_SANITIZER_USE_AFTER_RETURN|ARGUMENTS|DISABLE_MAIN_THREAD_CHECKER|DYNAMIC_LIBRARY_LOADS|DYNAMIC_LINKER_API_USAGE|ENVIRONMENT|EXECUTABLE|GUARD_MALLOC|MAIN_THREAD_CHECKER_STOP|MALLOC_GUARD_EDGES|MALLOC_SCRIBBLE|MALLOC_STACK|THREAD_SANITIZER(?:_STOP)?|UNDEFINED_BEHAVIOUR_SANITIZER(?:_STOP)?|ZOMBIE_OBJECTS))|XCTEST)\b/,keyword:/\b(?:add_compile_definitions|add_compile_options|add_custom_command|add_custom_target|add_definitions|add_dependencies|add_executable|add_library|add_link_options|add_subdirectory|add_test|aux_source_directory|break|build_command|build_name|cmake_host_system_information|cmake_minimum_required|cmake_parse_arguments|cmake_policy|configure_file|continue|create_test_sourcelist|ctest_build|ctest_configure|ctest_coverage|ctest_empty_binary_directory|ctest_memcheck|ctest_read_custom_files|ctest_run_script|ctest_sleep|ctest_start|ctest_submit|ctest_test|ctest_update|ctest_upload|define_property|else|elseif|enable_language|enable_testing|endforeach|endfunction|endif|endmacro|endwhile|exec_program|execute_process|export|export_library_dependencies|file|find_file|find_library|find_package|find_path|find_program|fltk_wrap_ui|foreach|function|get_cmake_property|get_directory_property|get_filename_component|get_property|get_source_file_property|get_target_property|get_test_property|if|include|include_directories|include_external_msproject|include_guard|include_regular_expression|install|install_files|install_programs|install_targets|link_directories|link_libraries|list|load_cache|load_command|macro|make_directory|mark_as_advanced|math|message|option|output_required_files|project|qt_wrap_cpp|qt_wrap_ui|remove|remove_definitions|return|separate_arguments|set|set_directory_properties|set_property|set_source_files_properties|set_target_properties|set_tests_properties|site_name|source_group|string|subdir_depends|subdirs|target_compile_definitions|target_compile_features|target_compile_options|target_include_directories|target_link_directories|target_link_libraries|target_link_options|target_sources|try_compile|try_run|unset|use_mangled_mesa|utility_source|variable_requires|variable_watch|while|write_file)(?=\s*\()\b/,boolean:/\b(?:FALSE|OFF|ON|TRUE)\b/,namespace:/\b(?:INTERFACE|PRIVATE|PROPERTIES|PUBLIC|SHARED|STATIC|TARGET_OBJECTS)\b/,operator:/\b(?:AND|DEFINED|EQUAL|GREATER|LESS|MATCHES|NOT|OR|STREQUAL|STRGREATER|STRLESS|VERSION_EQUAL|VERSION_GREATER|VERSION_LESS)\b/,inserted:{pattern:/\b\w+::\w+\b/,alias:"class-name"},number:/\b\d+(?:\.\d+)*\b/,function:/\b[a-z_]\w*(?=\s*\()\b/i,punctuation:/[()>}]|\$[<{]/}}aE.displayName="cobol";aE.aliases=[];function aE(e){e.languages.cobol={comment:{pattern:/\*>.*|(^[ \t]*)\*.*/m,lookbehind:!0,greedy:!0},string:{pattern:/[xzgn]?(?:"(?:[^\r\n"]|"")*"(?!")|'(?:[^\r\n']|'')*'(?!'))/i,greedy:!0},level:{pattern:/(^[ \t]*)\d+\b/m,lookbehind:!0,greedy:!0,alias:"number"},"class-name":{pattern:/(\bpic(?:ture)?\s+)(?:(?:[-\w$/,:*+<>]|\.(?!\s|$))(?:\(\d+\))?)+/i,lookbehind:!0,inside:{number:{pattern:/(\()\d+/,lookbehind:!0},punctuation:/[()]/}},keyword:{pattern:/(^|[^\w-])(?:ABORT|ACCEPT|ACCESS|ADD|ADDRESS|ADVANCING|AFTER|ALIGNED|ALL|ALPHABET|ALPHABETIC|ALPHABETIC-LOWER|ALPHABETIC-UPPER|ALPHANUMERIC|ALPHANUMERIC-EDITED|ALSO|ALTER|ALTERNATE|ANY|ARE|AREA|AREAS|AS|ASCENDING|ASCII|ASSIGN|ASSOCIATED-DATA|ASSOCIATED-DATA-LENGTH|AT|ATTRIBUTE|AUTHOR|AUTO|AUTO-SKIP|BACKGROUND-COLOR|BACKGROUND-COLOUR|BASIS|BEEP|BEFORE|BEGINNING|BELL|BINARY|BIT|BLANK|BLINK|BLOCK|BOTTOM|BOUNDS|BY|BYFUNCTION|BYTITLE|CALL|CANCEL|CAPABLE|CCSVERSION|CD|CF|CH|CHAINING|CHANGED|CHANNEL|CHARACTER|CHARACTERS|CLASS|CLASS-ID|CLOCK-UNITS|CLOSE|CLOSE-DISPOSITION|COBOL|CODE|CODE-SET|COL|COLLATING|COLUMN|COM-REG|COMMA|COMMITMENT|COMMON|COMMUNICATION|COMP|COMP-1|COMP-2|COMP-3|COMP-4|COMP-5|COMPUTATIONAL|COMPUTATIONAL-1|COMPUTATIONAL-2|COMPUTATIONAL-3|COMPUTATIONAL-4|COMPUTATIONAL-5|COMPUTE|CONFIGURATION|CONTAINS|CONTENT|CONTINUE|CONTROL|CONTROL-POINT|CONTROLS|CONVENTION|CONVERTING|COPY|CORR|CORRESPONDING|COUNT|CRUNCH|CURRENCY|CURSOR|DATA|DATA-BASE|DATE|DATE-COMPILED|DATE-WRITTEN|DAY|DAY-OF-WEEK|DBCS|DE|DEBUG-CONTENTS|DEBUG-ITEM|DEBUG-LINE|DEBUG-NAME|DEBUG-SUB-1|DEBUG-SUB-2|DEBUG-SUB-3|DEBUGGING|DECIMAL-POINT|DECLARATIVES|DEFAULT|DEFAULT-DISPLAY|DEFINITION|DELETE|DELIMITED|DELIMITER|DEPENDING|DESCENDING|DESTINATION|DETAIL|DFHRESP|DFHVALUE|DISABLE|DISK|DISPLAY|DISPLAY-1|DIVIDE|DIVISION|DONTCARE|DOUBLE|DOWN|DUPLICATES|DYNAMIC|EBCDIC|EGCS|EGI|ELSE|EMI|EMPTY-CHECK|ENABLE|END|END-ACCEPT|END-ADD|END-CALL|END-COMPUTE|END-DELETE|END-DIVIDE|END-EVALUATE|END-IF|END-MULTIPLY|END-OF-PAGE|END-PERFORM|END-READ|END-RECEIVE|END-RETURN|END-REWRITE|END-SEARCH|END-START|END-STRING|END-SUBTRACT|END-UNSTRING|END-WRITE|ENDING|ENTER|ENTRY|ENTRY-PROCEDURE|ENVIRONMENT|EOL|EOP|EOS|ERASE|ERROR|ESCAPE|ESI|EVALUATE|EVENT|EVERY|EXCEPTION|EXCLUSIVE|EXHIBIT|EXIT|EXPORT|EXTEND|EXTENDED|EXTERNAL|FD|FILE|FILE-CONTROL|FILLER|FINAL|FIRST|FOOTING|FOR|FOREGROUND-COLOR|FOREGROUND-COLOUR|FROM|FULL|FUNCTION|FUNCTION-POINTER|FUNCTIONNAME|GENERATE|GIVING|GLOBAL|GO|GOBACK|GRID|GROUP|HEADING|HIGH-VALUE|HIGH-VALUES|HIGHLIGHT|I-O|I-O-CONTROL|ID|IDENTIFICATION|IF|IMPLICIT|IMPORT|IN|INDEX|INDEXED|INDICATE|INITIAL|INITIALIZE|INITIATE|INPUT|INPUT-OUTPUT|INSPECT|INSTALLATION|INTEGER|INTO|INVALID|INVOKE|IS|JUST|JUSTIFIED|KANJI|KEPT|KEY|KEYBOARD|LABEL|LANGUAGE|LAST|LB|LD|LEADING|LEFT|LEFTLINE|LENGTH|LENGTH-CHECK|LIBACCESS|LIBPARAMETER|LIBRARY|LIMIT|LIMITS|LINAGE|LINAGE-COUNTER|LINE|LINE-COUNTER|LINES|LINKAGE|LIST|LOCAL|LOCAL-STORAGE|LOCK|LONG-DATE|LONG-TIME|LOW-VALUE|LOW-VALUES|LOWER|LOWLIGHT|MEMORY|MERGE|MESSAGE|MMDDYYYY|MODE|MODULES|MORE-LABELS|MOVE|MULTIPLE|MULTIPLY|NAMED|NATIONAL|NATIONAL-EDITED|NATIVE|NEGATIVE|NETWORK|NEXT|NO|NO-ECHO|NULL|NULLS|NUMBER|NUMERIC|NUMERIC-DATE|NUMERIC-EDITED|NUMERIC-TIME|OBJECT-COMPUTER|OCCURS|ODT|OF|OFF|OMITTED|ON|OPEN|OPTIONAL|ORDER|ORDERLY|ORGANIZATION|OTHER|OUTPUT|OVERFLOW|OVERLINE|OWN|PACKED-DECIMAL|PADDING|PAGE|PAGE-COUNTER|PASSWORD|PERFORM|PF|PH|PIC|PICTURE|PLUS|POINTER|PORT|POSITION|POSITIVE|PRINTER|PRINTING|PRIVATE|PROCEDURE|PROCEDURE-POINTER|PROCEDURES|PROCEED|PROCESS|PROGRAM|PROGRAM-ID|PROGRAM-LIBRARY|PROMPT|PURGE|QUEUE|QUOTE|QUOTES|RANDOM|RD|READ|READER|REAL|RECEIVE|RECEIVED|RECORD|RECORDING|RECORDS|RECURSIVE|REDEFINES|REEL|REF|REFERENCE|REFERENCES|RELATIVE|RELEASE|REMAINDER|REMARKS|REMOTE|REMOVAL|REMOVE|RENAMES|REPLACE|REPLACING|REPORT|REPORTING|REPORTS|REQUIRED|RERUN|RESERVE|RESET|RETURN|RETURN-CODE|RETURNING|REVERSE-VIDEO|REVERSED|REWIND|REWRITE|RF|RH|RIGHT|ROUNDED|RUN|SAME|SAVE|SCREEN|SD|SEARCH|SECTION|SECURE|SECURITY|SEGMENT|SEGMENT-LIMIT|SELECT|SEND|SENTENCE|SEPARATE|SEQUENCE|SEQUENTIAL|SET|SHARED|SHAREDBYALL|SHAREDBYRUNUNIT|SHARING|SHIFT-IN|SHIFT-OUT|SHORT-DATE|SIGN|SIZE|SORT|SORT-CONTROL|SORT-CORE-SIZE|SORT-FILE-SIZE|SORT-MERGE|SORT-MESSAGE|SORT-MODE-SIZE|SORT-RETURN|SOURCE|SOURCE-COMPUTER|SPACE|SPACES|SPECIAL-NAMES|STANDARD|STANDARD-1|STANDARD-2|START|STATUS|STOP|STRING|SUB-QUEUE-1|SUB-QUEUE-2|SUB-QUEUE-3|SUBTRACT|SUM|SUPPRESS|SYMBOL|SYMBOLIC|SYNC|SYNCHRONIZED|TABLE|TALLY|TALLYING|TAPE|TASK|TERMINAL|TERMINATE|TEST|TEXT|THEN|THREAD|THREAD-LOCAL|THROUGH|THRU|TIME|TIMER|TIMES|TITLE|TO|TODAYS-DATE|TODAYS-NAME|TOP|TRAILING|TRUNCATED|TYPE|TYPEDEF|UNDERLINE|UNIT|UNSTRING|UNTIL|UP|UPON|USAGE|USE|USING|VALUE|VALUES|VARYING|VIRTUAL|WAIT|WHEN|WHEN-COMPILED|WITH|WORDS|WORKING-STORAGE|WRITE|YEAR|YYYYDDD|YYYYMMDD|ZERO-FILL|ZEROES|ZEROS)(?![\w-])/i,lookbehind:!0},boolean:{pattern:/(^|[^\w-])(?:false|true)(?![\w-])/i,lookbehind:!0},number:{pattern:/(^|[^\w-])(?:[+-]?(?:(?:\d+(?:[.,]\d+)?|[.,]\d+)(?:e[+-]?\d+)?|zero))(?![\w-])/i,lookbehind:!0},operator:[/<>|[<>]=?|[=+*/&]/,{pattern:/(^|[^\w-])(?:-|and|equal|greater|less|not|or|than)(?![\w-])/i,lookbehind:!0}],punctuation:/[.:,()]/}}iE.displayName="coffeescript";iE.aliases=["coffee"];function iE(e){e.register(wr),(function(t){var n=/#(?!\{).+/,r={pattern:/#\{[^}]+\}/,alias:"variable"};t.languages.coffeescript=t.languages.extend("javascript",{comment:n,string:[{pattern:/'(?:\\[\s\S]|[^\\'])*'/,greedy:!0},{pattern:/"(?:\\[\s\S]|[^\\"])*"/,greedy:!0,inside:{interpolation:r}}],keyword:/\b(?:and|break|by|catch|class|continue|debugger|delete|do|each|else|extend|extends|false|finally|for|if|in|instanceof|is|isnt|let|loop|namespace|new|no|not|null|of|off|on|or|own|return|super|switch|then|this|throw|true|try|typeof|undefined|unless|until|when|while|window|with|yes|yield)\b/,"class-member":{pattern:/@(?!\d)\w+/,alias:"variable"}}),t.languages.insertBefore("coffeescript","comment",{"multiline-comment":{pattern:/###[\s\S]+?###/,alias:"comment"},"block-regex":{pattern:/\/{3}[\s\S]*?\/{3}/,alias:"regex",inside:{comment:n,interpolation:r}}}),t.languages.insertBefore("coffeescript","string",{"inline-javascript":{pattern:/`(?:\\[\s\S]|[^\\`])*`/,inside:{delimiter:{pattern:/^`|`$/,alias:"punctuation"},script:{pattern:/[\s\S]+/,alias:"language-javascript",inside:t.languages.javascript}}},"multiline-string":[{pattern:/'''[\s\S]*?'''/,greedy:!0,alias:"string"},{pattern:/"""[\s\S]*?"""/,greedy:!0,alias:"string",inside:{interpolation:r}}]}),t.languages.insertBefore("coffeescript","keyword",{property:/(?!\d)\w+(?=\s*:(?!:))/}),delete t.languages.coffeescript["template-string"],t.languages.coffee=t.languages.coffeescript})(e)}oE.displayName="concurnas";oE.aliases=["conc"];function oE(e){e.languages.concurnas={comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?(?:\*\/|$)|\/\/.*)/,lookbehind:!0,greedy:!0},langext:{pattern:/\b\w+\s*\|\|[\s\S]+?\|\|/,greedy:!0,inside:{"class-name":/^\w+/,string:{pattern:/(^\s*\|\|)[\s\S]+(?=\|\|$)/,lookbehind:!0},punctuation:/\|\|/}},function:{pattern:/((?:^|\s)def[ \t]+)[a-zA-Z_]\w*(?=\s*\()/,lookbehind:!0},keyword:/\b(?:abstract|actor|also|annotation|assert|async|await|bool|boolean|break|byte|case|catch|changed|char|class|closed|constant|continue|def|default|del|double|elif|else|enum|every|extends|false|finally|float|for|from|global|gpudef|gpukernel|if|import|in|init|inject|int|lambda|local|long|loop|match|new|nodefault|null|of|onchange|open|out|override|package|parfor|parforsync|post|pre|private|protected|provide|provider|public|return|shared|short|single|size_t|sizeof|super|sync|this|throw|trait|trans|transient|true|try|typedef|unchecked|using|val|var|void|while|with)\b/,boolean:/\b(?:false|true)\b/,number:/\b0b[01][01_]*L?\b|\b0x(?:[\da-f_]*\.)?[\da-f_p+-]+\b|(?:\b\d[\d_]*(?:\.[\d_]*)?|\B\.\d[\d_]*)(?:e[+-]?\d[\d_]*)?[dfls]?/i,punctuation:/[{}[\];(),.:]/,operator:/<==|>==|=>|->|<-|<>|&==|&<>|\?:?|\.\?|\+\+|--|[-+*/=<>]=?|[!^~]|\b(?:and|as|band|bor|bxor|comp|is|isnot|mod|or)\b=?/,annotation:{pattern:/@(?:\w+:)?(?:\w+|\[[^\]]+\])?/,alias:"builtin"}},e.languages.insertBefore("concurnas","langext",{"regex-literal":{pattern:/\br("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0,inside:{interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}/,lookbehind:!0,inside:e.languages.concurnas},regex:/[\s\S]+/}},"string-literal":{pattern:/(?:\B|\bs)("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0,inside:{interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}/,lookbehind:!0,inside:e.languages.concurnas},string:/[\s\S]+/}}}),e.languages.conc=e.languages.concurnas}sE.displayName="csp";sE.aliases=[];function sE(e){(function(t){function n(r){return RegExp(/([ \t])/.source+"(?:"+r+")"+/(?=[\s;]|$)/.source,"i")}t.languages.csp={directive:{pattern:/(^|[\s;])(?:base-uri|block-all-mixed-content|(?:child|connect|default|font|frame|img|manifest|media|object|prefetch|script|style|worker)-src|disown-opener|form-action|frame-(?:ancestors|options)|input-protection(?:-(?:clip|selectors))?|navigate-to|plugin-types|policy-uri|referrer|reflected-xss|report-(?:to|uri)|require-sri-for|sandbox|(?:script|style)-src-(?:attr|elem)|upgrade-insecure-requests)(?=[\s;]|$)/i,lookbehind:!0,alias:"property"},scheme:{pattern:n(/[a-z][a-z0-9.+-]*:/.source),lookbehind:!0},none:{pattern:n(/'none'/.source),lookbehind:!0,alias:"keyword"},nonce:{pattern:n(/'nonce-[-+/\w=]+'/.source),lookbehind:!0,alias:"number"},hash:{pattern:n(/'sha(?:256|384|512)-[-+/\w=]+'/.source),lookbehind:!0,alias:"number"},host:{pattern:n(/[a-z][a-z0-9.+-]*:\/\/[^\s;,']*/.source+"|"+/\*[^\s;,']*/.source+"|"+/[a-z0-9-]+(?:\.[a-z0-9-]+)+(?::[\d*]+)?(?:\/[^\s;,']*)?/.source),lookbehind:!0,alias:"url",inside:{important:/\*/}},keyword:[{pattern:n(/'unsafe-[a-z-]+'/.source),lookbehind:!0,alias:"unsafe"},{pattern:n(/'[a-z-]+'/.source),lookbehind:!0,alias:"safe"}],punctuation:/;/}})(e)}lE.displayName="cooklang";lE.aliases=[];function lE(e){(function(t){var n=/(?:(?!\s)[\d$+<=a-zA-Z\x80-\uFFFF])+/.source,r=/[^{}@#]+/.source,a=/\{[^}#@]*\}/.source,i=r+a,o=/(?:h|hours|hrs|m|min|minutes)/.source,l={pattern:/\{[^{}]*\}/,inside:{amount:{pattern:/([\{|])[^{}|*%]+/,lookbehind:!0,alias:"number"},unit:{pattern:/(%)[^}]+/,lookbehind:!0,alias:"symbol"},"servings-scaler":{pattern:/\*/,alias:"operator"},"servings-alternative-separator":{pattern:/\|/,alias:"operator"},"unit-separator":{pattern:/(?:%|(\*)%)/,lookbehind:!0,alias:"operator"},punctuation:/[{}]/}};t.languages.cooklang={comment:{pattern:/\[-[\s\S]*?-\]|--.*/,greedy:!0},meta:{pattern:/>>.*:.*/,inside:{property:{pattern:/(>>\s*)[^\s:](?:[^:]*[^\s:])?/,lookbehind:!0}}},"cookware-group":{pattern:new RegExp("#(?:"+i+"|"+n+")"),inside:{cookware:{pattern:new RegExp("(^#)(?:"+r+")"),lookbehind:!0,alias:"variable"},"cookware-keyword":{pattern:/^#/,alias:"keyword"},"quantity-group":{pattern:new RegExp(/\{[^{}@#]*\}/),inside:{quantity:{pattern:new RegExp(/(^\{)/.source+r),lookbehind:!0,alias:"number"},punctuation:/[{}]/}}}},"ingredient-group":{pattern:new RegExp("@(?:"+i+"|"+n+")"),inside:{ingredient:{pattern:new RegExp("(^@)(?:"+r+")"),lookbehind:!0,alias:"variable"},"ingredient-keyword":{pattern:/^@/,alias:"keyword"},"amount-group":l}},"timer-group":{pattern:/~(?!\s)[^@#~{}]*\{[^{}]*\}/,inside:{timer:{pattern:/(^~)[^{]+/,lookbehind:!0,alias:"variable"},"duration-group":{pattern:/\{[^{}]*\}/,inside:{punctuation:/[{}]/,unit:{pattern:new RegExp(/(%\s*)/.source+o+/\b/.source),lookbehind:!0,alias:"symbol"},operator:/%/,duration:{pattern:/\d+/,alias:"number"}}},"timer-keyword":{pattern:/^~/,alias:"keyword"}}}}})(e)}cE.displayName="coq";cE.aliases=[];function cE(e){(function(t){for(var n=/\(\*(?:[^(*]|\((?!\*)|\*(?!\))|<self>)*\*\)/.source,r=0;r<2;r++)n=n.replace(/<self>/g,function(){return n});n=n.replace(/<self>/g,"[]"),t.languages.coq={comment:RegExp(n),string:{pattern:/"(?:[^"]|"")*"(?!")/,greedy:!0},attribute:[{pattern:RegExp(/#\[(?:[^\[\]("]|"(?:[^"]|"")*"(?!")|\((?!\*)|<comment>)*\]/.source.replace(/<comment>/g,function(){return n})),greedy:!0,alias:"attr-name",inside:{comment:RegExp(n),string:{pattern:/"(?:[^"]|"")*"(?!")/,greedy:!0},operator:/=/,punctuation:/^#\[|\]$|[,()]/}},{pattern:/\b(?:Cumulative|Global|Local|Monomorphic|NonCumulative|Polymorphic|Private|Program)\b/,alias:"attr-name"}],keyword:/\b(?:Abort|About|Add|Admit|Admitted|All|Arguments|As|Assumptions|Axiom|Axioms|Back|BackTo|Backtrace|BinOp|BinOpSpec|BinRel|Bind|Blacklist|Canonical|Case|Cd|Check|Class|Classes|Close|CoFixpoint|CoInductive|Coercion|Coercions|Collection|Combined|Compute|Conjecture|Conjectures|Constant|Constants|Constraint|Constructors|Context|Corollary|Create|CstOp|Custom|Cut|Debug|Declare|Defined|Definition|Delimit|Dependencies|Dependent|Derive|Diffs|Drop|Elimination|End|Entry|Equality|Eval|Example|Existential|Existentials|Existing|Export|Extern|Extraction|Fact|Fail|Field|File|Firstorder|Fixpoint|Flags|Focus|From|Funclass|Function|Functional|GC|Generalizable|Goal|Grab|Grammar|Graph|Guarded|Haskell|Heap|Hide|Hint|HintDb|Hints|Hypotheses|Hypothesis|IF|Identity|Immediate|Implicit|Implicits|Import|Include|Induction|Inductive|Infix|Info|Initial|InjTyp|Inline|Inspect|Instance|Instances|Intro|Intros|Inversion|Inversion_clear|JSON|Language|Left|Lemma|Let|Lia|Libraries|Library|Load|LoadPath|Locate|Ltac|Ltac2|ML|Match|Method|Minimality|Module|Modules|Morphism|Next|NoInline|Notation|Number|OCaml|Obligation|Obligations|Opaque|Open|Optimize|Parameter|Parameters|Parametric|Path|Paths|Prenex|Preterm|Primitive|Print|Profile|Projections|Proof|Prop|PropBinOp|PropOp|PropUOp|Property|Proposition|Pwd|Qed|Quit|Rec|Record|Recursive|Redirect|Reduction|Register|Relation|Remark|Remove|Require|Reserved|Reset|Resolve|Restart|Rewrite|Right|Ring|Rings|SProp|Saturate|Save|Scheme|Scope|Scopes|Search|SearchHead|SearchPattern|SearchRewrite|Section|Separate|Set|Setoid|Show|Signatures|Solve|Solver|Sort|Sortclass|Sorted|Spec|Step|Strategies|Strategy|String|Structure|SubClass|Subgraph|SuchThat|Tactic|Term|TestCompile|Theorem|Time|Timeout|To|Transparent|Type|Typeclasses|Types|Typing|UnOp|UnOpSpec|Undelimit|Undo|Unfocus|Unfocused|Unfold|Universe|Universes|Unshelve|Variable|Variables|Variant|Verbose|View|Visibility|Zify|_|apply|as|at|by|cofix|else|end|exists|exists2|fix|for|forall|fun|if|in|let|match|measure|move|removed|return|struct|then|using|wf|where|with)\b/,number:/\b(?:0x[a-f0-9][a-f0-9_]*(?:\.[a-f0-9_]+)?(?:p[+-]?\d[\d_]*)?|\d[\d_]*(?:\.[\d_]+)?(?:e[+-]?\d[\d_]*)?)\b/i,punct:{pattern:/@\{|\{\||\[=|:>/,alias:"punctuation"},operator:/\/\\|\\\/|\.{2,3}|:{1,2}=|\*\*|[-=]>|<(?:->?|[+:=>]|<:)|>(?:=|->)|\|[-|]?|[-!%&*+/<=>?@^~']/,punctuation:/\.\(|`\(|@\{|`\{|\{\||\[=|:>|[:.,;(){}\[\]]/}})(e)}Tu.displayName="ruby";Tu.aliases=["rb"];function Tu(e){e.register(Mt),(function(t){t.languages.ruby=t.languages.extend("clike",{comment:{pattern:/#.*|^=begin\s[\s\S]*?^=end/m,greedy:!0},"class-name":{pattern:/(\b(?:class|module)\s+|\bcatch\s+\()[\w.\\]+|\b[A-Z_]\w*(?=\s*\.\s*new\b)/,lookbehind:!0,inside:{punctuation:/[.\\]/}},keyword:/\b(?:BEGIN|END|alias|and|begin|break|case|class|def|define_method|defined|do|each|else|elsif|end|ensure|extend|for|if|in|include|module|new|next|nil|not|or|prepend|private|protected|public|raise|redo|require|rescue|retry|return|self|super|then|throw|undef|unless|until|when|while|yield)\b/,operator:/\.{2,3}|&\.|===|<?=>|[!=]?~|(?:&&|\|\||<<|>>|\*\*|[+\-*/%<>!^&|=])=?|[?:]/,punctuation:/[(){}[\].,;]/}),t.languages.insertBefore("ruby","operator",{"double-colon":{pattern:/::/,alias:"punctuation"}});var n={pattern:/((?:^|[^\\])(?:\\{2})*)#\{(?:[^{}]|\{[^{}]*\})*\}/,lookbehind:!0,inside:{content:{pattern:/^(#\{)[\s\S]+(?=\}$)/,lookbehind:!0,inside:t.languages.ruby},delimiter:{pattern:/^#\{|\}$/,alias:"punctuation"}}};delete t.languages.ruby.function;var r="(?:"+[/([^a-zA-Z0-9\s{(\[<=])(?:(?!\1)[^\\]|\\[\s\S])*\1/.source,/\((?:[^()\\]|\\[\s\S]|\((?:[^()\\]|\\[\s\S])*\))*\)/.source,/\{(?:[^{}\\]|\\[\s\S]|\{(?:[^{}\\]|\\[\s\S])*\})*\}/.source,/\[(?:[^\[\]\\]|\\[\s\S]|\[(?:[^\[\]\\]|\\[\s\S])*\])*\]/.source,/<(?:[^<>\\]|\\[\s\S]|<(?:[^<>\\]|\\[\s\S])*>)*>/.source].join("|")+")",a=/(?:"(?:\\.|[^"\\\r\n])*"|(?:\b[a-zA-Z_]\w*|[^\s\0-\x7F]+)[?!]?|\$.)/.source;t.languages.insertBefore("ruby","keyword",{"regex-literal":[{pattern:RegExp(/%r/.source+r+/[egimnosux]{0,6}/.source),greedy:!0,inside:{interpolation:n,regex:/[\s\S]+/}},{pattern:/(^|[^/])\/(?!\/)(?:\[[^\r\n\]]+\]|\\.|[^[/\\\r\n])+\/[egimnosux]{0,6}(?=\s*(?:$|[\r\n,.;})#]))/,lookbehind:!0,greedy:!0,inside:{interpolation:n,regex:/[\s\S]+/}}],variable:/[@$]+[a-zA-Z_]\w*(?:[?!]|\b)/,symbol:[{pattern:RegExp(/(^|[^:]):/.source+a),lookbehind:!0,greedy:!0},{pattern:RegExp(/([\r\n{(,][ \t]*)/.source+a+/(?=:(?!:))/.source),lookbehind:!0,greedy:!0}],"method-definition":{pattern:/(\bdef\s+)\w+(?:\s*\.\s*\w+)?/,lookbehind:!0,inside:{function:/\b\w+$/,keyword:/^self\b/,"class-name":/^\w+/,punctuation:/\./}}}),t.languages.insertBefore("ruby","string",{"string-literal":[{pattern:RegExp(/%[qQiIwWs]?/.source+r),greedy:!0,inside:{interpolation:n,string:/[\s\S]+/}},{pattern:/("|')(?:#\{[^}]+\}|#(?!\{)|\\(?:\r\n|[\s\S])|(?!\1)[^\\#\r\n])*\1/,greedy:!0,inside:{interpolation:n,string:/[\s\S]+/}},{pattern:/<<[-~]?([a-z_]\w*)[\r\n](?:.*[\r\n])*?[\t ]*\1/i,alias:"heredoc-string",greedy:!0,inside:{delimiter:{pattern:/^<<[-~]?[a-z_]\w*|\b[a-z_]\w*$/i,inside:{symbol:/\b\w+/,punctuation:/^<<[-~]?/}},interpolation:n,string:/[\s\S]+/}},{pattern:/<<[-~]?'([a-z_]\w*)'[\r\n](?:.*[\r\n])*?[\t ]*\1/i,alias:"heredoc-string",greedy:!0,inside:{delimiter:{pattern:/^<<[-~]?'[a-z_]\w*'|\b[a-z_]\w*$/i,inside:{symbol:/\b\w+/,punctuation:/^<<[-~]?'|'$/}},string:/[\s\S]+/}}],"command-literal":[{pattern:RegExp(/%x/.source+r),greedy:!0,inside:{interpolation:n,command:{pattern:/[\s\S]+/,alias:"string"}}},{pattern:/`(?:#\{[^}]+\}|#(?!\{)|\\(?:\r\n|[\s\S])|[^\\`#\r\n])*`/,greedy:!0,inside:{interpolation:n,command:{pattern:/[\s\S]+/,alias:"string"}}}]}),delete t.languages.ruby.string,t.languages.insertBefore("ruby","number",{builtin:/\b(?:Array|Bignum|Binding|Class|Continuation|Dir|Exception|FalseClass|File|Fixnum|Float|Hash|IO|Integer|MatchData|Method|Module|NilClass|Numeric|Object|Proc|Range|Regexp|Stat|String|Struct|Symbol|TMS|Thread|ThreadGroup|Time|TrueClass)\b/,constant:/\b[A-Z][A-Z0-9_]*(?:[?!]|\b)/}),t.languages.rb=t.languages.ruby})(e)}uE.displayName="crystal";uE.aliases=[];function uE(e){e.register(Tu),(function(t){t.languages.crystal=t.languages.extend("ruby",{keyword:[/\b(?:__DIR__|__END_LINE__|__FILE__|__LINE__|abstract|alias|annotation|as|asm|begin|break|case|class|def|do|else|elsif|end|ensure|enum|extend|for|fun|if|ifdef|include|instance_sizeof|lib|macro|module|next|of|out|pointerof|private|protected|ptr|require|rescue|return|select|self|sizeof|struct|super|then|type|typeof|undef|uninitialized|union|unless|until|when|while|with|yield)\b/,{pattern:/(\.\s*)(?:is_a|responds_to)\?/,lookbehind:!0}],number:/\b(?:0b[01_]*[01]|0o[0-7_]*[0-7]|0x[\da-fA-F_]*[\da-fA-F]|(?:\d(?:[\d_]*\d)?)(?:\.[\d_]*\d)?(?:[eE][+-]?[\d_]*\d)?)(?:_(?:[uif](?:8|16|32|64))?)?\b/,operator:[/->/,t.languages.ruby.operator],punctuation:/[(){}[\].,;\\]/}),t.languages.insertBefore("crystal","string-literal",{attribute:{pattern:/@\[.*?\]/,inside:{delimiter:{pattern:/^@\[|\]$/,alias:"punctuation"},attribute:{pattern:/^(\s*)\w+/,lookbehind:!0,alias:"class-name"},args:{pattern:/\S(?:[\s\S]*\S)?/,inside:t.languages.crystal}}},expansion:{pattern:/\{(?:\{.*?\}|%.*?%)\}/,inside:{content:{pattern:/^(\{.)[\s\S]+(?=.\}$)/,lookbehind:!0,inside:t.languages.crystal},delimiter:{pattern:/^\{[\{%]|[\}%]\}$/,alias:"operator"}}},char:{pattern:/'(?:[^\\\r\n]{1,2}|\\(?:.|u(?:[A-Fa-f0-9]{1,4}|\{[A-Fa-f0-9]{1,6}\})))'/,greedy:!0}})})(e)}dE.displayName="css-extras";dE.aliases=[];function dE(e){e.register(Ll),(function(t){var n=/("|')(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,r;t.languages.css.selector={pattern:t.languages.css.selector.pattern,lookbehind:!0,inside:r={"pseudo-element":/:(?:after|before|first-letter|first-line|selection)|::[-\w]+/,"pseudo-class":/:[-\w]+/,class:/\.[-\w]+/,id:/#[-\w]+/,attribute:{pattern:RegExp(`\\[(?:[^[\\]"']|`+n.source+")*\\]"),greedy:!0,inside:{punctuation:/^\[|\]$/,"case-sensitivity":{pattern:/(\s)[si]$/i,lookbehind:!0,alias:"keyword"},namespace:{pattern:/^(\s*)(?:(?!\s)[-*\w\xA0-\uFFFF])*\|(?!=)/,lookbehind:!0,inside:{punctuation:/\|$/}},"attr-name":{pattern:/^(\s*)(?:(?!\s)[-\w\xA0-\uFFFF])+/,lookbehind:!0},"attr-value":[n,{pattern:/(=\s*)(?:(?!\s)[-\w\xA0-\uFFFF])+(?=\s*$)/,lookbehind:!0}],operator:/[|~*^$]?=/}},"n-th":[{pattern:/(\(\s*)[+-]?\d*[\dn](?:\s*[+-]\s*\d+)?(?=\s*\))/,lookbehind:!0,inside:{number:/[\dn]+/,operator:/[+-]/}},{pattern:/(\(\s*)(?:even|odd)(?=\s*\))/i,lookbehind:!0}],combinator:/>|\+|~|\|\|/,punctuation:/[(),]/}},t.languages.css.atrule.inside["selector-function-argument"].inside=r,t.languages.insertBefore("css","property",{variable:{pattern:/(^|[^-\w\xA0-\uFFFF])--(?!\s)[-_a-z\xA0-\uFFFF](?:(?!\s)[-\w\xA0-\uFFFF])*/i,lookbehind:!0}});var a={pattern:/(\b\d+)(?:%|[a-z]+(?![\w-]))/,lookbehind:!0},i={pattern:/(^|[^\w.-])-?(?:\d+(?:\.\d+)?|\.\d+)/,lookbehind:!0};t.languages.insertBefore("css","function",{operator:{pattern:/(\s)[+\-*\/](?=\s)/,lookbehind:!0},hexcode:{pattern:/\B#[\da-f]{3,8}\b/i,alias:"color"},color:[{pattern:/(^|[^\w-])(?:AliceBlue|AntiqueWhite|Aqua|Aquamarine|Azure|Beige|Bisque|Black|BlanchedAlmond|Blue|BlueViolet|Brown|BurlyWood|CadetBlue|Chartreuse|Chocolate|Coral|CornflowerBlue|Cornsilk|Crimson|Cyan|DarkBlue|DarkCyan|DarkGoldenRod|DarkGr[ae]y|DarkGreen|DarkKhaki|DarkMagenta|DarkOliveGreen|DarkOrange|DarkOrchid|DarkRed|DarkSalmon|DarkSeaGreen|DarkSlateBlue|DarkSlateGr[ae]y|DarkTurquoise|DarkViolet|DeepPink|DeepSkyBlue|DimGr[ae]y|DodgerBlue|FireBrick|FloralWhite|ForestGreen|Fuchsia|Gainsboro|GhostWhite|Gold|GoldenRod|Gr[ae]y|Green|GreenYellow|HoneyDew|HotPink|IndianRed|Indigo|Ivory|Khaki|Lavender|LavenderBlush|LawnGreen|LemonChiffon|LightBlue|LightCoral|LightCyan|LightGoldenRodYellow|LightGr[ae]y|LightGreen|LightPink|LightSalmon|LightSeaGreen|LightSkyBlue|LightSlateGr[ae]y|LightSteelBlue|LightYellow|Lime|LimeGreen|Linen|Magenta|Maroon|MediumAquaMarine|MediumBlue|MediumOrchid|MediumPurple|MediumSeaGreen|MediumSlateBlue|MediumSpringGreen|MediumTurquoise|MediumVioletRed|MidnightBlue|MintCream|MistyRose|Moccasin|NavajoWhite|Navy|OldLace|Olive|OliveDrab|Orange|OrangeRed|Orchid|PaleGoldenRod|PaleGreen|PaleTurquoise|PaleVioletRed|PapayaWhip|PeachPuff|Peru|Pink|Plum|PowderBlue|Purple|RebeccaPurple|Red|RosyBrown|RoyalBlue|SaddleBrown|Salmon|SandyBrown|SeaGreen|SeaShell|Sienna|Silver|SkyBlue|SlateBlue|SlateGr[ae]y|Snow|SpringGreen|SteelBlue|Tan|Teal|Thistle|Tomato|Transparent|Turquoise|Violet|Wheat|White|WhiteSmoke|Yellow|YellowGreen)(?![\w-])/i,lookbehind:!0},{pattern:/\b(?:hsl|rgb)\(\s*\d{1,3}\s*,\s*\d{1,3}%?\s*,\s*\d{1,3}%?\s*\)\B|\b(?:hsl|rgb)a\(\s*\d{1,3}\s*,\s*\d{1,3}%?\s*,\s*\d{1,3}%?\s*,\s*(?:0|0?\.\d+|1)\s*\)\B/i,inside:{unit:a,number:i,function:/[\w-]+(?=\()/,punctuation:/[(),]/}}],entity:/\\[\da-f]{1,8}/i,unit:a,number:i})})(e)}hE.displayName="csv";hE.aliases=[];function hE(e){e.languages.csv={value:/[^\r\n,"]+|"(?:[^"]|"")*"(?!")/,punctuation:/,/}}pE.displayName="cue";pE.aliases=[];function pE(e){(function(t){var n=/\\(?:(?!\2)|\2(?:[^()\r\n]|\([^()]*\)))/.source,r=/"""(?:[^\\"]|"(?!""\2)|<esc>)*"""/.source+"|"+/'''(?:[^\\']|'(?!''\2)|<esc>)*'''/.source+"|"+/"(?:[^\\\r\n"]|"(?!\2)|<esc>)*"/.source+"|"+/'(?:[^\\\r\n']|'(?!\2)|<esc>)*'/.source,a="(?:"+r.replace(/<esc>/g,n)+")";t.languages.cue={comment:{pattern:/\/\/.*/,greedy:!0},"string-literal":{pattern:RegExp(/(^|[^#"'\\])(#*)/.source+a+/(?!["'])\2/.source),lookbehind:!0,greedy:!0,inside:{escape:{pattern:/(?=[\s\S]*["'](#*)$)\\\1(?:U[a-fA-F0-9]{1,8}|u[a-fA-F0-9]{1,4}|x[a-fA-F0-9]{1,2}|\d{2,3}|[^(])/,greedy:!0,alias:"string"},interpolation:{pattern:/(?=[\s\S]*["'](#*)$)\\\1\([^()]*\)/,greedy:!0,inside:{punctuation:/^\\#*\(|\)$/,expression:{pattern:/[\s\S]+/,inside:null}}},string:/[\s\S]+/}},keyword:{pattern:/(^|[^\w$])(?:for|if|import|in|let|null|package)(?![\w$])/,lookbehind:!0},boolean:{pattern:/(^|[^\w$])(?:false|true)(?![\w$])/,lookbehind:!0},builtin:{pattern:/(^|[^\w$])(?:bool|bytes|float|float(?:32|64)|u?int(?:8|16|32|64|128)?|number|rune|string)(?![\w$])/,lookbehind:!0},attribute:{pattern:/@[\w$]+(?=\s*\()/,alias:"function"},function:{pattern:/(^|[^\w$])[a-z_$][\w$]*(?=\s*\()/i,lookbehind:!0},number:{pattern:/(^|[^\w$.])(?:0b[01]+(?:_[01]+)*|0o[0-7]+(?:_[0-7]+)*|0[xX][0-9A-Fa-f]+(?:_[0-9A-Fa-f]+)*|(?:\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\.\d+(?:_\d+)*)(?:[eE][+-]?\d+(?:_\d+)*)?(?:[KMGTP]i?)?)(?![\w$])/,lookbehind:!0},operator:/\.{3}|_\|_|&&?|\|\|?|[=!]~|[<>=!]=?|[+\-*/?]/,punctuation:/[()[\]{},.:]/},t.languages.cue["string-literal"].inside.interpolation.inside.expression.inside=t.languages.cue})(e)}fE.displayName="cypher";fE.aliases=[];function fE(e){e.languages.cypher={comment:/\/\/.*/,string:{pattern:/"(?:[^"\\\r\n]|\\.)*"|'(?:[^'\\\r\n]|\\.)*'/,greedy:!0},"class-name":{pattern:/(:\s*)(?:\w+|`(?:[^`\\\r\n])*`)(?=\s*[{):])/,lookbehind:!0,greedy:!0},relationship:{pattern:/(-\[\s*(?:\w+\s*|`(?:[^`\\\r\n])*`\s*)?:\s*|\|\s*:\s*)(?:\w+|`(?:[^`\\\r\n])*`)/,lookbehind:!0,greedy:!0,alias:"property"},identifier:{pattern:/`(?:[^`\\\r\n])*`/,greedy:!0},variable:/\$\w+/,keyword:/\b(?:ADD|ALL|AND|AS|ASC|ASCENDING|ASSERT|BY|CALL|CASE|COMMIT|CONSTRAINT|CONTAINS|CREATE|CSV|DELETE|DESC|DESCENDING|DETACH|DISTINCT|DO|DROP|ELSE|END|ENDS|EXISTS|FOR|FOREACH|IN|INDEX|IS|JOIN|KEY|LIMIT|LOAD|MANDATORY|MATCH|MERGE|NODE|NOT|OF|ON|OPTIONAL|OR|ORDER(?=\s+BY)|PERIODIC|REMOVE|REQUIRE|RETURN|SCALAR|SCAN|SET|SKIP|START|STARTS|THEN|UNION|UNIQUE|UNWIND|USING|WHEN|WHERE|WITH|XOR|YIELD)\b/i,function:/\b\w+\b(?=\s*\()/,boolean:/\b(?:false|null|true)\b/i,number:/\b(?:0x[\da-fA-F]+|\d+(?:\.\d+)?(?:[eE][+-]?\d+)?)\b/,operator:/:|<--?|--?>?|<>|=~?|[<>]=?|[+*/%^|]|\.\.\.?/,punctuation:/[()[\]{},;.]/}}mE.displayName="d";mE.aliases=[];function mE(e){e.register(Mt),e.languages.d=e.languages.extend("clike",{comment:[{pattern:/^\s*#!.+/,greedy:!0},{pattern:RegExp(/(^|[^\\])/.source+"(?:"+[/\/\+(?:\/\+(?:[^+]|\+(?!\/))*\+\/|(?!\/\+)[\s\S])*?\+\//.source,/\/\/.*/.source,/\/\*[\s\S]*?\*\//.source].join("|")+")"),lookbehind:!0,greedy:!0}],string:[{pattern:RegExp([/\b[rx]"(?:\\[\s\S]|[^\\"])*"[cwd]?/.source,/\bq"(?:\[[\s\S]*?\]|\([\s\S]*?\)|<[\s\S]*?>|\{[\s\S]*?\})"/.source,/\bq"((?!\d)\w+)$[\s\S]*?^\1"/.source,/\bq"(.)[\s\S]*?\2"/.source,/(["`])(?:\\[\s\S]|(?!\3)[^\\])*\3[cwd]?/.source].join("|"),"m"),greedy:!0},{pattern:/\bq\{(?:\{[^{}]*\}|[^{}])*\}/,greedy:!0,alias:"token-string"}],keyword:/\$|\b(?:__(?:(?:DATE|EOF|FILE|FUNCTION|LINE|MODULE|PRETTY_FUNCTION|TIMESTAMP|TIME|VENDOR|VERSION)__|gshared|parameters|traits|vector)|abstract|alias|align|asm|assert|auto|body|bool|break|byte|case|cast|catch|cdouble|cent|cfloat|char|class|const|continue|creal|dchar|debug|default|delegate|delete|deprecated|do|double|dstring|else|enum|export|extern|false|final|finally|float|for|foreach|foreach_reverse|function|goto|idouble|if|ifloat|immutable|import|inout|int|interface|invariant|ireal|lazy|long|macro|mixin|module|new|nothrow|null|out|override|package|pragma|private|protected|ptrdiff_t|public|pure|real|ref|return|scope|shared|short|size_t|static|string|struct|super|switch|synchronized|template|this|throw|true|try|typedef|typeid|typeof|ubyte|ucent|uint|ulong|union|unittest|ushort|version|void|volatile|wchar|while|with|wstring)\b/,number:[/\b0x\.?[a-f\d_]+(?:(?!\.\.)\.[a-f\d_]*)?(?:p[+-]?[a-f\d_]+)?[ulfi]{0,4}/i,{pattern:/((?:\.\.)?)(?:\b0b\.?|\b|\.)\d[\d_]*(?:(?!\.\.)\.[\d_]*)?(?:e[+-]?\d[\d_]*)?[ulfi]{0,4}/i,lookbehind:!0}],operator:/\|[|=]?|&[&=]?|\+[+=]?|-[-=]?|\.?\.\.|=[>=]?|!(?:i[ns]\b|<>?=?|>=?|=)?|\bi[ns]\b|(?:<[<>]?|>>?>?|\^\^|[*\/%^~])=?/}),e.languages.insertBefore("d","string",{char:/'(?:\\(?:\W|\w+)|[^\\])'/}),e.languages.insertBefore("d","keyword",{property:/\B@\w*/}),e.languages.insertBefore("d","function",{register:{pattern:/\b(?:[ABCD][LHX]|E?(?:BP|DI|SI|SP)|[BS]PL|[ECSDGF]S|CR[0234]|[DS]IL|DR[012367]|E[ABCD]X|X?MM[0-7]|R(?:1[0-5]|[89])[BWD]?|R[ABCD]X|R[BS]P|R[DS]I|TR[3-7]|XMM(?:1[0-5]|[89])|YMM(?:1[0-5]|\d))\b|\bST(?:\([0-7]\)|\b)/,alias:"variable"}})}gE.displayName="dart";gE.aliases=[];function gE(e){e.register(Mt),(function(t){var n=[/\b(?:async|sync|yield)\*/,/\b(?:abstract|assert|async|await|break|case|catch|class|const|continue|covariant|default|deferred|do|dynamic|else|enum|export|extends|extension|external|factory|final|finally|for|get|hide|if|implements|import|in|interface|library|mixin|new|null|on|operator|part|rethrow|return|set|show|static|super|switch|sync|this|throw|try|typedef|var|void|while|with|yield)\b/],r=/(^|[^\w.])(?:[a-z]\w*\s*\.\s*)*(?:[A-Z]\w*\s*\.\s*)*/.source,a={pattern:RegExp(r+/[A-Z](?:[\d_A-Z]*[a-z]\w*)?\b/.source),lookbehind:!0,inside:{namespace:{pattern:/^[a-z]\w*(?:\s*\.\s*[a-z]\w*)*(?:\s*\.)?/,inside:{punctuation:/\./}}}};t.languages.dart=t.languages.extend("clike",{"class-name":[a,{pattern:RegExp(r+/[A-Z]\w*(?=\s+\w+\s*[;,=()])/.source),lookbehind:!0,inside:a.inside}],keyword:n,operator:/\bis!|\b(?:as|is)\b|\+\+|--|&&|\|\||<<=?|>>=?|~(?:\/=?)?|[+\-*\/%&^|=!<>]=?|\?/}),t.languages.insertBefore("dart","string",{"string-literal":{pattern:/r?(?:("""|''')[\s\S]*?\1|(["'])(?:\\.|(?!\2)[^\\\r\n])*\2(?!\2))/,greedy:!0,inside:{interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\$(?:\w+|\{(?:[^{}]|\{[^{}]*\})*\})/,lookbehind:!0,inside:{punctuation:/^\$\{?|\}$/,expression:{pattern:/[\s\S]+/,inside:t.languages.dart}}},string:/[\s\S]+/}},string:void 0}),t.languages.insertBefore("dart","class-name",{metadata:{pattern:/@\w+/,alias:"function"}}),t.languages.insertBefore("dart","class-name",{generics:{pattern:/<(?:[\w\s,.&?]|<(?:[\w\s,.&?]|<(?:[\w\s,.&?]|<[\w\s,.&?]*>)*>)*>)*>/,inside:{"class-name":a,keyword:n,punctuation:/[<>(),.:]/,operator:/[?&|]/}}})})(e)}bE.displayName="dataweave";bE.aliases=[];function bE(e){(function(t){t.languages.dataweave={url:/\b[A-Za-z]+:\/\/[\w/:.?=&-]+|\burn:[\w:.?=&-]+/,property:{pattern:/(?:\b\w+#)?(?:"(?:\\.|[^\\"\r\n])*"|\b\w+)(?=\s*[:@])/,greedy:!0},string:{pattern:/(["'`])(?:\\[\s\S]|(?!\1)[^\\])*\1/,greedy:!0},"mime-type":/\b(?:application|audio|image|multipart|text|video)\/[\w+-]+/,date:{pattern:/\|[\w:+-]+\|/,greedy:!0},comment:[{pattern:/(^|[^\\])\/\*[\s\S]*?(?:\*\/|$)/,lookbehind:!0,greedy:!0},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0,greedy:!0}],regex:{pattern:/\/(?:[^\\\/\r\n]|\\[^\r\n])+\//,greedy:!0},keyword:/\b(?:and|as|at|case|do|else|fun|if|input|is|match|not|ns|null|or|output|type|unless|update|using|var)\b/,function:/\b[A-Z_]\w*(?=\s*\()/i,number:/-?\b\d+(?:\.\d+)?(?:e[+-]?\d+)?\b/i,punctuation:/[{}[\];(),.:@]/,operator:/<<|>>|->|[<>~=]=?|!=|--?-?|\+\+?|!|\?/,boolean:/\b(?:false|true)\b/}})(e)}yE.displayName="dax";yE.aliases=[];function yE(e){e.languages.dax={comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?\*\/|(?:--|\/\/).*)/,lookbehind:!0},"data-field":{pattern:/'(?:[^']|'')*'(?!')(?:\[[ \w\xA0-\uFFFF]+\])?|\w+\[[ \w\xA0-\uFFFF]+\]/,alias:"symbol"},measure:{pattern:/\[[ \w\xA0-\uFFFF]+\]/,alias:"constant"},string:{pattern:/"(?:[^"]|"")*"(?!")/,greedy:!0},function:/\b(?:ABS|ACOS|ACOSH|ACOT|ACOTH|ADDCOLUMNS|ADDMISSINGITEMS|ALL|ALLCROSSFILTERED|ALLEXCEPT|ALLNOBLANKROW|ALLSELECTED|AND|APPROXIMATEDISTINCTCOUNT|ASIN|ASINH|ATAN|ATANH|AVERAGE|AVERAGEA|AVERAGEX|BETA\.DIST|BETA\.INV|BLANK|CALCULATE|CALCULATETABLE|CALENDAR|CALENDARAUTO|CEILING|CHISQ\.DIST|CHISQ\.DIST\.RT|CHISQ\.INV|CHISQ\.INV\.RT|CLOSINGBALANCEMONTH|CLOSINGBALANCEQUARTER|CLOSINGBALANCEYEAR|COALESCE|COMBIN|COMBINA|COMBINEVALUES|CONCATENATE|CONCATENATEX|CONFIDENCE\.NORM|CONFIDENCE\.T|CONTAINS|CONTAINSROW|CONTAINSSTRING|CONTAINSSTRINGEXACT|CONVERT|COS|COSH|COT|COTH|COUNT|COUNTA|COUNTAX|COUNTBLANK|COUNTROWS|COUNTX|CROSSFILTER|CROSSJOIN|CURRENCY|CURRENTGROUP|CUSTOMDATA|DATATABLE|DATE|DATEADD|DATEDIFF|DATESBETWEEN|DATESINPERIOD|DATESMTD|DATESQTD|DATESYTD|DATEVALUE|DAY|DEGREES|DETAILROWS|DISTINCT|DISTINCTCOUNT|DISTINCTCOUNTNOBLANK|DIVIDE|EARLIER|EARLIEST|EDATE|ENDOFMONTH|ENDOFQUARTER|ENDOFYEAR|EOMONTH|ERROR|EVEN|EXACT|EXCEPT|EXP|EXPON\.DIST|FACT|FALSE|FILTER|FILTERS|FIND|FIRSTDATE|FIRSTNONBLANK|FIRSTNONBLANKVALUE|FIXED|FLOOR|FORMAT|GCD|GENERATE|GENERATEALL|GENERATESERIES|GEOMEAN|GEOMEANX|GROUPBY|HASONEFILTER|HASONEVALUE|HOUR|IF|IF\.EAGER|IFERROR|IGNORE|INT|INTERSECT|ISBLANK|ISCROSSFILTERED|ISEMPTY|ISERROR|ISEVEN|ISFILTERED|ISINSCOPE|ISLOGICAL|ISNONTEXT|ISNUMBER|ISO\.CEILING|ISODD|ISONORAFTER|ISSELECTEDMEASURE|ISSUBTOTAL|ISTEXT|KEEPFILTERS|KEYWORDMATCH|LASTDATE|LASTNONBLANK|LASTNONBLANKVALUE|LCM|LEFT|LEN|LN|LOG|LOG10|LOOKUPVALUE|LOWER|MAX|MAXA|MAXX|MEDIAN|MEDIANX|MID|MIN|MINA|MINUTE|MINX|MOD|MONTH|MROUND|NATURALINNERJOIN|NATURALLEFTOUTERJOIN|NEXTDAY|NEXTMONTH|NEXTQUARTER|NEXTYEAR|NONVISUAL|NORM\.DIST|NORM\.INV|NORM\.S\.DIST|NORM\.S\.INV|NOT|NOW|ODD|OPENINGBALANCEMONTH|OPENINGBALANCEQUARTER|OPENINGBALANCEYEAR|OR|PARALLELPERIOD|PATH|PATHCONTAINS|PATHITEM|PATHITEMREVERSE|PATHLENGTH|PERCENTILE\.EXC|PERCENTILE\.INC|PERCENTILEX\.EXC|PERCENTILEX\.INC|PERMUT|PI|POISSON\.DIST|POWER|PREVIOUSDAY|PREVIOUSMONTH|PREVIOUSQUARTER|PREVIOUSYEAR|PRODUCT|PRODUCTX|QUARTER|QUOTIENT|RADIANS|RAND|RANDBETWEEN|RANK\.EQ|RANKX|RELATED|RELATEDTABLE|REMOVEFILTERS|REPLACE|REPT|RIGHT|ROLLUP|ROLLUPADDISSUBTOTAL|ROLLUPGROUP|ROLLUPISSUBTOTAL|ROUND|ROUNDDOWN|ROUNDUP|ROW|SAMEPERIODLASTYEAR|SAMPLE|SEARCH|SECOND|SELECTCOLUMNS|SELECTEDMEASURE|SELECTEDMEASUREFORMATSTRING|SELECTEDMEASURENAME|SELECTEDVALUE|SIGN|SIN|SINH|SQRT|SQRTPI|STARTOFMONTH|STARTOFQUARTER|STARTOFYEAR|STDEV\.P|STDEV\.S|STDEVX\.P|STDEVX\.S|SUBSTITUTE|SUBSTITUTEWITHINDEX|SUM|SUMMARIZE|SUMMARIZECOLUMNS|SUMX|SWITCH|T\.DIST|T\.DIST\.2T|T\.DIST\.RT|T\.INV|T\.INV\.2T|TAN|TANH|TIME|TIMEVALUE|TODAY|TOPN|TOPNPERLEVEL|TOPNSKIP|TOTALMTD|TOTALQTD|TOTALYTD|TREATAS|TRIM|TRUE|TRUNC|UNICHAR|UNICODE|UNION|UPPER|USERELATIONSHIP|USERNAME|USEROBJECTID|USERPRINCIPALNAME|UTCNOW|UTCTODAY|VALUE|VALUES|VAR\.P|VAR\.S|VARX\.P|VARX\.S|WEEKDAY|WEEKNUM|XIRR|XNPV|YEAR|YEARFRAC)(?=\s*\()/i,keyword:/\b(?:DEFINE|EVALUATE|MEASURE|ORDER\s+BY|RETURN|VAR|START\s+AT|ASC|DESC)\b/i,boolean:{pattern:/\b(?:FALSE|NULL|TRUE)\b/i,alias:"constant"},number:/\b\d+(?:\.\d*)?|\B\.\d+\b/,operator:/:=|[-+*\/=^]|&&?|\|\||<(?:=>?|<|>)?|>[>=]?|\b(?:IN|NOT)\b/i,punctuation:/[;\[\](){}`,.]/}}vE.displayName="dhall";vE.aliases=[];function vE(e){e.languages.dhall={comment:/--.*|\{-(?:[^-{]|-(?!\})|\{(?!-)|\{-(?:[^-{]|-(?!\})|\{(?!-))*-\})*-\}/,string:{pattern:/"(?:[^"\\]|\\.)*"|''(?:[^']|'(?!')|'''|''\$\{)*''(?!'|\$)/,greedy:!0,inside:{interpolation:{pattern:/\$\{[^{}]*\}/,inside:{expression:{pattern:/(^\$\{)[\s\S]+(?=\}$)/,lookbehind:!0,alias:"language-dhall",inside:null},punctuation:/\$\{|\}/}}}},label:{pattern:/`[^`]*`/,greedy:!0},url:{pattern:/\bhttps?:\/\/[\w.:%!$&'*+;=@~-]+(?:\/[\w.:%!$&'*+;=@~-]*)*(?:\?[/?\w.:%!$&'*+;=@~-]*)?/,greedy:!0},env:{pattern:/\benv:(?:(?!\d)\w+|"(?:[^"\\=]|\\.)*")/,greedy:!0,inside:{function:/^env/,operator:/^:/,variable:/[\s\S]+/}},hash:{pattern:/\bsha256:[\da-fA-F]{64}\b/,inside:{function:/sha256/,operator:/:/,number:/[\da-fA-F]{64}/}},keyword:/\b(?:as|assert|else|forall|if|in|let|merge|missing|then|toMap|using|with)\b|\u2200/,builtin:/\b(?:None|Some)\b/,boolean:/\b(?:False|True)\b/,number:/\bNaN\b|-?\bInfinity\b|[+-]?\b(?:0x[\da-fA-F]+|\d+(?:\.\d+)?(?:e[+-]?\d+)?)\b/,operator:/\/\\|\/\/\\\\|&&|\|\||===|[!=]=|\/\/|->|\+\+|::|[+*#@=:?<>|\\\u2227\u2a53\u2261\u2afd\u03bb\u2192]/,punctuation:/\.\.|[{}\[\](),./]/,"class-name":/\b[A-Z]\w*\b/},e.languages.dhall.string.inside.interpolation.inside.expression.inside=e.languages.dhall}xE.displayName="diff";xE.aliases=[];function xE(e){(function(t){t.languages.diff={coord:[/^(?:\*{3}|-{3}|\+{3}).*$/m,/^@@.*@@$/m,/^\d.*$/m]};var n={"deleted-sign":"-","deleted-arrow":"<","inserted-sign":"+","inserted-arrow":">",unchanged:" ",diff:"!"};Object.keys(n).forEach(function(r){var a=n[r],i=[];/^\w+$/.test(r)||i.push(/\w+/.exec(r)[0]),r==="diff"&&i.push("bold"),t.languages.diff[r]={pattern:RegExp("^(?:["+a+`].*(?:\r
?|
|(?![\\s\\S])))+`,"m"),alias:i,inside:{line:{pattern:/(.)(?=[\s\S]).*(?:\r\n?|\n)?/,lookbehind:!0},prefix:{pattern:/[\s\S]/,alias:/\w+/.exec(r)[0]}}}}),Object.defineProperty(t.languages.diff,"PREFIXES",{value:n})})(e)}Er.displayName="markup-templating";Er.aliases=[];function Er(e){e.register(cr),(function(t){function n(r,a){return"___"+r.toUpperCase()+a+"___"}Object.defineProperties(t.languages["markup-templating"]={},{buildPlaceholders:{value:function(r,a,i,o){if(r.language===a){var l=r.tokenStack=[];r.code=r.code.replace(i,function(u){if(typeof o=="function"&&!o(u))return u;for(var d=l.length,h;r.code.indexOf(h=n(a,d))!==-1;)++d;return l[d]=u,h}),r.grammar=t.languages.markup}}},tokenizePlaceholders:{value:function(r,a){if(r.language!==a||!r.tokenStack)return;r.grammar=t.languages[a];var i=0,o=Object.keys(r.tokenStack);function l(u){for(var d=0;d<u.length&&!(i>=o.length);d++){var h=u[d];if(typeof h=="string"||h.content&&typeof h.content=="string"){var f=o[i],m=r.tokenStack[f],b=typeof h=="string"?h:h.content,y=n(a,f),v=b.indexOf(y);if(v>-1){++i;var w=b.substring(0,v),S=new t.Token(a,t.tokenize(m,r.grammar),"language-"+a,m),k=b.substring(v+y.length),R=[];w&&R.push.apply(R,l([w])),R.push(S),k&&R.push.apply(R,l([k])),typeof h=="string"?u.splice.apply(u,[d,1].concat(R)):h.content=R}}else h.content&&l(h.content)}return u}l(r.tokens)}}})})(e)}SE.displayName="django";SE.aliases=["jinja2"];function SE(e){e.register(Er),(function(t){t.languages.django={comment:/^\{#[\s\S]*?#\}$/,tag:{pattern:/(^\{%[+-]?\s*)\w+/,lookbehind:!0,alias:"keyword"},delimiter:{pattern:/^\{[{%][+-]?|[+-]?[}%]\}$/,alias:"punctuation"},string:{pattern:/("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0},filter:{pattern:/(\|)\w+/,lookbehind:!0,alias:"function"},test:{pattern:/(\bis\s+(?:not\s+)?)(?!not\b)\w+/,lookbehind:!0,alias:"function"},function:/\b[a-z_]\w+(?=\s*\()/i,keyword:/\b(?:and|as|by|else|for|if|import|in|is|loop|not|or|recursive|with|without)\b/,operator:/[-+%=]=?|!=|\*\*?=?|\/\/?=?|<[<=>]?|>[=>]?|[&|^~]/,number:/\b\d+(?:\.\d+)?\b/,boolean:/[Ff]alse|[Nn]one|[Tt]rue/,variable:/\b\w+\b/,punctuation:/[{}[\](),.:;]/};var n=/\{\{[\s\S]*?\}\}|\{%[\s\S]*?%\}|\{#[\s\S]*?#\}/g,r=t.languages["markup-templating"];t.hooks.add("before-tokenize",function(a){r.buildPlaceholders(a,"django",n)}),t.hooks.add("after-tokenize",function(a){r.tokenizePlaceholders(a,"django")}),t.languages.jinja2=t.languages.django,t.hooks.add("before-tokenize",function(a){r.buildPlaceholders(a,"jinja2",n)}),t.hooks.add("after-tokenize",function(a){r.tokenizePlaceholders(a,"jinja2")})})(e)}wE.displayName="dns-zone-file";wE.aliases=["dns-zone"];function wE(e){e.languages["dns-zone-file"]={comment:/;.*/,string:{pattern:/"(?:\\.|[^"\\\r\n])*"/,greedy:!0},variable:[{pattern:/(^\$ORIGIN[ \t]+)\S+/m,lookbehind:!0},{pattern:/(^|\s)@(?=\s|$)/,lookbehind:!0}],keyword:/^\$(?:INCLUDE|ORIGIN|TTL)(?=\s|$)/m,class:{pattern:/(^|\s)(?:CH|CS|HS|IN)(?=\s|$)/,lookbehind:!0,alias:"keyword"},type:{pattern:/(^|\s)(?:A|A6|AAAA|AFSDB|APL|ATMA|CAA|CDNSKEY|CDS|CERT|CNAME|DHCID|DLV|DNAME|DNSKEY|DS|EID|GID|GPOS|HINFO|HIP|IPSECKEY|ISDN|KEY|KX|LOC|MAILA|MAILB|MB|MD|MF|MG|MINFO|MR|MX|NAPTR|NB|NBSTAT|NIMLOC|NINFO|NS|NSAP|NSAP-PTR|NSEC|NSEC3|NSEC3PARAM|NULL|NXT|OPENPGPKEY|PTR|PX|RKEY|RP|RRSIG|RT|SIG|SINK|SMIMEA|SOA|SPF|SRV|SSHFP|TA|TKEY|TLSA|TSIG|TXT|UID|UINFO|UNSPEC|URI|WKS|X25)(?=\s|$)/,lookbehind:!0,alias:"keyword"},punctuation:/[()]/},e.languages["dns-zone"]=e.languages["dns-zone-file"]}EE.displayName="docker";EE.aliases=["dockerfile"];function EE(e){(function(t){var n=/\\[\r\n](?:\s|\\[\r\n]|#.*(?!.))*(?![\s#]|\\[\r\n])/.source,r=/(?:[ \t]+(?![ \t])(?:<SP_BS>)?|<SP_BS>)/.source.replace(/<SP_BS>/g,function(){return n}),a=/"(?:[^"\\\r\n]|\\(?:\r\n|[\s\S]))*"|'(?:[^'\\\r\n]|\\(?:\r\n|[\s\S]))*'/.source,i=/--[\w-]+=(?:<STR>|(?!["'])(?:[^\s\\]|\\.)+)/.source.replace(/<STR>/g,function(){return a}),o={pattern:RegExp(a),greedy:!0},l={pattern:/(^[ \t]*)#.*/m,lookbehind:!0,greedy:!0};function u(d,h){return d=d.replace(/<OPT>/g,function(){return i}).replace(/<SP>/g,function(){return r}),RegExp(d,h)}t.languages.docker={instruction:{pattern:/(^[ \t]*)(?:ADD|ARG|CMD|COPY|ENTRYPOINT|ENV|EXPOSE|FROM|HEALTHCHECK|LABEL|MAINTAINER|ONBUILD|RUN|SHELL|STOPSIGNAL|USER|VOLUME|WORKDIR)(?=\s)(?:\\.|[^\r\n\\])*(?:\\$(?:\s|#.*$)*(?![\s#])(?:\\.|[^\r\n\\])*)*/im,lookbehind:!0,greedy:!0,inside:{options:{pattern:u(/(^(?:ONBUILD<SP>)?\w+<SP>)<OPT>(?:<SP><OPT>)*/.source,"i"),lookbehind:!0,greedy:!0,inside:{property:{pattern:/(^|\s)--[\w-]+/,lookbehind:!0},string:[o,{pattern:/(=)(?!["'])(?:[^\s\\]|\\.)+/,lookbehind:!0}],operator:/\\$/m,punctuation:/=/}},keyword:[{pattern:u(/(^(?:ONBUILD<SP>)?HEALTHCHECK<SP>(?:<OPT><SP>)*)(?:CMD|NONE)\b/.source,"i"),lookbehind:!0,greedy:!0},{pattern:u(/(^(?:ONBUILD<SP>)?FROM<SP>(?:<OPT><SP>)*(?!--)[^ \t\\]+<SP>)AS/.source,"i"),lookbehind:!0,greedy:!0},{pattern:u(/(^ONBUILD<SP>)\w+/.source,"i"),lookbehind:!0,greedy:!0},{pattern:/^\w+/,greedy:!0}],comment:l,string:o,variable:/\$(?:\w+|\{[^{}"'\\]*\})/,operator:/\\$/m}},comment:l},t.languages.dockerfile=t.languages.docker})(e)}kE.displayName="dot";kE.aliases=["gv"];function kE(e){(function(t){var n="(?:"+[/[a-zA-Z_\x80-\uFFFF][\w\x80-\uFFFF]*/.source,/-?(?:\.\d+|\d+(?:\.\d*)?)/.source,/"[^"\\]*(?:\\[\s\S][^"\\]*)*"/.source,/<(?:[^<>]|(?!<!--)<(?:[^<>"']|"[^"]*"|'[^']*')+>|<!--(?:[^-]|-(?!->))*-->)*>/.source].join("|")+")",r={markup:{pattern:/(^<)[\s\S]+(?=>$)/,lookbehind:!0,alias:["language-markup","language-html","language-xml"],inside:t.languages.markup}};function a(i,o){return RegExp(i.replace(/<ID>/g,function(){return n}),o)}t.languages.dot={comment:{pattern:/\/\/.*|\/\*[\s\S]*?\*\/|^#.*/m,greedy:!0},"graph-name":{pattern:a(/(\b(?:digraph|graph|subgraph)[ \t\r\n]+)<ID>/.source,"i"),lookbehind:!0,greedy:!0,alias:"class-name",inside:r},"attr-value":{pattern:a(/(=[ \t\r\n]*)<ID>/.source),lookbehind:!0,greedy:!0,inside:r},"attr-name":{pattern:a(/([\[;, \t\r\n])<ID>(?=[ \t\r\n]*=)/.source),lookbehind:!0,greedy:!0,inside:r},keyword:/\b(?:digraph|edge|graph|node|strict|subgraph)\b/i,"compass-point":{pattern:/(:[ \t\r\n]*)(?:[ewc_]|[ns][ew]?)(?![\w\x80-\uFFFF])/,lookbehind:!0,alias:"builtin"},node:{pattern:a(/(^|[^-.\w\x80-\uFFFF\\])<ID>/.source),lookbehind:!0,greedy:!0,inside:r},operator:/[=:]|-[->]/,punctuation:/[\[\]{};,]/},t.languages.gv=t.languages.dot})(e)}TE.displayName="ebnf";TE.aliases=[];function TE(e){e.languages.ebnf={comment:/\(\*[\s\S]*?\*\)/,string:{pattern:/"[^"\r\n]*"|'[^'\r\n]*'/,greedy:!0},special:{pattern:/\?[^?\r\n]*\?/,greedy:!0,alias:"class-name"},definition:{pattern:/^([\t ]*)[a-z]\w*(?:[ \t]+[a-z]\w*)*(?=\s*=)/im,lookbehind:!0,alias:["rule","keyword"]},rule:/\b[a-z]\w*(?:[ \t]+[a-z]\w*)*\b/i,punctuation:/\([:/]|[:/]\)|[.,;()[\]{}]/,operator:/[-=|*/!]/}}_E.displayName="editorconfig";_E.aliases=[];function _E(e){e.languages.editorconfig={comment:/[;#].*/,section:{pattern:/(^[ \t]*)\[.+\]/m,lookbehind:!0,alias:"selector",inside:{regex:/\\\\[\[\]{},!?.*]/,operator:/[!?]|\.\.|\*{1,2}/,punctuation:/[\[\]{},]/}},key:{pattern:/(^[ \t]*)[^\s=]+(?=[ \t]*=)/m,lookbehind:!0,alias:"attr-name"},value:{pattern:/=.*/,alias:"attr-value",inside:{punctuation:/^=/}}}}CE.displayName="eiffel";CE.aliases=[];function CE(e){e.languages.eiffel={comment:/--.*/,string:[{pattern:/"([^[]*)\[[\s\S]*?\]\1"/,greedy:!0},{pattern:/"([^{]*)\{[\s\S]*?\}\1"/,greedy:!0},{pattern:/"(?:%(?:(?!\n)\s)*\n\s*%|%\S|[^%"\r\n])*"/,greedy:!0}],char:/'(?:%.|[^%'\r\n])+'/,keyword:/\b(?:across|agent|alias|all|and|as|assign|attached|attribute|check|class|convert|create|Current|debug|deferred|detachable|do|else|elseif|end|ensure|expanded|export|external|feature|from|frozen|if|implies|inherit|inspect|invariant|like|local|loop|not|note|obsolete|old|once|or|Precursor|redefine|rename|require|rescue|Result|retry|select|separate|some|then|undefine|until|variant|Void|when|xor)\b/i,boolean:/\b(?:False|True)\b/i,"class-name":/\b[A-Z][\dA-Z_]*\b/,number:[/\b0[xcb][\da-f](?:_*[\da-f])*\b/i,/(?:\b\d(?:_*\d)*)?\.(?:(?:\d(?:_*\d)*)?e[+-]?)?\d(?:_*\d)*\b|\b\d(?:_*\d)*\b\.?/i],punctuation:/:=|<<|>>|\(\||\|\)|->|\.(?=\w)|[{}[\];(),:?]/,operator:/\\\\|\|\.\.\||\.\.|\/[~\/=]?|[><]=?|[-+*^=~]/}}AE.displayName="ejs";AE.aliases=["eta"];function AE(e){e.register(wr),e.register(Er),(function(t){t.languages.ejs={delimiter:{pattern:/^<%[-_=]?|[-_]?%>$/,alias:"punctuation"},comment:/^#[\s\S]*/,"language-javascript":{pattern:/[\s\S]+/,inside:t.languages.javascript}},t.hooks.add("before-tokenize",function(n){var r=/<%(?!%)[\s\S]+?%>/g;t.languages["markup-templating"].buildPlaceholders(n,"ejs",r)}),t.hooks.add("after-tokenize",function(n){t.languages["markup-templating"].tokenizePlaceholders(n,"ejs")}),t.languages.eta=t.languages.ejs})(e)}RE.displayName="elixir";RE.aliases=[];function RE(e){e.languages.elixir={doc:{pattern:/@(?:doc|moduledoc)\s+(?:("""|''')[\s\S]*?\1|("|')(?:\\(?:\r\n|[\s\S])|(?!\2)[^\\\r\n])*\2)/,inside:{attribute:/^@\w+/,string:/['"][\s\S]+/}},comment:{pattern:/#.*/,greedy:!0},regex:{pattern:/~[rR](?:("""|''')(?:\\[\s\S]|(?!\1)[^\\])+\1|([\/|"'])(?:\\.|(?!\2)[^\\\r\n])+\2|\((?:\\.|[^\\)\r\n])+\)|\[(?:\\.|[^\\\]\r\n])+\]|\{(?:\\.|[^\\}\r\n])+\}|<(?:\\.|[^\\>\r\n])+>)[uismxfr]*/,greedy:!0},string:[{pattern:/~[cCsSwW](?:("""|''')(?:\\[\s\S]|(?!\1)[^\\])+\1|([\/|"'])(?:\\.|(?!\2)[^\\\r\n])+\2|\((?:\\.|[^\\)\r\n])+\)|\[(?:\\.|[^\\\]\r\n])+\]|\{(?:\\.|#\{[^}]+\}|#(?!\{)|[^#\\}\r\n])+\}|<(?:\\.|[^\\>\r\n])+>)[csa]?/,greedy:!0,inside:{}},{pattern:/("""|''')[\s\S]*?\1/,greedy:!0,inside:{}},{pattern:/("|')(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,greedy:!0,inside:{}}],atom:{pattern:/(^|[^:]):\w+/,lookbehind:!0,alias:"symbol"},module:{pattern:/\b[A-Z]\w*\b/,alias:"class-name"},"attr-name":/\b\w+\??:(?!:)/,argument:{pattern:/(^|[^&])&\d+/,lookbehind:!0,alias:"variable"},attribute:{pattern:/@\w+/,alias:"variable"},function:/\b[_a-zA-Z]\w*[?!]?(?:(?=\s*(?:\.\s*)?\()|(?=\/\d))/,number:/\b(?:0[box][a-f\d_]+|\d[\d_]*)(?:\.[\d_]+)?(?:e[+-]?[\d_]+)?\b/i,keyword:/\b(?:after|alias|and|case|catch|cond|def(?:callback|delegate|exception|impl|macro|module|n|np|p|protocol|struct)?|do|else|end|fn|for|if|import|not|or|quote|raise|require|rescue|try|unless|unquote|use|when)\b/,boolean:/\b(?:false|nil|true)\b/,operator:[/\bin\b|&&?|\|[|>]?|\\\\|::|\.\.\.?|\+\+?|-[->]?|<[-=>]|>=|!==?|\B!|=(?:==?|[>~])?|[*\/^]/,{pattern:/([^<])<(?!<)/,lookbehind:!0},{pattern:/([^>])>(?!>)/,lookbehind:!0}],punctuation:/<<|>>|[.,%\[\]{}()]/},e.languages.elixir.string.forEach(function(t){t.inside={interpolation:{pattern:/#\{[^}]+\}/,inside:{delimiter:{pattern:/^#\{|\}$/,alias:"punctuation"},rest:e.languages.elixir}}}})}NE.displayName="elm";NE.aliases=[];function NE(e){e.languages.elm={comment:/--.*|\{-[\s\S]*?-\}/,char:{pattern:/'(?:[^\\'\r\n]|\\(?:[abfnrtv\\']|\d+|x[0-9a-fA-F]+|u\{[0-9a-fA-F]+\}))'/,greedy:!0},string:[{pattern:/"""[\s\S]*?"""/,greedy:!0},{pattern:/"(?:[^\\"\r\n]|\\.)*"/,greedy:!0}],"import-statement":{pattern:/(^[\t ]*)import\s+[A-Z]\w*(?:\.[A-Z]\w*)*(?:\s+as\s+(?:[A-Z]\w*)(?:\.[A-Z]\w*)*)?(?:\s+exposing\s+)?/m,lookbehind:!0,inside:{keyword:/\b(?:as|exposing|import)\b/}},keyword:/\b(?:alias|as|case|else|exposing|if|in|infixl|infixr|let|module|of|then|type)\b/,builtin:/\b(?:abs|acos|always|asin|atan|atan2|ceiling|clamp|compare|cos|curry|degrees|e|flip|floor|fromPolar|identity|isInfinite|isNaN|logBase|max|min|negate|never|not|pi|radians|rem|round|sin|sqrt|tan|toFloat|toPolar|toString|truncate|turns|uncurry|xor)\b/,number:/\b(?:\d+(?:\.\d+)?(?:e[+-]?\d+)?|0x[0-9a-f]+)\b/i,operator:/\s\.\s|[+\-/*=.$<>:&|^?%#@~!]{2,}|[+\-/*=$<>:&|^?%#@~!]/,hvariable:/\b(?:[A-Z]\w*\.)*[a-z]\w*\b/,constant:/\b(?:[A-Z]\w*\.)*[A-Z]\w*\b/,punctuation:/[{}[\]|(),.:]/}}Lg.displayName="lua";Lg.aliases=[];function Lg(e){e.languages.lua={comment:/^#!.+|--(?:\[(=*)\[[\s\S]*?\]\1\]|.*)/m,string:{pattern:/(["'])(?:(?!\1)[^\\\r\n]|\\z(?:\r\n|\s)|\\(?:\r\n|[^z]))*\1|\[(=*)\[[\s\S]*?\]\2\]/,greedy:!0},number:/\b0x[a-f\d]+(?:\.[a-f\d]*)?(?:p[+-]?\d+)?\b|\b\d+(?:\.\B|(?:\.\d*)?(?:e[+-]?\d+)?\b)|\B\.\d+(?:e[+-]?\d+)?\b/i,keyword:/\b(?:and|break|do|else|elseif|end|false|for|function|goto|if|in|local|nil|not|or|repeat|return|then|true|until|while)\b/,function:/(?!\d)\w+(?=\s*(?:[({]))/,operator:[/[-+*%^&|#]|\/\/?|<[<=]?|>[>=]?|[=~]=?/,{pattern:/(^|[^.])\.\.(?!\.)/,lookbehind:!0}],punctuation:/[\[\](){},;]|\.+|:+/}}OE.displayName="etlua";OE.aliases=[];function OE(e){e.register(Lg),e.register(Er),(function(t){t.languages.etlua={delimiter:{pattern:/^<%[-=]?|-?%>$/,alias:"punctuation"},"language-lua":{pattern:/[\s\S]+/,inside:t.languages.lua}},t.hooks.add("before-tokenize",function(n){var r=/<%[\s\S]+?%>/g;t.languages["markup-templating"].buildPlaceholders(n,"etlua",r)}),t.hooks.add("after-tokenize",function(n){t.languages["markup-templating"].tokenizePlaceholders(n,"etlua")})})(e)}IE.displayName="erb";IE.aliases=[];function IE(e){e.register(Er),e.register(Tu),(function(t){t.languages.erb={delimiter:{pattern:/^(\s*)<%=?|%>(?=\s*$)/,lookbehind:!0,alias:"punctuation"},ruby:{pattern:/\s*\S[\s\S]*/,alias:"language-ruby",inside:t.languages.ruby}},t.hooks.add("before-tokenize",function(n){var r=/<%=?(?:[^\r\n]|[\r\n](?!=begin)|[\r\n]=begin\s(?:[^\r\n]|[\r\n](?!=end))*[\r\n]=end)+?%>/g;t.languages["markup-templating"].buildPlaceholders(n,"erb",r)}),t.hooks.add("after-tokenize",function(n){t.languages["markup-templating"].tokenizePlaceholders(n,"erb")})})(e)}LE.displayName="erlang";LE.aliases=[];function LE(e){e.languages.erlang={comment:/%.+/,string:{pattern:/"(?:\\.|[^\\"\r\n])*"/,greedy:!0},"quoted-function":{pattern:/'(?:\\.|[^\\'\r\n])+'(?=\()/,alias:"function"},"quoted-atom":{pattern:/'(?:\\.|[^\\'\r\n])+'/,alias:"atom"},boolean:/\b(?:false|true)\b/,keyword:/\b(?:after|begin|case|catch|end|fun|if|of|receive|try|when)\b/,number:[/\$\\?./,/\b\d+#[a-z0-9]+/i,/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?/i],function:/\b[a-z][\w@]*(?=\()/,variable:{pattern:/(^|[^@])(?:\b|\?)[A-Z_][\w@]*/,lookbehind:!0},operator:[/[=\/<>:]=|=[:\/]=|\+\+?|--?|[=*\/!]|\b(?:and|andalso|band|bnot|bor|bsl|bsr|bxor|div|not|or|orelse|rem|xor)\b/,{pattern:/(^|[^<])<(?!<)/,lookbehind:!0},{pattern:/(^|[^>])>(?!>)/,lookbehind:!0}],atom:/\b[a-z][\w@]*/,punctuation:/[()[\]{}:;,.#|]|<<|>>/}}DE.displayName="excel-formula";DE.aliases=["xls","xlsx"];function DE(e){e.languages["excel-formula"]={comment:{pattern:/(\bN\(\s*)"(?:[^"]|"")*"(?=\s*\))/i,lookbehind:!0,greedy:!0},string:{pattern:/"(?:[^"]|"")*"(?!")/,greedy:!0},reference:{pattern:/(?:'[^']*'|(?:[^\s()[\]{}<>*?"';,$&]*\[[^^\s()[\]{}<>*?"']+\])?\w+)!/,greedy:!0,alias:"string",inside:{operator:/!$/,punctuation:/'/,sheet:{pattern:/[^[\]]+$/,alias:"function"},file:{pattern:/\[[^[\]]+\]$/,inside:{punctuation:/[[\]]/}},path:/[\s\S]+/}},"function-name":{pattern:/\b[A-Z]\w*(?=\()/i,alias:"builtin"},range:{pattern:/\$?\b(?:[A-Z]+\$?\d+:\$?[A-Z]+\$?\d+|[A-Z]+:\$?[A-Z]+|\d+:\$?\d+)\b/i,alias:"selector",inside:{operator:/:/,cell:/\$?[A-Z]+\$?\d+/i,column:/\$?[A-Z]+/i,row:/\$?\d+/}},cell:{pattern:/\b[A-Z]+\d+\b|\$[A-Za-z]+\$?\d+\b|\b[A-Za-z]+\$\d+\b/,alias:"selector"},number:/(?:\b\d+(?:\.\d+)?|\B\.\d+)(?:e[+-]?\d+)?\b/i,boolean:/\b(?:FALSE|TRUE)\b/i,operator:/[-+*/^%=&,]|<[=>]?|>=?/,punctuation:/[[\]();{}|]/},e.languages.xlsx=e.languages.xls=e.languages["excel-formula"]}ME.displayName="fsharp";ME.aliases=[];function ME(e){e.register(Mt),e.languages.fsharp=e.languages.extend("clike",{comment:[{pattern:/(^|[^\\])\(\*(?!\))[\s\S]*?\*\)/,lookbehind:!0,greedy:!0},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0,greedy:!0}],string:{pattern:/(?:"""[\s\S]*?"""|@"(?:""|[^"])*"|"(?:\\[\s\S]|[^\\"])*")B?/,greedy:!0},"class-name":{pattern:/(\b(?:exception|inherit|interface|new|of|type)\s+|\w\s*:\s*|\s:\??>\s*)[.\w]+\b(?:\s*(?:->|\*)\s*[.\w]+\b)*(?!\s*[:.])/,lookbehind:!0,inside:{operator:/->|\*/,punctuation:/\./}},keyword:/\b(?:let|return|use|yield)(?:!\B|\b)|\b(?:abstract|and|as|asr|assert|atomic|base|begin|break|checked|class|component|const|constraint|constructor|continue|default|delegate|do|done|downcast|downto|eager|elif|else|end|event|exception|extern|external|false|finally|fixed|for|fun|function|functor|global|if|in|include|inherit|inline|interface|internal|land|lazy|lor|lsl|lsr|lxor|match|member|method|mixin|mod|module|mutable|namespace|new|not|null|object|of|open|or|override|parallel|private|process|protected|public|pure|rec|sealed|select|sig|static|struct|tailcall|then|to|trait|true|try|type|upcast|val|virtual|void|volatile|when|while|with)\b/,number:[/\b0x[\da-fA-F]+(?:LF|lf|un)?\b/,/\b0b[01]+(?:uy|y)?\b/,/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[fm]|e[+-]?\d+)?\b/i,/\b\d+(?:[IlLsy]|UL|u[lsy]?)?\b/],operator:/([<>~&^])\1\1|([*.:<>&])\2|<-|->|[!=:]=|<?\|{1,3}>?|\??(?:<=|>=|<>|[-+*/%=<>])\??|[!?^&]|~[+~-]|:>|:\?>?/}),e.languages.insertBefore("fsharp","keyword",{preprocessor:{pattern:/(^[\t ]*)#.*/m,lookbehind:!0,alias:"property",inside:{directive:{pattern:/(^#)\b(?:else|endif|if|light|line|nowarn)\b/,lookbehind:!0,alias:"keyword"}}}}),e.languages.insertBefore("fsharp","punctuation",{"computation-expression":{pattern:/\b[_a-z]\w*(?=\s*\{)/i,alias:"keyword"}}),e.languages.insertBefore("fsharp","string",{annotation:{pattern:/\[<.+?>\]/,greedy:!0,inside:{punctuation:/^\[<|>\]$/,"class-name":{pattern:/^\w+$|(^|;\s*)[A-Z]\w*(?=\()/,lookbehind:!0},"annotation-content":{pattern:/[\s\S]+/,inside:e.languages.fsharp}}},char:{pattern:/'(?:[^\\']|\\(?:.|\d{3}|x[a-fA-F\d]{2}|u[a-fA-F\d]{4}|U[a-fA-F\d]{8}))'B?/,greedy:!0}})}BE.displayName="factor";BE.aliases=[];function BE(e){(function(t){var n={function:/\b(?:BUGS?|FIX(?:MES?)?|NOTES?|TODOS?|XX+|HACKS?|WARN(?:ING)?|\?{2,}|!{2,})\b/},r={number:/\\[^\s']|%\w/},a={comment:[{pattern:/(^|\s)(?:! .*|!$)/,lookbehind:!0,inside:n},{pattern:/(^|\s)\/\*\s[\s\S]*?\*\/(?=\s|$)/,lookbehind:!0,greedy:!0,inside:n},{pattern:/(^|\s)!\[(={0,6})\[\s[\s\S]*?\]\2\](?=\s|$)/,lookbehind:!0,greedy:!0,inside:n}],number:[{pattern:/(^|\s)[+-]?\d+(?=\s|$)/,lookbehind:!0},{pattern:/(^|\s)[+-]?0(?:b[01]+|o[0-7]+|d\d+|x[\dA-F]+)(?=\s|$)/i,lookbehind:!0},{pattern:/(^|\s)[+-]?\d+\/\d+\.?(?=\s|$)/,lookbehind:!0},{pattern:/(^|\s)\+?\d+\+\d+\/\d+(?=\s|$)/,lookbehind:!0},{pattern:/(^|\s)-\d+-\d+\/\d+(?=\s|$)/,lookbehind:!0},{pattern:/(^|\s)[+-]?(?:\d*\.\d+|\d+\.\d*|\d+)(?:e[+-]?\d+)?(?=\s|$)/i,lookbehind:!0},{pattern:/(^|\s)NAN:\s+[\da-fA-F]+(?=\s|$)/,lookbehind:!0},{pattern:/(^|\s)[+-]?0(?:b1\.[01]*|o1\.[0-7]*|d1\.\d*|x1\.[\dA-F]*)p\d+(?=\s|$)/i,lookbehind:!0}],regexp:{pattern:/(^|\s)R\/\s(?:\\\S|[^\\/])*\/(?:[idmsr]*|[idmsr]+-[idmsr]+)(?=\s|$)/,lookbehind:!0,alias:"number",inside:{variable:/\\\S/,keyword:/[+?*\[\]^$(){}.|]/,operator:{pattern:/(\/)[idmsr]+(?:-[idmsr]+)?/,lookbehind:!0}}},boolean:{pattern:/(^|\s)[tf](?=\s|$)/,lookbehind:!0},"custom-string":{pattern:/(^|\s)[A-Z0-9\-]+"\s(?:\\\S|[^"\\])*"/,lookbehind:!0,greedy:!0,alias:"string",inside:{number:/\\\S|%\w|\//}},"multiline-string":[{pattern:/(^|\s)STRING:\s+\S+(?:\n|\r\n).*(?:\n|\r\n)\s*;(?=\s|$)/,lookbehind:!0,greedy:!0,alias:"string",inside:{number:r.number,"semicolon-or-setlocal":{pattern:/([\r\n][ \t]*);(?=\s|$)/,lookbehind:!0,alias:"function"}}},{pattern:/(^|\s)HEREDOC:\s+\S+(?:\n|\r\n).*(?:\n|\r\n)\s*\S+(?=\s|$)/,lookbehind:!0,greedy:!0,alias:"string",inside:r},{pattern:/(^|\s)\[(={0,6})\[\s[\s\S]*?\]\2\](?=\s|$)/,lookbehind:!0,greedy:!0,alias:"string",inside:r}],"special-using":{pattern:/(^|\s)USING:(?:\s\S+)*(?=\s+;(?:\s|$))/,lookbehind:!0,alias:"function",inside:{string:{pattern:/(\s)[^:\s]+/,lookbehind:!0}}},"stack-effect-delimiter":[{pattern:/(^|\s)(?:call|eval|execute)?\((?=\s)/,lookbehind:!0,alias:"operator"},{pattern:/(\s)--(?=\s)/,lookbehind:!0,alias:"operator"},{pattern:/(\s)\)(?=\s|$)/,lookbehind:!0,alias:"operator"}],combinators:{pattern:null,lookbehind:!0,alias:"keyword"},"kernel-builtin":{pattern:null,lookbehind:!0,alias:"variable"},"sequences-builtin":{pattern:null,lookbehind:!0,alias:"variable"},"math-builtin":{pattern:null,lookbehind:!0,alias:"variable"},"constructor-word":{pattern:/(^|\s)<(?!=+>|-+>)\S+>(?=\s|$)/,lookbehind:!0,alias:"keyword"},"other-builtin-syntax":{pattern:null,lookbehind:!0,alias:"operator"},"conventionally-named-word":{pattern:/(^|\s)(?!")(?:(?:change|new|set|with)-\S+|\$\S+|>[^>\s]+|[^:>\s]+>|[^>\s]+>[^>\s]+|\+[^+\s]+\+|[^?\s]+\?|\?[^?\s]+|[^>\s]+>>|>>[^>\s]+|[^<\s]+<<|\([^()\s]+\)|[^!\s]+!|[^*\s]\S*\*|[^.\s]\S*\.)(?=\s|$)/,lookbehind:!0,alias:"keyword"},"colon-syntax":{pattern:/(^|\s)(?:[A-Z0-9\-]+#?)?:{1,2}\s+(?:;\S+|(?!;)\S+)(?=\s|$)/,lookbehind:!0,greedy:!0,alias:"function"},"semicolon-or-setlocal":{pattern:/(\s)(?:;|:>)(?=\s|$)/,lookbehind:!0,alias:"function"},"curly-brace-literal-delimiter":[{pattern:/(^|\s)[a-z]*\{(?=\s)/i,lookbehind:!0,alias:"operator"},{pattern:/(\s)\}(?=\s|$)/,lookbehind:!0,alias:"operator"}],"quotation-delimiter":[{pattern:/(^|\s)\[(?=\s)/,lookbehind:!0,alias:"operator"},{pattern:/(\s)\](?=\s|$)/,lookbehind:!0,alias:"operator"}],"normal-word":{pattern:/(^|\s)[^"\s]\S*(?=\s|$)/,lookbehind:!0},string:{pattern:/"(?:\\\S|[^"\\])*"/,greedy:!0,inside:r}},i=function(d){return(d+"").replace(/([.?*+\^$\[\]\\(){}|\-])/g,"\\$1")},o=function(d){return new RegExp("(^|\\s)(?:"+d.map(i).join("|")+")(?=\\s|$)")},l={"kernel-builtin":["or","2nipd","4drop","tuck","wrapper","nip","wrapper?","callstack>array","die","dupd","callstack","callstack?","3dup","hashcode","pick","4nip","build",">boolean","nipd","clone","5nip","eq?","?","=","swapd","2over","clear","2dup","get-retainstack","not","tuple?","dup","3nipd","call","-rotd","object","drop","assert=","assert?","-rot","execute","boa","get-callstack","curried?","3drop","pickd","overd","over","roll","3nip","swap","and","2nip","rotd","throw","(clone)","hashcode*","spin","reach","4dup","equal?","get-datastack","assert","2drop","<wrapper>","boolean?","identity-hashcode","identity-tuple?","null","composed?","new","5drop","rot","-roll","xor","identity-tuple","boolean"],"other-builtin-syntax":["=======","recursive","flushable",">>","<<<<<<","M\\","B","PRIVATE>","\\","======","final","inline","delimiter","deprecated","<PRIVATE",">>>>>>","<<<<<<<","parse-complex","malformed-complex","read-only",">>>>>>>","call-next-method","<<","foldable","$","$[","${"],"sequences-builtin":["member-eq?","mismatch","append","assert-sequence=","longer","repetition","clone-like","3sequence","assert-sequence?","last-index-from","reversed","index-from","cut*","pad-tail","join-as","remove-eq!","concat-as","but-last","snip","nths","nth","sequence","longest","slice?","<slice>","remove-nth","tail-slice","empty?","tail*","member?","virtual-sequence?","set-length","drop-prefix","iota","unclip","bounds-error?","unclip-last-slice","non-negative-integer-expected","non-negative-integer-expected?","midpoint@","longer?","?set-nth","?first","rest-slice","prepend-as","prepend","fourth","sift","subseq-start","new-sequence","?last","like","first4","1sequence","reverse","slice","virtual@","repetition?","set-last","index","4sequence","max-length","set-second","immutable-sequence","first2","first3","supremum","unclip-slice","suffix!","insert-nth","tail","3append","short","suffix","concat","flip","immutable?","reverse!","2sequence","sum","delete-all","indices","snip-slice","<iota>","check-slice","sequence?","head","append-as","halves","sequence=","collapse-slice","?second","slice-error?","product","bounds-check?","bounds-check","immutable","virtual-exemplar","harvest","remove","pad-head","last","set-fourth","cartesian-product","remove-eq","shorten","shorter","reversed?","shorter?","shortest","head-slice","pop*","tail-slice*","but-last-slice","iota?","append!","cut-slice","new-resizable","head-slice*","sequence-hashcode","pop","set-nth","?nth","second","join","immutable-sequence?","<reversed>","3append-as","virtual-sequence","subseq?","remove-nth!","length","last-index","lengthen","assert-sequence","copy","move","third","first","tail?","set-first","prefix","bounds-error","<repetition>","exchange","surround","cut","min-length","set-third","push-all","head?","subseq-start-from","delete-slice","rest","sum-lengths","head*","infimum","remove!","glue","slice-error","subseq","push","replace-slice","subseq-as","unclip-last"],"math-builtin":["number=","next-power-of-2","?1+","fp-special?","imaginary-part","float>bits","number?","fp-infinity?","bignum?","fp-snan?","denominator","gcd","*","+","fp-bitwise=","-","u>=","/",">=","bitand","power-of-2?","log2-expects-positive","neg?","<","log2",">","integer?","number","bits>double","2/","zero?","bits>float","float?","shift","ratio?","rect>","even?","ratio","fp-sign","bitnot",">fixnum","complex?","/i","integer>fixnum","/f","sgn",">bignum","next-float","u<","u>","mod","recip","rational",">float","2^","integer","fixnum?","neg","fixnum","sq","bignum",">rect","bit?","fp-qnan?","simple-gcd","complex","<fp-nan>","real",">fraction","double>bits","bitor","rem","fp-nan-payload","real-part","log2-expects-positive?","prev-float","align","unordered?","float","fp-nan?","abs","bitxor","integer>fixnum-strict","u<=","odd?","<=","/mod",">integer","real?","rational?","numerator"]};Object.keys(l).forEach(function(d){a[d].pattern=o(l[d])});var u=["2bi","while","2tri","bi*","4dip","both?","same?","tri@","curry","prepose","3bi","?if","tri*","2keep","3keep","curried","2keepd","when","2bi*","2tri*","4keep","bi@","keepdd","do","unless*","tri-curry","if*","loop","bi-curry*","when*","2bi@","2tri@","with","2with","either?","bi","until","3dip","3curry","tri-curry*","tri-curry@","bi-curry","keepd","compose","2dip","if","3tri","unless","tuple","keep","2curry","tri","most","while*","dip","composed","bi-curry@","find-last-from","trim-head-slice","map-as","each-from","none?","trim-tail","partition","if-empty","accumulate*","reject!","find-from","accumulate-as","collector-for-as","reject","map","map-sum","accumulate!","2each-from","follow","supremum-by","map!","unless-empty","collector","padding","reduce-index","replicate-as","infimum-by","trim-tail-slice","count","find-index","filter","accumulate*!","reject-as","map-integers","map-find","reduce","selector","interleave","2map","filter-as","binary-reduce","map-index-as","find","produce","filter!","replicate","cartesian-map","cartesian-each","find-index-from","map-find-last","3map-as","3map","find-last","selector-as","2map-as","2map-reduce","accumulate","each","each-index","accumulate*-as","when-empty","all?","collector-as","push-either","new-like","collector-for","2selector","push-if","2all?","map-reduce","3each","any?","trim-slice","2reduce","change-nth","produce-as","2each","trim","trim-head","cartesian-find","map-index","if-zero","each-integer","unless-zero","(find-integer)","when-zero","find-last-integer","(all-integers?)","times","(each-integer)","find-integer","all-integers?","unless-negative","if-positive","when-positive","when-negative","unless-positive","if-negative","case","2cleave","cond>quot","case>quot","3cleave","wrong-values","to-fixed-point","alist>quot","cond","cleave","call-effect","recursive-hashcode","spread","deep-spread>quot","2||","0||","n||","0&&","2&&","3||","1||","1&&","n&&","3&&","smart-unless*","keep-inputs","reduce-outputs","smart-when*","cleave>array","smart-with","smart-apply","smart-if","inputs/outputs","output>sequence-n","map-outputs","map-reduce-outputs","dropping","output>array","smart-map-reduce","smart-2map-reduce","output>array-n","nullary","input<sequence","append-outputs","drop-inputs","inputs","smart-2reduce","drop-outputs","smart-reduce","preserving","smart-when","outputs","append-outputs-as","smart-unless","smart-if*","sum-outputs","input<sequence-unsafe","output>sequence"];a.combinators.pattern=o(u),t.languages.factor=a})(e)}FE.displayName="false";FE.aliases=[];function FE(e){(function(t){t.languages.false={comment:{pattern:/\{[^}]*\}/},string:{pattern:/"[^"]*"/,greedy:!0},"character-code":{pattern:/'(?:[^\r]|\r\n?)/,alias:"number"},"assembler-code":{pattern:/\d+`/,alias:"important"},number:/\d+/,operator:/[-!#$%&'*+,./:;=>?@\\^_`|~ßø]/,punctuation:/\[|\]/,variable:/[a-z]/,"non-standard":{pattern:/[()<BDO®]/,alias:"bold"}}})(e)}zE.displayName="firestore-security-rules";zE.aliases=[];function zE(e){e.register(Mt),e.languages["firestore-security-rules"]=e.languages.extend("clike",{comment:/\/\/.*/,keyword:/\b(?:allow|function|if|match|null|return|rules_version|service)\b/,operator:/&&|\|\||[<>!=]=?|[-+*/%]|\b(?:in|is)\b/}),delete e.languages["firestore-security-rules"]["class-name"],e.languages.insertBefore("firestore-security-rules","keyword",{path:{pattern:/(^|[\s(),])(?:\/(?:[\w\xA0-\uFFFF]+|\{[\w\xA0-\uFFFF]+(?:=\*\*)?\}|\$\([\w\xA0-\uFFFF.]+\)))+/,lookbehind:!0,greedy:!0,inside:{variable:{pattern:/\{[\w\xA0-\uFFFF]+(?:=\*\*)?\}|\$\([\w\xA0-\uFFFF.]+\)/,inside:{operator:/=/,keyword:/\*\*/,punctuation:/[.$(){}]/}},punctuation:/\//}},method:{pattern:/(\ballow\s+)[a-z]+(?:\s*,\s*[a-z]+)*(?=\s*[:;])/,lookbehind:!0,alias:"builtin",inside:{punctuation:/,/}}})}$E.displayName="flow";$E.aliases=[];function $E(e){e.register(wr),(function(t){t.languages.flow=t.languages.extend("javascript",{}),t.languages.insertBefore("flow","keyword",{type:[{pattern:/\b(?:[Bb]oolean|Function|[Nn]umber|[Ss]tring|[Ss]ymbol|any|mixed|null|void)\b/,alias:"class-name"}]}),t.languages.flow["function-variable"].pattern=/(?!\s)[_$a-z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*=\s*(?:function\b|(?:\([^()]*\)(?:\s*:\s*\w+)?|(?!\s)[_$a-z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)\s*=>))/i,delete t.languages.flow.parameter,t.languages.insertBefore("flow","operator",{"flow-punctuation":{pattern:/\{\||\|\}/,alias:"punctuation"}}),Array.isArray(t.languages.flow.keyword)||(t.languages.flow.keyword=[t.languages.flow.keyword]),t.languages.flow.keyword.unshift({pattern:/(^|[^$]\b)(?:Class|declare|opaque|type)\b(?!\$)/,lookbehind:!0},{pattern:/(^|[^$]\B)\$(?:Diff|Enum|Exact|Keys|ObjMap|PropertyType|Record|Shape|Subtype|Supertype|await)\b(?!\$)/,lookbehind:!0})})(e)}PE.displayName="fortran";PE.aliases=[];function PE(e){e.languages.fortran={"quoted-number":{pattern:/[BOZ](['"])[A-F0-9]+\1/i,alias:"number"},string:{pattern:/(?:\b\w+_)?(['"])(?:\1\1|&(?:\r\n?|\n)(?:[ \t]*!.*(?:\r\n?|\n)|(?![ \t]*!))|(?!\1).)*(?:\1|&)/,inside:{comment:{pattern:/(&(?:\r\n?|\n)\s*)!.*/,lookbehind:!0}}},comment:{pattern:/!.*/,greedy:!0},boolean:/\.(?:FALSE|TRUE)\.(?:_\w+)?/i,number:/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[ED][+-]?\d+)?(?:_\w+)?/i,keyword:[/\b(?:CHARACTER|COMPLEX|DOUBLE ?PRECISION|INTEGER|LOGICAL|REAL)\b/i,/\b(?:END ?)?(?:BLOCK ?DATA|DO|FILE|FORALL|FUNCTION|IF|INTERFACE|MODULE(?! PROCEDURE)|PROGRAM|SELECT|SUBROUTINE|TYPE|WHERE)\b/i,/\b(?:ALLOCATABLE|ALLOCATE|BACKSPACE|CALL|CASE|CLOSE|COMMON|CONTAINS|CONTINUE|CYCLE|DATA|DEALLOCATE|DIMENSION|DO|END|EQUIVALENCE|EXIT|EXTERNAL|FORMAT|GO ?TO|IMPLICIT(?: NONE)?|INQUIRE|INTENT|INTRINSIC|MODULE PROCEDURE|NAMELIST|NULLIFY|OPEN|OPTIONAL|PARAMETER|POINTER|PRINT|PRIVATE|PUBLIC|READ|RETURN|REWIND|SAVE|SELECT|STOP|TARGET|WHILE|WRITE)\b/i,/\b(?:ASSIGNMENT|DEFAULT|ELEMENTAL|ELSE|ELSEIF|ELSEWHERE|ENTRY|IN|INCLUDE|INOUT|KIND|NULL|ONLY|OPERATOR|OUT|PURE|RECURSIVE|RESULT|SEQUENCE|STAT|THEN|USE)\b/i],operator:[/\*\*|\/\/|=>|[=\/]=|[<>]=?|::|[+\-*=%]|\.[A-Z]+\./i,{pattern:/(^|(?!\().)\/(?!\))/,lookbehind:!0}],punctuation:/\(\/|\/\)|[(),;:&]/}}UE.displayName="ftl";UE.aliases=[];function UE(e){e.register(Er),(function(t){for(var n=/[^<()"']|\((?:<expr>)*\)|<(?!#--)|<#--(?:[^-]|-(?!->))*-->|"(?:[^\\"]|\\.)*"|'(?:[^\\']|\\.)*'/.source,r=0;r<2;r++)n=n.replace(/<expr>/g,function(){return n});n=n.replace(/<expr>/g,/[^\s\S]/.source);var a={comment:/<#--[\s\S]*?-->/,string:[{pattern:/\br("|')(?:(?!\1)[^\\]|\\.)*\1/,greedy:!0},{pattern:RegExp(/("|')(?:(?!\1|\$\{)[^\\]|\\.|\$\{(?:(?!\})(?:<expr>))*\})*\1/.source.replace(/<expr>/g,function(){return n})),greedy:!0,inside:{interpolation:{pattern:RegExp(/((?:^|[^\\])(?:\\\\)*)\$\{(?:(?!\})(?:<expr>))*\}/.source.replace(/<expr>/g,function(){return n})),lookbehind:!0,inside:{"interpolation-punctuation":{pattern:/^\$\{|\}$/,alias:"punctuation"},rest:null}}}}],keyword:/\b(?:as)\b/,boolean:/\b(?:false|true)\b/,"builtin-function":{pattern:/((?:^|[^?])\?\s*)\w+/,lookbehind:!0,alias:"function"},function:/\b\w+(?=\s*\()/,number:/\b\d+(?:\.\d+)?\b/,operator:/\.\.[<*!]?|->|--|\+\+|&&|\|\||\?{1,2}|[-+*/%!=<>]=?|\b(?:gt|gte|lt|lte)\b/,punctuation:/[,;.:()[\]{}]/};a.string[1].inside.interpolation.inside.rest=a,t.languages.ftl={"ftl-comment":{pattern:/^<#--[\s\S]*/,alias:"comment"},"ftl-directive":{pattern:/^<[\s\S]+>$/,inside:{directive:{pattern:/(^<\/?)[#@][a-z]\w*/i,lookbehind:!0,alias:"keyword"},punctuation:/^<\/?|\/?>$/,content:{pattern:/\s*\S[\s\S]*/,alias:"ftl",inside:a}}},"ftl-interpolation":{pattern:/^\$\{[\s\S]*\}$/,inside:{punctuation:/^\$\{|\}$/,content:{pattern:/\s*\S[\s\S]*/,alias:"ftl",inside:a}}}},t.hooks.add("before-tokenize",function(i){var o=RegExp(/<#--[\s\S]*?-->|<\/?[#@][a-zA-Z](?:<expr>)*?>|\$\{(?:<expr>)*?\}/.source.replace(/<expr>/g,function(){return n}),"gi");t.languages["markup-templating"].buildPlaceholders(i,"ftl",o)}),t.hooks.add("after-tokenize",function(i){t.languages["markup-templating"].tokenizePlaceholders(i,"ftl")})})(e)}jE.displayName="gml";jE.aliases=["gamemakerlanguage"];function jE(e){e.register(Mt),e.languages.gamemakerlanguage=e.languages.gml=e.languages.extend("clike",{keyword:/\b(?:break|case|continue|default|do|else|enum|exit|for|globalvar|if|repeat|return|switch|until|var|while)\b/,number:/(?:\b0x[\da-f]+|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?)[ulf]{0,4}/i,operator:/--|\+\+|[-+%/=]=?|!=|\*\*?=?|<[<=>]?|>[=>]?|&&?|\^\^?|\|\|?|~|\b(?:and|at|not|or|with|xor)\b/,constant:/\b(?:GM_build_date|GM_version|action_(?:continue|restart|reverse|stop)|all|gamespeed_(?:fps|microseconds)|global|local|noone|other|pi|pointer_(?:invalid|null)|self|timezone_(?:local|utc)|undefined|ev_(?:create|destroy|step|alarm|keyboard|mouse|collision|other|draw|draw_(?:begin|end|post|pre)|keypress|keyrelease|trigger|(?:left|middle|no|right)_button|(?:left|middle|right)_press|(?:left|middle|right)_release|mouse_(?:enter|leave|wheel_down|wheel_up)|global_(?:left|middle|right)_button|global_(?:left|middle|right)_press|global_(?:left|middle|right)_release|joystick(?:1|2)_(?:button1|button2|button3|button4|button5|button6|button7|button8|down|left|right|up)|outside|boundary|game_start|game_end|room_start|room_end|no_more_lives|animation_end|end_of_path|no_more_health|user\d|gui|gui_begin|gui_end|step_(?:begin|end|normal))|vk_(?:alt|anykey|backspace|control|delete|down|end|enter|escape|home|insert|left|nokey|pagedown|pageup|pause|printscreen|return|right|shift|space|tab|up|f\d|numpad\d|add|decimal|divide|lalt|lcontrol|lshift|multiply|ralt|rcontrol|rshift|subtract)|achievement_(?:filter_(?:all_players|favorites_only|friends_only)|friends_info|info|leaderboard_info|our_info|pic_loaded|show_(?:achievement|bank|friend_picker|leaderboard|profile|purchase_prompt|ui)|type_challenge|type_score_challenge)|asset_(?:font|object|path|room|script|shader|sound|sprite|tiles|timeline|unknown)|audio_(?:3d|falloff_(?:exponent_distance|exponent_distance_clamped|inverse_distance|inverse_distance_clamped|linear_distance|linear_distance_clamped|none)|mono|new_system|old_system|stereo)|bm_(?:add|complex|dest_alpha|dest_color|dest_colour|inv_dest_alpha|inv_dest_color|inv_dest_colour|inv_src_alpha|inv_src_color|inv_src_colour|max|normal|one|src_alpha|src_alpha_sat|src_color|src_colour|subtract|zero)|browser_(?:chrome|firefox|ie|ie_mobile|not_a_browser|opera|safari|safari_mobile|tizen|unknown|windows_store)|buffer_(?:bool|f16|f32|f64|fast|fixed|generalerror|grow|invalidtype|network|outofbounds|outofspace|s16|s32|s8|seek_end|seek_relative|seek_start|string|text|u16|u32|u64|u8|vbuffer|wrap)|c_(?:aqua|black|blue|dkgray|fuchsia|gray|green|lime|ltgray|maroon|navy|olive|orange|purple|red|silver|teal|white|yellow)|cmpfunc_(?:always|equal|greater|greaterequal|less|lessequal|never|notequal)|cr_(?:appstart|arrow|beam|cross|default|drag|handpoint|hourglass|none|size_all|size_nesw|size_ns|size_nwse|size_we|uparrow)|cull_(?:clockwise|counterclockwise|noculling)|device_(?:emulator|tablet)|device_ios_(?:ipad|ipad_retina|iphone|iphone5|iphone6|iphone6plus|iphone_retina|unknown)|display_(?:landscape|landscape_flipped|portrait|portrait_flipped)|dll_(?:cdecl|cdel|stdcall)|ds_type_(?:grid|list|map|priority|queue|stack)|ef_(?:cloud|ellipse|explosion|firework|flare|rain|ring|smoke|smokeup|snow|spark|star)|fa_(?:archive|bottom|center|directory|hidden|left|middle|readonly|right|sysfile|top|volumeid)|fb_login_(?:default|fallback_to_webview|forcing_safari|forcing_webview|no_fallback_to_webview|use_system_account)|iap_(?:available|canceled|ev_consume|ev_product|ev_purchase|ev_restore|ev_storeload|failed|purchased|refunded|status_available|status_loading|status_processing|status_restoring|status_unavailable|status_uninitialised|storeload_failed|storeload_ok|unavailable)|leaderboard_type_(?:number|time_mins_secs)|lighttype_(?:dir|point)|matrix_(?:projection|view|world)|mb_(?:any|left|middle|none|right)|network_(?:config_(?:connect_timeout|disable_reliable_udp|enable_reliable_udp|use_non_blocking_socket)|socket_(?:bluetooth|tcp|udp)|type_(?:connect|data|disconnect|non_blocking_connect))|of_challenge_(?:lose|tie|win)|os_(?:android|ios|linux|macosx|ps3|ps4|psvita|unknown|uwp|win32|win8native|windows|winphone|xboxone)|phy_debug_render_(?:aabb|collision_pairs|coms|core_shapes|joints|obb|shapes)|phy_joint_(?:anchor_1_x|anchor_1_y|anchor_2_x|anchor_2_y|angle|angle_limits|damping_ratio|frequency|length_1|length_2|lower_angle_limit|max_force|max_length|max_motor_force|max_motor_torque|max_torque|motor_force|motor_speed|motor_torque|reaction_force_x|reaction_force_y|reaction_torque|speed|translation|upper_angle_limit)|phy_particle_data_flag_(?:category|color|colour|position|typeflags|velocity)|phy_particle_flag_(?:colormixing|colourmixing|elastic|powder|spring|tensile|viscous|wall|water|zombie)|phy_particle_group_flag_(?:rigid|solid)|pr_(?:linelist|linestrip|pointlist|trianglefan|trianglelist|trianglestrip)|ps_(?:distr|shape)_(?:diamond|ellipse|gaussian|invgaussian|line|linear|rectangle)|pt_shape_(?:circle|cloud|disk|explosion|flare|line|pixel|ring|smoke|snow|spark|sphere|square|star)|ty_(?:real|string)|gp_(?:face\d|axislh|axislv|axisrh|axisrv|padd|padl|padr|padu|select|shoulderl|shoulderlb|shoulderr|shoulderrb|start|stickl|stickr)|lb_disp_(?:none|numeric|time_ms|time_sec)|lb_sort_(?:ascending|descending|none)|ov_(?:achievements|community|friends|gamegroup|players|settings)|ugc_(?:filetype_(?:community|microtrans)|list_(?:Favorited|Followed|Published|Subscribed|UsedOrPlayed|VotedDown|VotedOn|VotedUp|WillVoteLater)|match_(?:AllGuides|Artwork|Collections|ControllerBindings|IntegratedGuides|Items|Items_Mtx|Items_ReadyToUse|Screenshots|UsableInGame|Videos|WebGuides)|query_(?:AcceptedForGameRankedByAcceptanceDate|CreatedByFriendsRankedByPublicationDate|FavoritedByFriendsRankedByPublicationDate|NotYetRated)|query_RankedBy(?:NumTimesReported|PublicationDate|TextSearch|TotalVotesAsc|Trend|Vote|VotesUp)|result_success|sortorder_CreationOrder(?:Asc|Desc)|sortorder_(?:ForModeration|LastUpdatedDesc|SubscriptionDateDesc|TitleAsc|VoteScoreDesc)|visibility_(?:friends_only|private|public))|vertex_usage_(?:binormal|blendindices|blendweight|color|colour|depth|fog|normal|position|psize|sample|tangent|texcoord|textcoord)|vertex_type_(?:float\d|color|colour|ubyte4)|input_type|layerelementtype_(?:background|instance|oldtilemap|particlesystem|sprite|tile|tilemap|undefined)|se_(?:chorus|compressor|echo|equalizer|flanger|gargle|none|reverb)|text_type|tile_(?:flip|index_mask|mirror|rotate)|(?:obj|rm|scr|spr)\w+)\b/,variable:/\b(?:alarm|application_surface|async_load|background_(?:alpha|blend|color|colour|foreground|height|hspeed|htiled|index|showcolor|showcolour|visible|vspeed|vtiled|width|x|xscale|y|yscale)|bbox_(?:bottom|left|right|top)|browser_(?:height|width)|caption_(?:health|lives|score)|current_(?:day|hour|minute|month|second|time|weekday|year)|cursor_sprite|debug_mode|delta_time|direction|display_aa|error_(?:last|occurred)|event_(?:action|number|object|type)|fps|fps_real|friction|game_(?:display|project|save)_(?:id|name)|gamemaker_(?:pro|registered|version)|gravity|gravity_direction|(?:h|v)speed|health|iap_data|id|image_(?:alpha|angle|blend|depth|index|number|speed|xscale|yscale)|instance_(?:count|id)|keyboard_(?:key|lastchar|lastkey|string)|layer|lives|mask_index|mouse_(?:button|lastbutton|x|y)|object_index|os_(?:browser|device|type|version)|path_(?:endaction|index|orientation|position|positionprevious|scale|speed)|persistent|phy_(?:rotation|(?:col_normal|collision|com|linear_velocity|position|speed)_(?:x|y)|angular_(?:damping|velocity)|position_(?:x|y)previous|speed|linear_damping|bullet|fixed_rotation|active|mass|inertia|dynamic|kinematic|sleeping|collision_points)|pointer_(?:invalid|null)|room|room_(?:caption|first|height|last|persistent|speed|width)|score|secure_mode|show_(?:health|lives|score)|solid|speed|sprite_(?:height|index|width|xoffset|yoffset)|temp_directory|timeline_(?:index|loop|position|running|speed)|transition_(?:color|kind|steps)|undefined|view_(?:angle|current|enabled|(?:h|v)(?:border|speed)|(?:h|w|x|y)port|(?:h|w|x|y)view|object|surface_id|visible)|visible|webgl_enabled|working_directory|(?:x|y)(?:previous|start)|x|y|argument(?:_relitive|_count|\d)|argument|global|local|other|self)\b/})}HE.displayName="gap";HE.aliases=[];function HE(e){e.languages.gap={shell:{pattern:/^gap>[\s\S]*?(?=^gap>|$(?![\s\S]))/m,greedy:!0,inside:{gap:{pattern:/^(gap>).+(?:(?:\r(?:\n|(?!\n))|\n)>.*)*/,lookbehind:!0,inside:null},punctuation:/^gap>/}},comment:{pattern:/#.*/,greedy:!0},string:{pattern:/(^|[^\\'"])(?:'(?:[^\r\n\\']|\\.){1,10}'|"(?:[^\r\n\\"]|\\.)*"(?!")|"""[\s\S]*?""")/,lookbehind:!0,greedy:!0,inside:{continuation:{pattern:/([\r\n])>/,lookbehind:!0,alias:"punctuation"}}},keyword:/\b(?:Assert|Info|IsBound|QUIT|TryNextMethod|Unbind|and|atomic|break|continue|do|elif|else|end|fi|for|function|if|in|local|mod|not|od|or|quit|readonly|readwrite|rec|repeat|return|then|until|while)\b/,boolean:/\b(?:false|true)\b/,function:/\b[a-z_]\w*(?=\s*\()/i,number:{pattern:/(^|[^\w.]|\.\.)(?:\d+(?:\.\d*)?|\.\d+)(?:[eE][+-]?\d+)?(?:_[a-z]?)?(?=$|[^\w.]|\.\.)/,lookbehind:!0},continuation:{pattern:/([\r\n])>/,lookbehind:!0,alias:"punctuation"},operator:/->|[-+*/^~=!]|<>|[<>]=?|:=|\.\./,punctuation:/[()[\]{},;.:]/},e.languages.gap.shell.inside.gap.inside=e.languages.gap}GE.displayName="gcode";GE.aliases=[];function GE(e){e.languages.gcode={comment:/;.*|\B\(.*?\)\B/,string:{pattern:/"(?:""|[^"])*"/,greedy:!0},keyword:/\b[GM]\d+(?:\.\d+)?\b/,property:/\b[A-Z]/,checksum:{pattern:/(\*)\d+/,lookbehind:!0,alias:"number"},punctuation:/[:*]/}}qE.displayName="gdscript";qE.aliases=[];function qE(e){e.languages.gdscript={comment:/#.*/,string:{pattern:/@?(?:("|')(?:(?!\1)[^\n\\]|\\[\s\S])*\1(?!"|')|"""(?:[^\\]|\\[\s\S])*?""")/,greedy:!0},"class-name":{pattern:/(^(?:class|class_name|extends)[ \t]+|^export\([ \t]*|\bas[ \t]+|(?:\b(?:const|var)[ \t]|[,(])[ \t]*\w+[ \t]*:[ \t]*|->[ \t]*)[a-zA-Z_]\w*/m,lookbehind:!0},keyword:/\b(?:and|as|assert|break|breakpoint|class|class_name|const|continue|elif|else|enum|export|extends|for|func|if|in|is|master|mastersync|match|not|null|onready|or|pass|preload|puppet|puppetsync|remote|remotesync|return|self|setget|signal|static|tool|var|while|yield)\b/,function:/\b[a-z_]\w*(?=[ \t]*\()/i,variable:/\$\w+/,number:[/\b0b[01_]+\b|\b0x[\da-fA-F_]+\b|(?:\b\d[\d_]*(?:\.[\d_]*)?|\B\.[\d_]+)(?:e[+-]?[\d_]+)?\b/,/\b(?:INF|NAN|PI|TAU)\b/],constant:/\b[A-Z][A-Z_\d]*\b/,boolean:/\b(?:false|true)\b/,operator:/->|:=|&&|\|\||<<|>>|[-+*/%&|!<>=]=?|[~^]/,punctuation:/[.:,;()[\]{}]/}}WE.displayName="gedcom";WE.aliases=[];function WE(e){e.languages.gedcom={"line-value":{pattern:/(^[\t ]*\d+ +(?:@\w[\w!"$%&'()*+,\-./:;<=>?[\\\]^`{|}~\x80-\xfe #]*@ +)?\w+ ).+/m,lookbehind:!0,inside:{pointer:{pattern:/^@\w[\w!"$%&'()*+,\-./:;<=>?[\\\]^`{|}~\x80-\xfe #]*@$/,alias:"variable"}}},record:{pattern:/(^[\t ]*\d+ +(?:@\w[\w!"$%&'()*+,\-./:;<=>?[\\\]^`{|}~\x80-\xfe #]*@ +)?)\w+/m,lookbehind:!0,alias:"tag"},level:{pattern:/(^[\t ]*)\d+/m,lookbehind:!0,alias:"number"},pointer:{pattern:/@\w[\w!"$%&'()*+,\-./:;<=>?[\\\]^`{|}~\x80-\xfe #]*@/,alias:"variable"}}}VE.displayName="gettext";VE.aliases=["po"];function VE(e){e.languages.gettext={comment:[{pattern:/# .*/,greedy:!0,alias:"translator-comment"},{pattern:/#\..*/,greedy:!0,alias:"extracted-comment"},{pattern:/#:.*/,greedy:!0,alias:"reference-comment"},{pattern:/#,.*/,greedy:!0,alias:"flag-comment"},{pattern:/#\|.*/,greedy:!0,alias:"previously-untranslated-comment"},{pattern:/#.*/,greedy:!0}],string:{pattern:/(^|[^\\])"(?:[^"\\]|\\.)*"/,lookbehind:!0,greedy:!0},keyword:/^msg(?:ctxt|id|id_plural|str)\b/m,number:/\b\d+\b/,punctuation:/[\[\]]/},e.languages.po=e.languages.gettext}YE.displayName="gherkin";YE.aliases=[];function YE(e){(function(t){var n=/(?:\r?\n|\r)[ \t]*\|.+\|(?:(?!\|).)*/.source;t.languages.gherkin={pystring:{pattern:/("""|''')[\s\S]+?\1/,alias:"string"},comment:{pattern:/(^[ \t]*)#.*/m,lookbehind:!0},tag:{pattern:/(^[ \t]*)@\S*/m,lookbehind:!0},feature:{pattern:/((?:^|\r?\n|\r)[ \t]*)(?:Ability|Ahoy matey!|Arwedd|Aspekt|Besigheid Behoefte|Business Need|Caracteristica|Característica|Egenskab|Egenskap|Eiginleiki|Feature|Fīča|Fitur|Fonctionnalité|Fonksyonalite|Funcionalidade|Funcionalitat|Functionalitate|Funcţionalitate|Funcționalitate|Functionaliteit|Fungsi|Funkcia|Funkcija|Funkcionalitāte|Funkcionalnost|Funkcja|Funksie|Funktionalität|Funktionalitéit|Funzionalità|Hwaet|Hwæt|Jellemző|Karakteristik|Lastnost|Mak|Mogucnost|laH|Mogućnost|Moznosti|Možnosti|OH HAI|Omadus|Ominaisuus|Osobina|Özellik|Potrzeba biznesowa|perbogh|poQbogh malja'|Požadavek|Požiadavka|Pretty much|Qap|Qu'meH 'ut|Savybė|Tính năng|Trajto|Vermoë|Vlastnosť|Właściwość|Značilnost|Δυνατότητα|Λειτουργία|Могућност|Мөмкинлек|Особина|Свойство|Үзенчәлеклелек|Функционал|Функционалност|Функция|Функціонал|תכונה|خاصية|خصوصیت|صلاحیت|کاروبار کی ضرورت|وِیژگی|रूप लेख|ਖਾਸੀਅਤ|ਨਕਸ਼ ਨੁਹਾਰ|ਮੁਹਾਂਦਰਾ|గుణము|ಹೆಚ್ಚಳ|ความต้องการทางธุรกิจ|ความสามารถ|โครงหลัก|기능|フィーチャ|功能|機能):(?:[^:\r\n]+(?:\r?\n|\r|$))*/,lookbehind:!0,inside:{important:{pattern:/(:)[^\r\n]+/,lookbehind:!0},keyword:/[^:\r\n]+:/}},scenario:{pattern:/(^[ \t]*)(?:Abstract Scenario|Abstrakt Scenario|Achtergrond|Aer|Ær|Agtergrond|All y'all|Antecedentes|Antecedents|Atburðarás|Atburðarásir|Awww, look mate|B4|Background|Baggrund|Bakgrund|Bakgrunn|Bakgrunnur|Beispiele|Beispiller|Bối cảnh|Cefndir|Cenario|Cenário|Cenario de Fundo|Cenário de Fundo|Cenarios|Cenários|Contesto|Context|Contexte|Contexto|Conto|Contoh|Contone|Dæmi|Dasar|Dead men tell no tales|Delineacao do Cenario|Delineação do Cenário|Dis is what went down|Dữ liệu|Dyagram Senaryo|Dyagram senaryo|Egzanp|Ejemplos|Eksempler|Ekzemploj|Enghreifftiau|Esbozo do escenario|Escenari|Escenario|Esempi|Esquema de l'escenari|Esquema del escenario|Esquema do Cenario|Esquema do Cenário|EXAMPLZ|Examples|Exempel|Exemple|Exemples|Exemplos|First off|Fono|Forgatókönyv|Forgatókönyv vázlat|Fundo|Geçmiş|Grundlage|Hannergrond|ghantoH|Háttér|Heave to|Istorik|Juhtumid|Keadaan|Khung kịch bản|Khung tình huống|Kịch bản|Koncept|Konsep skenario|Kontèks|Kontekst|Kontekstas|Konteksts|Kontext|Konturo de la scenaro|Latar Belakang|lut chovnatlh|lut|lutmey|Lýsing Atburðarásar|Lýsing Dæma|MISHUN SRSLY|MISHUN|Menggariskan Senario|mo'|Náčrt Scenára|Náčrt Scénáře|Náčrt Scenáru|Oris scenarija|Örnekler|Osnova|Osnova Scenára|Osnova scénáře|Osnutek|Ozadje|Paraugs|Pavyzdžiai|Példák|Piemēri|Plan du scénario|Plan du Scénario|Plan Senaryo|Plan senaryo|Plang vum Szenario|Pozadí|Pozadie|Pozadina|Príklady|Příklady|Primer|Primeri|Primjeri|Przykłady|Raamstsenaarium|Reckon it's like|Rerefons|Scenár|Scénář|Scenarie|Scenarij|Scenarijai|Scenarijaus šablonas|Scenariji|Scenārijs|Scenārijs pēc parauga|Scenarijus|Scenario|Scénario|Scenario Amlinellol|Scenario Outline|Scenario Template|Scenariomal|Scenariomall|Scenarios|Scenariu|Scenariusz|Scenaro|Schema dello scenario|Se ðe|Se the|Se þe|Senario|Senaryo Deskripsyon|Senaryo deskripsyon|Senaryo|Senaryo taslağı|Shiver me timbers|Situācija|Situai|Situasie Uiteensetting|Situasie|Skenario konsep|Skenario|Skica|Structura scenariu|Structură scenariu|Struktura scenarija|Stsenaarium|Swa hwaer swa|Swa|Swa hwær swa|Szablon scenariusza|Szenario|Szenariogrundriss|Tapaukset|Tapaus|Tapausaihio|Taust|Tausta|Template Keadaan|Template Senario|Template Situai|The thing of it is|Tình huống|Variantai|Voorbeelde|Voorbeelden|Wharrimean is|Yo-ho-ho|You'll wanna|Założenia|Παραδείγματα|Περιγραφή Σεναρίου|Σενάρια|Σενάριο|Υπόβαθρο|Кереш|Контекст|Концепт|Мисаллар|Мисоллар|Основа|Передумова|Позадина|Предистория|Предыстория|Приклади|Пример|Примери|Примеры|Рамка на сценарий|Скица|Структура сценарија|Структура сценария|Структура сценарію|Сценарий|Сценарий структураси|Сценарийның төзелеше|Сценарији|Сценарио|Сценарій|Тарих|Үрнәкләр|דוגמאות|רקע|תבנית תרחיש|תרחיש|الخلفية|الگوی سناریو|امثلة|پس منظر|زمینه|سناریو|سيناريو|سيناريو مخطط|مثالیں|منظر نامے کا خاکہ|منظرنامہ|نمونه ها|उदाहरण|परिदृश्य|परिदृश्य रूपरेखा|पृष्ठभूमि|ਉਦਾਹਰਨਾਂ|ਪਟਕਥਾ|ਪਟਕਥਾ ਢਾਂਚਾ|ਪਟਕਥਾ ਰੂਪ ਰੇਖਾ|ਪਿਛੋਕੜ|ఉదాహరణలు|కథనం|నేపథ్యం|సన్నివేశం|ಉದಾಹರಣೆಗಳು|ಕಥಾಸಾರಾಂಶ|ವಿವರಣೆ|ಹಿನ್ನೆಲೆ|โครงสร้างของเหตุการณ์|ชุดของตัวอย่าง|ชุดของเหตุการณ์|แนวคิด|สรุปเหตุการณ์|เหตุการณ์|배경|시나리오|시나리오 개요|예|サンプル|シナリオ|シナリオアウトライン|シナリオテンプレ|シナリオテンプレート|テンプレ|例|例子|剧本|剧本大纲|劇本|劇本大綱|场景|场景大纲|場景|場景大綱|背景):[^:\r\n]*/m,lookbehind:!0,inside:{important:{pattern:/(:)[^\r\n]*/,lookbehind:!0},keyword:/[^:\r\n]+:/}},"table-body":{pattern:RegExp("("+n+")(?:"+n+")+"),lookbehind:!0,inside:{outline:{pattern:/<[^>]+>/,alias:"variable"},td:{pattern:/\s*[^\s|][^|]*/,alias:"string"},punctuation:/\|/}},"table-head":{pattern:RegExp(n),inside:{th:{pattern:/\s*[^\s|][^|]*/,alias:"variable"},punctuation:/\|/}},atrule:{pattern:/(^[ \t]+)(?:'a|'ach|'ej|7|a|A také|A taktiež|A tiež|A zároveň|Aber|Ac|Adott|Akkor|Ak|Aleshores|Ale|Ali|Allora|Alors|Als|Ama|Amennyiben|Amikor|Ampak|an|AN|Ananging|And y'all|And|Angenommen|Anrhegedig a|An|Apabila|Atès|Atesa|Atunci|Avast!|Aye|A|awer|Bagi|Banjur|Bet|Biết|Blimey!|Buh|But at the end of the day I reckon|But y'all|But|BUT|Cal|Când|Cand|Cando|Ce|Cuando|Če|Ða ðe|Ða|Dadas|Dada|Dados|Dado|DaH ghu' bejlu'|dann|Dann|Dano|Dan|Dar|Dat fiind|Data|Date fiind|Date|Dati fiind|Dati|Daţi fiind|Dați fiind|DEN|Dato|De|Den youse gotta|Dengan|Diberi|Diyelim ki|Donada|Donat|Donitaĵo|Do|Dun|Duota|Ðurh|Eeldades|Ef|Eğer ki|Entao|Então|Entón|E|En|Entonces|Epi|És|Etant donnée|Etant donné|Et|Étant données|Étant donnée|Étant donné|Etant données|Etant donnés|Étant donnés|Fakat|Gangway!|Gdy|Gegeben seien|Gegeben sei|Gegeven|Gegewe|ghu' noblu'|Gitt|Given y'all|Given|Givet|Givun|Ha|Cho|I CAN HAZ|In|Ir|It's just unbelievable|I|Ja|Jeśli|Jeżeli|Kad|Kada|Kadar|Kai|Kaj|Když|Keď|Kemudian|Ketika|Khi|Kiedy|Ko|Kuid|Kui|Kun|Lan|latlh|Le sa a|Let go and haul|Le|Lè sa a|Lè|Logo|Lorsqu'<|Lorsque|mä|Maar|Mais|Mając|Ma|Majd|Maka|Manawa|Mas|Men|Menawa|Mutta|Nalika|Nalikaning|Nanging|Når|När|Nato|Nhưng|Niin|Njuk|O zaman|Och|Og|Oletetaan|Ond|Onda|Oraz|Pak|Pero|Però|Podano|Pokiaľ|Pokud|Potem|Potom|Privzeto|Pryd|Quan|Quand|Quando|qaSDI'|Så|Sed|Se|Siis|Sipoze ke|Sipoze Ke|Sipoze|Si|Şi|Și|Soit|Stel|Tada|Tad|Takrat|Tak|Tapi|Ter|Tetapi|Tha the|Tha|Then y'all|Then|Thì|Thurh|Toda|Too right|Un|Und|ugeholl|Và|vaj|Vendar|Ve|wann|Wanneer|WEN|Wenn|When y'all|When|Wtedy|Wun|Y'know|Yeah nah|Yna|Youse know like when|Youse know when youse got|Y|Za predpokladu|Za předpokladu|Zadan|Zadani|Zadano|Zadate|Zadato|Zakładając|Zaradi|Zatati|Þa þe|Þa|Þá|Þegar|Þurh|Αλλά|Δεδομένου|Και|Όταν|Τότε|А також|Агар|Але|Али|Аммо|А|Әгәр|Әйтик|Әмма|Бирок|Ва|Вә|Дадено|Дано|Допустим|Если|Задате|Задати|Задато|И|І|К тому же|Када|Кад|Когато|Когда|Коли|Ләкин|Лекин|Нәтиҗәдә|Нехай|Но|Онда|Припустимо, що|Припустимо|Пусть|Также|Та|Тогда|Тоді|То|Унда|Һәм|Якщо|אבל|אזי|אז|בהינתן|וגם|כאשר|آنگاه|اذاً|اگر|اما|اور|با فرض|بالفرض|بفرض|پھر|تب|ثم|جب|عندما|فرض کیا|لكن|لیکن|متى|هنگامی|و|अगर|और|कदा|किन्तु|चूंकि|जब|तथा|तदा|तब|परन्तु|पर|यदि|ਅਤੇ|ਜਦੋਂ|ਜਿਵੇਂ ਕਿ|ਜੇਕਰ|ਤਦ|ਪਰ|అప్పుడు|ఈ పరిస్థితిలో|కాని|చెప్పబడినది|మరియు|ಆದರೆ|ನಂತರ|ನೀಡಿದ|ಮತ್ತು|ಸ್ಥಿತಿಯನ್ನು|กำหนดให้|ดังนั้น|แต่|เมื่อ|และ|그러면<|그리고<|단<|만약<|만일<|먼저<|조건<|하지만<|かつ<|しかし<|ただし<|ならば<|もし<|並且<|但し<|但是<|假如<|假定<|假設<|假设<|前提<|同时<|同時<|并且<|当<|當<|而且<|那么<|那麼<)(?=[ \t])/m,lookbehind:!0},string:{pattern:/"(?:\\.|[^"\\\r\n])*"|'(?:\\.|[^'\\\r\n])*'/,inside:{outline:{pattern:/<[^>]+>/,alias:"variable"}}},outline:{pattern:/<[^>]+>/,alias:"variable"}}})(e)}XE.displayName="git";XE.aliases=[];function XE(e){e.languages.git={comment:/^#.*/m,deleted:/^[-–].*/m,inserted:/^\+.*/m,string:/("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,command:{pattern:/^.*\$ git .*$/m,inside:{parameter:/\s--?\w+/}},coord:/^@@.*@@$/m,"commit-sha1":/^commit \w{40}$/m}}KE.displayName="glsl";KE.aliases=[];function KE(e){e.register($i),e.languages.glsl=e.languages.extend("c",{keyword:/\b(?:active|asm|atomic_uint|attribute|[ibdu]?vec[234]|bool|break|buffer|case|cast|centroid|class|coherent|common|const|continue|d?mat[234](?:x[234])?|default|discard|do|double|else|enum|extern|external|false|filter|fixed|flat|float|for|fvec[234]|goto|half|highp|hvec[234]|[iu]?sampler2DMS(?:Array)?|[iu]?sampler2DRect|[iu]?samplerBuffer|[iu]?samplerCube|[iu]?samplerCubeArray|[iu]?sampler[123]D|[iu]?sampler[12]DArray|[iu]?image2DMS(?:Array)?|[iu]?image2DRect|[iu]?imageBuffer|[iu]?imageCube|[iu]?imageCubeArray|[iu]?image[123]D|[iu]?image[12]DArray|if|in|inline|inout|input|int|interface|invariant|layout|long|lowp|mediump|namespace|noinline|noperspective|out|output|partition|patch|precise|precision|public|readonly|resource|restrict|return|sample|sampler[12]DArrayShadow|sampler[12]DShadow|sampler2DRectShadow|sampler3DRect|samplerCubeArrayShadow|samplerCubeShadow|shared|short|sizeof|smooth|static|struct|subroutine|superp|switch|template|this|true|typedef|uint|uniform|union|unsigned|using|varying|void|volatile|while|writeonly)\b/})}ZE.displayName="gn";ZE.aliases=["gni"];function ZE(e){e.languages.gn={comment:{pattern:/#.*/,greedy:!0},"string-literal":{pattern:/(^|[^\\"])"(?:[^\r\n"\\]|\\.)*"/,lookbehind:!0,greedy:!0,inside:{interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\$(?:\{[\s\S]*?\}|[a-zA-Z_]\w*|0x[a-fA-F0-9]{2})/,lookbehind:!0,inside:{number:/^\$0x[\s\S]{2}$/,variable:/^\$\w+$/,"interpolation-punctuation":{pattern:/^\$\{|\}$/,alias:"punctuation"},expression:{pattern:/[\s\S]+/,inside:null}}},string:/[\s\S]+/}},keyword:/\b(?:else|if)\b/,boolean:/\b(?:false|true)\b/,"builtin-function":{pattern:/\b(?:assert|defined|foreach|import|pool|print|template|tool|toolchain)(?=\s*\()/i,alias:"keyword"},function:/\b[a-z_]\w*(?=\s*\()/i,constant:/\b(?:current_cpu|current_os|current_toolchain|default_toolchain|host_cpu|host_os|root_build_dir|root_gen_dir|root_out_dir|target_cpu|target_gen_dir|target_os|target_out_dir)\b/,number:/-?\b\d+\b/,operator:/[-+!=<>]=?|&&|\|\|/,punctuation:/[(){}[\],.]/},e.languages.gn["string-literal"].inside.interpolation.inside.expression.inside=e.languages.gn,e.languages.gni=e.languages.gn}QE.displayName="linker-script";QE.aliases=["ld"];function QE(e){e.languages["linker-script"]={comment:{pattern:/(^|\s)\/\*[\s\S]*?(?:$|\*\/)/,lookbehind:!0,greedy:!0},identifier:{pattern:/"[^"\r\n]*"/,greedy:!0},"location-counter":{pattern:/\B\.\B/,alias:"important"},section:{pattern:/(^|[^\w*])\.\w+\b/,lookbehind:!0,alias:"keyword"},function:/\b[A-Z][A-Z_]*(?=\s*\()/,number:/\b(?:0[xX][a-fA-F0-9]+|\d+)[KM]?\b/,operator:/>>=?|<<=?|->|\+\+|--|&&|\|\||::|[?:~]|[-+*/%&|^!=<>]=?/,punctuation:/[(){},;]/},e.languages.ld=e.languages["linker-script"]}JE.displayName="go";JE.aliases=[];function JE(e){e.register(Mt),e.languages.go=e.languages.extend("clike",{string:{pattern:/(^|[^\\])"(?:\\.|[^"\\\r\n])*"|`[^`]*`/,lookbehind:!0,greedy:!0},keyword:/\b(?:break|case|chan|const|continue|default|defer|else|fallthrough|for|func|go(?:to)?|if|import|interface|map|package|range|return|select|struct|switch|type|var)\b/,boolean:/\b(?:_|false|iota|nil|true)\b/,number:[/\b0(?:b[01_]+|o[0-7_]+)i?\b/i,/\b0x(?:[a-f\d_]+(?:\.[a-f\d_]*)?|\.[a-f\d_]+)(?:p[+-]?\d+(?:_\d+)*)?i?(?!\w)/i,/(?:\b\d[\d_]*(?:\.[\d_]*)?|\B\.\d[\d_]*)(?:e[+-]?[\d_]+)?i?(?!\w)/i],operator:/[*\/%^!=]=?|\+[=+]?|-[=-]?|\|[=|]?|&(?:=|&|\^=?)?|>(?:>=?|=)?|<(?:<=?|=|-)?|:=|\.\.\./,builtin:/\b(?:append|bool|byte|cap|close|complex|complex(?:64|128)|copy|delete|error|float(?:32|64)|u?int(?:8|16|32|64)?|imag|len|make|new|panic|print(?:ln)?|real|recover|rune|string|uintptr)\b/}),e.languages.insertBefore("go","string",{char:{pattern:/'(?:\\.|[^'\\\r\n]){0,10}'/,greedy:!0}}),delete e.languages.go["class-name"]}ek.displayName="go-module";ek.aliases=["go-mod"];function ek(e){e.languages["go-mod"]=e.languages["go-module"]={comment:{pattern:/\/\/.*/,greedy:!0},version:{pattern:/(^|[\s()[\],])v\d+\.\d+\.\d+(?:[+-][-+.\w]*)?(?![^\s()[\],])/,lookbehind:!0,alias:"number"},"go-version":{pattern:/((?:^|\s)go\s+)\d+(?:\.\d+){1,2}/,lookbehind:!0,alias:"number"},keyword:{pattern:/^([ \t]*)(?:exclude|go|module|replace|require|retract)\b/m,lookbehind:!0},operator:/=>/,punctuation:/[()[\],]/}}tk.displayName="gradle";tk.aliases=[];function tk(e){e.register(Mt),(function(t){var n={pattern:/((?:^|[^\\$])(?:\\{2})*)\$(?:\w+|\{[^{}]*\})/,lookbehind:!0,inside:{"interpolation-punctuation":{pattern:/^\$\{?|\}$/,alias:"punctuation"},expression:{pattern:/[\s\S]+/,inside:null}}};t.languages.gradle=t.languages.extend("clike",{string:{pattern:/'''(?:[^\\]|\\[\s\S])*?'''|'(?:\\.|[^\\'\r\n])*'/,greedy:!0},keyword:/\b(?:apply|def|dependencies|else|if|implementation|import|plugin|plugins|project|repositories|repository|sourceSets|tasks|val)\b/,number:/\b(?:0b[01_]+|0x[\da-f_]+(?:\.[\da-f_p\-]+)?|[\d_]+(?:\.[\d_]+)?(?:e[+-]?\d+)?)[glidf]?\b/i,operator:{pattern:/(^|[^.])(?:~|==?~?|\?[.:]?|\*(?:[.=]|\*=?)?|\.[@&]|\.\.<|\.\.(?!\.)|-[-=>]?|\+[+=]?|!=?|<(?:<=?|=>?)?|>(?:>>?=?|=)?|&[&=]?|\|[|=]?|\/=?|\^=?|%=?)/,lookbehind:!0},punctuation:/\.+|[{}[\];(),:$]/}),t.languages.insertBefore("gradle","string",{shebang:{pattern:/#!.+/,alias:"comment",greedy:!0},"interpolation-string":{pattern:/"""(?:[^\\]|\\[\s\S])*?"""|(["/])(?:\\.|(?!\1)[^\\\r\n])*\1|\$\/(?:[^/$]|\$(?:[/$]|(?![/$]))|\/(?!\$))*\/\$/,greedy:!0,inside:{interpolation:n,string:/[\s\S]+/}}}),t.languages.insertBefore("gradle","punctuation",{"spock-block":/\b(?:and|cleanup|expect|given|setup|then|when|where):/}),t.languages.insertBefore("gradle","function",{annotation:{pattern:/(^|[^.])@\w+/,lookbehind:!0,alias:"punctuation"}}),n.inside.expression.inside=t.languages.gradle})(e)}nk.displayName="graphql";nk.aliases=[];function nk(e){e.languages.graphql={comment:/#.*/,description:{pattern:/(?:"""(?:[^"]|(?!""")")*"""|"(?:\\.|[^\\"\r\n])*")(?=\s*[a-z_])/i,greedy:!0,alias:"string",inside:{"language-markdown":{pattern:/(^"(?:"")?)(?!\1)[\s\S]+(?=\1$)/,lookbehind:!0,inside:e.languages.markdown}}},string:{pattern:/"""(?:[^"]|(?!""")")*"""|"(?:\\.|[^\\"\r\n])*"/,greedy:!0},number:/(?:\B-|\b)\d+(?:\.\d+)?(?:e[+-]?\d+)?\b/i,boolean:/\b(?:false|true)\b/,variable:/\$[a-z_]\w*/i,directive:{pattern:/@[a-z_]\w*/i,alias:"function"},"attr-name":{pattern:/\b[a-z_]\w*(?=\s*(?:\((?:[^()"]|"(?:\\.|[^\\"\r\n])*")*\))?:)/i,greedy:!0},"atom-input":{pattern:/\b[A-Z]\w*Input\b/,alias:"class-name"},scalar:/\b(?:Boolean|Float|ID|Int|String)\b/,constant:/\b[A-Z][A-Z_\d]*\b/,"class-name":{pattern:/(\b(?:enum|implements|interface|on|scalar|type|union)\s+|&\s*|:\s*|\[)[A-Z_]\w*/,lookbehind:!0},fragment:{pattern:/(\bfragment\s+|\.{3}\s*(?!on\b))[a-zA-Z_]\w*/,lookbehind:!0,alias:"function"},"definition-mutation":{pattern:/(\bmutation\s+)[a-zA-Z_]\w*/,lookbehind:!0,alias:"function"},"definition-query":{pattern:/(\bquery\s+)[a-zA-Z_]\w*/,lookbehind:!0,alias:"function"},keyword:/\b(?:directive|enum|extend|fragment|implements|input|interface|mutation|on|query|repeatable|scalar|schema|subscription|type|union)\b/,operator:/[!=|&]|\.{3}/,"property-query":/\w+(?=\s*\()/,object:/\w+(?=\s*\{)/,punctuation:/[!(){}\[\]:=,]/,property:/\w+/},e.hooks.add("after-tokenize",function(n){if(n.language!=="graphql")return;var r=n.tokens.filter(function(w){return typeof w!="string"&&w.type!=="comment"&&w.type!=="scalar"}),a=0;function i(w){return r[a+w]}function o(w,S){S=S||0;for(var k=0;k<w.length;k++){var R=i(k+S);if(!R||R.type!==w[k])return!1}return!0}function l(w,S){for(var k=1,R=a;R<r.length;R++){var I=r[R],L=I.content;if(I.type==="punctuation"&&typeof L=="string"){if(w.test(L))k++;else if(S.test(L)&&(k--,k===0))return R}}return-1}function u(w,S){var k=w.alias;k?Array.isArray(k)||(w.alias=k=[k]):w.alias=k=[],k.push(S)}for(;a<r.length;){var d=r[a++];if(d.type==="keyword"&&d.content==="mutation"){var h=[];if(o(["definition-mutation","punctuation"])&&i(1).content==="("){a+=2;var f=l(/^\($/,/^\)$/);if(f===-1)continue;for(;a<f;a++){var m=i(0);m.type==="variable"&&(u(m,"variable-input"),h.push(m.content))}a=f+1}if(o(["punctuation","property-query"])&&i(0).content==="{"&&(a++,u(i(0),"property-mutation"),h.length>0)){var b=l(/^\{$/,/^\}$/);if(b===-1)continue;for(var y=a;y<b;y++){var v=r[y];v.type==="variable"&&h.indexOf(v.content)>=0&&u(v,"variable-input")}}}}})}rk.displayName="groovy";rk.aliases=[];function rk(e){e.register(Mt),(function(t){var n={pattern:/((?:^|[^\\$])(?:\\{2})*)\$(?:\w+|\{[^{}]*\})/,lookbehind:!0,inside:{"interpolation-punctuation":{pattern:/^\$\{?|\}$/,alias:"punctuation"},expression:{pattern:/[\s\S]+/,inside:null}}};t.languages.groovy=t.languages.extend("clike",{string:{pattern:/'''(?:[^\\]|\\[\s\S])*?'''|'(?:\\.|[^\\'\r\n])*'/,greedy:!0},keyword:/\b(?:abstract|as|assert|boolean|break|byte|case|catch|char|class|const|continue|def|default|do|double|else|enum|extends|final|finally|float|for|goto|if|implements|import|in|instanceof|int|interface|long|native|new|package|private|protected|public|return|short|static|strictfp|super|switch|synchronized|this|throw|throws|trait|transient|try|void|volatile|while)\b/,number:/\b(?:0b[01_]+|0x[\da-f_]+(?:\.[\da-f_p\-]+)?|[\d_]+(?:\.[\d_]+)?(?:e[+-]?\d+)?)[glidf]?\b/i,operator:{pattern:/(^|[^.])(?:~|==?~?|\?[.:]?|\*(?:[.=]|\*=?)?|\.[@&]|\.\.<|\.\.(?!\.)|-[-=>]?|\+[+=]?|!=?|<(?:<=?|=>?)?|>(?:>>?=?|=)?|&[&=]?|\|[|=]?|\/=?|\^=?|%=?)/,lookbehind:!0},punctuation:/\.+|[{}[\];(),:$]/}),t.languages.insertBefore("groovy","string",{shebang:{pattern:/#!.+/,alias:"comment",greedy:!0},"interpolation-string":{pattern:/"""(?:[^\\]|\\[\s\S])*?"""|(["/])(?:\\.|(?!\1)[^\\\r\n])*\1|\$\/(?:[^/$]|\$(?:[/$]|(?![/$]))|\/(?!\$))*\/\$/,greedy:!0,inside:{interpolation:n,string:/[\s\S]+/}}}),t.languages.insertBefore("groovy","punctuation",{"spock-block":/\b(?:and|cleanup|expect|given|setup|then|when|where):/}),t.languages.insertBefore("groovy","function",{annotation:{pattern:/(^|[^.])@\w+/,lookbehind:!0,alias:"punctuation"}}),n.inside.expression.inside=t.languages.groovy})(e)}ak.displayName="less";ak.aliases=[];function ak(e){e.register(Ll),e.languages.less=e.languages.extend("css",{comment:[/\/\*[\s\S]*?\*\//,{pattern:/(^|[^\\])\/\/.*/,lookbehind:!0}],atrule:{pattern:/@[\w-](?:\((?:[^(){}]|\([^(){}]*\))*\)|[^(){};\s]|\s+(?!\s))*?(?=\s*\{)/,inside:{punctuation:/[:()]/}},selector:{pattern:/(?:@\{[\w-]+\}|[^{};\s@])(?:@\{[\w-]+\}|\((?:[^(){}]|\([^(){}]*\))*\)|[^(){};@\s]|\s+(?!\s))*?(?=\s*\{)/,inside:{variable:/@+[\w-]+/}},property:/(?:@\{[\w-]+\}|[\w-])+(?:\+_?)?(?=\s*:)/,operator:/[+\-*\/]/}),e.languages.insertBefore("less","property",{variable:[{pattern:/@[\w-]+\s*:/,inside:{punctuation:/:/}},/@@?[\w-]+/],"mixin-usage":{pattern:/([{;]\s*)[.#](?!\d)[\w-].*?(?=[(;])/,lookbehind:!0,alias:"function"}})}ik.displayName="scss";ik.aliases=[];function ik(e){e.register(Ll),e.languages.scss=e.languages.extend("css",{comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?\*\/|\/\/.*)/,lookbehind:!0},atrule:{pattern:/@[\w-](?:\([^()]+\)|[^()\s]|\s+(?!\s))*?(?=\s+[{;])/,inside:{rule:/@[\w-]+/}},url:/(?:[-a-z]+-)?url(?=\()/i,selector:{pattern:/(?=\S)[^@;{}()]?(?:[^@;{}()\s]|\s+(?!\s)|#\{\$[-\w]+\})+(?=\s*\{(?:\}|\s|[^}][^:{}]*[:{][^}]))/,inside:{parent:{pattern:/&/,alias:"important"},placeholder:/%[-\w]+/,variable:/\$[-\w]+|#\{\$[-\w]+\}/}},property:{pattern:/(?:[-\w]|\$[-\w]|#\{\$[-\w]+\})+(?=\s*:)/,inside:{variable:/\$[-\w]+|#\{\$[-\w]+\}/}}}),e.languages.insertBefore("scss","atrule",{keyword:[/@(?:content|debug|each|else(?: if)?|extend|for|forward|function|if|import|include|mixin|return|use|warn|while)\b/i,{pattern:/( )(?:from|through)(?= )/,lookbehind:!0}]}),e.languages.insertBefore("scss","important",{variable:/\$[-\w]+|#\{\$[-\w]+\}/}),e.languages.insertBefore("scss","function",{"module-modifier":{pattern:/\b(?:as|hide|show|with)\b/i,alias:"keyword"},placeholder:{pattern:/%[-\w]+/,alias:"selector"},statement:{pattern:/\B!(?:default|optional)\b/i,alias:"keyword"},boolean:/\b(?:false|true)\b/,null:{pattern:/\bnull\b/,alias:"keyword"},operator:{pattern:/(\s)(?:[-+*\/%]|[=!]=|<=?|>=?|and|not|or)(?=\s)/,lookbehind:!0}}),e.languages.scss.atrule.inside.rest=e.languages.scss}ok.displayName="textile";ok.aliases=[];function ok(e){e.register(cr),(function(t){var n=/\([^|()\n]+\)|\[[^\]\n]+\]|\{[^}\n]+\}/.source,r=/\)|\((?![^|()\n]+\))/.source;function a(f,m){return RegExp(f.replace(/<MOD>/g,function(){return"(?:"+n+")"}).replace(/<PAR>/g,function(){return"(?:"+r+")"}),m||"")}var i={css:{pattern:/\{[^{}]+\}/,inside:{rest:t.languages.css}},"class-id":{pattern:/(\()[^()]+(?=\))/,lookbehind:!0,alias:"attr-value"},lang:{pattern:/(\[)[^\[\]]+(?=\])/,lookbehind:!0,alias:"attr-value"},punctuation:/[\\\/]\d+|\S/},o=t.languages.textile=t.languages.extend("markup",{phrase:{pattern:/(^|\r|\n)\S[\s\S]*?(?=$|\r?\n\r?\n|\r\r)/,lookbehind:!0,inside:{"block-tag":{pattern:a(/^[a-z]\w*(?:<MOD>|<PAR>|[<>=])*\./.source),inside:{modifier:{pattern:a(/(^[a-z]\w*)(?:<MOD>|<PAR>|[<>=])+(?=\.)/.source),lookbehind:!0,inside:i},tag:/^[a-z]\w*/,punctuation:/\.$/}},list:{pattern:a(/^[*#]+<MOD>*\s+\S.*/.source,"m"),inside:{modifier:{pattern:a(/(^[*#]+)<MOD>+/.source),lookbehind:!0,inside:i},punctuation:/^[*#]+/}},table:{pattern:a(/^(?:(?:<MOD>|<PAR>|[<>=^~])+\.\s*)?(?:\|(?:(?:<MOD>|<PAR>|[<>=^~_]|[\\/]\d+)+\.|(?!(?:<MOD>|<PAR>|[<>=^~_]|[\\/]\d+)+\.))[^|]*)+\|/.source,"m"),inside:{modifier:{pattern:a(/(^|\|(?:\r?\n|\r)?)(?:<MOD>|<PAR>|[<>=^~_]|[\\/]\d+)+(?=\.)/.source),lookbehind:!0,inside:i},punctuation:/\||^\./}},inline:{pattern:a(/(^|[^a-zA-Z\d])(\*\*|__|\?\?|[*_%@+\-^~])<MOD>*.+?\2(?![a-zA-Z\d])/.source),lookbehind:!0,inside:{bold:{pattern:a(/(^(\*\*?)<MOD>*).+?(?=\2)/.source),lookbehind:!0},italic:{pattern:a(/(^(__?)<MOD>*).+?(?=\2)/.source),lookbehind:!0},cite:{pattern:a(/(^\?\?<MOD>*).+?(?=\?\?)/.source),lookbehind:!0,alias:"string"},code:{pattern:a(/(^@<MOD>*).+?(?=@)/.source),lookbehind:!0,alias:"keyword"},inserted:{pattern:a(/(^\+<MOD>*).+?(?=\+)/.source),lookbehind:!0},deleted:{pattern:a(/(^-<MOD>*).+?(?=-)/.source),lookbehind:!0},span:{pattern:a(/(^%<MOD>*).+?(?=%)/.source),lookbehind:!0},modifier:{pattern:a(/(^\*\*|__|\?\?|[*_%@+\-^~])<MOD>+/.source),lookbehind:!0,inside:i},punctuation:/[*_%?@+\-^~]+/}},"link-ref":{pattern:/^\[[^\]]+\]\S+$/m,inside:{string:{pattern:/(^\[)[^\]]+(?=\])/,lookbehind:!0},url:{pattern:/(^\])\S+$/,lookbehind:!0},punctuation:/[\[\]]/}},link:{pattern:a(/"<MOD>*[^"]+":.+?(?=[^\w/]?(?:\s|$))/.source),inside:{text:{pattern:a(/(^"<MOD>*)[^"]+(?=")/.source),lookbehind:!0},modifier:{pattern:a(/(^")<MOD>+/.source),lookbehind:!0,inside:i},url:{pattern:/(:).+/,lookbehind:!0},punctuation:/[":]/}},image:{pattern:a(/!(?:<MOD>|<PAR>|[<>=])*(?![<>=])[^!\s()]+(?:\([^)]+\))?!(?::.+?(?=[^\w/]?(?:\s|$)))?/.source),inside:{source:{pattern:a(/(^!(?:<MOD>|<PAR>|[<>=])*)(?![<>=])[^!\s()]+(?:\([^)]+\))?(?=!)/.source),lookbehind:!0,alias:"url"},modifier:{pattern:a(/(^!)(?:<MOD>|<PAR>|[<>=])+/.source),lookbehind:!0,inside:i},url:{pattern:/(:).+/,lookbehind:!0},punctuation:/[!:]/}},footnote:{pattern:/\b\[\d+\]/,alias:"comment",inside:{punctuation:/\[|\]/}},acronym:{pattern:/\b[A-Z\d]+\([^)]+\)/,inside:{comment:{pattern:/(\()[^()]+(?=\))/,lookbehind:!0},punctuation:/[()]/}},mark:{pattern:/\b\((?:C|R|TM)\)/,alias:"comment",inside:{punctuation:/[()]/}}}}}),l=o.phrase.inside,u={inline:l.inline,link:l.link,image:l.image,footnote:l.footnote,acronym:l.acronym,mark:l.mark};o.tag.pattern=/<\/?(?!\d)[a-z0-9]+(?:\s+[^\s>\/=]+(?:=(?:("|')(?:\\[\s\S]|(?!\1)[^\\])*\1|[^\s'">=]+))?)*\s*\/?>/i;var d=l.inline.inside;d.bold.inside=u,d.italic.inside=u,d.inserted.inside=u,d.deleted.inside=u,d.span.inside=u;var h=l.table.inside;h.inline=u.inline,h.link=u.link,h.image=u.image,h.footnote=u.footnote,h.acronym=u.acronym,h.mark=u.mark})(e)}sk.displayName="haml";sk.aliases=[];function sk(e){e.register(Tu),(function(t){t.languages.haml={"multiline-comment":{pattern:/((?:^|\r?\n|\r)([\t ]*))(?:\/|-#).*(?:(?:\r?\n|\r)\2[\t ].+)*/,lookbehind:!0,alias:"comment"},"multiline-code":[{pattern:/((?:^|\r?\n|\r)([\t ]*)(?:[~-]|[&!]?=)).*,[\t ]*(?:(?:\r?\n|\r)\2[\t ].*,[\t ]*)*(?:(?:\r?\n|\r)\2[\t ].+)/,lookbehind:!0,inside:t.languages.ruby},{pattern:/((?:^|\r?\n|\r)([\t ]*)(?:[~-]|[&!]?=)).*\|[\t ]*(?:(?:\r?\n|\r)\2[\t ].*\|[\t ]*)*/,lookbehind:!0,inside:t.languages.ruby}],filter:{pattern:/((?:^|\r?\n|\r)([\t ]*)):[\w-]+(?:(?:\r?\n|\r)(?:\2[\t ].+|\s*?(?=\r?\n|\r)))+/,lookbehind:!0,inside:{"filter-name":{pattern:/^:[\w-]+/,alias:"symbol"}}},markup:{pattern:/((?:^|\r?\n|\r)[\t ]*)<.+/,lookbehind:!0,inside:t.languages.markup},doctype:{pattern:/((?:^|\r?\n|\r)[\t ]*)!!!(?: .+)?/,lookbehind:!0},tag:{pattern:/((?:^|\r?\n|\r)[\t ]*)[%.#][\w\-#.]*[\w\-](?:\([^)]+\)|\{(?:\{[^}]+\}|[^{}])+\}|\[[^\]]+\])*[\/<>]*/,lookbehind:!0,inside:{attributes:[{pattern:/(^|[^#])\{(?:\{[^}]+\}|[^{}])+\}/,lookbehind:!0,inside:t.languages.ruby},{pattern:/\([^)]+\)/,inside:{"attr-value":{pattern:/(=\s*)(?:"(?:\\.|[^\\"\r\n])*"|[^)\s]+)/,lookbehind:!0},"attr-name":/[\w:-]+(?=\s*!?=|\s*[,)])/,punctuation:/[=(),]/}},{pattern:/\[[^\]]+\]/,inside:t.languages.ruby}],punctuation:/[<>]/}},code:{pattern:/((?:^|\r?\n|\r)[\t ]*(?:[~-]|[&!]?=)).+/,lookbehind:!0,inside:t.languages.ruby},interpolation:{pattern:/#\{[^}]+\}/,inside:{delimiter:{pattern:/^#\{|\}$/,alias:"punctuation"},ruby:{pattern:/[\s\S]+/,inside:t.languages.ruby}}},punctuation:{pattern:/((?:^|\r?\n|\r)[\t ]*)[~=\-&!]+/,lookbehind:!0}};for(var n="((?:^|\\r?\\n|\\r)([\\t ]*)):{{filter_name}}(?:(?:\\r?\\n|\\r)(?:\\2[\\t ].+|\\s*?(?=\\r?\\n|\\r)))+",r=["css",{filter:"coffee",language:"coffeescript"},"erb","javascript","less","markdown","ruby","scss","textile"],a={},i=0,o=r.length;i<o;i++){var l=r[i];l=typeof l=="string"?{filter:l,language:l}:l,t.languages[l.language]&&(a["filter-"+l.filter]={pattern:RegExp(n.replace("{{filter_name}}",function(){return l.filter})),lookbehind:!0,inside:{"filter-name":{pattern:/^:[\w-]+/,alias:"symbol"},text:{pattern:/[\s\S]+/,alias:[l.language,"language-"+l.language],inside:t.languages[l.language]}}})}t.languages.insertBefore("haml","filter",a)})(e)}lk.displayName="handlebars";lk.aliases=["hbs","mustache"];function lk(e){e.register(Er),(function(t){t.languages.handlebars={comment:/\{\{![\s\S]*?\}\}/,delimiter:{pattern:/^\{\{\{?|\}\}\}?$/,alias:"punctuation"},string:/(["'])(?:\\.|(?!\1)[^\\\r\n])*\1/,number:/\b0x[\dA-Fa-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee][+-]?\d+)?/,boolean:/\b(?:false|true)\b/,block:{pattern:/^(\s*(?:~\s*)?)[#\/]\S+?(?=\s*(?:~\s*)?$|\s)/,lookbehind:!0,alias:"keyword"},brackets:{pattern:/\[[^\]]+\]/,inside:{punctuation:/\[|\]/,variable:/[\s\S]+/}},punctuation:/[!"#%&':()*+,.\/;<=>@\[\\\]^`{|}~]/,variable:/[^!"#%&'()*+,\/;<=>@\[\\\]^`{|}~\s]+/},t.hooks.add("before-tokenize",function(n){var r=/\{\{\{[\s\S]+?\}\}\}|\{\{[\s\S]+?\}\}/g;t.languages["markup-templating"].buildPlaceholders(n,"handlebars",r)}),t.hooks.add("after-tokenize",function(n){t.languages["markup-templating"].tokenizePlaceholders(n,"handlebars")}),t.languages.hbs=t.languages.handlebars,t.languages.mustache=t.languages.handlebars})(e)}op.displayName="haskell";op.aliases=["hs"];function op(e){e.languages.haskell={comment:{pattern:/(^|[^-!#$%*+=?&@|~.:<>^\\\/])(?:--(?:(?=.)[^-!#$%*+=?&@|~.:<>^\\\/].*|$)|\{-[\s\S]*?-\})/m,lookbehind:!0},char:{pattern:/'(?:[^\\']|\\(?:[abfnrtv\\"'&]|\^[A-Z@[\]^_]|ACK|BEL|BS|CAN|CR|DC1|DC2|DC3|DC4|DEL|DLE|EM|ENQ|EOT|ESC|ETB|ETX|FF|FS|GS|HT|LF|NAK|NUL|RS|SI|SO|SOH|SP|STX|SUB|SYN|US|VT|\d+|o[0-7]+|x[0-9a-fA-F]+))'/,alias:"string"},string:{pattern:/"(?:[^\\"]|\\(?:\S|\s+\\))*"/,greedy:!0},keyword:/\b(?:case|class|data|deriving|do|else|if|in|infixl|infixr|instance|let|module|newtype|of|primitive|then|type|where)\b/,"import-statement":{pattern:/(^[\t ]*)import\s+(?:qualified\s+)?(?:[A-Z][\w']*)(?:\.[A-Z][\w']*)*(?:\s+as\s+(?:[A-Z][\w']*)(?:\.[A-Z][\w']*)*)?(?:\s+hiding\b)?/m,lookbehind:!0,inside:{keyword:/\b(?:as|hiding|import|qualified)\b/,punctuation:/\./}},builtin:/\b(?:abs|acos|acosh|all|and|any|appendFile|approxRational|asTypeOf|asin|asinh|atan|atan2|atanh|basicIORun|break|catch|ceiling|chr|compare|concat|concatMap|const|cos|cosh|curry|cycle|decodeFloat|denominator|digitToInt|div|divMod|drop|dropWhile|either|elem|encodeFloat|enumFrom|enumFromThen|enumFromThenTo|enumFromTo|error|even|exp|exponent|fail|filter|flip|floatDigits|floatRadix|floatRange|floor|fmap|foldl|foldl1|foldr|foldr1|fromDouble|fromEnum|fromInt|fromInteger|fromIntegral|fromRational|fst|gcd|getChar|getContents|getLine|group|head|id|inRange|index|init|intToDigit|interact|ioError|isAlpha|isAlphaNum|isAscii|isControl|isDenormalized|isDigit|isHexDigit|isIEEE|isInfinite|isLower|isNaN|isNegativeZero|isOctDigit|isPrint|isSpace|isUpper|iterate|last|lcm|length|lex|lexDigits|lexLitChar|lines|log|logBase|lookup|map|mapM|mapM_|max|maxBound|maximum|maybe|min|minBound|minimum|mod|negate|not|notElem|null|numerator|odd|or|ord|otherwise|pack|pi|pred|primExitWith|print|product|properFraction|putChar|putStr|putStrLn|quot|quotRem|range|rangeSize|read|readDec|readFile|readFloat|readHex|readIO|readInt|readList|readLitChar|readLn|readOct|readParen|readSigned|reads|readsPrec|realToFrac|recip|rem|repeat|replicate|return|reverse|round|scaleFloat|scanl|scanl1|scanr|scanr1|seq|sequence|sequence_|show|showChar|showInt|showList|showLitChar|showParen|showSigned|showString|shows|showsPrec|significand|signum|sin|sinh|snd|sort|span|splitAt|sqrt|subtract|succ|sum|tail|take|takeWhile|tan|tanh|threadToIOResult|toEnum|toInt|toInteger|toLower|toRational|toUpper|truncate|uncurry|undefined|unlines|until|unwords|unzip|unzip3|userError|words|writeFile|zip|zip3|zipWith|zipWith3)\b/,number:/\b(?:\d+(?:\.\d+)?(?:e[+-]?\d+)?|0o[0-7]+|0x[0-9a-f]+)\b/i,operator:[{pattern:/`(?:[A-Z][\w']*\.)*[_a-z][\w']*`/,greedy:!0},{pattern:/(\s)\.(?=\s)/,lookbehind:!0},/[-!#$%*+=?&@|~:<>^\\\/][-!#$%*+=?&@|~.:<>^\\\/]*|\.[-!#$%*+=?&@|~.:<>^\\\/]+/],hvariable:{pattern:/\b(?:[A-Z][\w']*\.)*[_a-z][\w']*/,inside:{punctuation:/\./}},constant:{pattern:/\b(?:[A-Z][\w']*\.)*[A-Z][\w']*/,inside:{punctuation:/\./}},punctuation:/[{}[\];(),.:]/},e.languages.hs=e.languages.haskell}ck.displayName="haxe";ck.aliases=[];function ck(e){e.register(Mt),e.languages.haxe=e.languages.extend("clike",{string:{pattern:/"(?:[^"\\]|\\[\s\S])*"/,greedy:!0},"class-name":[{pattern:/(\b(?:abstract|class|enum|extends|implements|interface|new|typedef)\s+)[A-Z_]\w*/,lookbehind:!0},/\b[A-Z]\w*/],keyword:/\bthis\b|\b(?:abstract|as|break|case|cast|catch|class|continue|default|do|dynamic|else|enum|extends|extern|final|for|from|function|if|implements|import|in|inline|interface|macro|new|null|operator|overload|override|package|private|public|return|static|super|switch|throw|to|try|typedef|untyped|using|var|while)(?!\.)\b/,function:{pattern:/\b[a-z_]\w*(?=\s*(?:<[^<>]*>\s*)?\()/i,greedy:!0},operator:/\.{3}|\+\+|--|&&|\|\||->|=>|(?:<<?|>{1,3}|[-+*/%!=&|^])=?|[?:~]/}),e.languages.insertBefore("haxe","string",{"string-interpolation":{pattern:/'(?:[^'\\]|\\[\s\S])*'/,greedy:!0,inside:{interpolation:{pattern:/(^|[^\\])\$(?:\w+|\{[^{}]+\})/,lookbehind:!0,inside:{"interpolation-punctuation":{pattern:/^\$\{?|\}$/,alias:"punctuation"},expression:{pattern:/[\s\S]+/,inside:e.languages.haxe}}},string:/[\s\S]+/}}}),e.languages.insertBefore("haxe","class-name",{regex:{pattern:/~\/(?:[^\/\\\r\n]|\\.)+\/[a-z]*/,greedy:!0,inside:{"regex-flags":/\b[a-z]+$/,"regex-source":{pattern:/^(~\/)[\s\S]+(?=\/$)/,lookbehind:!0,alias:"language-regex",inside:e.languages.regex},"regex-delimiter":/^~\/|\/$/}}}),e.languages.insertBefore("haxe","keyword",{preprocessor:{pattern:/#(?:else|elseif|end|if)\b.*/,alias:"property"},metadata:{pattern:/@:?[\w.]+/,alias:"symbol"},reification:{pattern:/\$(?:\w+|(?=\{))/,alias:"important"}})}uk.displayName="hcl";uk.aliases=[];function uk(e){e.languages.hcl={comment:/(?:\/\/|#).*|\/\*[\s\S]*?(?:\*\/|$)/,heredoc:{pattern:/<<-?(\w+\b)[\s\S]*?^[ \t]*\1/m,greedy:!0,alias:"string"},keyword:[{pattern:/(?:data|resource)\s+(?:"(?:\\[\s\S]|[^\\"])*")(?=\s+"[\w-]+"\s+\{)/i,inside:{type:{pattern:/(resource|data|\s+)(?:"(?:\\[\s\S]|[^\\"])*")/i,lookbehind:!0,alias:"variable"}}},{pattern:/(?:backend|module|output|provider|provisioner|variable)\s+(?:[\w-]+|"(?:\\[\s\S]|[^\\"])*")\s+(?=\{)/i,inside:{type:{pattern:/(backend|module|output|provider|provisioner|variable)\s+(?:[\w-]+|"(?:\\[\s\S]|[^\\"])*")\s+/i,lookbehind:!0,alias:"variable"}}},/[\w-]+(?=\s+\{)/],property:[/[-\w\.]+(?=\s*=(?!=))/,/"(?:\\[\s\S]|[^\\"])+"(?=\s*[:=])/],string:{pattern:/"(?:[^\\$"]|\\[\s\S]|\$(?:(?=")|\$+(?!\$)|[^"${])|\$\{(?:[^{}"]|"(?:[^\\"]|\\[\s\S])*")*\})*"/,greedy:!0,inside:{interpolation:{pattern:/(^|[^$])\$\{(?:[^{}"]|"(?:[^\\"]|\\[\s\S])*")*\}/,lookbehind:!0,inside:{type:{pattern:/(\b(?:count|data|local|module|path|self|terraform|var)\b\.)[\w\*]+/i,lookbehind:!0,alias:"variable"},keyword:/\b(?:count|data|local|module|path|self|terraform|var)\b/i,function:/\w+(?=\()/,string:{pattern:/"(?:\\[\s\S]|[^\\"])*"/,greedy:!0},number:/\b0x[\da-f]+\b|\b\d+(?:\.\d*)?(?:e[+-]?\d+)?/i,punctuation:/[!\$#%&'()*+,.\/;<=>@\[\\\]^`{|}~?:]/}}}},number:/\b0x[\da-f]+\b|\b\d+(?:\.\d*)?(?:e[+-]?\d+)?/i,boolean:/\b(?:false|true)\b/i,punctuation:/[=\[\]{}]/}}dk.displayName="hlsl";dk.aliases=[];function dk(e){e.register($i),e.languages.hlsl=e.languages.extend("c",{"class-name":[e.languages.c["class-name"],/\b(?:AppendStructuredBuffer|BlendState|Buffer|ByteAddressBuffer|CompileShader|ComputeShader|ConsumeStructuredBuffer|DepthStencilState|DepthStencilView|DomainShader|GeometryShader|Hullshader|InputPatch|LineStream|OutputPatch|PixelShader|PointStream|RWBuffer|RWByteAddressBuffer|RWStructuredBuffer|RWTexture(?:1D|1DArray|2D|2DArray|3D)|RasterizerState|RenderTargetView|SamplerComparisonState|SamplerState|StructuredBuffer|Texture(?:1D|1DArray|2D|2DArray|2DMS|2DMSArray|3D|Cube|CubeArray)|TriangleStream|VertexShader)\b/],keyword:[/\b(?:asm|asm_fragment|auto|break|case|catch|cbuffer|centroid|char|class|column_major|compile|compile_fragment|const|const_cast|continue|default|delete|discard|do|dynamic_cast|else|enum|explicit|export|extern|for|friend|fxgroup|goto|groupshared|if|in|inline|inout|interface|line|lineadj|linear|long|matrix|mutable|namespace|new|nointerpolation|noperspective|operator|out|packoffset|pass|pixelfragment|point|precise|private|protected|public|register|reinterpret_cast|return|row_major|sample|sampler|shared|short|signed|sizeof|snorm|stateblock|stateblock_state|static|static_cast|string|struct|switch|tbuffer|technique|technique10|technique11|template|texture|this|throw|triangle|triangleadj|try|typedef|typename|uniform|union|unorm|unsigned|using|vector|vertexfragment|virtual|void|volatile|while)\b/,/\b(?:bool|double|dword|float|half|int|min(?:10float|12int|16(?:float|int|uint))|uint)(?:[1-4](?:x[1-4])?)?\b/],number:/(?:(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[eE][+-]?\d+)?|\b0x[\da-fA-F]+)[fFhHlLuU]?\b/,boolean:/\b(?:false|true)\b/})}hk.displayName="hoon";hk.aliases=[];function hk(e){e.languages.hoon={comment:{pattern:/::.*/,greedy:!0},string:{pattern:/"(?:[^"\\]|\\.)*"|'(?:[^'\\]|\\.)*'/,greedy:!0},constant:/%(?:\.[ny]|[\w-]+)/,"class-name":/@(?:[a-z0-9-]*[a-z0-9])?|\*/i,function:/(?:\+[-+] {2})?(?:[a-z](?:[a-z0-9-]*[a-z0-9])?)/,keyword:/\.[\^\+\*=\?]|![><:\.=\?!]|=[>|:,\.\-\^<+;/~\*\?]|\?[>|:\.\-\^<\+&~=@!]|\|[\$_%:\.\-\^~\*=@\?]|\+[|\$\+\*]|:[_\-\^\+~\*]|%[_:\.\-\^\+~\*=]|\^[|:\.\-\+&~\*=\?]|\$[|_%:<>\-\^&~@=\?]|;[:<\+;\/~\*=]|~[>|\$_%<\+\/&=\?!]|--|==/}}pk.displayName="hpkp";pk.aliases=[];function pk(e){e.languages.hpkp={directive:{pattern:/\b(?:includeSubDomains|max-age|pin-sha256|preload|report-to|report-uri|strict)(?=[\s;=]|$)/i,alias:"property"},operator:/=/,punctuation:/;/}}fk.displayName="hsts";fk.aliases=[];function fk(e){e.languages.hsts={directive:{pattern:/\b(?:includeSubDomains|max-age|preload)(?=[\s;=]|$)/i,alias:"property"},operator:/=/,punctuation:/;/}}sp.displayName="json";sp.aliases=["webmanifest"];function sp(e){e.languages.json={property:{pattern:/(^|[^\\])"(?:\\.|[^\\"\r\n])*"(?=\s*:)/,lookbehind:!0,greedy:!0},string:{pattern:/(^|[^\\])"(?:\\.|[^\\"\r\n])*"(?!\s*:)/,lookbehind:!0,greedy:!0},comment:{pattern:/\/\/.*|\/\*[\s\S]*?(?:\*\/|$)/,greedy:!0},number:/-?\b\d+(?:\.\d+)?(?:e[+-]?\d+)?\b/i,punctuation:/[{}[\],]/,operator:/:/,boolean:/\b(?:false|true)\b/,null:{pattern:/\bnull\b/,alias:"keyword"}},e.languages.webmanifest=e.languages.json}mk.displayName="uri";mk.aliases=["url"];function mk(e){e.languages.uri={scheme:{pattern:/^[a-z][a-z0-9+.-]*:/im,greedy:!0,inside:{"scheme-delimiter":/:$/}},fragment:{pattern:/#[\w\-.~!$&'()*+,;=%:@/?]*/,inside:{"fragment-delimiter":/^#/}},query:{pattern:/\?[\w\-.~!$&'()*+,;=%:@/?]*/,inside:{"query-delimiter":{pattern:/^\?/,greedy:!0},"pair-delimiter":/[&;]/,pair:{pattern:/^[^=][\s\S]*/,inside:{key:/^[^=]+/,value:{pattern:/(^=)[\s\S]+/,lookbehind:!0}}}}},authority:{pattern:RegExp(/^\/\//.source+/(?:[\w\-.~!$&'()*+,;=%:]*@)?/.source+("(?:"+/\[(?:[0-9a-fA-F:.]{2,48}|v[0-9a-fA-F]+\.[\w\-.~!$&'()*+,;=]+)\]/.source+"|"+/[\w\-.~!$&'()*+,;=%]*/.source+")")+/(?::\d*)?/.source,"m"),inside:{"authority-delimiter":/^\/\//,"user-info-segment":{pattern:/^[\w\-.~!$&'()*+,;=%:]*@/,inside:{"user-info-delimiter":/@$/,"user-info":/^[\w\-.~!$&'()*+,;=%:]+/}},"port-segment":{pattern:/:\d*$/,inside:{"port-delimiter":/^:/,port:/^\d+/}},host:{pattern:/[\s\S]+/,inside:{"ip-literal":{pattern:/^\[[\s\S]+\]$/,inside:{"ip-literal-delimiter":/^\[|\]$/,"ipv-future":/^v[\s\S]+/,"ipv6-address":/^[\s\S]+/}},"ipv4-address":/^(?:(?:[03-9]\d?|[12]\d{0,2})\.){3}(?:[03-9]\d?|[12]\d{0,2})$/}}}},path:{pattern:/^[\w\-.~!$&'()*+,;=%:@/]+/m,inside:{"path-separator":/\//}}},e.languages.url=e.languages.uri}gk.displayName="http";gk.aliases=[];function gk(e){(function(t){function n(h){return RegExp("(^(?:"+h+"):[ 	]*(?![ 	]))[^]+","i")}t.languages.http={"request-line":{pattern:/^(?:CONNECT|DELETE|GET|HEAD|OPTIONS|PATCH|POST|PRI|PUT|SEARCH|TRACE)\s(?:https?:\/\/|\/)\S*\sHTTP\/[\d.]+/m,inside:{method:{pattern:/^[A-Z]+\b/,alias:"property"},"request-target":{pattern:/^(\s)(?:https?:\/\/|\/)\S*(?=\s)/,lookbehind:!0,alias:"url",inside:t.languages.uri},"http-version":{pattern:/^(\s)HTTP\/[\d.]+/,lookbehind:!0,alias:"property"}}},"response-status":{pattern:/^HTTP\/[\d.]+ \d+ .+/m,inside:{"http-version":{pattern:/^HTTP\/[\d.]+/,alias:"property"},"status-code":{pattern:/^(\s)\d+(?=\s)/,lookbehind:!0,alias:"number"},"reason-phrase":{pattern:/^(\s).+/,lookbehind:!0,alias:"string"}}},header:{pattern:/^[\w-]+:.+(?:(?:\r\n?|\n)[ \t].+)*/m,inside:{"header-value":[{pattern:n(/Content-Security-Policy/.source),lookbehind:!0,alias:["csp","languages-csp"],inside:t.languages.csp},{pattern:n(/Public-Key-Pins(?:-Report-Only)?/.source),lookbehind:!0,alias:["hpkp","languages-hpkp"],inside:t.languages.hpkp},{pattern:n(/Strict-Transport-Security/.source),lookbehind:!0,alias:["hsts","languages-hsts"],inside:t.languages.hsts},{pattern:n(/[^:]+/.source),lookbehind:!0}],"header-name":{pattern:/^[^:]+/,alias:"keyword"},punctuation:/^:/}}};var r=t.languages,a={"application/javascript":r.javascript,"application/json":r.json||r.javascript,"application/xml":r.xml,"text/xml":r.xml,"text/html":r.html,"text/css":r.css,"text/plain":r.plain},i={"application/json":!0,"application/xml":!0};function o(h){var f=h.replace(/^[a-z]+\//,""),m="\\w+/(?:[\\w.-]+\\+)+"+f+"(?![+\\w.-])";return"(?:"+h+"|"+m+")"}var l;for(var u in a)if(a[u]){l=l||{};var d=i[u]?o(u):u;l[u.replace(/\//g,"-")]={pattern:RegExp("("+/content-type:\s*/.source+d+/(?:(?:\r\n?|\n)[\w-].*)*(?:\r(?:\n|(?!\n))|\n)/.source+")"+/[^ \t\w-][\s\S]*/.source,"i"),lookbehind:!0,inside:a[u]}}l&&t.languages.insertBefore("http","header",l)})(e)}bk.displayName="ichigojam";bk.aliases=[];function bk(e){e.languages.ichigojam={comment:/(?:\B'|REM)(?:[^\n\r]*)/i,string:{pattern:/"(?:""|[!#$%&'()*,\/:;<=>?^\w +\-.])*"/,greedy:!0},number:/\B#[0-9A-F]+|\B`[01]+|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:E[+-]?\d+)?/i,keyword:/\b(?:BEEP|BPS|CASE|CLEAR|CLK|CLO|CLP|CLS|CLT|CLV|CONT|COPY|ELSE|END|FILE|FILES|FOR|GOSUB|GOTO|GSB|IF|INPUT|KBD|LED|LET|LIST|LOAD|LOCATE|LRUN|NEW|NEXT|OUT|PLAY|POKE|PRINT|PWM|REM|RENUM|RESET|RETURN|RIGHT|RTN|RUN|SAVE|SCROLL|SLEEP|SRND|STEP|STOP|SUB|TEMPO|THEN|TO|UART|VIDEO|WAIT)(?:\$|\b)/i,function:/\b(?:ABS|ANA|ASC|BIN|BTN|DEC|END|FREE|HELP|HEX|I2CR|I2CW|IN|INKEY|LEN|LINE|PEEK|RND|SCR|SOUND|STR|TICK|USR|VER|VPEEK|ZER)(?:\$|\b)/i,label:/(?:\B@\S+)/,operator:/<[=>]?|>=?|\|\||&&|[+\-*\/=|&^~!]|\b(?:AND|NOT|OR)\b/i,punctuation:/[\[,;:()\]]/}}yk.displayName="icon";yk.aliases=[];function yk(e){e.languages.icon={comment:/#.*/,string:{pattern:/(["'])(?:(?!\1)[^\\\r\n_]|\\.|_(?!\1)(?:\r\n|[\s\S]))*\1/,greedy:!0},number:/\b(?:\d+r[a-z\d]+|\d+(?:\.\d+)?(?:e[+-]?\d+)?)\b|\.\d+\b/i,"builtin-keyword":{pattern:/&(?:allocated|ascii|clock|collections|cset|current|date|dateline|digits|dump|e|error(?:number|text|value)?|errout|fail|features|file|host|input|lcase|letters|level|line|main|null|output|phi|pi|pos|progname|random|regions|source|storage|subject|time|trace|ucase|version)\b/,alias:"variable"},directive:{pattern:/\$\w+/,alias:"builtin"},keyword:/\b(?:break|by|case|create|default|do|else|end|every|fail|global|if|initial|invocable|link|local|next|not|of|procedure|record|repeat|return|static|suspend|then|to|until|while)\b/,function:/\b(?!\d)\w+(?=\s*[({]|\s*!\s*\[)/,operator:/[+-]:(?!=)|(?:[\/?@^%&]|\+\+?|--?|==?=?|~==?=?|\*\*?|\|\|\|?|<(?:->?|<?=?)|>>?=?)(?::=)?|:(?:=:?)?|[!.\\|~]/,punctuation:/[\[\](){},;]/}}vk.displayName="icu-message-format";vk.aliases=[];function vk(e){(function(t){function n(u,d){return d<=0?/[]/.source:u.replace(/<SELF>/g,function(){return n(u,d-1)})}var r=/'[{}:=,](?:[^']|'')*'(?!')/,a={pattern:/''/,greedy:!0,alias:"operator"},i={pattern:r,greedy:!0,inside:{escape:a}},o=n(/\{(?:[^{}']|'(?![{},'])|''|<STR>|<SELF>)*\}/.source.replace(/<STR>/g,function(){return r.source}),8),l={pattern:RegExp(o),inside:{message:{pattern:/^(\{)[\s\S]+(?=\}$)/,lookbehind:!0,inside:null},"message-delimiter":{pattern:/./,alias:"punctuation"}}};t.languages["icu-message-format"]={argument:{pattern:RegExp(o),greedy:!0,inside:{content:{pattern:/^(\{)[\s\S]+(?=\}$)/,lookbehind:!0,inside:{"argument-name":{pattern:/^(\s*)[^{}:=,\s]+/,lookbehind:!0},"choice-style":{pattern:/^(\s*,\s*choice\s*,\s*)\S(?:[\s\S]*\S)?/,lookbehind:!0,inside:{punctuation:/\|/,range:{pattern:/^(\s*)[+-]?(?:\d+(?:\.\d*)?|\u221e)\s*[<#\u2264]/,lookbehind:!0,inside:{operator:/[<#\u2264]/,number:/\S+/}},rest:null}},"plural-style":{pattern:/^(\s*,\s*(?:plural|selectordinal)\s*,\s*)\S(?:[\s\S]*\S)?/,lookbehind:!0,inside:{offset:/^offset:\s*\d+/,"nested-message":l,selector:{pattern:/=\d+|[^{}:=,\s]+/,inside:{keyword:/^(?:few|many|one|other|two|zero)$/}}}},"select-style":{pattern:/^(\s*,\s*select\s*,\s*)\S(?:[\s\S]*\S)?/,lookbehind:!0,inside:{"nested-message":l,selector:{pattern:/[^{}:=,\s]+/,inside:{keyword:/^other$/}}}},keyword:/\b(?:choice|plural|select|selectordinal)\b/,"arg-type":{pattern:/\b(?:date|duration|number|ordinal|spellout|time)\b/,alias:"keyword"},"arg-skeleton":{pattern:/(,\s*)::[^{}:=,\s]+/,lookbehind:!0},"arg-style":{pattern:/(,\s*)(?:currency|full|integer|long|medium|percent|short)(?=\s*$)/,lookbehind:!0},"arg-style-text":{pattern:RegExp(/(^\s*,\s*(?=\S))/.source+n(/(?:[^{}']|'[^']*'|\{(?:<SELF>)?\})+/.source,8)+"$"),lookbehind:!0,alias:"string"},punctuation:/,/}},"argument-delimiter":{pattern:/./,alias:"operator"}}},escape:a,string:i},l.inside.message.inside=t.languages["icu-message-format"],t.languages["icu-message-format"].argument.inside.content.inside["choice-style"].inside.rest=t.languages["icu-message-format"]})(e)}xk.displayName="idris";xk.aliases=["idr"];function xk(e){e.register(op),e.languages.idris=e.languages.extend("haskell",{comment:{pattern:/(?:(?:--|\|\|\|).*$|\{-[\s\S]*?-\})/m},keyword:/\b(?:Type|case|class|codata|constructor|corecord|data|do|dsl|else|export|if|implementation|implicit|import|impossible|in|infix|infixl|infixr|instance|interface|let|module|mutual|namespace|of|parameters|partial|postulate|private|proof|public|quoteGoal|record|rewrite|syntax|then|total|using|where|with)\b/,builtin:void 0}),e.languages.insertBefore("idris","keyword",{"import-statement":{pattern:/(^\s*import\s+)(?:[A-Z][\w']*)(?:\.[A-Z][\w']*)*/m,lookbehind:!0,inside:{punctuation:/\./}}}),e.languages.idr=e.languages.idris}Sk.displayName="ignore";Sk.aliases=["gitignore","hgignore","npmignore"];function Sk(e){(function(t){t.languages.ignore={comment:/^#.*/m,entry:{pattern:/\S(?:.*(?:(?:\\ )|\S))?/,alias:"string",inside:{operator:/^!|\*\*?|\?/,regex:{pattern:/(^|[^\\])\[[^\[\]]*\]/,lookbehind:!0},punctuation:/\//}}},t.languages.gitignore=t.languages.ignore,t.languages.hgignore=t.languages.ignore,t.languages.npmignore=t.languages.ignore})(e)}wk.displayName="inform7";wk.aliases=[];function wk(e){e.languages.inform7={string:{pattern:/"[^"]*"/,inside:{substitution:{pattern:/\[[^\[\]]+\]/,inside:{delimiter:{pattern:/\[|\]/,alias:"punctuation"}}}}},comment:{pattern:/\[[^\[\]]+\]/,greedy:!0},title:{pattern:/^[ \t]*(?:book|chapter|part(?! of)|section|table|volume)\b.+/im,alias:"important"},number:{pattern:/(^|[^-])(?:\b\d+(?:\.\d+)?(?:\^\d+)?(?:(?!\d)\w+)?|\b(?:eight|eleven|five|four|nine|one|seven|six|ten|three|twelve|two))\b(?!-)/i,lookbehind:!0},verb:{pattern:/(^|[^-])\b(?:answering|applying to|are|asking|attacking|be(?:ing)?|burning|buying|called|carries|carry(?! out)|carrying|climbing|closing|conceal(?:ing|s)?|consulting|contain(?:ing|s)?|cutting|drinking|dropping|eating|enclos(?:es?|ing)|entering|examining|exiting|getting|giving|going|ha(?:s|ve|ving)|hold(?:ing|s)?|impl(?:ies|y)|incorporat(?:es?|ing)|inserting|is|jumping|kissing|listening|locking|looking|mean(?:ing|s)?|opening|provid(?:es?|ing)|pulling|pushing|putting|relat(?:es?|ing)|removing|searching|see(?:ing|s)?|setting|showing|singing|sleeping|smelling|squeezing|support(?:ing|s)?|swearing|switching|taking|tasting|telling|thinking|throwing|touching|turning|tying|unlock(?:ing|s)?|var(?:ies|y|ying)|waiting|waking|waving|wear(?:ing|s)?)\b(?!-)/i,lookbehind:!0,alias:"operator"},keyword:{pattern:/(^|[^-])\b(?:after|before|carry out|check|continue the action|definition(?= *:)|do nothing|else|end (?:if|the story|unless)|every turn|if|include|instead(?: of)?|let|move|no|now|otherwise|repeat|report|resume the story|rule for|running through|say(?:ing)?|stop the action|test|try(?:ing)?|understand|unless|use|when|while|yes)\b(?!-)/i,lookbehind:!0},property:{pattern:/(^|[^-])\b(?:adjacent(?! to)|carried|closed|concealed|contained|dark|described|edible|empty|enclosed|enterable|even|female|fixed in place|full|handled|held|improper-named|incorporated|inedible|invisible|lighted|lit|lock(?:able|ed)|male|marked for listing|mentioned|negative|neuter|non-(?:empty|full|recurring)|odd|opaque|open(?:able)?|plural-named|portable|positive|privately-named|proper-named|provided|publically-named|pushable between rooms|recurring|related|rubbing|scenery|seen|singular-named|supported|swinging|switch(?:able|ed(?: off| on)?)|touch(?:able|ed)|transparent|unconcealed|undescribed|unlit|unlocked|unmarked for listing|unmentioned|unopenable|untouchable|unvisited|variable|visible|visited|wearable|worn)\b(?!-)/i,lookbehind:!0,alias:"symbol"},position:{pattern:/(^|[^-])\b(?:above|adjacent to|back side of|below|between|down|east|everywhere|front side|here|in|inside(?: from)?|north(?:east|west)?|nowhere|on(?: top of)?|other side|outside(?: from)?|parts? of|regionally in|south(?:east|west)?|through|up|west|within)\b(?!-)/i,lookbehind:!0,alias:"keyword"},type:{pattern:/(^|[^-])\b(?:actions?|activit(?:ies|y)|actors?|animals?|backdrops?|containers?|devices?|directions?|doors?|holders?|kinds?|lists?|m[ae]n|nobody|nothing|nouns?|numbers?|objects?|people|persons?|player(?:'s holdall)?|regions?|relations?|rooms?|rule(?:book)?s?|scenes?|someone|something|supporters?|tables?|texts?|things?|time|vehicles?|wom[ae]n)\b(?!-)/i,lookbehind:!0,alias:"variable"},punctuation:/[.,:;(){}]/},e.languages.inform7.string.inside.substitution.inside.rest=e.languages.inform7,e.languages.inform7.string.inside.substitution.inside.rest.text={pattern:/\S(?:\s*\S)*/,alias:"comment"}}Ek.displayName="ini";Ek.aliases=[];function Ek(e){e.languages.ini={comment:{pattern:/(^[ \f\t\v]*)[#;][^\n\r]*/m,lookbehind:!0},section:{pattern:/(^[ \f\t\v]*)\[[^\n\r\]]*\]?/m,lookbehind:!0,inside:{"section-name":{pattern:/(^\[[ \f\t\v]*)[^ \f\t\v\]]+(?:[ \f\t\v]+[^ \f\t\v\]]+)*/,lookbehind:!0,alias:"selector"},punctuation:/\[|\]/}},key:{pattern:/(^[ \f\t\v]*)[^ \f\n\r\t\v=]+(?:[ \f\t\v]+[^ \f\n\r\t\v=]+)*(?=[ \f\t\v]*=)/m,lookbehind:!0,alias:"attr-name"},value:{pattern:/(=[ \f\t\v]*)[^ \f\n\r\t\v]+(?:[ \f\t\v]+[^ \f\n\r\t\v]+)*/,lookbehind:!0,alias:"attr-value",inside:{"inner-value":{pattern:/^("|').+(?=\1$)/,lookbehind:!0}}},punctuation:/=/}}kk.displayName="io";kk.aliases=[];function kk(e){e.languages.io={comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?(?:\*\/|$)|\/\/.*|#.*)/,lookbehind:!0,greedy:!0},"triple-quoted-string":{pattern:/"""(?:\\[\s\S]|(?!""")[^\\])*"""/,greedy:!0,alias:"string"},string:{pattern:/"(?:\\.|[^\\\r\n"])*"/,greedy:!0},keyword:/\b(?:activate|activeCoroCount|asString|block|break|call|catch|clone|collectGarbage|compileString|continue|do|doFile|doMessage|doString|else|elseif|exit|for|foreach|forward|getEnvironmentVariable|getSlot|hasSlot|if|ifFalse|ifNil|ifNilEval|ifTrue|isActive|isNil|isResumable|list|message|method|parent|pass|pause|perform|performWithArgList|print|println|proto|raise|raiseResumable|removeSlot|resend|resume|schedulerSleepSeconds|self|sender|setSchedulerSleepSeconds|setSlot|shallowCopy|slotNames|super|system|then|thisBlock|thisContext|try|type|uniqueId|updateSlot|wait|while|write|yield)\b/,builtin:/\b(?:Array|AudioDevice|AudioMixer|BigNum|Block|Box|Buffer|CFunction|CGI|Color|Curses|DBM|DNSResolver|DOConnection|DOProxy|DOServer|Date|Directory|Duration|DynLib|Error|Exception|FFT|File|Fnmatch|Font|Future|GL|GLE|GLScissor|GLU|GLUCylinder|GLUQuadric|GLUSphere|GLUT|Host|Image|Importer|LinkList|List|Lobby|Locals|MD5|MP3Decoder|MP3Encoder|Map|Message|Movie|Notification|Number|Object|OpenGL|Point|Protos|Random|Regex|SGML|SGMLElement|SGMLParser|SQLite|Sequence|Server|ShowMessage|SleepyCat|SleepyCatCursor|Socket|SocketManager|Sound|Soup|Store|String|Tree|UDPSender|UPDReceiver|URL|User|Warning|WeakLink)\b/,boolean:/\b(?:false|nil|true)\b/,number:/\b0x[\da-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e-?\d+)?/i,operator:/[=!*/%+\-^&|]=|>>?=?|<<?=?|:?:?=|\+\+?|--?|\*\*?|\/\/?|%|\|\|?|&&?|\b(?:and|not|or|return)\b|@@?|\?\??|\.\./,punctuation:/[{}[\];(),.:]/}}Tk.displayName="j";Tk.aliases=[];function Tk(e){e.languages.j={comment:{pattern:/\bNB\..*/,greedy:!0},string:{pattern:/'(?:''|[^'\r\n])*'/,greedy:!0},keyword:/\b(?:(?:CR|LF|adverb|conjunction|def|define|dyad|monad|noun|verb)\b|(?:assert|break|case|catch[dt]?|continue|do|else|elseif|end|fcase|for|for_\w+|goto_\w+|if|label_\w+|return|select|throw|try|while|whilst)\.)/,verb:{pattern:/(?!\^:|;\.|[=!][.:])(?:\{(?:\.|::?)?|p(?:\.\.?|:)|[=!\]]|[<>+*\-%$|,#][.:]?|[?^]\.?|[;\[]:?|[~}"i][.:]|[ACeEIjLor]\.|(?:[_\/\\qsux]|_?\d):)/,alias:"keyword"},number:/\b_?(?:(?!\d:)\d+(?:\.\d+)?(?:(?:ad|ar|[ejpx])_?\d+(?:\.\d+)?)*(?:b_?[\da-z]+(?:\.[\da-z]+)?)?|_\b(?!\.))/,adverb:{pattern:/[~}]|[\/\\]\.?|[bfM]\.|t[.:]/,alias:"builtin"},operator:/[=a][.:]|_\./,conjunction:{pattern:/&(?:\.:?|:)?|[.:@][.:]?|[!D][.:]|[;dHT]\.|`:?|[\^LS]:|"/,alias:"variable"},punctuation:/[()]/}}_u.displayName="java";_u.aliases=[];function _u(e){e.register(Mt),(function(t){var n=/\b(?:abstract|assert|boolean|break|byte|case|catch|char|class|const|continue|default|do|double|else|enum|exports|extends|final|finally|float|for|goto|if|implements|import|instanceof|int|interface|long|module|native|new|non-sealed|null|open|opens|package|permits|private|protected|provides|public|record(?!\s*[(){}[\]<>=%~.:,;?+\-*/&|^])|requires|return|sealed|short|static|strictfp|super|switch|synchronized|this|throw|throws|to|transient|transitive|try|uses|var|void|volatile|while|with|yield)\b/,r=/(?:[a-z]\w*\s*\.\s*)*(?:[A-Z]\w*\s*\.\s*)*/.source,a={pattern:RegExp(/(^|[^\w.])/.source+r+/[A-Z](?:[\d_A-Z]*[a-z]\w*)?\b/.source),lookbehind:!0,inside:{namespace:{pattern:/^[a-z]\w*(?:\s*\.\s*[a-z]\w*)*(?:\s*\.)?/,inside:{punctuation:/\./}},punctuation:/\./}};t.languages.java=t.languages.extend("clike",{string:{pattern:/(^|[^\\])"(?:\\.|[^"\\\r\n])*"/,lookbehind:!0,greedy:!0},"class-name":[a,{pattern:RegExp(/(^|[^\w.])/.source+r+/[A-Z]\w*(?=\s+\w+\s*[;,=()]|\s*(?:\[[\s,]*\]\s*)?::\s*new\b)/.source),lookbehind:!0,inside:a.inside},{pattern:RegExp(/(\b(?:class|enum|extends|implements|instanceof|interface|new|record|throws)\s+)/.source+r+/[A-Z]\w*\b/.source),lookbehind:!0,inside:a.inside}],keyword:n,function:[t.languages.clike.function,{pattern:/(::\s*)[a-z_]\w*/,lookbehind:!0}],number:/\b0b[01][01_]*L?\b|\b0x(?:\.[\da-f_p+-]+|[\da-f_]+(?:\.[\da-f_p+-]+)?)\b|(?:\b\d[\d_]*(?:\.[\d_]*)?|\B\.\d[\d_]*)(?:e[+-]?\d[\d_]*)?[dfl]?/i,operator:{pattern:/(^|[^.])(?:<<=?|>>>?=?|->|--|\+\+|&&|\|\||::|[?:~]|[-+*/%&|^!=<>]=?)/m,lookbehind:!0},constant:/\b[A-Z][A-Z_\d]+\b/}),t.languages.insertBefore("java","string",{"triple-quoted-string":{pattern:/"""[ \t]*[\r\n](?:(?:"|"")?(?:\\.|[^"\\]))*"""/,greedy:!0,alias:"string"},char:{pattern:/'(?:\\.|[^'\\\r\n]){1,6}'/,greedy:!0}}),t.languages.insertBefore("java","class-name",{annotation:{pattern:/(^|[^.])@\w+(?:\s*\.\s*\w+)*/,lookbehind:!0,alias:"punctuation"},generics:{pattern:/<(?:[\w\s,.?]|&(?!&)|<(?:[\w\s,.?]|&(?!&)|<(?:[\w\s,.?]|&(?!&)|<(?:[\w\s,.?]|&(?!&))*>)*>)*>)*>/,inside:{"class-name":a,keyword:n,punctuation:/[<>(),.:]/,operator:/[?&|]/}},import:[{pattern:RegExp(/(\bimport\s+)/.source+r+/(?:[A-Z]\w*|\*)(?=\s*;)/.source),lookbehind:!0,inside:{namespace:a.inside.namespace,punctuation:/\./,operator:/\*/,"class-name":/\w+/}},{pattern:RegExp(/(\bimport\s+static\s+)/.source+r+/(?:\w+|\*)(?=\s*;)/.source),lookbehind:!0,alias:"static",inside:{namespace:a.inside.namespace,static:/\b\w+$/,punctuation:/\./,operator:/\*/,"class-name":/\w+/}}],namespace:{pattern:RegExp(/(\b(?:exports|import(?:\s+static)?|module|open|opens|package|provides|requires|to|transitive|uses|with)\s+)(?!<keyword>)[a-z]\w*(?:\.[a-z]\w*)*\.?/.source.replace(/<keyword>/g,function(){return n.source})),lookbehind:!0,inside:{punctuation:/\./}}})})(e)}Cu.displayName="php";Cu.aliases=[];function Cu(e){e.register(Er),(function(t){var n=/\/\*[\s\S]*?\*\/|\/\/.*|#(?!\[).*/,r=[{pattern:/\b(?:false|true)\b/i,alias:"boolean"},{pattern:/(::\s*)\b[a-z_]\w*\b(?!\s*\()/i,greedy:!0,lookbehind:!0},{pattern:/(\b(?:case|const)\s+)\b[a-z_]\w*(?=\s*[;=])/i,greedy:!0,lookbehind:!0},/\b(?:null)\b/i,/\b[A-Z_][A-Z0-9_]*\b(?!\s*\()/],a=/\b0b[01]+(?:_[01]+)*\b|\b0o[0-7]+(?:_[0-7]+)*\b|\b0x[\da-f]+(?:_[\da-f]+)*\b|(?:\b\d+(?:_\d+)*\.?(?:\d+(?:_\d+)*)?|\B\.\d+)(?:e[+-]?\d+)?/i,i=/<?=>|\?\?=?|\.{3}|\??->|[!=]=?=?|::|\*\*=?|--|\+\+|&&|\|\||<<|>>|[?~]|[/^|%*&<>.+-]=?/,o=/[{}\[\](),:;]/;t.languages.php={delimiter:{pattern:/\?>$|^<\?(?:php(?=\s)|=)?/i,alias:"important"},comment:n,variable:/\$+(?:\w+\b|(?=\{))/,package:{pattern:/(namespace\s+|use\s+(?:function\s+)?)(?:\\?\b[a-z_]\w*)+\b(?!\\)/i,lookbehind:!0,inside:{punctuation:/\\/}},"class-name-definition":{pattern:/(\b(?:class|enum|interface|trait)\s+)\b[a-z_]\w*(?!\\)\b/i,lookbehind:!0,alias:"class-name"},"function-definition":{pattern:/(\bfunction\s+)[a-z_]\w*(?=\s*\()/i,lookbehind:!0,alias:"function"},keyword:[{pattern:/(\(\s*)\b(?:array|bool|boolean|float|int|integer|object|string)\b(?=\s*\))/i,alias:"type-casting",greedy:!0,lookbehind:!0},{pattern:/([(,?]\s*)\b(?:array(?!\s*\()|bool|callable|(?:false|null)(?=\s*\|)|float|int|iterable|mixed|object|self|static|string)\b(?=\s*\$)/i,alias:"type-hint",greedy:!0,lookbehind:!0},{pattern:/(\)\s*:\s*(?:\?\s*)?)\b(?:array(?!\s*\()|bool|callable|(?:false|null)(?=\s*\|)|float|int|iterable|mixed|never|object|self|static|string|void)\b/i,alias:"return-type",greedy:!0,lookbehind:!0},{pattern:/\b(?:array(?!\s*\()|bool|float|int|iterable|mixed|object|string|void)\b/i,alias:"type-declaration",greedy:!0},{pattern:/(\|\s*)(?:false|null)\b|\b(?:false|null)(?=\s*\|)/i,alias:"type-declaration",greedy:!0,lookbehind:!0},{pattern:/\b(?:parent|self|static)(?=\s*::)/i,alias:"static-context",greedy:!0},{pattern:/(\byield\s+)from\b/i,lookbehind:!0},/\bclass\b/i,{pattern:/((?:^|[^\s>:]|(?:^|[^-])>|(?:^|[^:]):)\s*)\b(?:abstract|and|array|as|break|callable|case|catch|clone|const|continue|declare|default|die|do|echo|else|elseif|empty|enddeclare|endfor|endforeach|endif|endswitch|endwhile|enum|eval|exit|extends|final|finally|fn|for|foreach|function|global|goto|if|implements|include|include_once|instanceof|insteadof|interface|isset|list|match|namespace|never|new|or|parent|print|private|protected|public|readonly|require|require_once|return|self|static|switch|throw|trait|try|unset|use|var|while|xor|yield|__halt_compiler)\b/i,lookbehind:!0}],"argument-name":{pattern:/([(,]\s*)\b[a-z_]\w*(?=\s*:(?!:))/i,lookbehind:!0},"class-name":[{pattern:/(\b(?:extends|implements|instanceof|new(?!\s+self|\s+static))\s+|\bcatch\s*\()\b[a-z_]\w*(?!\\)\b/i,greedy:!0,lookbehind:!0},{pattern:/(\|\s*)\b[a-z_]\w*(?!\\)\b/i,greedy:!0,lookbehind:!0},{pattern:/\b[a-z_]\w*(?!\\)\b(?=\s*\|)/i,greedy:!0},{pattern:/(\|\s*)(?:\\?\b[a-z_]\w*)+\b/i,alias:"class-name-fully-qualified",greedy:!0,lookbehind:!0,inside:{punctuation:/\\/}},{pattern:/(?:\\?\b[a-z_]\w*)+\b(?=\s*\|)/i,alias:"class-name-fully-qualified",greedy:!0,inside:{punctuation:/\\/}},{pattern:/(\b(?:extends|implements|instanceof|new(?!\s+self\b|\s+static\b))\s+|\bcatch\s*\()(?:\\?\b[a-z_]\w*)+\b(?!\\)/i,alias:"class-name-fully-qualified",greedy:!0,lookbehind:!0,inside:{punctuation:/\\/}},{pattern:/\b[a-z_]\w*(?=\s*\$)/i,alias:"type-declaration",greedy:!0},{pattern:/(?:\\?\b[a-z_]\w*)+(?=\s*\$)/i,alias:["class-name-fully-qualified","type-declaration"],greedy:!0,inside:{punctuation:/\\/}},{pattern:/\b[a-z_]\w*(?=\s*::)/i,alias:"static-context",greedy:!0},{pattern:/(?:\\?\b[a-z_]\w*)+(?=\s*::)/i,alias:["class-name-fully-qualified","static-context"],greedy:!0,inside:{punctuation:/\\/}},{pattern:/([(,?]\s*)[a-z_]\w*(?=\s*\$)/i,alias:"type-hint",greedy:!0,lookbehind:!0},{pattern:/([(,?]\s*)(?:\\?\b[a-z_]\w*)+(?=\s*\$)/i,alias:["class-name-fully-qualified","type-hint"],greedy:!0,lookbehind:!0,inside:{punctuation:/\\/}},{pattern:/(\)\s*:\s*(?:\?\s*)?)\b[a-z_]\w*(?!\\)\b/i,alias:"return-type",greedy:!0,lookbehind:!0},{pattern:/(\)\s*:\s*(?:\?\s*)?)(?:\\?\b[a-z_]\w*)+\b(?!\\)/i,alias:["class-name-fully-qualified","return-type"],greedy:!0,lookbehind:!0,inside:{punctuation:/\\/}}],constant:r,function:{pattern:/(^|[^\\\w])\\?[a-z_](?:[\w\\]*\w)?(?=\s*\()/i,lookbehind:!0,inside:{punctuation:/\\/}},property:{pattern:/(->\s*)\w+/,lookbehind:!0},number:a,operator:i,punctuation:o};var l={pattern:/\{\$(?:\{(?:\{[^{}]+\}|[^{}]+)\}|[^{}])+\}|(^|[^\\{])\$+(?:\w+(?:\[[^\r\n\[\]]+\]|->\w+)?)/,lookbehind:!0,inside:t.languages.php},u=[{pattern:/<<<'([^']+)'[\r\n](?:.*[\r\n])*?\1;/,alias:"nowdoc-string",greedy:!0,inside:{delimiter:{pattern:/^<<<'[^']+'|[a-z_]\w*;$/i,alias:"symbol",inside:{punctuation:/^<<<'?|[';]$/}}}},{pattern:/<<<(?:"([^"]+)"[\r\n](?:.*[\r\n])*?\1;|([a-z_]\w*)[\r\n](?:.*[\r\n])*?\2;)/i,alias:"heredoc-string",greedy:!0,inside:{delimiter:{pattern:/^<<<(?:"[^"]+"|[a-z_]\w*)|[a-z_]\w*;$/i,alias:"symbol",inside:{punctuation:/^<<<"?|[";]$/}},interpolation:l}},{pattern:/`(?:\\[\s\S]|[^\\`])*`/,alias:"backtick-quoted-string",greedy:!0},{pattern:/'(?:\\[\s\S]|[^\\'])*'/,alias:"single-quoted-string",greedy:!0},{pattern:/"(?:\\[\s\S]|[^\\"])*"/,alias:"double-quoted-string",greedy:!0,inside:{interpolation:l}}];t.languages.insertBefore("php","variable",{string:u,attribute:{pattern:/#\[(?:[^"'\/#]|\/(?![*/])|\/\/.*$|#(?!\[).*$|\/\*(?:[^*]|\*(?!\/))*\*\/|"(?:\\[\s\S]|[^\\"])*"|'(?:\\[\s\S]|[^\\'])*')+\](?=\s*[a-z$#])/im,greedy:!0,inside:{"attribute-content":{pattern:/^(#\[)[\s\S]+(?=\]$)/,lookbehind:!0,inside:{comment:n,string:u,"attribute-class-name":[{pattern:/([^:]|^)\b[a-z_]\w*(?!\\)\b/i,alias:"class-name",greedy:!0,lookbehind:!0},{pattern:/([^:]|^)(?:\\?\b[a-z_]\w*)+/i,alias:["class-name","class-name-fully-qualified"],greedy:!0,lookbehind:!0,inside:{punctuation:/\\/}}],constant:r,number:a,operator:i,punctuation:o}},delimiter:{pattern:/^#\[|\]$/,alias:"punctuation"}}}}),t.hooks.add("before-tokenize",function(d){if(/<\?/.test(d.code)){var h=/<\?(?:[^"'/#]|\/(?![*/])|("|')(?:\\[\s\S]|(?!\1)[^\\])*\1|(?:\/\/|#(?!\[))(?:[^?\n\r]|\?(?!>))*(?=$|\?>|[\r\n])|#\[|\/\*(?:[^*]|\*(?!\/))*(?:\*\/|$))*?(?:\?>|$)/g;t.languages["markup-templating"].buildPlaceholders(d,"php",h)}}),t.hooks.add("after-tokenize",function(d){t.languages["markup-templating"].tokenizePlaceholders(d,"php")})})(e)}Au.displayName="javadoclike";Au.aliases=[];function Au(e){(function(t){var n=t.languages.javadoclike={parameter:{pattern:/(^[\t ]*(?:\/{3}|\*|\/\*\*)\s*@(?:arg|arguments|param)\s+)\w+/m,lookbehind:!0},keyword:{pattern:/(^[\t ]*(?:\/{3}|\*|\/\*\*)\s*|\{)@[a-z][a-zA-Z-]+\b/m,lookbehind:!0},punctuation:/[{}]/};function r(i,o){var l="doc-comment",u=t.languages[i];if(u){var d=u[l];if(!d){var h={};h[l]={pattern:/(^|[^\\])\/\*\*[^/][\s\S]*?(?:\*\/|$)/,lookbehind:!0,alias:"comment"},u=t.languages.insertBefore(i,"comment",h),d=u[l]}if(d instanceof RegExp&&(d=u[l]={pattern:d}),Array.isArray(d))for(var f=0,m=d.length;f<m;f++)d[f]instanceof RegExp&&(d[f]={pattern:d[f]}),o(d[f]);else o(d)}}function a(i,o){typeof i=="string"&&(i=[i]),i.forEach(function(l){r(l,function(u){u.inside||(u.inside={}),u.inside.rest=o})})}Object.defineProperty(n,"addSupport",{value:a}),n.addSupport(["java","javascript","php"],n)})(e)}_k.displayName="scala";_k.aliases=[];function _k(e){e.register(_u),e.languages.scala=e.languages.extend("java",{"triple-quoted-string":{pattern:/"""[\s\S]*?"""/,greedy:!0,alias:"string"},string:{pattern:/("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0},keyword:/<-|=>|\b(?:abstract|case|catch|class|def|derives|do|else|enum|extends|extension|final|finally|for|forSome|given|if|implicit|import|infix|inline|lazy|match|new|null|object|opaque|open|override|package|private|protected|return|sealed|self|super|this|throw|trait|transparent|try|type|using|val|var|while|with|yield)\b/,number:/\b0x(?:[\da-f]*\.)?[\da-f]+|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e\d+)?[dfl]?/i,builtin:/\b(?:Any|AnyRef|AnyVal|Boolean|Byte|Char|Double|Float|Int|Long|Nothing|Short|String|Unit)\b/,symbol:/'[^\d\s\\]\w*/}),e.languages.insertBefore("scala","triple-quoted-string",{"string-interpolation":{pattern:/\b[a-z]\w*(?:"""(?:[^$]|\$(?:[^{]|\{(?:[^{}]|\{[^{}]*\})*\}))*?"""|"(?:[^$"\r\n]|\$(?:[^{]|\{(?:[^{}]|\{[^{}]*\})*\}))*")/i,greedy:!0,inside:{id:{pattern:/^\w+/,greedy:!0,alias:"function"},escape:{pattern:/\\\$"|\$[$"]/,greedy:!0,alias:"symbol"},interpolation:{pattern:/\$(?:\w+|\{(?:[^{}]|\{[^{}]*\})*\})/,greedy:!0,inside:{punctuation:/^\$\{?|\}$/,expression:{pattern:/[\s\S]+/,inside:e.languages.scala}}},string:/[\s\S]+/}}}),delete e.languages.scala["class-name"],delete e.languages.scala.function,delete e.languages.scala.constant}Ck.displayName="javadoc";Ck.aliases=[];function Ck(e){e.register(_u),e.register(Au),e.register(cr),(function(t){var n=/(^(?:[\t ]*(?:\*\s*)*))[^*\s].*$/m,r=/#\s*\w+(?:\s*\([^()]*\))?/.source,a=/(?:\b[a-zA-Z]\w+\s*\.\s*)*\b[A-Z]\w*(?:\s*<mem>)?|<mem>/.source.replace(/<mem>/g,function(){return r});t.languages.javadoc=t.languages.extend("javadoclike",{}),t.languages.insertBefore("javadoc","keyword",{reference:{pattern:RegExp(/(@(?:exception|link|linkplain|see|throws|value)\s+(?:\*\s*)?)/.source+"(?:"+a+")"),lookbehind:!0,inside:{function:{pattern:/(#\s*)\w+(?=\s*\()/,lookbehind:!0},field:{pattern:/(#\s*)\w+/,lookbehind:!0},namespace:{pattern:/\b(?:[a-z]\w*\s*\.\s*)+/,inside:{punctuation:/\./}},"class-name":/\b[A-Z]\w*/,keyword:t.languages.java.keyword,punctuation:/[#()[\],.]/}},"class-name":{pattern:/(@param\s+)<[A-Z]\w*>/,lookbehind:!0,inside:{punctuation:/[.<>]/}},"code-section":[{pattern:/(\{@code\s+(?!\s))(?:[^\s{}]|\s+(?![\s}])|\{(?:[^{}]|\{(?:[^{}]|\{(?:[^{}]|\{[^{}]*\})*\})*\})*\})+(?=\s*\})/,lookbehind:!0,inside:{code:{pattern:n,lookbehind:!0,inside:t.languages.java,alias:"language-java"}}},{pattern:/(<(code|pre|tt)>(?!<code>)\s*)\S(?:\S|\s+\S)*?(?=\s*<\/\2>)/,lookbehind:!0,inside:{line:{pattern:n,lookbehind:!0,inside:{tag:t.languages.markup.tag,entity:t.languages.markup.entity,code:{pattern:/.+/,inside:t.languages.java,alias:"language-java"}}}}}],tag:t.languages.markup.tag,entity:t.languages.markup.entity}),t.languages.javadoclike.addSupport("java",t.languages.javadoc)})(e)}Ak.displayName="javastacktrace";Ak.aliases=[];function Ak(e){e.languages.javastacktrace={summary:{pattern:/^([\t ]*)(?:(?:Caused by:|Suppressed:|Exception in thread "[^"]*")[\t ]+)?[\w$.]+(?::.*)?$/m,lookbehind:!0,inside:{keyword:{pattern:/^([\t ]*)(?:(?:Caused by|Suppressed)(?=:)|Exception in thread)/m,lookbehind:!0},string:{pattern:/^(\s*)"[^"]*"/,lookbehind:!0},exceptions:{pattern:/^(:?\s*)[\w$.]+(?=:|$)/,lookbehind:!0,inside:{"class-name":/[\w$]+$/,namespace:/\b[a-z]\w*\b/,punctuation:/\./}},message:{pattern:/(:\s*)\S.*/,lookbehind:!0,alias:"string"},punctuation:/:/}},"stack-frame":{pattern:/^([\t ]*)at (?:[\w$./]|@[\w$.+-]*\/)+(?:<init>)?\([^()]*\)/m,lookbehind:!0,inside:{keyword:{pattern:/^(\s*)at(?= )/,lookbehind:!0},source:[{pattern:/(\()\w+\.\w+:\d+(?=\))/,lookbehind:!0,inside:{file:/^\w+\.\w+/,punctuation:/:/,"line-number":{pattern:/\b\d+\b/,alias:"number"}}},{pattern:/(\()[^()]*(?=\))/,lookbehind:!0,inside:{keyword:/^(?:Native Method|Unknown Source)$/}}],"class-name":/[\w$]+(?=\.(?:<init>|[\w$]+)\()/,function:/(?:<init>|[\w$]+)(?=\()/,"class-loader":{pattern:/(\s)[a-z]\w*(?:\.[a-z]\w*)*(?=\/[\w@$.]*\/)/,lookbehind:!0,alias:"namespace",inside:{punctuation:/\./}},module:{pattern:/([\s/])[a-z]\w*(?:\.[a-z]\w*)*(?:@[\w$.+-]*)?(?=\/)/,lookbehind:!0,inside:{version:{pattern:/(@)[\s\S]+/,lookbehind:!0,alias:"number"},punctuation:/[@.]/}},namespace:{pattern:/(?:\b[a-z]\w*\.)+/,inside:{punctuation:/\./}},punctuation:/[()/.]/}},more:{pattern:/^([\t ]*)\.{3} \d+ [a-z]+(?: [a-z]+)*/m,lookbehind:!0,inside:{punctuation:/\.{3}/,number:/\d+/,keyword:/\b[a-z]+(?: [a-z]+)*\b/}}}}Rk.displayName="jexl";Rk.aliases=[];function Rk(e){e.languages.jexl={string:/(["'])(?:\\[\s\S]|(?!\1)[^\\])*\1/,transform:{pattern:/(\|\s*)[a-zA-Zа-яА-Я_\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u00FF$][\wа-яА-Я\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u00FF$]*/,alias:"function",lookbehind:!0},function:/[a-zA-Zа-яА-Я_\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u00FF$][\wа-яА-Я\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u00FF$]*\s*(?=\()/,number:/\b\d+(?:\.\d+)?\b|\B\.\d+\b/,operator:/[<>!]=?|-|\+|&&|==|\|\|?|\/\/?|[?:*^%]/,boolean:/\b(?:false|true)\b/,keyword:/\bin\b/,punctuation:/[{}[\](),.]/}}Nk.displayName="jolie";Nk.aliases=[];function Nk(e){e.register(Mt),e.languages.jolie=e.languages.extend("clike",{string:{pattern:/(^|[^\\])"(?:\\[\s\S]|[^"\\])*"/,lookbehind:!0,greedy:!0},"class-name":{pattern:/((?:\b(?:as|courier|embed|in|inputPort|outputPort|service)\b|@)[ \t]*)\w+/,lookbehind:!0},keyword:/\b(?:as|cH|comp|concurrent|constants|courier|cset|csets|default|define|else|embed|embedded|execution|exit|extender|for|foreach|forward|from|global|if|import|in|include|init|inputPort|install|instanceof|interface|is_defined|linkIn|linkOut|main|new|nullProcess|outputPort|over|private|provide|public|scope|sequential|service|single|spawn|synchronized|this|throw|throws|type|undef|until|while|with)\b/,function:/\b[a-z_]\w*(?=[ \t]*[@(])/i,number:/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?l?/i,operator:/-[-=>]?|\+[+=]?|<[<=]?|[>=*!]=?|&&|\|\||[?\/%^@|]/,punctuation:/[()[\]{},;.:]/,builtin:/\b(?:Byte|any|bool|char|double|enum|float|int|length|long|ranges|regex|string|undefined|void)\b/}),e.languages.insertBefore("jolie","keyword",{aggregates:{pattern:/(\bAggregates\s*:\s*)(?:\w+(?:\s+with\s+\w+)?\s*,\s*)*\w+(?:\s+with\s+\w+)?/,lookbehind:!0,inside:{keyword:/\bwith\b/,"class-name":/\w+/,punctuation:/,/}},redirects:{pattern:/(\bRedirects\s*:\s*)(?:\w+\s*=>\s*\w+\s*,\s*)*(?:\w+\s*=>\s*\w+)/,lookbehind:!0,inside:{punctuation:/,/,"class-name":/\w+/,operator:/=>/}},property:{pattern:/\b(?:Aggregates|[Ii]nterfaces|Java|Javascript|Jolie|[Ll]ocation|OneWay|[Pp]rotocol|Redirects|RequestResponse)\b(?=[ \t]*:)/}})}Ok.displayName="jq";Ok.aliases=[];function Ok(e){(function(t){var n=/\\\((?:[^()]|\([^()]*\))*\)/.source,r=RegExp(/(^|[^\\])"(?:[^"\r\n\\]|\\[^\r\n(]|__)*"/.source.replace(/__/g,function(){return n})),a={interpolation:{pattern:RegExp(/((?:^|[^\\])(?:\\{2})*)/.source+n),lookbehind:!0,inside:{content:{pattern:/^(\\\()[\s\S]+(?=\)$)/,lookbehind:!0,inside:null},punctuation:/^\\\(|\)$/}}},i=t.languages.jq={comment:/#.*/,property:{pattern:RegExp(r.source+/(?=\s*:(?!:))/.source),lookbehind:!0,greedy:!0,inside:a},string:{pattern:r,lookbehind:!0,greedy:!0,inside:a},function:{pattern:/(\bdef\s+)[a-z_]\w+/i,lookbehind:!0},variable:/\B\$\w+/,"property-literal":{pattern:/\b[a-z_]\w*(?=\s*:(?!:))/i,alias:"property"},keyword:/\b(?:as|break|catch|def|elif|else|end|foreach|if|import|include|label|module|modulemeta|null|reduce|then|try|while)\b/,boolean:/\b(?:false|true)\b/,number:/(?:\b\d+\.|\B\.)?\b\d+(?:[eE][+-]?\d+)?\b/,operator:[{pattern:/\|=?/,alias:"pipe"},/\.\.|[!=<>]?=|\?\/\/|\/\/=?|[-+*/%]=?|[<>?]|\b(?:and|not|or)\b/],"c-style-function":{pattern:/\b[a-z_]\w*(?=\s*\()/i,alias:"function"},punctuation:/::|[()\[\]{},:;]|\.(?=\s*[\[\w$])/,dot:{pattern:/\./,alias:"important"}};a.interpolation.inside.content.inside=i})(e)}Ik.displayName="js-templates";Ik.aliases=[];function Ik(e){e.register(wr),(function(t){var n=t.languages.javascript["template-string"],r=n.pattern.source,a=n.inside.interpolation,i=a.inside["interpolation-punctuation"],o=a.pattern.source;function l(y,v){if(t.languages[y])return{pattern:RegExp("((?:"+v+")\\s*)"+r),lookbehind:!0,greedy:!0,inside:{"template-punctuation":{pattern:/^`|`$/,alias:"string"},"embedded-code":{pattern:/[\s\S]+/,alias:y}}}}t.languages.javascript["template-string"]=[l("css",/\b(?:styled(?:\([^)]*\))?(?:\s*\.\s*\w+(?:\([^)]*\))*)*|css(?:\s*\.\s*(?:global|resolve))?|createGlobalStyle|keyframes)/.source),l("html",/\bhtml|\.\s*(?:inner|outer)HTML\s*\+?=/.source),l("svg",/\bsvg/.source),l("markdown",/\b(?:markdown|md)/.source),l("graphql",/\b(?:gql|graphql(?:\s*\.\s*experimental)?)/.source),l("sql",/\bsql/.source),n].filter(Boolean);function u(y,v){return"___"+v.toUpperCase()+"_"+y+"___"}function d(y,v,w){var S={code:y,grammar:v,language:w};return t.hooks.run("before-tokenize",S),S.tokens=t.tokenize(S.code,S.grammar),t.hooks.run("after-tokenize",S),S.tokens}function h(y){var v={};v["interpolation-punctuation"]=i;var w=t.tokenize(y,v);if(w.length===3){var S=[1,1];S.push.apply(S,d(w[1],t.languages.javascript,"javascript")),w.splice.apply(w,S)}return new t.Token("interpolation",w,a.alias,y)}function f(y,v,w){var S=t.tokenize(y,{interpolation:{pattern:RegExp(o),lookbehind:!0}}),k=0,R={},I=S.map(function(P){if(typeof P=="string")return P;for(var G=P.content,B;y.indexOf(B=u(k++,w))!==-1;);return R[B]=G,B}).join(""),L=d(I,v,w),A=Object.keys(R);k=0;function M(P){for(var G=0;G<P.length;G++){if(k>=A.length)return;var B=P[G];if(typeof B=="string"||typeof B.content=="string"){var H=A[k],Z=typeof B=="string"?B:B.content,V=Z.indexOf(H);if(V!==-1){++k;var q=Z.substring(0,V),X=h(R[H]),$=Z.substring(V+H.length),Q=[];if(q&&Q.push(q),Q.push(X),$){var J=[$];M(J),Q.push.apply(Q,J)}typeof B=="string"?(P.splice.apply(P,[G,1].concat(Q)),G+=Q.length-1):B.content=Q}}else{var ie=B.content;Array.isArray(ie)?M(ie):M([ie])}}}return M(L),new t.Token(w,L,"language-"+w,y)}var m={javascript:!0,js:!0,typescript:!0,ts:!0,jsx:!0,tsx:!0};t.hooks.add("after-tokenize",function(y){if(!(y.language in m))return;function v(w){for(var S=0,k=w.length;S<k;S++){var R=w[S];if(typeof R!="string"){var I=R.content;if(!Array.isArray(I)){typeof I!="string"&&v([I]);continue}if(R.type==="template-string"){var L=I[1];if(I.length===3&&typeof L!="string"&&L.type==="embedded-code"){var A=b(L),M=L.alias,P=Array.isArray(M)?M[0]:M,G=t.languages[P];if(!G)continue;I[1]=f(A,G,P)}}else v(I)}}}v(y.tokens)});function b(y){return typeof y=="string"?y:Array.isArray(y)?y.map(b).join(""):b(y.content)}})(e)}lp.displayName="typescript";lp.aliases=["ts"];function lp(e){e.register(wr),(function(t){t.languages.typescript=t.languages.extend("javascript",{"class-name":{pattern:/(\b(?:class|extends|implements|instanceof|interface|new|type)\s+)(?!keyof\b)(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?:\s*<(?:[^<>]|<(?:[^<>]|<[^<>]*>)*>)*>)?/,lookbehind:!0,greedy:!0,inside:null},builtin:/\b(?:Array|Function|Promise|any|boolean|console|never|number|string|symbol|unknown)\b/}),t.languages.typescript.keyword.push(/\b(?:abstract|declare|is|keyof|readonly|require)\b/,/\b(?:asserts|infer|interface|module|namespace|type)\b(?=\s*(?:[{_$a-zA-Z\xA0-\uFFFF]|$))/,/\btype\b(?=\s*(?:[\{*]|$))/),delete t.languages.typescript.parameter,delete t.languages.typescript["literal-property"];var n=t.languages.extend("typescript",{});delete n["class-name"],t.languages.typescript["class-name"].inside=n,t.languages.insertBefore("typescript","function",{decorator:{pattern:/@[$\w\xA0-\uFFFF]+/,inside:{at:{pattern:/^@/,alias:"operator"},function:/^[\s\S]+/}},"generic-function":{pattern:/#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*\s*<(?:[^<>]|<(?:[^<>]|<[^<>]*>)*>)*>(?=\s*\()/,greedy:!0,inside:{function:/^#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*/,generic:{pattern:/<[\s\S]+/,alias:"class-name",inside:n}}}}),t.languages.ts=t.languages.typescript})(e)}Lk.displayName="jsdoc";Lk.aliases=[];function Lk(e){e.register(Au),e.register(wr),e.register(lp),(function(t){var n=t.languages.javascript,r=/\{(?:[^{}]|\{(?:[^{}]|\{[^{}]*\})*\})+\}/.source,a="(@(?:arg|argument|param|property)\\s+(?:"+r+"\\s+)?)";t.languages.jsdoc=t.languages.extend("javadoclike",{parameter:{pattern:RegExp(a+/(?:(?!\s)[$\w\xA0-\uFFFF.])+(?=\s|$)/.source),lookbehind:!0,inside:{punctuation:/\./}}}),t.languages.insertBefore("jsdoc","keyword",{"optional-parameter":{pattern:RegExp(a+/\[(?:(?!\s)[$\w\xA0-\uFFFF.])+(?:=[^[\]]+)?\](?=\s|$)/.source),lookbehind:!0,inside:{parameter:{pattern:/(^\[)[$\w\xA0-\uFFFF\.]+/,lookbehind:!0,inside:{punctuation:/\./}},code:{pattern:/(=)[\s\S]*(?=\]$)/,lookbehind:!0,inside:n,alias:"language-javascript"},punctuation:/[=[\]]/}},"class-name":[{pattern:RegExp(/(@(?:augments|class|extends|interface|memberof!?|template|this|typedef)\s+(?:<TYPE>\s+)?)[A-Z]\w*(?:\.[A-Z]\w*)*/.source.replace(/<TYPE>/g,function(){return r})),lookbehind:!0,inside:{punctuation:/\./}},{pattern:RegExp("(@[a-z]+\\s+)"+r),lookbehind:!0,inside:{string:n.string,number:n.number,boolean:n.boolean,keyword:t.languages.typescript.keyword,operator:/=>|\.\.\.|[&|?:*]/,punctuation:/[.,;=<>{}()[\]]/}}],example:{pattern:/(@example\s+(?!\s))(?:[^@\s]|\s+(?!\s))+?(?=\s*(?:\*\s*)?(?:@\w|\*\/))/,lookbehind:!0,inside:{code:{pattern:/^([\t ]*(?:\*\s*)?)\S.*$/m,lookbehind:!0,inside:n,alias:"language-javascript"}}}}),t.languages.javadoclike.addSupport("javascript",t.languages.jsdoc)})(e)}Dk.displayName="n4js";Dk.aliases=["n4jsd"];function Dk(e){e.register(wr),e.languages.n4js=e.languages.extend("javascript",{keyword:/\b(?:Array|any|boolean|break|case|catch|class|const|constructor|continue|debugger|declare|default|delete|do|else|enum|export|extends|false|finally|for|from|function|get|if|implements|import|in|instanceof|interface|let|module|new|null|number|package|private|protected|public|return|set|static|string|super|switch|this|throw|true|try|typeof|var|void|while|with|yield)\b/}),e.languages.insertBefore("n4js","constant",{annotation:{pattern:/@+\w+/,alias:"operator"}}),e.languages.n4jsd=e.languages.n4js}Mk.displayName="js-extras";Mk.aliases=[];function Mk(e){e.register(wr),(function(t){t.languages.insertBefore("javascript","function-variable",{"method-variable":{pattern:RegExp("(\\.\\s*)"+t.languages.javascript["function-variable"].pattern.source),lookbehind:!0,alias:["function-variable","method","function","property-access"]}}),t.languages.insertBefore("javascript","function",{method:{pattern:RegExp("(\\.\\s*)"+t.languages.javascript.function.source),lookbehind:!0,alias:["function","property-access"]}}),t.languages.insertBefore("javascript","constant",{"known-class-name":[{pattern:/\b(?:(?:Float(?:32|64)|(?:Int|Uint)(?:8|16|32)|Uint8Clamped)?Array|ArrayBuffer|BigInt|Boolean|DataView|Date|Error|Function|Intl|JSON|(?:Weak)?(?:Map|Set)|Math|Number|Object|Promise|Proxy|Reflect|RegExp|String|Symbol|WebAssembly)\b/,alias:"class-name"},{pattern:/\b(?:[A-Z]\w*)Error\b/,alias:"class-name"}]});function n(u,d){return RegExp(u.replace(/<ID>/g,function(){return/(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*/.source}),d)}t.languages.insertBefore("javascript","keyword",{imports:{pattern:n(/(\bimport\b\s*)(?:<ID>(?:\s*,\s*(?:\*\s*as\s+<ID>|\{[^{}]*\}))?|\*\s*as\s+<ID>|\{[^{}]*\})(?=\s*\bfrom\b)/.source),lookbehind:!0,inside:t.languages.javascript},exports:{pattern:n(/(\bexport\b\s*)(?:\*(?:\s*as\s+<ID>)?(?=\s*\bfrom\b)|\{[^{}]*\})/.source),lookbehind:!0,inside:t.languages.javascript}}),t.languages.javascript.keyword.unshift({pattern:/\b(?:as|default|export|from|import)\b/,alias:"module"},{pattern:/\b(?:await|break|catch|continue|do|else|finally|for|if|return|switch|throw|try|while|yield)\b/,alias:"control-flow"},{pattern:/\bnull\b/,alias:["null","nil"]},{pattern:/\bundefined\b/,alias:"nil"}),t.languages.insertBefore("javascript","operator",{spread:{pattern:/\.{3}/,alias:"operator"},arrow:{pattern:/=>/,alias:"operator"}}),t.languages.insertBefore("javascript","punctuation",{"property-access":{pattern:n(/(\.\s*)#?<ID>/.source),lookbehind:!0},"maybe-class-name":{pattern:/(^|[^$\w\xA0-\uFFFF])[A-Z][$\w\xA0-\uFFFF]+/,lookbehind:!0},dom:{pattern:/\b(?:document|(?:local|session)Storage|location|navigator|performance|window)\b/,alias:"variable"},console:{pattern:/\bconsole(?=\s*\.)/,alias:"class-name"}});for(var r=["function","function-variable","method","method-variable","property-access"],a=0;a<r.length;a++){var i=r[a],o=t.languages.javascript[i];t.util.type(o)==="RegExp"&&(o=t.languages.javascript[i]={pattern:o});var l=o.inside||{};o.inside=l,l["maybe-class-name"]=/^[A-Z][\s\S]*/}})(e)}Bk.displayName="json5";Bk.aliases=[];function Bk(e){e.register(sp),(function(t){var n=/("|')(?:\\(?:\r\n?|\n|.)|(?!\1)[^\\\r\n])*\1/;t.languages.json5=t.languages.extend("json",{property:[{pattern:RegExp(n.source+"(?=\\s*:)"),greedy:!0},{pattern:/(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*:)/,alias:"unquoted"}],string:{pattern:n,greedy:!0},number:/[+-]?\b(?:NaN|Infinity|0x[a-fA-F\d]+)\b|[+-]?(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[eE][+-]?\d+\b)?/})})(e)}Fk.displayName="jsonp";Fk.aliases=[];function Fk(e){e.register(sp),e.languages.jsonp=e.languages.extend("json",{punctuation:/[{}[\]();,.]/}),e.languages.insertBefore("jsonp","punctuation",{function:/(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*\()/})}zk.displayName="jsstacktrace";zk.aliases=[];function zk(e){e.languages.jsstacktrace={"error-message":{pattern:/^\S.*/m,alias:"string"},"stack-frame":{pattern:/(^[ \t]+)at[ \t].*/m,lookbehind:!0,inside:{"not-my-code":{pattern:/^at[ \t]+(?!\s)(?:node\.js|<unknown>|.*(?:node_modules|\(<anonymous>\)|\(<unknown>|<anonymous>$|\(internal\/|\(node\.js)).*/m,alias:"comment"},filename:{pattern:/(\bat\s+(?!\s)|\()(?:[a-zA-Z]:)?[^():]+(?=:)/,lookbehind:!0,alias:"url"},function:{pattern:/(\bat\s+(?:new\s+)?)(?!\s)[_$a-zA-Z\xA0-\uFFFF<][.$\w\xA0-\uFFFF<>]*/,lookbehind:!0,inside:{punctuation:/\./}},punctuation:/[()]/,keyword:/\b(?:at|new)\b/,alias:{pattern:/\[(?:as\s+)?(?!\s)[_$a-zA-Z\xA0-\uFFFF][$\w\xA0-\uFFFF]*\]/,alias:"variable"},"line-number":{pattern:/:\d+(?::\d+)?\b/,alias:"number",inside:{punctuation:/:/}}}}}}$k.displayName="julia";$k.aliases=[];function $k(e){e.languages.julia={comment:{pattern:/(^|[^\\])(?:#=(?:[^#=]|=(?!#)|#(?!=)|#=(?:[^#=]|=(?!#)|#(?!=))*=#)*=#|#.*)/,lookbehind:!0},regex:{pattern:/r"(?:\\.|[^"\\\r\n])*"[imsx]{0,4}/,greedy:!0},string:{pattern:/"""[\s\S]+?"""|(?:\b\w+)?"(?:\\.|[^"\\\r\n])*"|`(?:[^\\`\r\n]|\\.)*`/,greedy:!0},char:{pattern:/(^|[^\w'])'(?:\\[^\r\n][^'\r\n]*|[^\\\r\n])'/,lookbehind:!0,greedy:!0},keyword:/\b(?:abstract|baremodule|begin|bitstype|break|catch|ccall|const|continue|do|else|elseif|end|export|finally|for|function|global|if|immutable|import|importall|in|let|local|macro|module|print|println|quote|return|struct|try|type|typealias|using|while)\b/,boolean:/\b(?:false|true)\b/,number:/(?:\b(?=\d)|\B(?=\.))(?:0[box])?(?:[\da-f]+(?:_[\da-f]+)*(?:\.(?:\d+(?:_\d+)*)?)?|\.\d+(?:_\d+)*)(?:[efp][+-]?\d+(?:_\d+)*)?j?/i,operator:/&&|\|\||[-+*^%÷⊻&$\\]=?|\/[\/=]?|!=?=?|\|[=>]?|<(?:<=?|[=:|])?|>(?:=|>>?=?)?|==?=?|[~≠≤≥'√∛]/,punctuation:/::?|[{}[\]();,.?]/,constant:/\b(?:(?:Inf|NaN)(?:16|32|64)?|im|pi)\b|[πℯ]/}}Pk.displayName="keepalived";Pk.aliases=[];function Pk(e){e.languages.keepalived={comment:{pattern:/[#!].*/,greedy:!0},string:{pattern:/(^|[^\\])(?:"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"|'(?:\\(?:\r\n|[\s\S])|[^'\\\r\n])*')/,lookbehind:!0,greedy:!0},ip:{pattern:RegExp(/\b(?:(?:(?:[\da-f]{1,4}:){7}[\da-f]{1,4}|(?:[\da-f]{1,4}:){6}:[\da-f]{1,4}|(?:[\da-f]{1,4}:){5}:(?:[\da-f]{1,4}:)?[\da-f]{1,4}|(?:[\da-f]{1,4}:){4}:(?:[\da-f]{1,4}:){0,2}[\da-f]{1,4}|(?:[\da-f]{1,4}:){3}:(?:[\da-f]{1,4}:){0,3}[\da-f]{1,4}|(?:[\da-f]{1,4}:){2}:(?:[\da-f]{1,4}:){0,4}[\da-f]{1,4}|(?:[\da-f]{1,4}:){6}<ipv4>|(?:[\da-f]{1,4}:){0,5}:<ipv4>|::(?:[\da-f]{1,4}:){0,5}<ipv4>|[\da-f]{1,4}::(?:[\da-f]{1,4}:){0,5}[\da-f]{1,4}|::(?:[\da-f]{1,4}:){0,6}[\da-f]{1,4}|(?:[\da-f]{1,4}:){1,7}:)(?:\/\d{1,3})?|<ipv4>(?:\/\d{1,2})?)\b/.source.replace(/<ipv4>/g,function(){return/(?:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]\d|\d)\.){3}(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]\d|\d))/.source}),"i"),alias:"number"},path:{pattern:/(\s)\/(?:[^\/\s]+\/)*[^\/\s]*|\b[a-zA-Z]:\\(?:[^\\\s]+\\)*[^\\\s]*/,lookbehind:!0,alias:"string"},variable:/\$\{?\w+\}?/,email:{pattern:/[\w-]+@[\w-]+(?:\.[\w-]{2,3}){1,2}/,alias:"string"},"conditional-configuration":{pattern:/@\^?[\w-]+/,alias:"variable"},operator:/=/,property:/\b(?:BFD_CHECK|DNS_CHECK|FILE_CHECK|HTTP_GET|MISC_CHECK|NAME|PING_CHECK|SCRIPTS|SMTP_CHECK|SSL|SSL_GET|TCP_CHECK|UDP_CHECK|accept|advert_int|alpha|auth_pass|auth_type|authentication|bfd_cpu_affinity|bfd_instance|bfd_no_swap|bfd_priority|bfd_process_name|bfd_rlimit_rttime|bfd_rt_priority|bind_if|bind_port|bindto|ca|certificate|check_unicast_src|checker|checker_cpu_affinity|checker_log_all_failures|checker_no_swap|checker_priority|checker_rlimit_rttime|checker_rt_priority|child_wait_time|connect_ip|connect_port|connect_timeout|dbus_service_name|debug|default_interface|delay|delay_before_retry|delay_loop|digest|dont_track_primary|dynamic|dynamic_interfaces|enable_(?:dbus|script_security|sni|snmp_checker|snmp_rfc|snmp_rfcv2|snmp_rfcv3|snmp_vrrp|traps)|end|fall|fast_recovery|file|flag-[123]|fork_delay|full_command|fwmark|garp_group|garp_interval|garp_lower_prio_delay|garp_lower_prio_repeat|garp_master_delay|garp_master_refresh|garp_master_refresh_repeat|garp_master_repeat|global_defs|global_tracking|gna_interval|group|ha_suspend|hashed|helo_name|higher_prio_send_advert|hoplimit|http_protocol|hysteresis|idle_tx|include|inhibit_on_failure|init_fail|init_file|instance|interface|interfaces|interval|ip_family|ipvs_process_name|keepalived.conf|kernel_rx_buf_size|key|linkbeat_interfaces|linkbeat_use_polling|log_all_failures|log_unknown_vrids|lower_prio_no_advert|lthreshold|lvs_flush|lvs_flush_onstop|lvs_method|lvs_netlink_cmd_rcv_bufs|lvs_netlink_cmd_rcv_bufs_force|lvs_netlink_monitor_rcv_bufs|lvs_netlink_monitor_rcv_bufs_force|lvs_notify_fifo|lvs_notify_fifo_script|lvs_sched|lvs_sync_daemon|max_auto_priority|max_hops|mcast_src_ip|mh-fallback|mh-port|min_auto_priority_delay|min_rx|min_tx|misc_dynamic|misc_path|misc_timeout|multiplier|name|namespace_with_ipsets|native_ipv6|neighbor_ip|net_namespace|net_namespace_ipvs|nftables|nftables_counters|nftables_ifindex|nftables_priority|no_accept|no_checker_emails|no_email_faults|nopreempt|notification_email|notification_email_from|notify|notify_backup|notify_deleted|notify_down|notify_fault|notify_fifo|notify_fifo_script|notify_master|notify_master_rx_lower_pri|notify_priority_changes|notify_stop|notify_up|old_unicast_checksum|omega|ops|param_match|passive|password|path|persistence_engine|persistence_granularity|persistence_timeout|preempt|preempt_delay|priority|process|process_monitor_rcv_bufs|process_monitor_rcv_bufs_force|process_name|process_names|promote_secondaries|protocol|proxy_arp|proxy_arp_pvlan|quorum|quorum_down|quorum_max|quorum_up|random_seed|real_server|regex|regex_max_offset|regex_min_offset|regex_no_match|regex_options|regex_stack|reload_repeat|reload_time_file|require_reply|retry|rise|router_id|rs_init_notifies|script|script_user|sh-fallback|sh-port|shutdown_script|shutdown_script_timeout|skip_check_adv_addr|smtp_alert|smtp_alert_checker|smtp_alert_vrrp|smtp_connect_timeout|smtp_helo_name|smtp_server|snmp_socket|sorry_server|sorry_server_inhibit|sorry_server_lvs_method|source_ip|start|startup_script|startup_script_timeout|state|static_ipaddress|static_routes|static_rules|status_code|step|strict_mode|sync_group_tracking_weight|terminate_delay|timeout|track_bfd|track_file|track_group|track_interface|track_process|track_script|track_src_ip|ttl|type|umask|unicast_peer|unicast_src_ip|unicast_ttl|url|use_ipvlan|use_pid_dir|use_vmac|user|uthreshold|val[123]|version|virtual_ipaddress|virtual_ipaddress_excluded|virtual_router_id|virtual_routes|virtual_rules|virtual_server|virtual_server_group|virtualhost|vmac_xmit_base|vrrp|vrrp_(?:check_unicast_src|cpu_affinity|garp_interval|garp_lower_prio_delay|garp_lower_prio_repeat|garp_master_delay|garp_master_refresh|garp_master_refresh_repeat|garp_master_repeat|gna_interval|higher_prio_send_advert|instance|ipsets|iptables|lower_prio_no_advert|mcast_group4|mcast_group6|min_garp|netlink_cmd_rcv_bufs|netlink_cmd_rcv_bufs_force|netlink_monitor_rcv_bufs|netlink_monitor_rcv_bufs_force|no_swap|notify_fifo|notify_fifo_script|notify_priority_changes|priority|process_name|rlimit_rttime|rt_priority|rx_bufs_multiplier|rx_bufs_policy|script|skip_check_adv_addr|startup_delay|strict|sync_group|track_process|version)|warmup|weight)\b/,constant:/\b(?:A|AAAA|AH|BACKUP|CNAME|DR|MASTER|MX|NAT|NS|PASS|SCTP|SOA|TCP|TUN|TXT|UDP|dh|fo|lblc|lblcr|lc|mh|nq|ovf|rr|sed|sh|wlc|wrr)\b/,number:{pattern:/(^|[^\w.-])-?\d+(?:\.\d+)?/,lookbehind:!0},boolean:/\b(?:false|no|off|on|true|yes)\b/,punctuation:/[\{\}]/}}Uk.displayName="keyman";Uk.aliases=[];function Uk(e){e.languages.keyman={comment:{pattern:/\bc .*/i,greedy:!0},string:{pattern:/"[^"\r\n]*"|'[^'\r\n]*'/,greedy:!0},"virtual-key":{pattern:/\[\s*(?:(?:ALT|CAPS|CTRL|LALT|LCTRL|NCAPS|RALT|RCTRL|SHIFT)\s+)*(?:[TKU]_[\w?]+|[A-E]\d\d?|"[^"\r\n]*"|'[^'\r\n]*')\s*\]/i,greedy:!0,alias:"function"},"header-keyword":{pattern:/&\w+/,alias:"bold"},"header-statement":{pattern:/\b(?:bitmap|bitmaps|caps always off|caps on only|copyright|hotkey|language|layout|message|name|shift frees caps|version)\b/i,alias:"bold"},"rule-keyword":{pattern:/\b(?:any|baselayout|beep|call|context|deadkey|dk|if|index|layer|notany|nul|outs|platform|reset|return|save|set|store|use)\b/i,alias:"keyword"},"structural-keyword":{pattern:/\b(?:ansi|begin|group|match|newcontext|nomatch|postkeystroke|readonly|unicode|using keys)\b/i,alias:"keyword"},"compile-target":{pattern:/\$(?:keyman|keymanonly|keymanweb|kmfl|weaver):/i,alias:"property"},number:/\b(?:U\+[\dA-F]+|d\d+|x[\da-f]+|\d+)\b/i,operator:/[+>\\$]|\.\./,punctuation:/[()=,]/}}jk.displayName="kotlin";jk.aliases=["kt","kts"];function jk(e){e.register(Mt),(function(t){t.languages.kotlin=t.languages.extend("clike",{keyword:{pattern:/(^|[^.])\b(?:abstract|actual|annotation|as|break|by|catch|class|companion|const|constructor|continue|crossinline|data|do|dynamic|else|enum|expect|external|final|finally|for|fun|get|if|import|in|infix|init|inline|inner|interface|internal|is|lateinit|noinline|null|object|open|operator|out|override|package|private|protected|public|reified|return|sealed|set|super|suspend|tailrec|this|throw|to|try|typealias|val|var|vararg|when|where|while)\b/,lookbehind:!0},function:[{pattern:/(?:`[^\r\n`]+`|\b\w+)(?=\s*\()/,greedy:!0},{pattern:/(\.)(?:`[^\r\n`]+`|\w+)(?=\s*\{)/,lookbehind:!0,greedy:!0}],number:/\b(?:0[xX][\da-fA-F]+(?:_[\da-fA-F]+)*|0[bB][01]+(?:_[01]+)*|\d+(?:_\d+)*(?:\.\d+(?:_\d+)*)?(?:[eE][+-]?\d+(?:_\d+)*)?[fFL]?)\b/,operator:/\+[+=]?|-[-=>]?|==?=?|!(?:!|==?)?|[\/*%<>]=?|[?:]:?|\.\.|&&|\|\||\b(?:and|inv|or|shl|shr|ushr|xor)\b/}),delete t.languages.kotlin["class-name"];var n={"interpolation-punctuation":{pattern:/^\$\{?|\}$/,alias:"punctuation"},expression:{pattern:/[\s\S]+/,inside:t.languages.kotlin}};t.languages.insertBefore("kotlin","string",{"string-literal":[{pattern:/"""(?:[^$]|\$(?:(?!\{)|\{[^{}]*\}))*?"""/,alias:"multiline",inside:{interpolation:{pattern:/\$(?:[a-z_]\w*|\{[^{}]*\})/i,inside:n},string:/[\s\S]+/}},{pattern:/"(?:[^"\\\r\n$]|\\.|\$(?:(?!\{)|\{[^{}]*\}))*"/,alias:"singleline",inside:{interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\$(?:[a-z_]\w*|\{[^{}]*\})/i,lookbehind:!0,inside:n},string:/[\s\S]+/}}],char:{pattern:/'(?:[^'\\\r\n]|\\(?:.|u[a-fA-F0-9]{0,4}))'/,greedy:!0}}),delete t.languages.kotlin.string,t.languages.insertBefore("kotlin","keyword",{annotation:{pattern:/\B@(?:\w+:)?(?:[A-Z]\w*|\[[^\]]+\])/,alias:"builtin"}}),t.languages.insertBefore("kotlin","function",{label:{pattern:/\b\w+@|@\w+\b/,alias:"symbol"}}),t.languages.kt=t.languages.kotlin,t.languages.kts=t.languages.kotlin})(e)}Hk.displayName="kumir";Hk.aliases=["kum"];function Hk(e){(function(t){var n=/\s\x00-\x1f\x22-\x2f\x3a-\x3f\x5b-\x5e\x60\x7b-\x7e/.source;function r(a,i){return RegExp(a.replace(/<nonId>/g,n),i)}t.languages.kumir={comment:{pattern:/\|.*/},prolog:{pattern:/#.*/,greedy:!0},string:{pattern:/"[^\n\r"]*"|'[^\n\r']*'/,greedy:!0},boolean:{pattern:r(/(^|[<nonId>])(?:да|нет)(?=[<nonId>]|$)/.source),lookbehind:!0},"operator-word":{pattern:r(/(^|[<nonId>])(?:и|или|не)(?=[<nonId>]|$)/.source),lookbehind:!0,alias:"keyword"},"system-variable":{pattern:r(/(^|[<nonId>])знач(?=[<nonId>]|$)/.source),lookbehind:!0,alias:"keyword"},type:[{pattern:r(/(^|[<nonId>])(?:вещ|лит|лог|сим|цел)(?:\x20*таб)?(?=[<nonId>]|$)/.source),lookbehind:!0,alias:"builtin"},{pattern:r(/(^|[<nonId>])(?:компл|сканкод|файл|цвет)(?=[<nonId>]|$)/.source),lookbehind:!0,alias:"important"}],keyword:{pattern:r(/(^|[<nonId>])(?:алг|арг(?:\x20*рез)?|ввод|ВКЛЮЧИТЬ|вс[её]|выбор|вывод|выход|дано|для|до|дс|если|иначе|исп|использовать|кон(?:(?:\x20+|_)исп)?|кц(?:(?:\x20+|_)при)?|надо|нач|нс|нц|от|пауза|пока|при|раза?|рез|стоп|таб|то|утв|шаг)(?=[<nonId>]|$)/.source),lookbehind:!0},name:{pattern:r(/(^|[<nonId>])[^\d<nonId>][^<nonId>]*(?:\x20+[^<nonId>]+)*(?=[<nonId>]|$)/.source),lookbehind:!0},number:{pattern:r(/(^|[<nonId>])(?:\B\$[\da-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?)(?=[<nonId>]|$)/.source,"i"),lookbehind:!0},punctuation:/:=|[(),:;\[\]]/,"operator-char":{pattern:/\*\*?|<[=>]?|>=?|[-+/=]/,alias:"operator"}},t.languages.kum=t.languages.kumir})(e)}Gk.displayName="kusto";Gk.aliases=[];function Gk(e){e.languages.kusto={comment:{pattern:/\/\/.*/,greedy:!0},string:{pattern:/```[\s\S]*?```|[hH]?(?:"(?:[^\r\n\\"]|\\.)*"|'(?:[^\r\n\\']|\\.)*'|@(?:"[^\r\n"]*"|'[^\r\n']*'))/,greedy:!0},verb:{pattern:/(\|\s*)[a-z][\w-]*/i,lookbehind:!0,alias:"keyword"},command:{pattern:/\.[a-z][a-z\d-]*\b/,alias:"keyword"},"class-name":/\b(?:bool|datetime|decimal|dynamic|guid|int|long|real|string|timespan)\b/,keyword:/\b(?:access|alias|and|anti|as|asc|auto|between|by|(?:contains|(?:ends|starts)with|has(?:perfix|suffix)?)(?:_cs)?|database|declare|desc|external|from|fullouter|has_all|in|ingestion|inline|inner|innerunique|into|(?:left|right)(?:anti(?:semi)?|inner|outer|semi)?|let|like|local|not|of|on|or|pattern|print|query_parameters|range|restrict|schema|set|step|table|tables|to|view|where|with|matches\s+regex|nulls\s+(?:first|last))(?![\w-])/,boolean:/\b(?:false|null|true)\b/,function:/\b[a-z_]\w*(?=\s*\()/,datetime:[{pattern:/\b(?:(?:Fri|Friday|Mon|Monday|Sat|Saturday|Sun|Sunday|Thu|Thursday|Tue|Tuesday|Wed|Wednesday)\s*,\s*)?\d{1,2}(?:\s+|-)(?:Apr|Aug|Dec|Feb|Jan|Jul|Jun|Mar|May|Nov|Oct|Sep)(?:\s+|-)\d{2}\s+\d{2}:\d{2}(?::\d{2})?(?:\s*(?:\b(?:[A-Z]|(?:[ECMT][DS]|GM|U)T)|[+-]\d{4}))?\b/,alias:"number"},{pattern:/[+-]?\b(?:\d{4}-\d{2}-\d{2}(?:[ T]\d{2}:\d{2}(?::\d{2}(?:\.\d+)?)?)?|\d{2}:\d{2}(?::\d{2}(?:\.\d+)?)?)Z?/,alias:"number"}],number:/\b(?:0x[0-9A-Fa-f]+|\d+(?:\.\d+)?(?:[Ee][+-]?\d+)?)(?:(?:min|sec|[mnµ]s|[dhms]|microsecond|tick)\b)?|[+-]?\binf\b/,operator:/=>|[!=]~|[!=<>]=?|[-+*/%|]|\.\./,punctuation:/[()\[\]{},;.:]/}}qk.displayName="latex";qk.aliases=["context","tex"];function qk(e){(function(t){var n=/\\(?:[^a-z()[\]]|[a-z*]+)/i,r={"equation-command":{pattern:n,alias:"regex"}};t.languages.latex={comment:/%.*/,cdata:{pattern:/(\\begin\{((?:lstlisting|verbatim)\*?)\})[\s\S]*?(?=\\end\{\2\})/,lookbehind:!0},equation:[{pattern:/\$\$(?:\\[\s\S]|[^\\$])+\$\$|\$(?:\\[\s\S]|[^\\$])+\$|\\\([\s\S]*?\\\)|\\\[[\s\S]*?\\\]/,inside:r,alias:"string"},{pattern:/(\\begin\{((?:align|eqnarray|equation|gather|math|multline)\*?)\})[\s\S]*?(?=\\end\{\2\})/,lookbehind:!0,inside:r,alias:"string"}],keyword:{pattern:/(\\(?:begin|cite|documentclass|end|label|ref|usepackage)(?:\[[^\]]+\])?\{)[^}]+(?=\})/,lookbehind:!0},url:{pattern:/(\\url\{)[^}]+(?=\})/,lookbehind:!0},headline:{pattern:/(\\(?:chapter|frametitle|paragraph|part|section|subparagraph|subsection|subsubparagraph|subsubsection|subsubsubparagraph)\*?(?:\[[^\]]+\])?\{)[^}]+(?=\})/,lookbehind:!0,alias:"class-name"},function:{pattern:n,alias:"selector"},punctuation:/[[\]{}&]/},t.languages.tex=t.languages.latex,t.languages.context=t.languages.latex})(e)}Wk.displayName="latte";Wk.aliases=[];function Wk(e){e.register(Mt),e.register(Er),e.register(Cu),(function(t){t.languages.latte={comment:/^\{\*[\s\S]*/,"latte-tag":{pattern:/(^\{(?:\/(?=[a-z]))?)(?:[=_]|[a-z]\w*\b(?!\())/i,lookbehind:!0,alias:"important"},delimiter:{pattern:/^\{\/?|\}$/,alias:"punctuation"},php:{pattern:/\S(?:[\s\S]*\S)?/,alias:"language-php",inside:t.languages.php}};var n=t.languages.extend("markup",{});t.languages.insertBefore("inside","attr-value",{"n-attr":{pattern:/n:[\w-]+(?:\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+))?/,inside:{"attr-name":{pattern:/^[^\s=]+/,alias:"important"},"attr-value":{pattern:/=[\s\S]+/,inside:{punctuation:[/^=/,{pattern:/^(\s*)["']|["']$/,lookbehind:!0}],php:{pattern:/\S(?:[\s\S]*\S)?/,inside:t.languages.php}}}}}},n.tag),t.hooks.add("before-tokenize",function(r){if(r.language==="latte"){var a=/\{\*[\s\S]*?\*\}|\{[^'"\s{}*](?:[^"'/{}]|\/(?![*/])|("|')(?:\\[\s\S]|(?!\1)[^\\])*\1|\/\*(?:[^*]|\*(?!\/))*\*\/)*\}/g;t.languages["markup-templating"].buildPlaceholders(r,"latte",a),r.grammar=n}}),t.hooks.add("after-tokenize",function(r){t.languages["markup-templating"].tokenizePlaceholders(r,"latte")})})(e)}cp.displayName="scheme";cp.aliases=[];function cp(e){(function(t){t.languages.scheme={comment:/;.*|#;\s*(?:\((?:[^()]|\([^()]*\))*\)|\[(?:[^\[\]]|\[[^\[\]]*\])*\])|#\|(?:[^#|]|#(?!\|)|\|(?!#)|#\|(?:[^#|]|#(?!\|)|\|(?!#))*\|#)*\|#/,string:{pattern:/"(?:[^"\\]|\\.)*"/,greedy:!0},symbol:{pattern:/'[^()\[\]#'\s]+/,greedy:!0},char:{pattern:/#\\(?:[ux][a-fA-F\d]+\b|[-a-zA-Z]+\b|[\uD800-\uDBFF][\uDC00-\uDFFF]|\S)/,greedy:!0},"lambda-parameter":[{pattern:/((?:^|[^'`#])[(\[]lambda\s+)(?:[^|()\[\]'\s]+|\|(?:[^\\|]|\\.)*\|)/,lookbehind:!0},{pattern:/((?:^|[^'`#])[(\[]lambda\s+[(\[])[^()\[\]']+/,lookbehind:!0}],keyword:{pattern:/((?:^|[^'`#])[(\[])(?:begin|case(?:-lambda)?|cond(?:-expand)?|define(?:-library|-macro|-record-type|-syntax|-values)?|defmacro|delay(?:-force)?|do|else|except|export|guard|if|import|include(?:-ci|-library-declarations)?|lambda|let(?:rec)?(?:-syntax|-values|\*)?|let\*-values|only|parameterize|prefix|(?:quasi-?)?quote|rename|set!|syntax-(?:case|rules)|unless|unquote(?:-splicing)?|when)(?=[()\[\]\s]|$)/,lookbehind:!0},builtin:{pattern:/((?:^|[^'`#])[(\[])(?:abs|and|append|apply|assoc|ass[qv]|binary-port\?|boolean=?\?|bytevector(?:-append|-copy|-copy!|-length|-u8-ref|-u8-set!|\?)?|caar|cadr|call-with-(?:current-continuation|port|values)|call\/cc|car|cdar|cddr|cdr|ceiling|char(?:->integer|-ready\?|\?|<\?|<=\?|=\?|>\?|>=\?)|close-(?:input-port|output-port|port)|complex\?|cons|current-(?:error|input|output)-port|denominator|dynamic-wind|eof-object\??|eq\?|equal\?|eqv\?|error|error-object(?:-irritants|-message|\?)|eval|even\?|exact(?:-integer-sqrt|-integer\?|\?)?|expt|features|file-error\?|floor(?:-quotient|-remainder|\/)?|flush-output-port|for-each|gcd|get-output-(?:bytevector|string)|inexact\??|input-port(?:-open\?|\?)|integer(?:->char|\?)|lcm|length|list(?:->string|->vector|-copy|-ref|-set!|-tail|\?)?|make-(?:bytevector|list|parameter|string|vector)|map|max|member|memq|memv|min|modulo|negative\?|newline|not|null\?|number(?:->string|\?)|numerator|odd\?|open-(?:input|output)-(?:bytevector|string)|or|output-port(?:-open\?|\?)|pair\?|peek-char|peek-u8|port\?|positive\?|procedure\?|quotient|raise|raise-continuable|rational\?|rationalize|read-(?:bytevector|bytevector!|char|error\?|line|string|u8)|real\?|remainder|reverse|round|set-c[ad]r!|square|string(?:->list|->number|->symbol|->utf8|->vector|-append|-copy|-copy!|-fill!|-for-each|-length|-map|-ref|-set!|\?|<\?|<=\?|=\?|>\?|>=\?)?|substring|symbol(?:->string|\?|=\?)|syntax-error|textual-port\?|truncate(?:-quotient|-remainder|\/)?|u8-ready\?|utf8->string|values|vector(?:->list|->string|-append|-copy|-copy!|-fill!|-for-each|-length|-map|-ref|-set!|\?)?|with-exception-handler|write-(?:bytevector|char|string|u8)|zero\?)(?=[()\[\]\s]|$)/,lookbehind:!0},operator:{pattern:/((?:^|[^'`#])[(\[])(?:[-+*%/]|[<>]=?|=>?)(?=[()\[\]\s]|$)/,lookbehind:!0},number:{pattern:RegExp(n({"<ureal dec>":/\d+(?:\/\d+)|(?:\d+(?:\.\d*)?|\.\d+)(?:[esfdl][+-]?\d+)?/.source,"<real dec>":/[+-]?<ureal dec>|[+-](?:inf|nan)\.0/.source,"<imaginary dec>":/[+-](?:<ureal dec>|(?:inf|nan)\.0)?i/.source,"<complex dec>":/<real dec>(?:@<real dec>|<imaginary dec>)?|<imaginary dec>/.source,"<num dec>":/(?:#d(?:#[ei])?|#[ei](?:#d)?)?<complex dec>/.source,"<ureal box>":/[0-9a-f]+(?:\/[0-9a-f]+)?/.source,"<real box>":/[+-]?<ureal box>|[+-](?:inf|nan)\.0/.source,"<imaginary box>":/[+-](?:<ureal box>|(?:inf|nan)\.0)?i/.source,"<complex box>":/<real box>(?:@<real box>|<imaginary box>)?|<imaginary box>/.source,"<num box>":/#[box](?:#[ei])?|(?:#[ei])?#[box]<complex box>/.source,"<number>":/(^|[()\[\]\s])(?:<num dec>|<num box>)(?=[()\[\]\s]|$)/.source}),"i"),lookbehind:!0},boolean:{pattern:/(^|[()\[\]\s])#(?:[ft]|false|true)(?=[()\[\]\s]|$)/,lookbehind:!0},function:{pattern:/((?:^|[^'`#])[(\[])(?:[^|()\[\]'\s]+|\|(?:[^\\|]|\\.)*\|)(?=[()\[\]\s]|$)/,lookbehind:!0},identifier:{pattern:/(^|[()\[\]\s])\|(?:[^\\|]|\\.)*\|(?=[()\[\]\s]|$)/,lookbehind:!0,greedy:!0},punctuation:/[()\[\]']/};function n(r){for(var a in r)r[a]=r[a].replace(/<[\w\s]+>/g,function(i){return"(?:"+r[i].trim()+")"});return r[a]}})(e)}Vk.displayName="lilypond";Vk.aliases=["ly"];function Vk(e){e.register(cp),(function(t){for(var n=/\((?:[^();"#\\]|\\[\s\S]|;.*(?!.)|"(?:[^"\\]|\\.)*"|#(?:\{(?:(?!#\})[\s\S])*#\}|[^{])|<expr>)*\)/.source,r=5,a=0;a<r;a++)n=n.replace(/<expr>/g,function(){return n});n=n.replace(/<expr>/g,/[^\s\S]/.source);var i=t.languages.lilypond={comment:/%(?:(?!\{).*|\{[\s\S]*?%\})/,"embedded-scheme":{pattern:RegExp(/(^|[=\s])#(?:"(?:[^"\\]|\\.)*"|[^\s()"]*(?:[^\s()]|<expr>))/.source.replace(/<expr>/g,function(){return n}),"m"),lookbehind:!0,greedy:!0,inside:{scheme:{pattern:/^(#)[\s\S]+$/,lookbehind:!0,alias:"language-scheme",inside:{"embedded-lilypond":{pattern:/#\{[\s\S]*?#\}/,greedy:!0,inside:{punctuation:/^#\{|#\}$/,lilypond:{pattern:/[\s\S]+/,alias:"language-lilypond",inside:null}}},rest:t.languages.scheme}},punctuation:/#/}},string:{pattern:/"(?:[^"\\]|\\.)*"/,greedy:!0},"class-name":{pattern:/(\\new\s+)[\w-]+/,lookbehind:!0},keyword:{pattern:/\\[a-z][-\w]*/i,inside:{punctuation:/^\\/}},operator:/[=|]|<<|>>/,punctuation:{pattern:/(^|[a-z\d])(?:'+|,+|[_^]?-[_^]?(?:[-+^!>._]|(?=\d))|[_^]\.?|[.!])|[{}()[\]<>^~]|\\[()[\]<>\\!]|--|__/,lookbehind:!0},number:/\b\d+(?:\/\d+)?\b/};i["embedded-scheme"].inside.scheme.inside["embedded-lilypond"].inside.lilypond.inside=i,t.languages.ly=i})(e)}Yk.displayName="liquid";Yk.aliases=[];function Yk(e){e.register(Er),e.languages.liquid={comment:{pattern:/(^\{%\s*comment\s*%\})[\s\S]+(?=\{%\s*endcomment\s*%\}$)/,lookbehind:!0},delimiter:{pattern:/^\{(?:\{\{|[%\{])-?|-?(?:\}\}|[%\}])\}$/,alias:"punctuation"},string:{pattern:/"[^"]*"|'[^']*'/,greedy:!0},keyword:/\b(?:as|assign|break|(?:end)?(?:capture|case|comment|for|form|if|paginate|raw|style|tablerow|unless)|continue|cycle|decrement|echo|else|elsif|in|include|increment|limit|liquid|offset|range|render|reversed|section|when|with)\b/,object:/\b(?:address|all_country_option_tags|article|block|blog|cart|checkout|collection|color|country|country_option_tags|currency|current_page|current_tags|customer|customer_address|date|discount_allocation|discount_application|external_video|filter|filter_value|font|forloop|fulfillment|generic_file|gift_card|group|handle|image|line_item|link|linklist|localization|location|measurement|media|metafield|model|model_source|order|page|page_description|page_image|page_title|part|policy|product|product_option|recommendations|request|robots|routes|rule|script|search|selling_plan|selling_plan_allocation|selling_plan_group|shipping_method|shop|shop_locale|sitemap|store_availability|tax_line|template|theme|transaction|unit_price_measurement|user_agent|variant|video|video_source)\b/,function:[{pattern:/(\|\s*)\w+/,lookbehind:!0,alias:"filter"},{pattern:/(\.\s*)(?:first|last|size)/,lookbehind:!0}],boolean:/\b(?:false|nil|true)\b/,range:{pattern:/\.\./,alias:"operator"},number:/\b\d+(?:\.\d+)?\b/,operator:/[!=]=|<>|[<>]=?|[|?:=-]|\b(?:and|contains(?=\s)|or)\b/,punctuation:/[.,\[\]()]/,empty:{pattern:/\bempty\b/,alias:"keyword"}},e.hooks.add("before-tokenize",function(t){var n=/\{%\s*comment\s*%\}[\s\S]*?\{%\s*endcomment\s*%\}|\{(?:%[\s\S]*?%|\{\{[\s\S]*?\}\}|\{[\s\S]*?\})\}/g,r=!1;e.languages["markup-templating"].buildPlaceholders(t,"liquid",n,function(a){var i=/^\{%-?\s*(\w+)/.exec(a);if(i){var o=i[1];if(o==="raw"&&!r)return r=!0,!0;if(o==="endraw")return r=!1,!0}return!r})}),e.hooks.add("after-tokenize",function(t){e.languages["markup-templating"].tokenizePlaceholders(t,"liquid")})}Xk.displayName="lisp";Xk.aliases=["elisp","emacs","emacs-lisp"];function Xk(e){(function(t){function n(y){return RegExp(/(\()/.source+"(?:"+y+")"+/(?=[\s\)])/.source)}function r(y){return RegExp(/([\s([])/.source+"(?:"+y+")"+/(?=[\s)])/.source)}var a=/(?!\d)[-+*/~!@$%^=<>{}\w]+/.source,i="&"+a,o="(\\()",l="(?=\\))",u="(?=\\s)",d=/(?:[^()]|\((?:[^()]|\((?:[^()]|\((?:[^()]|\((?:[^()]|\([^()]*\))*\))*\))*\))*\))*/.source,h={heading:{pattern:/;;;.*/,alias:["comment","title"]},comment:/;.*/,string:{pattern:/"(?:[^"\\]|\\.)*"/,greedy:!0,inside:{argument:/[-A-Z]+(?=[.,\s])/,symbol:RegExp("`"+a+"'")}},"quoted-symbol":{pattern:RegExp("#?'"+a),alias:["variable","symbol"]},"lisp-property":{pattern:RegExp(":"+a),alias:"property"},splice:{pattern:RegExp(",@?"+a),alias:["symbol","variable"]},keyword:[{pattern:RegExp(o+"(?:and|(?:cl-)?letf|cl-loop|cond|cons|error|if|(?:lexical-)?let\\*?|message|not|null|or|provide|require|setq|unless|use-package|when|while)"+u),lookbehind:!0},{pattern:RegExp(o+"(?:append|by|collect|concat|do|finally|for|in|return)"+u),lookbehind:!0}],declare:{pattern:n(/declare/.source),lookbehind:!0,alias:"keyword"},interactive:{pattern:n(/interactive/.source),lookbehind:!0,alias:"keyword"},boolean:{pattern:r(/nil|t/.source),lookbehind:!0},number:{pattern:r(/[-+]?\d+(?:\.\d*)?/.source),lookbehind:!0},defvar:{pattern:RegExp(o+"def(?:const|custom|group|var)\\s+"+a),lookbehind:!0,inside:{keyword:/^def[a-z]+/,variable:RegExp(a)}},defun:{pattern:RegExp(o+/(?:cl-)?(?:defmacro|defun\*?)\s+/.source+a+/\s+\(/.source+d+/\)/.source),lookbehind:!0,greedy:!0,inside:{keyword:/^(?:cl-)?def\S+/,arguments:null,function:{pattern:RegExp("(^\\s)"+a),lookbehind:!0},punctuation:/[()]/}},lambda:{pattern:RegExp(o+"lambda\\s+\\(\\s*(?:&?"+a+"(?:\\s+&?"+a+")*\\s*)?\\)"),lookbehind:!0,greedy:!0,inside:{keyword:/^lambda/,arguments:null,punctuation:/[()]/}},car:{pattern:RegExp(o+a),lookbehind:!0},punctuation:[/(?:['`,]?\(|[)\[\]])/,{pattern:/(\s)\.(?=\s)/,lookbehind:!0}]},f={"lisp-marker":RegExp(i),varform:{pattern:RegExp(/\(/.source+a+/\s+(?=\S)/.source+d+/\)/.source),inside:h},argument:{pattern:RegExp(/(^|[\s(])/.source+a),lookbehind:!0,alias:"variable"},rest:h},m="\\S+(?:\\s+\\S+)*",b={pattern:RegExp(o+d+l),lookbehind:!0,inside:{"rest-vars":{pattern:RegExp("&(?:body|rest)\\s+"+m),inside:f},"other-marker-vars":{pattern:RegExp("&(?:aux|optional)\\s+"+m),inside:f},keys:{pattern:RegExp("&key\\s+"+m+"(?:\\s+&allow-other-keys)?"),inside:f},argument:{pattern:RegExp(a),alias:"variable"},punctuation:/[()]/}};h.lambda.inside.arguments=b,h.defun.inside.arguments=t.util.clone(b),h.defun.inside.arguments.inside.sublist=b,t.languages.lisp=h,t.languages.elisp=h,t.languages.emacs=h,t.languages["emacs-lisp"]=h})(e)}Kk.displayName="livescript";Kk.aliases=[];function Kk(e){e.languages.livescript={comment:[{pattern:/(^|[^\\])\/\*[\s\S]*?\*\//,lookbehind:!0},{pattern:/(^|[^\\])#.*/,lookbehind:!0}],"interpolated-string":{pattern:/(^|[^"])("""|")(?:\\[\s\S]|(?!\2)[^\\])*\2(?!")/,lookbehind:!0,greedy:!0,inside:{variable:{pattern:/(^|[^\\])#[a-z_](?:-?[a-z]|[\d_])*/m,lookbehind:!0},interpolation:{pattern:/(^|[^\\])#\{[^}]+\}/m,lookbehind:!0,inside:{"interpolation-punctuation":{pattern:/^#\{|\}$/,alias:"variable"}}},string:/[\s\S]+/}},string:[{pattern:/('''|')(?:\\[\s\S]|(?!\1)[^\\])*\1/,greedy:!0},{pattern:/<\[[\s\S]*?\]>/,greedy:!0},/\\[^\s,;\])}]+/],regex:[{pattern:/\/\/(?:\[[^\r\n\]]*\]|\\.|(?!\/\/)[^\\\[])+\/\/[gimyu]{0,5}/,greedy:!0,inside:{comment:{pattern:/(^|[^\\])#.*/,lookbehind:!0}}},{pattern:/\/(?:\[[^\r\n\]]*\]|\\.|[^/\\\r\n\[])+\/[gimyu]{0,5}/,greedy:!0}],keyword:{pattern:/(^|(?!-).)\b(?:break|case|catch|class|const|continue|default|do|else|extends|fallthrough|finally|for(?: ever)?|function|if|implements|it|let|loop|new|null|otherwise|own|return|super|switch|that|then|this|throw|try|unless|until|var|void|when|while|yield)(?!-)\b/m,lookbehind:!0},"keyword-operator":{pattern:/(^|[^-])\b(?:(?:delete|require|typeof)!|(?:and|by|delete|export|from|import(?: all)?|in|instanceof|is(?: not|nt)?|not|of|or|til|to|typeof|with|xor)(?!-)\b)/m,lookbehind:!0,alias:"operator"},boolean:{pattern:/(^|[^-])\b(?:false|no|off|on|true|yes)(?!-)\b/m,lookbehind:!0},argument:{pattern:/(^|(?!\.&\.)[^&])&(?!&)\d*/m,lookbehind:!0,alias:"variable"},number:/\b(?:\d+~[\da-z]+|\d[\d_]*(?:\.\d[\d_]*)?(?:[a-z]\w*)?)/i,identifier:/[a-z_](?:-?[a-z]|[\d_])*/i,operator:[{pattern:/( )\.(?= )/,lookbehind:!0},/\.(?:[=~]|\.\.?)|\.(?:[&|^]|<<|>>>?)\.|:(?:=|:=?)|&&|\|[|>]|<(?:<<?<?|--?!?|~~?!?|[|=?])?|>[>=?]?|-(?:->?|>)?|\+\+?|@@?|%%?|\*\*?|!(?:~?=|--?>|~?~>)?|~(?:~?>|=)?|==?|\^\^?|[\/?]/],punctuation:/[(){}\[\]|.,:;`]/},e.languages.livescript["interpolated-string"].inside.interpolation.inside.rest=e.languages.livescript}Zk.displayName="llvm";Zk.aliases=[];function Zk(e){(function(t){t.languages.llvm={comment:/;.*/,string:{pattern:/"[^"]*"/,greedy:!0},boolean:/\b(?:false|true)\b/,variable:/[%@!#](?:(?!\d)(?:[-$.\w]|\\[a-f\d]{2})+|\d+)/i,label:/(?!\d)(?:[-$.\w]|\\[a-f\d]{2})+:/i,type:{pattern:/\b(?:double|float|fp128|half|i[1-9]\d*|label|metadata|ppc_fp128|token|void|x86_fp80|x86_mmx)\b/,alias:"class-name"},keyword:/\b[a-z_][a-z_0-9]*\b/,number:/[+-]?\b\d+(?:\.\d+)?(?:[eE][+-]?\d+)?\b|\b0x[\dA-Fa-f]+\b|\b0xK[\dA-Fa-f]{20}\b|\b0x[ML][\dA-Fa-f]{32}\b|\b0xH[\dA-Fa-f]{4}\b/,punctuation:/[{}[\];(),.!*=<>]/}})(e)}Qk.displayName="log";Qk.aliases=[];function Qk(e){e.languages.log={string:{pattern:/"(?:[^"\\\r\n]|\\.)*"|'(?![st] | \w)(?:[^'\\\r\n]|\\.)*'/,greedy:!0},exception:{pattern:/(^|[^\w.])[a-z][\w.]*(?:Error|Exception):.*(?:(?:\r\n?|\n)[ \t]*(?:at[ \t].+|\.{3}.*|Caused by:.*))+(?:(?:\r\n?|\n)[ \t]*\.\.\. .*)?/,lookbehind:!0,greedy:!0,alias:["javastacktrace","language-javastacktrace"],inside:e.languages.javastacktrace||{keyword:/\bat\b/,function:/[a-z_][\w$]*(?=\()/,punctuation:/[.:()]/}},level:[{pattern:/\b(?:ALERT|CRIT|CRITICAL|EMERG|EMERGENCY|ERR|ERROR|FAILURE|FATAL|SEVERE)\b/,alias:["error","important"]},{pattern:/\b(?:WARN|WARNING|WRN)\b/,alias:["warning","important"]},{pattern:/\b(?:DISPLAY|INF|INFO|NOTICE|STATUS)\b/,alias:["info","keyword"]},{pattern:/\b(?:DBG|DEBUG|FINE)\b/,alias:["debug","keyword"]},{pattern:/\b(?:FINER|FINEST|TRACE|TRC|VERBOSE|VRB)\b/,alias:["trace","comment"]}],property:{pattern:/((?:^|[\]|])[ \t]*)[a-z_](?:[\w-]|\b\/\b)*(?:[. ]\(?\w(?:[\w-]|\b\/\b)*\)?)*:(?=\s)/im,lookbehind:!0},separator:{pattern:/(^|[^-+])-{3,}|={3,}|\*{3,}|- - /m,lookbehind:!0,alias:"comment"},url:/\b(?:file|ftp|https?):\/\/[^\s|,;'"]*[^\s|,;'">.]/,email:{pattern:/(^|\s)[-\w+.]+@[a-z][a-z0-9-]*(?:\.[a-z][a-z0-9-]*)+(?=\s)/,lookbehind:!0,alias:"url"},"ip-address":{pattern:/\b(?:\d{1,3}(?:\.\d{1,3}){3})\b/,alias:"constant"},"mac-address":{pattern:/\b[a-f0-9]{2}(?::[a-f0-9]{2}){5}\b/i,alias:"constant"},domain:{pattern:/(^|\s)[a-z][a-z0-9-]*(?:\.[a-z][a-z0-9-]*)*\.[a-z][a-z0-9-]+(?=\s)/,lookbehind:!0,alias:"constant"},uuid:{pattern:/\b[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}\b/i,alias:"constant"},hash:{pattern:/\b(?:[a-f0-9]{32}){1,2}\b/i,alias:"constant"},"file-path":{pattern:/\b[a-z]:[\\/][^\s|,;:(){}\[\]"']+|(^|[\s:\[\](>|])\.{0,2}\/\w[^\s|,;:(){}\[\]"']*/i,lookbehind:!0,greedy:!0,alias:"string"},date:{pattern:RegExp(/\b\d{4}[-/]\d{2}[-/]\d{2}(?:T(?=\d{1,2}:)|(?=\s\d{1,2}:))/.source+"|"+/\b\d{1,4}[-/ ](?:\d{1,2}|Apr|Aug|Dec|Feb|Jan|Jul|Jun|Mar|May|Nov|Oct|Sep)[-/ ]\d{2,4}T?\b/.source+"|"+/\b(?:(?:Fri|Mon|Sat|Sun|Thu|Tue|Wed)(?:\s{1,2}(?:Apr|Aug|Dec|Feb|Jan|Jul|Jun|Mar|May|Nov|Oct|Sep))?|Apr|Aug|Dec|Feb|Jan|Jul|Jun|Mar|May|Nov|Oct|Sep)\s{1,2}\d{1,2}\b/.source,"i"),alias:"number"},time:{pattern:/\b\d{1,2}:\d{1,2}:\d{1,2}(?:[.,:]\d+)?(?:\s?[+-]\d{2}:?\d{2}|Z)?\b/,alias:"number"},boolean:/\b(?:false|null|true)\b/i,number:{pattern:/(^|[^.\w])(?:0x[a-f0-9]+|0o[0-7]+|0b[01]+|v?\d[\da-f]*(?:\.\d+)*(?:e[+-]?\d+)?[a-z]{0,3}\b)\b(?!\.\w)/i,lookbehind:!0},operator:/[;:?<=>~/@!$%&+\-|^(){}*#]/,punctuation:/[\[\].,]/}}Jk.displayName="lolcode";Jk.aliases=[];function Jk(e){e.languages.lolcode={comment:[/\bOBTW\s[\s\S]*?\sTLDR\b/,/\bBTW.+/],string:{pattern:/"(?::.|[^":])*"/,inside:{variable:/:\{[^}]+\}/,symbol:[/:\([a-f\d]+\)/i,/:\[[^\]]+\]/,/:[)>o":]/]},greedy:!0},number:/(?:\B-)?(?:\b\d+(?:\.\d*)?|\B\.\d+)/,symbol:{pattern:/(^|\s)(?:A )?(?:BUKKIT|NOOB|NUMBAR|NUMBR|TROOF|YARN)(?=\s|,|$)/,lookbehind:!0,inside:{keyword:/A(?=\s)/}},label:{pattern:/((?:^|\s)(?:IM IN YR|IM OUTTA YR) )[a-zA-Z]\w*/,lookbehind:!0,alias:"string"},function:{pattern:/((?:^|\s)(?:HOW IZ I|I IZ|IZ) )[a-zA-Z]\w*/,lookbehind:!0},keyword:[{pattern:/(^|\s)(?:AN|FOUND YR|GIMMEH|GTFO|HAI|HAS A|HOW IZ I|I HAS A|I IZ|IF U SAY SO|IM IN YR|IM OUTTA YR|IS NOW(?: A)?|ITZ(?: A)?|IZ|KTHX|KTHXBYE|LIEK(?: A)?|MAEK|MEBBE|MKAY|NERFIN|NO WAI|O HAI IM|O RLY\?|OIC|OMG|OMGWTF|R|SMOOSH|SRS|TIL|UPPIN|VISIBLE|WILE|WTF\?|YA RLY|YR)(?=\s|,|$)/,lookbehind:!0},/'Z(?=\s|,|$)/],boolean:{pattern:/(^|\s)(?:FAIL|WIN)(?=\s|,|$)/,lookbehind:!0},variable:{pattern:/(^|\s)IT(?=\s|,|$)/,lookbehind:!0},operator:{pattern:/(^|\s)(?:NOT|BOTH SAEM|DIFFRINT|(?:ALL|ANY|BIGGR|BOTH|DIFF|EITHER|MOD|PRODUKT|QUOSHUNT|SMALLR|SUM|WON) OF)(?=\s|,|$)/,lookbehind:!0},punctuation:/\.{3}|…|,|!/}}e4.displayName="magma";e4.aliases=[];function e4(e){e.languages.magma={output:{pattern:/^(>.*(?:\r(?:\n|(?!\n))|\n))(?!>)(?:.+|(?:\r(?:\n|(?!\n))|\n)(?!>).*)(?:(?:\r(?:\n|(?!\n))|\n)(?!>).*)*/m,lookbehind:!0,greedy:!0},comment:{pattern:/\/\/.*|\/\*[\s\S]*?\*\//,greedy:!0},string:{pattern:/(^|[^\\"])"(?:[^\r\n\\"]|\\.)*"/,lookbehind:!0,greedy:!0},keyword:/\b(?:_|adj|and|assert|assert2|assert3|assigned|break|by|case|cat|catch|clear|cmpeq|cmpne|continue|declare|default|delete|diff|div|do|elif|else|end|eq|error|eval|exists|exit|for|forall|forward|fprintf|freeze|function|ge|gt|if|iload|import|in|intrinsic|is|join|le|load|local|lt|meet|mod|ne|not|notadj|notin|notsubset|or|print|printf|procedure|quit|random|read|readi|repeat|require|requirege|requirerange|restore|return|save|sdiff|select|subset|then|time|to|try|until|vprint|vprintf|vtime|when|where|while|xor)\b/,boolean:/\b(?:false|true)\b/,generator:{pattern:/\b[a-z_]\w*(?=\s*<)/i,alias:"class-name"},function:/\b[a-z_]\w*(?=\s*\()/i,number:{pattern:/(^|[^\w.]|\.\.)(?:\d+(?:\.\d*)?|\.\d+)(?:[eE][+-]?\d+)?(?:_[a-z]?)?(?=$|[^\w.]|\.\.)/,lookbehind:!0},operator:/->|[-+*/^~!|#=]|:=|\.\./,punctuation:/[()[\]{}<>,;.:]/}}t4.displayName="makefile";t4.aliases=[];function t4(e){e.languages.makefile={comment:{pattern:/(^|[^\\])#(?:\\(?:\r\n|[\s\S])|[^\\\r\n])*/,lookbehind:!0},string:{pattern:/(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,greedy:!0},"builtin-target":{pattern:/\.[A-Z][^:#=\s]+(?=\s*:(?!=))/,alias:"builtin"},target:{pattern:/^(?:[^:=\s]|[ \t]+(?![\s:]))+(?=\s*:(?!=))/m,alias:"symbol",inside:{variable:/\$+(?:(?!\$)[^(){}:#=\s]+|(?=[({]))/}},variable:/\$+(?:(?!\$)[^(){}:#=\s]+|\([@*%<^+?][DF]\)|(?=[({]))/,keyword:/-include\b|\b(?:define|else|endef|endif|export|ifn?def|ifn?eq|include|override|private|sinclude|undefine|unexport|vpath)\b/,function:{pattern:/(\()(?:abspath|addsuffix|and|basename|call|dir|error|eval|file|filter(?:-out)?|findstring|firstword|flavor|foreach|guile|if|info|join|lastword|load|notdir|or|origin|patsubst|realpath|shell|sort|strip|subst|suffix|value|warning|wildcard|word(?:list|s)?)(?=[ \t])/,lookbehind:!0},operator:/(?:::|[?:+!])?=|[|@]/,punctuation:/[:;(){}]/}}Dg.displayName="mata";Dg.aliases=[];function Dg(e){(function(t){var n=/\b(?:(?:col|row)?vector|matrix|scalar)\b/.source,r=/\bvoid\b|<org>|\b(?:complex|numeric|pointer(?:\s*\([^()]*\))?|real|string|(?:class|struct)\s+\w+|transmorphic)(?:\s*<org>)?/.source.replace(/<org>/g,n);t.languages.mata={comment:{pattern:/\/\/.*|\/\*(?:[^*/]|\*(?!\/)|\/(?!\*)|\/\*(?:[^*]|\*(?!\/))*\*\/)*\*\//,greedy:!0},string:{pattern:/"[^"\r\n]*"|[‘`']".*?"[’`']/,greedy:!0},"class-name":{pattern:/(\b(?:class|extends|struct)\s+)\w+(?=\s*(?:\{|\bextends\b))/,lookbehind:!0},type:{pattern:RegExp(r),alias:"class-name",inside:{punctuation:/[()]/,keyword:/\b(?:class|function|struct|void)\b/}},keyword:/\b(?:break|class|continue|do|else|end|extends|external|final|for|function|goto|if|pragma|private|protected|public|return|static|struct|unset|unused|version|virtual|while)\b/,constant:/\bNULL\b/,number:{pattern:/(^|[^\w.])(?:\d+(?:\.\d+)?(?:e[+-]?\d+)?|\d[a-f0-9]*(?:\.[a-f0-9]+)?x[+-]?\d+)i?(?![\w.])/i,lookbehind:!0},missing:{pattern:/(^|[^\w.])(?:\.[a-z]?)(?![\w.])/,lookbehind:!0,alias:"symbol"},function:/\b[a-z_]\w*(?=\s*\()/i,operator:/\.\.|\+\+|--|&&|\|\||:?(?:[!=<>]=|[+\-*/^<>&|:])|[!?=\\#’`']/,punctuation:/[()[\]{},;.]/}})(e)}n4.displayName="matlab";n4.aliases=[];function n4(e){e.languages.matlab={comment:[/%\{[\s\S]*?\}%/,/%.+/],string:{pattern:/\B'(?:''|[^'\r\n])*'/,greedy:!0},number:/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[eE][+-]?\d+)?(?:[ij])?|\b[ij]\b/,keyword:/\b(?:NaN|break|case|catch|continue|else|elseif|end|for|function|if|inf|otherwise|parfor|pause|pi|return|switch|try|while)\b/,function:/\b(?!\d)\w+(?=\s*\()/,operator:/\.?[*^\/\\']|[+\-:@]|[<>=~]=?|&&?|\|\|?/,punctuation:/\.{3}|[.,;\[\](){}!]/}}r4.displayName="maxscript";r4.aliases=[];function r4(e){(function(t){var n=/\b(?:about|and|animate|as|at|attributes|by|case|catch|collect|continue|coordsys|do|else|exit|fn|for|from|function|global|if|in|local|macroscript|mapped|max|not|of|off|on|or|parameters|persistent|plugin|rcmenu|return|rollout|set|struct|then|throw|to|tool|try|undo|utility|when|where|while|with)\b/i;t.languages.maxscript={comment:{pattern:/\/\*[\s\S]*?(?:\*\/|$)|--.*/,greedy:!0},string:{pattern:/(^|[^"\\@])(?:"(?:[^"\\]|\\[\s\S])*"|@"[^"]*")/,lookbehind:!0,greedy:!0},path:{pattern:/\$(?:[\w/\\.*?]|'[^']*')*/,greedy:!0,alias:"string"},"function-call":{pattern:RegExp("((?:"+(/^/.source+"|"+/[;=<>+\-*/^({\[]/.source+"|"+/\b(?:and|by|case|catch|collect|do|else|if|in|not|or|return|then|to|try|where|while|with)\b/.source)+")[ 	]*)(?!"+n.source+")"+/[a-z_]\w*\b/.source+"(?=[ 	]*(?:"+("(?!"+n.source+")"+/[a-z_]/.source+"|"+/\d|-\.?\d/.source+"|"+/[({'"$@#?]/.source)+"))","im"),lookbehind:!0,greedy:!0,alias:"function"},"function-definition":{pattern:/(\b(?:fn|function)\s+)\w+\b/i,lookbehind:!0,alias:"function"},argument:{pattern:/\b[a-z_]\w*(?=:)/i,alias:"attr-name"},keyword:n,boolean:/\b(?:false|true)\b/,time:{pattern:/(^|[^\w.])(?:(?:(?:\d+(?:\.\d*)?|\.\d+)(?:[eEdD][+-]\d+|[LP])?[msft])+|\d+:\d+(?:\.\d*)?)(?![\w.:])/,lookbehind:!0,alias:"number"},number:[{pattern:/(^|[^\w.])(?:(?:\d+(?:\.\d*)?|\.\d+)(?:[eEdD][+-]\d+|[LP])?|0x[a-fA-F0-9]+)(?![\w.:])/,lookbehind:!0},/\b(?:e|pi)\b/],constant:/\b(?:dontcollect|ok|silentValue|undefined|unsupplied)\b/,color:{pattern:/\b(?:black|blue|brown|gray|green|orange|red|white|yellow)\b/i,alias:"constant"},operator:/[-+*/<>=!]=?|[&^?]|#(?!\()/,punctuation:/[()\[\]{}.:,;]|#(?=\()|\\$/m}})(e)}a4.displayName="mel";a4.aliases=[];function a4(e){e.languages.mel={comment:{pattern:/\/\/.*|\/\*[\s\S]*?\*\//,greedy:!0},code:{pattern:/`(?:\\.|[^\\`])*`/,greedy:!0,alias:"italic",inside:{delimiter:{pattern:/^`|`$/,alias:"punctuation"},statement:{pattern:/[\s\S]+/,inside:null}}},string:{pattern:/"(?:\\.|[^\\"\r\n])*"/,greedy:!0},variable:/\$\w+/,number:/\b0x[\da-fA-F]+\b|\b\d+(?:\.\d*)?|\B\.\d+/,flag:{pattern:/-[^\d\W]\w*/,alias:"operator"},keyword:/\b(?:break|case|continue|default|do|else|float|for|global|if|in|int|matrix|proc|return|string|switch|vector|while)\b/,function:{pattern:/((?:^|[{;])[ \t]*)[a-z_]\w*\b(?!\s*(?:\.(?!\.)|[[{=]))|\b[a-z_]\w*(?=[ \t]*\()/im,lookbehind:!0,greedy:!0},"tensor-punctuation":{pattern:/<<|>>/,alias:"punctuation"},operator:/\+[+=]?|-[-=]?|&&|\|\||[<>]=?|[*\/!=]=?|[%^]/,punctuation:/[.,:;?\[\](){}]/},e.languages.mel.code.inside.statement.inside=e.languages.mel}i4.displayName="mermaid";i4.aliases=[];function i4(e){e.languages.mermaid={comment:{pattern:/%%.*/,greedy:!0},style:{pattern:/^([ \t]*(?:classDef|linkStyle|style)[ \t]+[\w$-]+[ \t]+)\w.*[^\s;]/m,lookbehind:!0,inside:{property:/\b\w[\w-]*(?=[ \t]*:)/,operator:/:/,punctuation:/,/}},"inter-arrow-label":{pattern:/([^<>ox.=-])(?:-[-.]|==)(?![<>ox.=-])[ \t]*(?:"[^"\r\n]*"|[^\s".=-](?:[^\r\n.=-]*[^\s.=-])?)[ \t]*(?:\.+->?|--+[->]|==+[=>])(?![<>ox.=-])/,lookbehind:!0,greedy:!0,inside:{arrow:{pattern:/(?:\.+->?|--+[->]|==+[=>])$/,alias:"operator"},label:{pattern:/^([\s\S]{2}[ \t]*)\S(?:[\s\S]*\S)?/,lookbehind:!0,alias:"property"},"arrow-head":{pattern:/^\S+/,alias:["arrow","operator"]}}},arrow:[{pattern:/(^|[^{}|o.-])[|}][|o](?:--|\.\.)[|o][|{](?![{}|o.-])/,lookbehind:!0,alias:"operator"},{pattern:/(^|[^<>ox.=-])(?:[<ox](?:==+|--+|-\.*-)[>ox]?|(?:==+|--+|-\.*-)[>ox]|===+|---+|-\.+-)(?![<>ox.=-])/,lookbehind:!0,alias:"operator"},{pattern:/(^|[^<>()x-])(?:--?(?:>>|[x>)])(?![<>()x])|(?:<<|[x<(])--?(?!-))/,lookbehind:!0,alias:"operator"},{pattern:/(^|[^<>|*o.-])(?:[*o]--|--[*o]|<\|?(?:--|\.\.)|(?:--|\.\.)\|?>|--|\.\.)(?![<>|*o.-])/,lookbehind:!0,alias:"operator"}],label:{pattern:/(^|[^|<])\|(?:[^\r\n"|]|"[^"\r\n]*")+\|/,lookbehind:!0,greedy:!0,alias:"property"},text:{pattern:/(?:[(\[{]+|\b>)(?:[^\r\n"()\[\]{}]|"[^"\r\n]*")+(?:[)\]}]+|>)/,alias:"string"},string:{pattern:/"[^"\r\n]*"/,greedy:!0},annotation:{pattern:/<<(?:abstract|choice|enumeration|fork|interface|join|service)>>|\[\[(?:choice|fork|join)\]\]/i,alias:"important"},keyword:[{pattern:/(^[ \t]*)(?:action|callback|class|classDef|classDiagram|click|direction|erDiagram|flowchart|gantt|gitGraph|graph|journey|link|linkStyle|pie|requirementDiagram|sequenceDiagram|stateDiagram|stateDiagram-v2|style|subgraph)(?![\w$-])/m,lookbehind:!0,greedy:!0},{pattern:/(^[ \t]*)(?:activate|alt|and|as|autonumber|deactivate|else|end(?:[ \t]+note)?|loop|opt|par|participant|rect|state|note[ \t]+(?:over|(?:left|right)[ \t]+of))(?![\w$-])/im,lookbehind:!0,greedy:!0}],entity:/#[a-z0-9]+;/,operator:{pattern:/(\w[ \t]*)&(?=[ \t]*\w)|:::|:/,lookbehind:!0},punctuation:/[(){};]/}}o4.displayName="metafont";o4.aliases=[];function o4(e){e.languages.metafont={comment:{pattern:/%.*/,greedy:!0},string:{pattern:/"[^\r\n"]*"/,greedy:!0},number:/\d*\.?\d+/,boolean:/\b(?:false|true)\b/,punctuation:[/[,;()]/,{pattern:/(^|[^{}])(?:\{|\})(?![{}])/,lookbehind:!0},{pattern:/(^|[^[])\[(?!\[)/,lookbehind:!0},{pattern:/(^|[^\]])\](?!\])/,lookbehind:!0}],constant:[{pattern:/(^|[^!?])\?\?\?(?![!?])/,lookbehind:!0},{pattern:/(^|[^/*\\])(?:\\|\\\\)(?![/*\\])/,lookbehind:!0},/\b(?:_|blankpicture|bp|cc|cm|dd|ditto|down|eps|epsilon|fullcircle|halfcircle|identity|in|infinity|left|mm|nullpen|nullpicture|origin|pc|penrazor|penspeck|pensquare|penstroke|proof|pt|quartercircle|relax|right|smoke|unitpixel|unitsquare|up)\b/],quantity:{pattern:/\b(?:autorounding|blacker|boundarychar|charcode|chardp|chardx|chardy|charext|charht|charic|charwd|currentwindow|day|designsize|displaying|fillin|fontmaking|granularity|hppp|join_radius|month|o_correction|pausing|pen_(?:bot|lft|rt|top)|pixels_per_inch|proofing|showstopping|smoothing|time|tolerance|tracingcapsules|tracingchoices|tracingcommands|tracingedges|tracingequations|tracingmacros|tracingonline|tracingoutput|tracingpens|tracingrestores|tracingspecs|tracingstats|tracingtitles|turningcheck|vppp|warningcheck|xoffset|year|yoffset)\b/,alias:"keyword"},command:{pattern:/\b(?:addto|batchmode|charlist|cull|display|errhelp|errmessage|errorstopmode|everyjob|extensible|fontdimen|headerbyte|inner|interim|let|ligtable|message|newinternal|nonstopmode|numspecial|openwindow|outer|randomseed|save|scrollmode|shipout|show|showdependencies|showstats|showtoken|showvariable|special)\b/,alias:"builtin"},operator:[{pattern:/(^|[^>=<:|])(?:<|<=|=|=:|\|=:|\|=:>|=:\|>|=:\||\|=:\||\|=:\|>|\|=:\|>>|>|>=|:|:=|<>|::|\|\|:)(?![>=<:|])/,lookbehind:!0},{pattern:/(^|[^+-])(?:\+|\+\+|-{1,3}|\+-\+)(?![+-])/,lookbehind:!0},{pattern:/(^|[^/*\\])(?:\*|\*\*|\/)(?![/*\\])/,lookbehind:!0},{pattern:/(^|[^.])(?:\.{2,3})(?!\.)/,lookbehind:!0},{pattern:/(^|[^@#&$])&(?![@#&$])/,lookbehind:!0},/\b(?:and|not|or)\b/],macro:{pattern:/\b(?:abs|beginchar|bot|byte|capsule_def|ceiling|change_width|clear_pen_memory|clearit|clearpen|clearxy|counterclockwise|cullit|cutdraw|cutoff|decr|define_blacker_pixels|define_corrected_pixels|define_good_x_pixels|define_good_y_pixels|define_horizontal_corrected_pixels|define_pixels|define_whole_blacker_pixels|define_whole_pixels|define_whole_vertical_blacker_pixels|define_whole_vertical_pixels|dir|direction|directionpoint|div|dotprod|downto|draw|drawdot|endchar|erase|fill|filldraw|fix_units|flex|font_coding_scheme|font_extra_space|font_identifier|font_normal_shrink|font_normal_space|font_normal_stretch|font_quad|font_size|font_slant|font_x_height|gfcorners|gobble|gobbled|good\.(?:bot|lft|rt|top|x|y)|grayfont|hide|hround|imagerules|incr|interact|interpath|intersectionpoint|inverse|italcorr|killtext|labelfont|labels|lft|loggingall|lowres_fix|makegrid|makelabel(?:\.(?:bot|lft|rt|top)(?:\.nodot)?)?|max|min|mod|mode_def|mode_setup|nodisplays|notransforms|numtok|openit|penlabels|penpos|pickup|proofoffset|proofrule|proofrulethickness|range|reflectedabout|rotatedabout|rotatedaround|round|rt|savepen|screenchars|screenrule|screenstrokes|shipit|showit|slantfont|softjoin|solve|stop|superellipse|tensepath|thru|titlefont|top|tracingall|tracingnone|undraw|undrawdot|unfill|unfilldraw|upto|vround)\b/,alias:"function"},builtin:/\b(?:ASCII|angle|char|cosd|decimal|directiontime|floor|hex|intersectiontimes|jobname|known|length|makepath|makepen|mexp|mlog|normaldeviate|oct|odd|pencircle|penoffset|point|postcontrol|precontrol|reverse|rotated|sind|sqrt|str|subpath|substring|totalweight|turningnumber|uniformdeviate|unknown|xpart|xxpart|xypart|ypart|yxpart|yypart)\b/,keyword:/\b(?:also|at|atleast|begingroup|charexists|contour|controls|curl|cycle|def|delimiters|doublepath|dropping|dump|else|elseif|end|enddef|endfor|endgroup|endinput|exitif|exitunless|expandafter|fi|for|forever|forsuffixes|from|if|input|inwindow|keeping|kern|of|primarydef|quote|readstring|scaled|scantokens|secondarydef|shifted|skipto|slanted|step|tension|tertiarydef|to|transformed|until|vardef|withpen|withweight|xscaled|yscaled|zscaled)\b/,type:{pattern:/\b(?:boolean|expr|numeric|pair|path|pen|picture|primary|secondary|string|suffix|tertiary|text|transform)\b/,alias:"property"},variable:{pattern:/(^|[^@#&$])(?:@#|#@|#|@)(?![@#&$])|\b(?:aspect_ratio|currentpen|currentpicture|currenttransform|d|extra_beginchar|extra_endchar|extra_setup|h|localfont|mag|mode|screen_cols|screen_rows|w|whatever|x|y|z)\b/,lookbehind:!0}}}s4.displayName="mizar";s4.aliases=[];function s4(e){e.languages.mizar={comment:/::.+/,keyword:/@proof\b|\b(?:according|aggregate|all|and|antonym|are|as|associativity|assume|asymmetry|attr|be|begin|being|by|canceled|case|cases|clusters?|coherence|commutativity|compatibility|connectedness|consider|consistency|constructors|contradiction|correctness|def|deffunc|define|definitions?|defpred|do|does|end|environ|equals|ex|exactly|existence|for|from|func|given|hence|hereby|holds|idempotence|identity|iff?|implies|involutiveness|irreflexivity|is|it|let|means|mode|non|not|notations?|now|of|or|otherwise|over|per|pred|prefix|projectivity|proof|provided|qua|reconsider|redefine|reduce|reducibility|reflexivity|registrations?|requirements|reserve|sch|schemes?|section|selector|set|sethood|st|struct|such|suppose|symmetry|synonym|take|that|the|then|theorems?|thesis|thus|to|transitivity|uniqueness|vocabular(?:ies|y)|when|where|with|wrt)\b/,parameter:{pattern:/\$(?:10|\d)/,alias:"variable"},variable:/\b\w+(?=:)/,number:/(?:\b|-)\d+\b/,operator:/\.\.\.|->|&|\.?=/,punctuation:/\(#|#\)|[,:;\[\](){}]/}}l4.displayName="mongodb";l4.aliases=[];function l4(e){e.register(wr),(function(t){var n=["$eq","$gt","$gte","$in","$lt","$lte","$ne","$nin","$and","$not","$nor","$or","$exists","$type","$expr","$jsonSchema","$mod","$regex","$text","$where","$geoIntersects","$geoWithin","$near","$nearSphere","$all","$elemMatch","$size","$bitsAllClear","$bitsAllSet","$bitsAnyClear","$bitsAnySet","$comment","$elemMatch","$meta","$slice","$currentDate","$inc","$min","$max","$mul","$rename","$set","$setOnInsert","$unset","$addToSet","$pop","$pull","$push","$pullAll","$each","$position","$slice","$sort","$bit","$addFields","$bucket","$bucketAuto","$collStats","$count","$currentOp","$facet","$geoNear","$graphLookup","$group","$indexStats","$limit","$listLocalSessions","$listSessions","$lookup","$match","$merge","$out","$planCacheStats","$project","$redact","$replaceRoot","$replaceWith","$sample","$set","$skip","$sort","$sortByCount","$unionWith","$unset","$unwind","$setWindowFields","$abs","$accumulator","$acos","$acosh","$add","$addToSet","$allElementsTrue","$and","$anyElementTrue","$arrayElemAt","$arrayToObject","$asin","$asinh","$atan","$atan2","$atanh","$avg","$binarySize","$bsonSize","$ceil","$cmp","$concat","$concatArrays","$cond","$convert","$cos","$dateFromParts","$dateToParts","$dateFromString","$dateToString","$dayOfMonth","$dayOfWeek","$dayOfYear","$degreesToRadians","$divide","$eq","$exp","$filter","$first","$floor","$function","$gt","$gte","$hour","$ifNull","$in","$indexOfArray","$indexOfBytes","$indexOfCP","$isArray","$isNumber","$isoDayOfWeek","$isoWeek","$isoWeekYear","$last","$last","$let","$literal","$ln","$log","$log10","$lt","$lte","$ltrim","$map","$max","$mergeObjects","$meta","$min","$millisecond","$minute","$mod","$month","$multiply","$ne","$not","$objectToArray","$or","$pow","$push","$radiansToDegrees","$range","$reduce","$regexFind","$regexFindAll","$regexMatch","$replaceOne","$replaceAll","$reverseArray","$round","$rtrim","$second","$setDifference","$setEquals","$setIntersection","$setIsSubset","$setUnion","$size","$sin","$slice","$split","$sqrt","$stdDevPop","$stdDevSamp","$strcasecmp","$strLenBytes","$strLenCP","$substr","$substrBytes","$substrCP","$subtract","$sum","$switch","$tan","$toBool","$toDate","$toDecimal","$toDouble","$toInt","$toLong","$toObjectId","$toString","$toLower","$toUpper","$trim","$trunc","$type","$week","$year","$zip","$count","$dateAdd","$dateDiff","$dateSubtract","$dateTrunc","$getField","$rand","$sampleRate","$setField","$unsetField","$comment","$explain","$hint","$max","$maxTimeMS","$min","$orderby","$query","$returnKey","$showDiskLoc","$natural"],r=["ObjectId","Code","BinData","DBRef","Timestamp","NumberLong","NumberDecimal","MaxKey","MinKey","RegExp","ISODate","UUID"];n=n.map(function(i){return i.replace("$","\\$")});var a="(?:"+n.join("|")+")\\b";t.languages.mongodb=t.languages.extend("javascript",{}),t.languages.insertBefore("mongodb","string",{property:{pattern:/(?:(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1|(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)(?=\s*:)/,greedy:!0,inside:{keyword:RegExp(`^(['"])?`+a+"(?:\\1)?$")}}}),t.languages.mongodb.string.inside={url:{pattern:/https?:\/\/[-\w@:%.+~#=]{1,256}\.[a-z0-9()]{1,6}\b[-\w()@:%+.~#?&/=]*/i,greedy:!0},entity:{pattern:/\b(?:(?:[01]?\d\d?|2[0-4]\d|25[0-5])\.){3}(?:[01]?\d\d?|2[0-4]\d|25[0-5])\b/,greedy:!0}},t.languages.insertBefore("mongodb","constant",{builtin:{pattern:RegExp("\\b(?:"+r.join("|")+")\\b"),alias:"keyword"}})})(e)}c4.displayName="monkey";c4.aliases=[];function c4(e){e.languages.monkey={comment:{pattern:/^#Rem\s[\s\S]*?^#End|'.+/im,greedy:!0},string:{pattern:/"[^"\r\n]*"/,greedy:!0},preprocessor:{pattern:/(^[ \t]*)#.+/m,lookbehind:!0,greedy:!0,alias:"property"},function:/\b\w+(?=\()/,"type-char":{pattern:/\b[?%#$]/,alias:"class-name"},number:{pattern:/((?:\.\.)?)(?:(?:\b|\B-\.?|\B\.)\d+(?:(?!\.\.)\.\d*)?|\$[\da-f]+)/i,lookbehind:!0},keyword:/\b(?:Abstract|Array|Bool|Case|Catch|Class|Const|Continue|Default|Eachin|Else|ElseIf|End|EndIf|Exit|Extends|Extern|False|Field|Final|Float|For|Forever|Function|Global|If|Implements|Import|Inline|Int|Interface|Local|Method|Module|New|Next|Null|Object|Private|Property|Public|Repeat|Return|Select|Self|Step|Strict|String|Super|Then|Throw|To|True|Try|Until|Void|Wend|While)\b/i,operator:/\.\.|<[=>]?|>=?|:?=|(?:[+\-*\/&~|]|\b(?:Mod|Shl|Shr)\b)=?|\b(?:And|Not|Or)\b/i,punctuation:/[.,:;()\[\]]/}}u4.displayName="moonscript";u4.aliases=["moon"];function u4(e){e.languages.moonscript={comment:/--.*/,string:[{pattern:/'[^']*'|\[(=*)\[[\s\S]*?\]\1\]/,greedy:!0},{pattern:/"[^"]*"/,greedy:!0,inside:{interpolation:{pattern:/#\{[^{}]*\}/,inside:{moonscript:{pattern:/(^#\{)[\s\S]+(?=\})/,lookbehind:!0,inside:null},"interpolation-punctuation":{pattern:/#\{|\}/,alias:"punctuation"}}}}}],"class-name":[{pattern:/(\b(?:class|extends)[ \t]+)\w+/,lookbehind:!0},/\b[A-Z]\w*/],keyword:/\b(?:class|continue|do|else|elseif|export|extends|for|from|if|import|in|local|nil|return|self|super|switch|then|unless|using|when|while|with)\b/,variable:/@@?\w*/,property:{pattern:/\b(?!\d)\w+(?=:)|(:)(?!\d)\w+/,lookbehind:!0},function:{pattern:/\b(?:_G|_VERSION|assert|collectgarbage|coroutine\.(?:create|resume|running|status|wrap|yield)|debug\.(?:debug|getfenv|gethook|getinfo|getlocal|getmetatable|getregistry|getupvalue|setfenv|sethook|setlocal|setmetatable|setupvalue|traceback)|dofile|error|getfenv|getmetatable|io\.(?:close|flush|input|lines|open|output|popen|read|stderr|stdin|stdout|tmpfile|type|write)|ipairs|load|loadfile|loadstring|math\.(?:abs|acos|asin|atan|atan2|ceil|cos|cosh|deg|exp|floor|fmod|frexp|ldexp|log|log10|max|min|modf|pi|pow|rad|random|randomseed|sin|sinh|sqrt|tan|tanh)|module|next|os\.(?:clock|date|difftime|execute|exit|getenv|remove|rename|setlocale|time|tmpname)|package\.(?:cpath|loaded|loadlib|path|preload|seeall)|pairs|pcall|print|rawequal|rawget|rawset|require|select|setfenv|setmetatable|string\.(?:byte|char|dump|find|format|gmatch|gsub|len|lower|match|rep|reverse|sub|upper)|table\.(?:concat|insert|maxn|remove|sort)|tonumber|tostring|type|unpack|xpcall)\b/,inside:{punctuation:/\./}},boolean:/\b(?:false|true)\b/,number:/(?:\B\.\d+|\b\d+\.\d+|\b\d+(?=[eE]))(?:[eE][-+]?\d+)?\b|\b(?:0x[a-fA-F\d]+|\d+)(?:U?LL)?\b/,operator:/\.{3}|[-=]>|~=|(?:[-+*/%<>!=]|\.\.)=?|[:#^]|\b(?:and|or)\b=?|\b(?:not)\b/,punctuation:/[.,()[\]{}\\]/},e.languages.moonscript.string[1].inside.interpolation.inside.moonscript.inside=e.languages.moonscript,e.languages.moon=e.languages.moonscript}d4.displayName="n1ql";d4.aliases=[];function d4(e){e.languages.n1ql={comment:{pattern:/\/\*[\s\S]*?(?:$|\*\/)|--.*/,greedy:!0},string:{pattern:/(["'])(?:\\[\s\S]|(?!\1)[^\\]|\1\1)*\1/,greedy:!0},identifier:{pattern:/`(?:\\[\s\S]|[^\\`]|``)*`/,greedy:!0},parameter:/\$[\w.]+/,keyword:/\b(?:ADVISE|ALL|ALTER|ANALYZE|AS|ASC|AT|BEGIN|BINARY|BOOLEAN|BREAK|BUCKET|BUILD|BY|CALL|CAST|CLUSTER|COLLATE|COLLECTION|COMMIT|COMMITTED|CONNECT|CONTINUE|CORRELATE|CORRELATED|COVER|CREATE|CURRENT|DATABASE|DATASET|DATASTORE|DECLARE|DECREMENT|DELETE|DERIVED|DESC|DESCRIBE|DISTINCT|DO|DROP|EACH|ELEMENT|EXCEPT|EXCLUDE|EXECUTE|EXPLAIN|FETCH|FILTER|FLATTEN|FLUSH|FOLLOWING|FOR|FORCE|FROM|FTS|FUNCTION|GOLANG|GRANT|GROUP|GROUPS|GSI|HASH|HAVING|IF|IGNORE|ILIKE|INCLUDE|INCREMENT|INDEX|INFER|INLINE|INNER|INSERT|INTERSECT|INTO|IS|ISOLATION|JAVASCRIPT|JOIN|KEY|KEYS|KEYSPACE|KNOWN|LANGUAGE|LAST|LEFT|LET|LETTING|LEVEL|LIMIT|LSM|MAP|MAPPING|MATCHED|MATERIALIZED|MERGE|MINUS|MISSING|NAMESPACE|NEST|NL|NO|NTH_VALUE|NULL|NULLS|NUMBER|OBJECT|OFFSET|ON|OPTION|OPTIONS|ORDER|OTHERS|OUTER|OVER|PARSE|PARTITION|PASSWORD|PATH|POOL|PRECEDING|PREPARE|PRIMARY|PRIVATE|PRIVILEGE|PROBE|PROCEDURE|PUBLIC|RANGE|RAW|REALM|REDUCE|RENAME|RESPECT|RETURN|RETURNING|REVOKE|RIGHT|ROLE|ROLLBACK|ROW|ROWS|SATISFIES|SAVEPOINT|SCHEMA|SCOPE|SELECT|SELF|SEMI|SET|SHOW|SOME|START|STATISTICS|STRING|SYSTEM|TIES|TO|TRAN|TRANSACTION|TRIGGER|TRUNCATE|UNBOUNDED|UNDER|UNION|UNIQUE|UNKNOWN|UNNEST|UNSET|UPDATE|UPSERT|USE|USER|USING|VALIDATE|VALUE|VALUES|VIA|VIEW|WHERE|WHILE|WINDOW|WITH|WORK|XOR)\b/i,function:/\b[a-z_]\w*(?=\s*\()/i,boolean:/\b(?:FALSE|TRUE)\b/i,number:/(?:\b\d+\.|\B\.)\d+e[+\-]?\d+\b|\b\d+(?:\.\d*)?|\B\.\d+\b/i,operator:/[-+*\/%]|!=|==?|\|\||<[>=]?|>=?|\b(?:AND|ANY|ARRAY|BETWEEN|CASE|ELSE|END|EVERY|EXISTS|FIRST|IN|LIKE|NOT|OR|THEN|VALUED|WHEN|WITHIN)\b/i,punctuation:/[;[\](),.{}:]/}}h4.displayName="nand2tetris-hdl";h4.aliases=[];function h4(e){e.languages["nand2tetris-hdl"]={comment:/\/\/.*|\/\*[\s\S]*?(?:\*\/|$)/,keyword:/\b(?:BUILTIN|CHIP|CLOCKED|IN|OUT|PARTS)\b/,boolean:/\b(?:false|true)\b/,function:/\b[A-Za-z][A-Za-z0-9]*(?=\()/,number:/\b\d+\b/,operator:/=|\.\./,punctuation:/[{}[\];(),:]/}}p4.displayName="naniscript";p4.aliases=["nani"];function p4(e){(function(t){var n=/\{[^\r\n\[\]{}]*\}/,r={"quoted-string":{pattern:/"(?:[^"\\]|\\.)*"/,alias:"operator"},"command-param-id":{pattern:/(\s)\w+:/,lookbehind:!0,alias:"property"},"command-param-value":[{pattern:n,alias:"selector"},{pattern:/([\t ])\S+/,lookbehind:!0,greedy:!0,alias:"operator"},{pattern:/\S(?:.*\S)?/,alias:"operator"}]};t.languages.naniscript={comment:{pattern:/^([\t ]*);.*/m,lookbehind:!0},define:{pattern:/^>.+/m,alias:"tag",inside:{value:{pattern:/(^>\w+[\t ]+)(?!\s)[^{}\r\n]+/,lookbehind:!0,alias:"operator"},key:{pattern:/(^>)\w+/,lookbehind:!0}}},label:{pattern:/^([\t ]*)#[\t ]*\w+[\t ]*$/m,lookbehind:!0,alias:"regex"},command:{pattern:/^([\t ]*)@\w+(?=[\t ]|$).*/m,lookbehind:!0,alias:"function",inside:{"command-name":/^@\w+/,expression:{pattern:n,greedy:!0,alias:"selector"},"command-params":{pattern:/\s*\S[\s\S]*/,inside:r}}},"generic-text":{pattern:/(^[ \t]*)[^#@>;\s].*/m,lookbehind:!0,alias:"punctuation",inside:{"escaped-char":/\\[{}\[\]"]/,expression:{pattern:n,greedy:!0,alias:"selector"},"inline-command":{pattern:/\[[\t ]*\w[^\r\n\[\]]*\]/,greedy:!0,alias:"function",inside:{"command-params":{pattern:/(^\[[\t ]*\w+\b)[\s\S]+(?=\]$)/,lookbehind:!0,inside:r},"command-param-name":{pattern:/^(\[[\t ]*)\w+/,lookbehind:!0,alias:"name"},"start-stop-char":/[\[\]]/}}}}},t.languages.nani=t.languages.naniscript,t.hooks.add("after-tokenize",function(o){var l=o.tokens;l.forEach(function(u){if(typeof u!="string"&&u.type==="generic-text"){var d=i(u);a(d)||(u.type="bad-line",u.content=d)}})});function a(o){for(var l="[]{}",u=[],d=0;d<o.length;d++){var h=o[d],f=l.indexOf(h);if(f!==-1){if(f%2===0)u.push(f+1);else if(u.pop()!==f)return!1}}return u.length===0}function i(o){return typeof o=="string"?o:Array.isArray(o)?o.map(i).join(""):i(o.content)}})(e)}f4.displayName="nasm";f4.aliases=[];function f4(e){e.languages.nasm={comment:/;.*$/m,string:/(["'`])(?:\\.|(?!\1)[^\\\r\n])*\1/,label:{pattern:/(^\s*)[A-Za-z._?$][\w.?$@~#]*:/m,lookbehind:!0,alias:"function"},keyword:[/\[?BITS (?:16|32|64)\]?/,{pattern:/(^\s*)section\s*[a-z.]+:?/im,lookbehind:!0},/(?:extern|global)[^;\r\n]*/i,/(?:CPU|DEFAULT|FLOAT).*$/m],register:{pattern:/\b(?:st\d|[xyz]mm\d\d?|[cdt]r\d|r\d\d?[bwd]?|[er]?[abcd]x|[abcd][hl]|[er]?(?:bp|di|si|sp)|[cdefgs]s)\b/i,alias:"variable"},number:/(?:\b|(?=\$))(?:0[hx](?:\.[\da-f]+|[\da-f]+(?:\.[\da-f]+)?)(?:p[+-]?\d+)?|\d[\da-f]+[hx]|\$\d[\da-f]*|0[oq][0-7]+|[0-7]+[oq]|0[by][01]+|[01]+[by]|0[dt]\d+|(?:\d+(?:\.\d+)?|\.\d+)(?:\.?e[+-]?\d+)?[dt]?)\b/i,operator:/[\[\]*+\-\/%<>=&|$!]/}}m4.displayName="neon";m4.aliases=[];function m4(e){e.languages.neon={comment:{pattern:/#.*/,greedy:!0},datetime:{pattern:/(^|[[{(=:,\s])\d\d\d\d-\d\d?-\d\d?(?:(?:[Tt]| +)\d\d?:\d\d:\d\d(?:\.\d*)? *(?:Z|[-+]\d\d?(?::?\d\d)?)?)?(?=$|[\]}),\s])/,lookbehind:!0,alias:"number"},key:{pattern:/(^|[[{(,\s])[^,:=[\]{}()'"\s]+(?=\s*:(?:$|[\]}),\s])|\s*=)/,lookbehind:!0,alias:"property"},number:{pattern:/(^|[[{(=:,\s])[+-]?(?:0x[\da-fA-F]+|0o[0-7]+|0b[01]+|(?:\d+(?:\.\d*)?|\.?\d+)(?:[eE][+-]?\d+)?)(?=$|[\]}),:=\s])/,lookbehind:!0},boolean:{pattern:/(^|[[{(=:,\s])(?:false|no|true|yes)(?=$|[\]}),:=\s])/i,lookbehind:!0},null:{pattern:/(^|[[{(=:,\s])(?:null)(?=$|[\]}),:=\s])/i,lookbehind:!0,alias:"keyword"},string:{pattern:/(^|[[{(=:,\s])(?:('''|""")\r?\n(?:(?:[^\r\n]|\r?\n(?![\t ]*\2))*\r?\n)?[\t ]*\2|'[^'\r\n]*'|"(?:\\.|[^\\"\r\n])*")/,lookbehind:!0,greedy:!0},literal:{pattern:/(^|[[{(=:,\s])(?:[^#"',:=[\]{}()\s`-]|[:-][^"',=[\]{}()\s])(?:[^,:=\]})(\s]|:(?![\s,\]})]|$)|[ \t]+[^#,:=\]})(\s])*/,lookbehind:!0,alias:"string"},punctuation:/[,:=[\]{}()-]/}}g4.displayName="nevod";g4.aliases=[];function g4(e){e.languages.nevod={comment:/\/\/.*|(?:\/\*[\s\S]*?(?:\*\/|$))/,string:{pattern:/(?:"(?:""|[^"])*"(?!")|'(?:''|[^'])*'(?!'))!?\*?/,greedy:!0,inside:{"string-attrs":/!$|!\*$|\*$/}},namespace:{pattern:/(@namespace\s+)[a-zA-Z0-9\-.]+(?=\s*\{)/,lookbehind:!0},pattern:{pattern:/(@pattern\s+)?#?[a-zA-Z0-9\-.]+(?:\s*\(\s*(?:~\s*)?[a-zA-Z0-9\-.]+\s*(?:,\s*(?:~\s*)?[a-zA-Z0-9\-.]*)*\))?(?=\s*=)/,lookbehind:!0,inside:{"pattern-name":{pattern:/^#?[a-zA-Z0-9\-.]+/,alias:"class-name"},fields:{pattern:/\(.*\)/,inside:{"field-name":{pattern:/[a-zA-Z0-9\-.]+/,alias:"variable"},punctuation:/[,()]/,operator:{pattern:/~/,alias:"field-hidden-mark"}}}}},search:{pattern:/(@search\s+|#)[a-zA-Z0-9\-.]+(?:\.\*)?(?=\s*;)/,alias:"function",lookbehind:!0},keyword:/@(?:having|inside|namespace|outside|pattern|require|search|where)\b/,"standard-pattern":{pattern:/\b(?:Alpha|AlphaNum|Any|Blank|End|LineBreak|Num|NumAlpha|Punct|Space|Start|Symbol|Word|WordBreak)\b(?:\([a-zA-Z0-9\-.,\s+]*\))?/,inside:{"standard-pattern-name":{pattern:/^[a-zA-Z0-9\-.]+/,alias:"builtin"},quantifier:{pattern:/\b\d+(?:\s*\+|\s*-\s*\d+)?(?!\w)/,alias:"number"},"standard-pattern-attr":{pattern:/[a-zA-Z0-9\-.]+/,alias:"builtin"},punctuation:/[,()]/}},quantifier:{pattern:/\b\d+(?:\s*\+|\s*-\s*\d+)?(?!\w)/,alias:"number"},operator:[{pattern:/=/,alias:"pattern-def"},{pattern:/&/,alias:"conjunction"},{pattern:/~/,alias:"exception"},{pattern:/\?/,alias:"optionality"},{pattern:/[[\]]/,alias:"repetition"},{pattern:/[{}]/,alias:"variation"},{pattern:/[+_]/,alias:"sequence"},{pattern:/\.{2,3}/,alias:"span"}],"field-capture":[{pattern:/([a-zA-Z0-9\-.]+\s*\()\s*[a-zA-Z0-9\-.]+\s*:\s*[a-zA-Z0-9\-.]+(?:\s*,\s*[a-zA-Z0-9\-.]+\s*:\s*[a-zA-Z0-9\-.]+)*(?=\s*\))/,lookbehind:!0,inside:{"field-name":{pattern:/[a-zA-Z0-9\-.]+/,alias:"variable"},colon:/:/}},{pattern:/[a-zA-Z0-9\-.]+\s*:/,inside:{"field-name":{pattern:/[a-zA-Z0-9\-.]+/,alias:"variable"},colon:/:/}}],punctuation:/[:;,()]/,name:/[a-zA-Z0-9\-.]+/}}b4.displayName="nginx";b4.aliases=[];function b4(e){(function(t){var n=/\$(?:\w[a-z\d]*(?:_[^\x00-\x1F\s"'\\()$]*)?|\{[^}\s"'\\]+\})/i;t.languages.nginx={comment:{pattern:/(^|[\s{};])#.*/,lookbehind:!0,greedy:!0},directive:{pattern:/(^|\s)\w(?:[^;{}"'\\\s]|\\.|"(?:[^"\\]|\\.)*"|'(?:[^'\\]|\\.)*'|\s+(?:#.*(?!.)|(?![#\s])))*?(?=\s*[;{])/,lookbehind:!0,greedy:!0,inside:{string:{pattern:/((?:^|[^\\])(?:\\\\)*)(?:"(?:[^"\\]|\\.)*"|'(?:[^'\\]|\\.)*')/,lookbehind:!0,greedy:!0,inside:{escape:{pattern:/\\["'\\nrt]/,alias:"entity"},variable:n}},comment:{pattern:/(\s)#.*/,lookbehind:!0,greedy:!0},keyword:{pattern:/^\S+/,greedy:!0},boolean:{pattern:/(\s)(?:off|on)(?!\S)/,lookbehind:!0},number:{pattern:/(\s)\d+[a-z]*(?!\S)/i,lookbehind:!0},variable:n}},punctuation:/[{};]/}})(e)}y4.displayName="nim";y4.aliases=[];function y4(e){e.languages.nim={comment:{pattern:/#.*/,greedy:!0},string:{pattern:/(?:\b(?!\d)(?:\w|\\x[89a-fA-F][0-9a-fA-F])+)?(?:"""[\s\S]*?"""(?!")|"(?:\\[\s\S]|""|[^"\\])*")/,greedy:!0},char:{pattern:/'(?:\\(?:\d+|x[\da-fA-F]{0,2}|.)|[^'])'/,greedy:!0},function:{pattern:/(?:(?!\d)(?:\w|\\x[89a-fA-F][0-9a-fA-F])+|`[^`\r\n]+`)\*?(?:\[[^\]]+\])?(?=\s*\()/,greedy:!0,inside:{operator:/\*$/}},identifier:{pattern:/`[^`\r\n]+`/,greedy:!0,inside:{punctuation:/`/}},number:/\b(?:0[xXoObB][\da-fA-F_]+|\d[\d_]*(?:(?!\.\.)\.[\d_]*)?(?:[eE][+-]?\d[\d_]*)?)(?:'?[iuf]\d*)?/,keyword:/\b(?:addr|as|asm|atomic|bind|block|break|case|cast|concept|const|continue|converter|defer|discard|distinct|do|elif|else|end|enum|except|export|finally|for|from|func|generic|if|import|include|interface|iterator|let|macro|method|mixin|nil|object|out|proc|ptr|raise|ref|return|static|template|try|tuple|type|using|var|when|while|with|without|yield)\b/,operator:{pattern:/(^|[({\[](?=\.\.)|(?![({\[]\.).)(?:(?:[=+\-*\/<>@$~&%|!?^:\\]|\.\.|\.(?![)}\]]))+|\b(?:and|div|in|is|isnot|mod|not|notin|of|or|shl|shr|xor)\b)/m,lookbehind:!0},punctuation:/[({\[]\.|\.[)}\]]|[`(){}\[\],:]/}}v4.displayName="nix";v4.aliases=[];function v4(e){e.languages.nix={comment:{pattern:/\/\*[\s\S]*?\*\/|#.*/,greedy:!0},string:{pattern:/"(?:[^"\\]|\\[\s\S])*"|''(?:(?!'')[\s\S]|''(?:'|\\|\$\{))*''/,greedy:!0,inside:{interpolation:{pattern:/(^|(?:^|(?!'').)[^\\])\$\{(?:[^{}]|\{[^}]*\})*\}/,lookbehind:!0,inside:null}}},url:[/\b(?:[a-z]{3,7}:\/\/)[\w\-+%~\/.:#=?&]+/,{pattern:/([^\/])(?:[\w\-+%~.:#=?&]*(?!\/\/)[\w\-+%~\/.:#=?&])?(?!\/\/)\/[\w\-+%~\/.:#=?&]*/,lookbehind:!0}],antiquotation:{pattern:/\$(?=\{)/,alias:"important"},number:/\b\d+\b/,keyword:/\b(?:assert|builtins|else|if|in|inherit|let|null|or|then|with)\b/,function:/\b(?:abort|add|all|any|attrNames|attrValues|baseNameOf|compareVersions|concatLists|currentSystem|deepSeq|derivation|dirOf|div|elem(?:At)?|fetch(?:Tarball|url)|filter(?:Source)?|fromJSON|genList|getAttr|getEnv|hasAttr|hashString|head|import|intersectAttrs|is(?:Attrs|Bool|Function|Int|List|Null|String)|length|lessThan|listToAttrs|map|mul|parseDrvName|pathExists|read(?:Dir|File)|removeAttrs|replaceStrings|seq|sort|stringLength|sub(?:string)?|tail|throw|to(?:File|JSON|Path|String|XML)|trace|typeOf)\b|\bfoldl'\B/,boolean:/\b(?:false|true)\b/,operator:/[=!<>]=?|\+\+?|\|\||&&|\/\/|->?|[?@]/,punctuation:/[{}()[\].,:;]/},e.languages.nix.string.inside.interpolation.inside=e.languages.nix}x4.displayName="nsis";x4.aliases=[];function x4(e){e.languages.nsis={comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?\*\/|[#;].*)/,lookbehind:!0,greedy:!0},string:{pattern:/("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0},keyword:{pattern:/(^[\t ]*)(?:Abort|Add(?:BrandingImage|Size)|AdvSplash|Allow(?:RootDirInstall|SkipFiles)|AutoCloseWindow|BG(?:Font|Gradient|Image)|Banner|BrandingText|BringToFront|CRCCheck|Call(?:InstDLL)?|Caption|ChangeUI|CheckBitmap|ClearErrors|CompletedText|ComponentText|CopyFiles|Create(?:Directory|Font|ShortCut)|Delete(?:INISec|INIStr|RegKey|RegValue)?|Detail(?:Print|sButtonText)|Dialer|Dir(?:Text|Var|Verify)|EnableWindow|Enum(?:RegKey|RegValue)|Exch|Exec(?:Shell(?:Wait)?|Wait)?|ExpandEnvStrings|File(?:BufSize|Close|ErrorText|Open|Read|ReadByte|ReadUTF16LE|ReadWord|Seek|Write|WriteByte|WriteUTF16LE|WriteWord)?|Find(?:Close|First|Next|Window)|FlushINI|Get(?:CurInstType|CurrentAddress|DLLVersion(?:Local)?|DlgItem|ErrorLevel|FileTime(?:Local)?|FullPathName|Function(?:Address|End)?|InstDirError|KnownFolderPath|LabelAddress|TempFileName|WinVer)|Goto|HideWindow|Icon|If(?:Abort|Errors|FileExists|RebootFlag|RtlLanguage|ShellVarContextAll|Silent)|InitPluginsDir|InstProgressFlags|Inst(?:Type(?:GetText|SetText)?)|Install(?:ButtonText|Colors|Dir(?:RegKey)?)|Int(?:64|Ptr)?CmpU?|Int(?:64)?Fmt|Int(?:Ptr)?Op|IsWindow|Lang(?:DLL|String)|License(?:BkColor|Data|ForceSelection|LangString|Text)|LoadLanguageFile|LockWindow|Log(?:Set|Text)|Manifest(?:DPIAware|SupportedOS)|Math|MessageBox|MiscButtonText|NSISdl|Name|Nop|OutFile|PE(?:DllCharacteristics|SubsysVer)|Page(?:Callbacks)?|Pop|Push|Quit|RMDir|Read(?:EnvStr|INIStr|RegDWORD|RegStr)|Reboot|RegDLL|Rename|RequestExecutionLevel|ReserveFile|Return|SearchPath|Section(?:End|GetFlags|GetInstTypes|GetSize|GetText|Group|In|SetFlags|SetInstTypes|SetSize|SetText)?|SendMessage|Set(?:AutoClose|BrandingImage|Compress|Compressor(?:DictSize)?|CtlColors|CurInstType|DatablockOptimize|DateSave|Details(?:Print|View)|ErrorLevel|Errors|FileAttributes|Font|OutPath|Overwrite|PluginUnload|RebootFlag|RegView|ShellVarContext|Silent)|Show(?:InstDetails|UninstDetails|Window)|Silent(?:Install|UnInstall)|Sleep|SpaceTexts|Splash|StartMenu|Str(?:CmpS?|Cpy|Len)|SubCaption|System|Target|UnRegDLL|Unicode|UninstPage|Uninstall(?:ButtonText|Caption|Icon|SubCaption|Text)|UserInfo|VI(?:AddVersionKey|FileVersion|ProductVersion)|VPatch|Var|WindowIcon|Write(?:INIStr|Reg(?:Bin|DWORD|ExpandStr|MultiStr|None|Str)|Uninstaller)|XPStyle|ns(?:Dialogs|Exec))\b/m,lookbehind:!0},property:/\b(?:ARCHIVE|FILE_(?:ATTRIBUTE_ARCHIVE|ATTRIBUTE_NORMAL|ATTRIBUTE_OFFLINE|ATTRIBUTE_READONLY|ATTRIBUTE_SYSTEM|ATTRIBUTE_TEMPORARY)|HK(?:(?:CR|CU|LM)(?:32|64)?|DD|PD|U)|HKEY_(?:CLASSES_ROOT|CURRENT_CONFIG|CURRENT_USER|DYN_DATA|LOCAL_MACHINE|PERFORMANCE_DATA|USERS)|ID(?:ABORT|CANCEL|IGNORE|NO|OK|RETRY|YES)|MB_(?:ABORTRETRYIGNORE|DEFBUTTON1|DEFBUTTON2|DEFBUTTON3|DEFBUTTON4|ICONEXCLAMATION|ICONINFORMATION|ICONQUESTION|ICONSTOP|OK|OKCANCEL|RETRYCANCEL|RIGHT|RTLREADING|SETFOREGROUND|TOPMOST|USERICON|YESNO)|NORMAL|OFFLINE|READONLY|SHCTX|SHELL_CONTEXT|SYSTEM|TEMPORARY|admin|all|auto|both|colored|false|force|hide|highest|lastused|leave|listonly|none|normal|notset|off|on|open|print|show|silent|silentlog|smooth|textonly|true|user)\b/,constant:/\$\{[!\w\.:\^-]+\}|\$\([!\w\.:\^-]+\)/,variable:/\$\w[\w\.]*/,number:/\b0x[\dA-Fa-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee]-?\d+)?/,operator:/--?|\+\+?|<=?|>=?|==?=?|&&?|\|\|?|[?*\/~^%]/,punctuation:/[{}[\];(),.:]/,important:{pattern:/(^[\t ]*)!(?:addincludedir|addplugindir|appendfile|cd|define|delfile|echo|else|endif|error|execute|finalize|getdllversion|gettlbversion|if|ifdef|ifmacrodef|ifmacrondef|ifndef|include|insertmacro|macro|macroend|makensis|packhdr|pragma|searchparse|searchreplace|system|tempfile|undef|verbose|warning)\b/im,lookbehind:!0}}}S4.displayName="objectivec";S4.aliases=["objc"];function S4(e){e.register($i),e.languages.objectivec=e.languages.extend("c",{string:{pattern:/@?"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"/,greedy:!0},keyword:/\b(?:asm|auto|break|case|char|const|continue|default|do|double|else|enum|extern|float|for|goto|if|in|inline|int|long|register|return|self|short|signed|sizeof|static|struct|super|switch|typedef|typeof|union|unsigned|void|volatile|while)\b|(?:@interface|@end|@implementation|@protocol|@class|@public|@protected|@private|@property|@try|@catch|@finally|@throw|@synthesize|@dynamic|@selector)\b/,operator:/-[->]?|\+\+?|!=?|<<?=?|>>?=?|==?|&&?|\|\|?|[~^%?*\/@]/}),delete e.languages.objectivec["class-name"],e.languages.objc=e.languages.objectivec}w4.displayName="ocaml";w4.aliases=[];function w4(e){e.languages.ocaml={comment:{pattern:/\(\*[\s\S]*?\*\)/,greedy:!0},char:{pattern:/'(?:[^\\\r\n']|\\(?:.|[ox]?[0-9a-f]{1,3}))'/i,greedy:!0},string:[{pattern:/"(?:\\(?:[\s\S]|\r\n)|[^\\\r\n"])*"/,greedy:!0},{pattern:/\{([a-z_]*)\|[\s\S]*?\|\1\}/,greedy:!0}],number:[/\b(?:0b[01][01_]*|0o[0-7][0-7_]*)\b/i,/\b0x[a-f0-9][a-f0-9_]*(?:\.[a-f0-9_]*)?(?:p[+-]?\d[\d_]*)?(?!\w)/i,/\b\d[\d_]*(?:\.[\d_]*)?(?:e[+-]?\d[\d_]*)?(?!\w)/i],directive:{pattern:/\B#\w+/,alias:"property"},label:{pattern:/\B~\w+/,alias:"property"},"type-variable":{pattern:/\B'\w+/,alias:"function"},variant:{pattern:/`\w+/,alias:"symbol"},keyword:/\b(?:as|assert|begin|class|constraint|do|done|downto|else|end|exception|external|for|fun|function|functor|if|in|include|inherit|initializer|lazy|let|match|method|module|mutable|new|nonrec|object|of|open|private|rec|sig|struct|then|to|try|type|val|value|virtual|when|where|while|with)\b/,boolean:/\b(?:false|true)\b/,"operator-like-punctuation":{pattern:/\[[<>|]|[>|]\]|\{<|>\}/,alias:"punctuation"},operator:/\.[.~]|:[=>]|[=<>@^|&+\-*\/$%!?~][!$%&*+\-.\/:<=>?@^|~]*|\b(?:and|asr|land|lor|lsl|lsr|lxor|mod|or)\b/,punctuation:/;;|::|[(){}\[\].,:;#]|\b_\b/}}E4.displayName="odin";E4.aliases=[];function E4(e){(function(t){var n=/\\(?:["'\\abefnrtv]|0[0-7]{2}|U[\dA-Fa-f]{6}|u[\dA-Fa-f]{4}|x[\dA-Fa-f]{2})/;t.languages.odin={comment:[{pattern:/\/\*(?:[^/*]|\/(?!\*)|\*(?!\/)|\/\*(?:\*(?!\/)|[^*])*(?:\*\/|$))*(?:\*\/|$)/,greedy:!0},{pattern:/#![^\n\r]*/,greedy:!0},{pattern:/\/\/[^\n\r]*/,greedy:!0}],char:{pattern:/'(?:\\(?:.|[0Uux][0-9A-Fa-f]{1,6})|[^\n\r'\\])'/,greedy:!0,inside:{symbol:n}},string:[{pattern:/`[^`]*`/,greedy:!0},{pattern:/"(?:\\.|[^\n\r"\\])*"/,greedy:!0,inside:{symbol:n}}],directive:{pattern:/#\w+/,alias:"property"},number:/\b0(?:b[01_]+|d[\d_]+|h_*(?:(?:(?:[\dA-Fa-f]_*){8}){1,2}|(?:[\dA-Fa-f]_*){4})|o[0-7_]+|x[\dA-F_a-f]+|z[\dAB_ab]+)\b|(?:\b\d+(?:\.(?!\.)\d*)?|\B\.\d+)(?:[Ee][+-]?\d*)?[ijk]?(?!\w)/,discard:{pattern:/\b_\b/,alias:"keyword"},"procedure-definition":{pattern:/\b\w+(?=[ \t]*(?::\s*){2}proc\b)/,alias:"function"},keyword:/\b(?:asm|auto_cast|bit_set|break|case|cast|context|continue|defer|distinct|do|dynamic|else|enum|fallthrough|for|foreign|if|import|in|map|matrix|not_in|or_else|or_return|package|proc|return|struct|switch|transmute|typeid|union|using|when|where)\b/,"procedure-name":{pattern:/\b\w+(?=[ \t]*\()/,alias:"function"},boolean:/\b(?:false|nil|true)\b/,"constant-parameter-sign":{pattern:/\$/,alias:"important"},undefined:{pattern:/---/,alias:"operator"},arrow:{pattern:/->/,alias:"punctuation"},operator:/\+\+|--|\.\.[<=]?|(?:&~|[-!*+/=~]|[%&<>|]{1,2})=?|[?^]/,punctuation:/[(),.:;@\[\]{}]/}})(e)}k4.displayName="opencl";k4.aliases=[];function k4(e){e.register($i),(function(t){t.languages.opencl=t.languages.extend("c",{keyword:/\b(?:(?:__)?(?:constant|global|kernel|local|private|read_only|read_write|write_only)|__attribute__|auto|(?:bool|u?(?:char|int|long|short)|half|quad)(?:2|3|4|8|16)?|break|case|complex|const|continue|(?:double|float)(?:16(?:x(?:1|2|4|8|16))?|1x(?:1|2|4|8|16)|2(?:x(?:1|2|4|8|16))?|3|4(?:x(?:1|2|4|8|16))?|8(?:x(?:1|2|4|8|16))?)?|default|do|else|enum|extern|for|goto|if|imaginary|inline|packed|pipe|register|restrict|return|signed|sizeof|static|struct|switch|typedef|uniform|union|unsigned|void|volatile|while)\b/,number:/(?:\b0x(?:[\da-f]+(?:\.[\da-f]*)?|\.[\da-f]+)(?:p[+-]?\d+)?|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?)[fuhl]{0,4}/i,boolean:/\b(?:false|true)\b/,"constant-opencl-kernel":{pattern:/\b(?:CHAR_(?:BIT|MAX|MIN)|CLK_(?:ADDRESS_(?:CLAMP(?:_TO_EDGE)?|NONE|REPEAT)|FILTER_(?:LINEAR|NEAREST)|(?:GLOBAL|LOCAL)_MEM_FENCE|NORMALIZED_COORDS_(?:FALSE|TRUE))|CL_(?:BGRA|(?:HALF_)?FLOAT|INTENSITY|LUMINANCE|A?R?G?B?[Ax]?|(?:(?:UN)?SIGNED|[US]NORM)_(?:INT(?:8|16|32))|UNORM_(?:INT_101010|SHORT_(?:555|565)))|(?:DBL|FLT|HALF)_(?:DIG|EPSILON|(?:MAX|MIN)(?:(?:_10)?_EXP)?|MANT_DIG)|FLT_RADIX|HUGE_VALF?|(?:INT|LONG|SCHAR|SHRT)_(?:MAX|MIN)|INFINITY|MAXFLOAT|M_(?:[12]_PI|2_SQRTPI|E|LN(?:2|10)|LOG(?:2|10)E?|PI(?:_[24])?|SQRT(?:1_2|2))(?:_F|_H)?|NAN|(?:UCHAR|UINT|ULONG|USHRT)_MAX)\b/,alias:"constant"}}),t.languages.insertBefore("opencl","class-name",{"builtin-type":{pattern:/\b(?:_cl_(?:command_queue|context|device_id|event|kernel|mem|platform_id|program|sampler)|cl_(?:image_format|mem_fence_flags)|clk_event_t|event_t|image(?:1d_(?:array_|buffer_)?t|2d_(?:array_(?:depth_|msaa_depth_|msaa_)?|depth_|msaa_depth_|msaa_)?t|3d_t)|intptr_t|ndrange_t|ptrdiff_t|queue_t|reserve_id_t|sampler_t|size_t|uintptr_t)\b/,alias:"keyword"}});var n={"type-opencl-host":{pattern:/\b(?:cl_(?:GLenum|GLint|GLuin|addressing_mode|bitfield|bool|buffer_create_type|build_status|channel_(?:order|type)|(?:u?(?:char|int|long|short)|double|float)(?:2|3|4|8|16)?|command_(?:queue(?:_info|_properties)?|type)|context(?:_info|_properties)?|device_(?:exec_capabilities|fp_config|id|info|local_mem_type|mem_cache_type|type)|(?:event|sampler)(?:_info)?|filter_mode|half|image_info|kernel(?:_info|_work_group_info)?|map_flags|mem(?:_flags|_info|_object_type)?|platform_(?:id|info)|profiling_info|program(?:_build_info|_info)?))\b/,alias:"keyword"},"boolean-opencl-host":{pattern:/\bCL_(?:FALSE|TRUE)\b/,alias:"boolean"},"constant-opencl-host":{pattern:/\bCL_(?:A|ABGR|ADDRESS_(?:CLAMP(?:_TO_EDGE)?|MIRRORED_REPEAT|NONE|REPEAT)|ARGB|BGRA|BLOCKING|BUFFER_CREATE_TYPE_REGION|BUILD_(?:ERROR|IN_PROGRESS|NONE|PROGRAM_FAILURE|SUCCESS)|COMMAND_(?:ACQUIRE_GL_OBJECTS|BARRIER|COPY_(?:BUFFER(?:_RECT|_TO_IMAGE)?|IMAGE(?:_TO_BUFFER)?)|FILL_(?:BUFFER|IMAGE)|MAP(?:_BUFFER|_IMAGE)|MARKER|MIGRATE(?:_SVM)?_MEM_OBJECTS|NATIVE_KERNEL|NDRANGE_KERNEL|READ_(?:BUFFER(?:_RECT)?|IMAGE)|RELEASE_GL_OBJECTS|SVM_(?:FREE|MAP|MEMCPY|MEMFILL|UNMAP)|TASK|UNMAP_MEM_OBJECT|USER|WRITE_(?:BUFFER(?:_RECT)?|IMAGE))|COMPILER_NOT_AVAILABLE|COMPILE_PROGRAM_FAILURE|COMPLETE|CONTEXT_(?:DEVICES|INTEROP_USER_SYNC|NUM_DEVICES|PLATFORM|PROPERTIES|REFERENCE_COUNT)|DEPTH(?:_STENCIL)?|DEVICE_(?:ADDRESS_BITS|AFFINITY_DOMAIN_(?:L[1-4]_CACHE|NEXT_PARTITIONABLE|NUMA)|AVAILABLE|BUILT_IN_KERNELS|COMPILER_AVAILABLE|DOUBLE_FP_CONFIG|ENDIAN_LITTLE|ERROR_CORRECTION_SUPPORT|EXECUTION_CAPABILITIES|EXTENSIONS|GLOBAL_(?:MEM_(?:CACHELINE_SIZE|CACHE_SIZE|CACHE_TYPE|SIZE)|VARIABLE_PREFERRED_TOTAL_SIZE)|HOST_UNIFIED_MEMORY|IL_VERSION|IMAGE(?:2D_MAX_(?:HEIGHT|WIDTH)|3D_MAX_(?:DEPTH|HEIGHT|WIDTH)|_BASE_ADDRESS_ALIGNMENT|_MAX_ARRAY_SIZE|_MAX_BUFFER_SIZE|_PITCH_ALIGNMENT|_SUPPORT)|LINKER_AVAILABLE|LOCAL_MEM_SIZE|LOCAL_MEM_TYPE|MAX_(?:CLOCK_FREQUENCY|COMPUTE_UNITS|CONSTANT_ARGS|CONSTANT_BUFFER_SIZE|GLOBAL_VARIABLE_SIZE|MEM_ALLOC_SIZE|NUM_SUB_GROUPS|ON_DEVICE_(?:EVENTS|QUEUES)|PARAMETER_SIZE|PIPE_ARGS|READ_IMAGE_ARGS|READ_WRITE_IMAGE_ARGS|SAMPLERS|WORK_GROUP_SIZE|WORK_ITEM_DIMENSIONS|WORK_ITEM_SIZES|WRITE_IMAGE_ARGS)|MEM_BASE_ADDR_ALIGN|MIN_DATA_TYPE_ALIGN_SIZE|NAME|NATIVE_VECTOR_WIDTH_(?:CHAR|DOUBLE|FLOAT|HALF|INT|LONG|SHORT)|NOT_(?:AVAILABLE|FOUND)|OPENCL_C_VERSION|PARENT_DEVICE|PARTITION_(?:AFFINITY_DOMAIN|BY_AFFINITY_DOMAIN|BY_COUNTS|BY_COUNTS_LIST_END|EQUALLY|FAILED|MAX_SUB_DEVICES|PROPERTIES|TYPE)|PIPE_MAX_(?:ACTIVE_RESERVATIONS|PACKET_SIZE)|PLATFORM|PREFERRED_(?:GLOBAL_ATOMIC_ALIGNMENT|INTEROP_USER_SYNC|LOCAL_ATOMIC_ALIGNMENT|PLATFORM_ATOMIC_ALIGNMENT|VECTOR_WIDTH_(?:CHAR|DOUBLE|FLOAT|HALF|INT|LONG|SHORT))|PRINTF_BUFFER_SIZE|PROFILE|PROFILING_TIMER_RESOLUTION|QUEUE_(?:ON_(?:DEVICE_(?:MAX_SIZE|PREFERRED_SIZE|PROPERTIES)|HOST_PROPERTIES)|PROPERTIES)|REFERENCE_COUNT|SINGLE_FP_CONFIG|SUB_GROUP_INDEPENDENT_FORWARD_PROGRESS|SVM_(?:ATOMICS|CAPABILITIES|COARSE_GRAIN_BUFFER|FINE_GRAIN_BUFFER|FINE_GRAIN_SYSTEM)|TYPE(?:_ACCELERATOR|_ALL|_CPU|_CUSTOM|_DEFAULT|_GPU)?|VENDOR(?:_ID)?|VERSION)|DRIVER_VERSION|EVENT_(?:COMMAND_(?:EXECUTION_STATUS|QUEUE|TYPE)|CONTEXT|REFERENCE_COUNT)|EXEC_(?:KERNEL|NATIVE_KERNEL|STATUS_ERROR_FOR_EVENTS_IN_WAIT_LIST)|FILTER_(?:LINEAR|NEAREST)|FLOAT|FP_(?:CORRECTLY_ROUNDED_DIVIDE_SQRT|DENORM|FMA|INF_NAN|ROUND_TO_INF|ROUND_TO_NEAREST|ROUND_TO_ZERO|SOFT_FLOAT)|GLOBAL|HALF_FLOAT|IMAGE_(?:ARRAY_SIZE|BUFFER|DEPTH|ELEMENT_SIZE|FORMAT|FORMAT_MISMATCH|FORMAT_NOT_SUPPORTED|HEIGHT|NUM_MIP_LEVELS|NUM_SAMPLES|ROW_PITCH|SLICE_PITCH|WIDTH)|INTENSITY|INVALID_(?:ARG_INDEX|ARG_SIZE|ARG_VALUE|BINARY|BUFFER_SIZE|BUILD_OPTIONS|COMMAND_QUEUE|COMPILER_OPTIONS|CONTEXT|DEVICE|DEVICE_PARTITION_COUNT|DEVICE_QUEUE|DEVICE_TYPE|EVENT|EVENT_WAIT_LIST|GLOBAL_OFFSET|GLOBAL_WORK_SIZE|GL_OBJECT|HOST_PTR|IMAGE_DESCRIPTOR|IMAGE_FORMAT_DESCRIPTOR|IMAGE_SIZE|KERNEL|KERNEL_ARGS|KERNEL_DEFINITION|KERNEL_NAME|LINKER_OPTIONS|MEM_OBJECT|MIP_LEVEL|OPERATION|PIPE_SIZE|PLATFORM|PROGRAM|PROGRAM_EXECUTABLE|PROPERTY|QUEUE_PROPERTIES|SAMPLER|VALUE|WORK_DIMENSION|WORK_GROUP_SIZE|WORK_ITEM_SIZE)|KERNEL_(?:ARG_(?:ACCESS_(?:NONE|QUALIFIER|READ_ONLY|READ_WRITE|WRITE_ONLY)|ADDRESS_(?:CONSTANT|GLOBAL|LOCAL|PRIVATE|QUALIFIER)|INFO_NOT_AVAILABLE|NAME|TYPE_(?:CONST|NAME|NONE|PIPE|QUALIFIER|RESTRICT|VOLATILE))|ATTRIBUTES|COMPILE_NUM_SUB_GROUPS|COMPILE_WORK_GROUP_SIZE|CONTEXT|EXEC_INFO_SVM_FINE_GRAIN_SYSTEM|EXEC_INFO_SVM_PTRS|FUNCTION_NAME|GLOBAL_WORK_SIZE|LOCAL_MEM_SIZE|LOCAL_SIZE_FOR_SUB_GROUP_COUNT|MAX_NUM_SUB_GROUPS|MAX_SUB_GROUP_SIZE_FOR_NDRANGE|NUM_ARGS|PREFERRED_WORK_GROUP_SIZE_MULTIPLE|PRIVATE_MEM_SIZE|PROGRAM|REFERENCE_COUNT|SUB_GROUP_COUNT_FOR_NDRANGE|WORK_GROUP_SIZE)|LINKER_NOT_AVAILABLE|LINK_PROGRAM_FAILURE|LOCAL|LUMINANCE|MAP_(?:FAILURE|READ|WRITE|WRITE_INVALIDATE_REGION)|MEM_(?:ALLOC_HOST_PTR|ASSOCIATED_MEMOBJECT|CONTEXT|COPY_HOST_PTR|COPY_OVERLAP|FLAGS|HOST_NO_ACCESS|HOST_PTR|HOST_READ_ONLY|HOST_WRITE_ONLY|KERNEL_READ_AND_WRITE|MAP_COUNT|OBJECT_(?:ALLOCATION_FAILURE|BUFFER|IMAGE1D|IMAGE1D_ARRAY|IMAGE1D_BUFFER|IMAGE2D|IMAGE2D_ARRAY|IMAGE3D|PIPE)|OFFSET|READ_ONLY|READ_WRITE|REFERENCE_COUNT|SIZE|SVM_ATOMICS|SVM_FINE_GRAIN_BUFFER|TYPE|USES_SVM_POINTER|USE_HOST_PTR|WRITE_ONLY)|MIGRATE_MEM_OBJECT_(?:CONTENT_UNDEFINED|HOST)|MISALIGNED_SUB_BUFFER_OFFSET|NONE|NON_BLOCKING|OUT_OF_(?:HOST_MEMORY|RESOURCES)|PIPE_(?:MAX_PACKETS|PACKET_SIZE)|PLATFORM_(?:EXTENSIONS|HOST_TIMER_RESOLUTION|NAME|PROFILE|VENDOR|VERSION)|PROFILING_(?:COMMAND_(?:COMPLETE|END|QUEUED|START|SUBMIT)|INFO_NOT_AVAILABLE)|PROGRAM_(?:BINARIES|BINARY_SIZES|BINARY_TYPE(?:_COMPILED_OBJECT|_EXECUTABLE|_LIBRARY|_NONE)?|BUILD_(?:GLOBAL_VARIABLE_TOTAL_SIZE|LOG|OPTIONS|STATUS)|CONTEXT|DEVICES|IL|KERNEL_NAMES|NUM_DEVICES|NUM_KERNELS|REFERENCE_COUNT|SOURCE)|QUEUED|QUEUE_(?:CONTEXT|DEVICE|DEVICE_DEFAULT|ON_DEVICE|ON_DEVICE_DEFAULT|OUT_OF_ORDER_EXEC_MODE_ENABLE|PROFILING_ENABLE|PROPERTIES|REFERENCE_COUNT|SIZE)|R|RA|READ_(?:ONLY|WRITE)_CACHE|RG|RGB|RGBA|RGBx|RGx|RUNNING|Rx|SAMPLER_(?:ADDRESSING_MODE|CONTEXT|FILTER_MODE|LOD_MAX|LOD_MIN|MIP_FILTER_MODE|NORMALIZED_COORDS|REFERENCE_COUNT)|(?:UN)?SIGNED_INT(?:8|16|32)|SNORM_INT(?:8|16)|SUBMITTED|SUCCESS|UNORM_INT(?:8|16|24|_101010|_101010_2)|UNORM_SHORT_(?:555|565)|VERSION_(?:1_0|1_1|1_2|2_0|2_1)|sBGRA|sRGB|sRGBA|sRGBx)\b/,alias:"constant"},"function-opencl-host":{pattern:/\bcl(?:BuildProgram|CloneKernel|CompileProgram|Create(?:Buffer|CommandQueue(?:WithProperties)?|Context|ContextFromType|Image|Image2D|Image3D|Kernel|KernelsInProgram|Pipe|ProgramWith(?:Binary|BuiltInKernels|IL|Source)|Sampler|SamplerWithProperties|SubBuffer|SubDevices|UserEvent)|Enqueue(?:(?:Barrier|Marker)(?:WithWaitList)?|Copy(?:Buffer(?:Rect|ToImage)?|Image(?:ToBuffer)?)|(?:Fill|Map)(?:Buffer|Image)|MigrateMemObjects|NDRangeKernel|NativeKernel|(?:Read|Write)(?:Buffer(?:Rect)?|Image)|SVM(?:Free|Map|MemFill|Memcpy|MigrateMem|Unmap)|Task|UnmapMemObject|WaitForEvents)|Finish|Flush|Get(?:CommandQueueInfo|ContextInfo|Device(?:AndHostTimer|IDs|Info)|Event(?:Profiling)?Info|ExtensionFunctionAddress(?:ForPlatform)?|HostTimer|ImageInfo|Kernel(?:ArgInfo|Info|SubGroupInfo|WorkGroupInfo)|MemObjectInfo|PipeInfo|Platform(?:IDs|Info)|Program(?:Build)?Info|SamplerInfo|SupportedImageFormats)|LinkProgram|(?:Release|Retain)(?:CommandQueue|Context|Device|Event|Kernel|MemObject|Program|Sampler)|SVM(?:Alloc|Free)|Set(?:CommandQueueProperty|DefaultDeviceCommandQueue|EventCallback|Kernel|Kernel(?:Arg(?:SVMPointer)?|ExecInfo)|MemObjectDestructorCallback|UserEventStatus)|Unload(?:Platform)?Compiler|WaitForEvents)\b/,alias:"function"}};t.languages.insertBefore("c","keyword",n),t.languages.cpp&&(n["type-opencl-host-cpp"]={pattern:/\b(?:Buffer|BufferGL|BufferRenderGL|CommandQueue|Context|Device|DeviceCommandQueue|EnqueueArgs|Event|Image|Image1D|Image1DArray|Image1DBuffer|Image2D|Image2DArray|Image2DGL|Image3D|Image3DGL|ImageFormat|ImageGL|Kernel|KernelFunctor|LocalSpaceArg|Memory|NDRange|Pipe|Platform|Program|SVMAllocator|SVMTraitAtomic|SVMTraitCoarse|SVMTraitFine|SVMTraitReadOnly|SVMTraitReadWrite|SVMTraitWriteOnly|Sampler|UserEvent)\b/,alias:"keyword"},t.languages.insertBefore("cpp","keyword",n))})(e)}T4.displayName="openqasm";T4.aliases=["qasm"];function T4(e){e.languages.openqasm={comment:/\/\*[\s\S]*?\*\/|\/\/.*/,string:{pattern:/"[^"\r\n\t]*"|'[^'\r\n\t]*'/,greedy:!0},keyword:/\b(?:CX|OPENQASM|U|barrier|boxas|boxto|break|const|continue|ctrl|def|defcal|defcalgrammar|delay|else|end|for|gate|gphase|if|in|include|inv|kernel|lengthof|let|measure|pow|reset|return|rotary|stretchinf|while)\b|#pragma\b/,"class-name":/\b(?:angle|bit|bool|creg|fixed|float|int|length|qreg|qubit|stretch|uint)\b/,function:/\b(?:cos|exp|ln|popcount|rotl|rotr|sin|sqrt|tan)\b(?=\s*\()/,constant:/\b(?:euler|pi|tau)\b|π|𝜏|ℇ/,number:{pattern:/(^|[^.\w$])(?:\d+(?:\.\d*)?|\.\d+)(?:e[+-]?\d+)?(?:dt|ns|us|µs|ms|s)?/i,lookbehind:!0},operator:/->|>>=?|<<=?|&&|\|\||\+\+|--|[!=<>&|~^+\-*/%]=?|@/,punctuation:/[(){}\[\];,:.]/},e.languages.qasm=e.languages.openqasm}_4.displayName="oz";_4.aliases=[];function _4(e){e.languages.oz={comment:{pattern:/\/\*[\s\S]*?\*\/|%.*/,greedy:!0},string:{pattern:/"(?:[^"\\]|\\[\s\S])*"/,greedy:!0},atom:{pattern:/'(?:[^'\\]|\\[\s\S])*'/,greedy:!0,alias:"builtin"},keyword:/\$|\[\]|\b(?:_|at|attr|case|catch|choice|class|cond|declare|define|dis|else(?:case|if)?|end|export|fail|false|feat|finally|from|fun|functor|if|import|in|local|lock|meth|nil|not|of|or|prepare|proc|prop|raise|require|self|skip|then|thread|true|try|unit)\b/,function:[/\b[a-z][A-Za-z\d]*(?=\()/,{pattern:/(\{)[A-Z][A-Za-z\d]*\b/,lookbehind:!0}],number:/\b(?:0[bx][\da-f]+|\d+(?:\.\d*)?(?:e~?\d+)?)\b|&(?:[^\\]|\\(?:\d{3}|.))/i,variable:/`(?:[^`\\]|\\.)+`/,"attr-name":/\b\w+(?=[ \t]*:(?![:=]))/,operator:/:(?:=|::?)|<[-:=]?|=(?:=|<?:?)|>=?:?|\\=:?|!!?|[|#+\-*\/,~^@]|\b(?:andthen|div|mod|orelse)\b/,punctuation:/[\[\](){}.:;?]/}}C4.displayName="parigp";C4.aliases=[];function C4(e){e.languages.parigp={comment:/\/\*[\s\S]*?\*\/|\\\\.*/,string:{pattern:/"(?:[^"\\\r\n]|\\.)*"/,greedy:!0},keyword:(function(){var t=["breakpoint","break","dbg_down","dbg_err","dbg_up","dbg_x","forcomposite","fordiv","forell","forpart","forprime","forstep","forsubgroup","forvec","for","iferr","if","local","my","next","return","until","while"];return t=t.map(function(n){return n.split("").join(" *")}).join("|"),RegExp("\\b(?:"+t+")\\b")})(),function:/\b\w(?:[\w ]*\w)?(?= *\()/,number:{pattern:/((?:\. *\. *)?)(?:\b\d(?: *\d)*(?: *(?!\. *\.)\.(?: *\d)*)?|\. *\d(?: *\d)*)(?: *e *(?:[+-] *)?\d(?: *\d)*)?/i,lookbehind:!0},operator:/\. *\.|[*\/!](?: *=)?|%(?: *=|(?: *#)?(?: *')*)?|\+(?: *[+=])?|-(?: *[-=>])?|<(?: *>|(?: *<)?(?: *=)?)?|>(?: *>)?(?: *=)?|=(?: *=){0,2}|\\(?: *\/)?(?: *=)?|&(?: *&)?|\| *\||['#~^]/,punctuation:/[\[\]{}().,:;|]/}}A4.displayName="parser";A4.aliases=[];function A4(e){e.register(cr),(function(t){var n=t.languages.parser=t.languages.extend("markup",{keyword:{pattern:/(^|[^^])(?:\^(?:case|eval|for|if|switch|throw)\b|@(?:BASE|CLASS|GET(?:_DEFAULT)?|OPTIONS|SET_DEFAULT|USE)\b)/,lookbehind:!0},variable:{pattern:/(^|[^^])\B\$(?:\w+|(?=[.{]))(?:(?:\.|::?)\w+)*(?:\.|::?)?/,lookbehind:!0,inside:{punctuation:/\.|:+/}},function:{pattern:/(^|[^^])\B[@^]\w+(?:(?:\.|::?)\w+)*(?:\.|::?)?/,lookbehind:!0,inside:{keyword:{pattern:/(^@)(?:GET_|SET_)/,lookbehind:!0},punctuation:/\.|:+/}},escape:{pattern:/\^(?:[$^;@()\[\]{}"':]|#[a-f\d]*)/i,alias:"builtin"},punctuation:/[\[\](){};]/});n=t.languages.insertBefore("parser","keyword",{"parser-comment":{pattern:/(\s)#.*/,lookbehind:!0,alias:"comment"},expression:{pattern:/(^|[^^])\((?:[^()]|\((?:[^()]|\((?:[^()])*\))*\))*\)/,greedy:!0,lookbehind:!0,inside:{string:{pattern:/(^|[^^])(["'])(?:(?!\2)[^^]|\^[\s\S])*\2/,lookbehind:!0},keyword:n.keyword,variable:n.variable,function:n.function,boolean:/\b(?:false|true)\b/,number:/\b(?:0x[a-f\d]+|\d+(?:\.\d*)?(?:e[+-]?\d+)?)\b/i,escape:n.escape,operator:/[~+*\/\\%]|!(?:\|\|?|=)?|&&?|\|\|?|==|<[<=]?|>[>=]?|-[fd]?|\b(?:def|eq|ge|gt|in|is|le|lt|ne)\b/,punctuation:n.punctuation}}}),t.languages.insertBefore("inside","punctuation",{expression:n.expression,keyword:n.keyword,variable:n.variable,function:n.function,escape:n.escape,"parser-punctuation":{pattern:n.punctuation,alias:"punctuation"}},n.tag.inside["attr-value"])})(e)}R4.displayName="pascal";R4.aliases=["objectpascal"];function R4(e){e.languages.pascal={directive:{pattern:/\{\$[\s\S]*?\}/,greedy:!0,alias:["marco","property"]},comment:{pattern:/\(\*[\s\S]*?\*\)|\{[\s\S]*?\}|\/\/.*/,greedy:!0},string:{pattern:/(?:'(?:''|[^'\r\n])*'(?!')|#[&$%]?[a-f\d]+)+|\^[a-z]/i,greedy:!0},asm:{pattern:/(\basm\b)[\s\S]+?(?=\bend\s*[;[])/i,lookbehind:!0,greedy:!0,inside:null},keyword:[{pattern:/(^|[^&])\b(?:absolute|array|asm|begin|case|const|constructor|destructor|do|downto|else|end|file|for|function|goto|if|implementation|inherited|inline|interface|label|nil|object|of|operator|packed|procedure|program|record|reintroduce|repeat|self|set|string|then|to|type|unit|until|uses|var|while|with)\b/i,lookbehind:!0},{pattern:/(^|[^&])\b(?:dispose|exit|false|new|true)\b/i,lookbehind:!0},{pattern:/(^|[^&])\b(?:class|dispinterface|except|exports|finalization|finally|initialization|inline|library|on|out|packed|property|raise|resourcestring|threadvar|try)\b/i,lookbehind:!0},{pattern:/(^|[^&])\b(?:absolute|abstract|alias|assembler|bitpacked|break|cdecl|continue|cppdecl|cvar|default|deprecated|dynamic|enumerator|experimental|export|external|far|far16|forward|generic|helper|implements|index|interrupt|iochecks|local|message|name|near|nodefault|noreturn|nostackframe|oldfpccall|otherwise|overload|override|pascal|platform|private|protected|public|published|read|register|reintroduce|result|safecall|saveregisters|softfloat|specialize|static|stdcall|stored|strict|unaligned|unimplemented|varargs|virtual|write)\b/i,lookbehind:!0}],number:[/(?:[&%]\d+|\$[a-f\d]+)/i,/\b\d+(?:\.\d+)?(?:e[+-]?\d+)?/i],operator:[/\.\.|\*\*|:=|<[<=>]?|>[>=]?|[+\-*\/]=?|[@^=]/,{pattern:/(^|[^&])\b(?:and|as|div|exclude|in|include|is|mod|not|or|shl|shr|xor)\b/,lookbehind:!0}],punctuation:/\(\.|\.\)|[()\[\]:;,.]/},e.languages.pascal.asm.inside=e.languages.extend("pascal",{asm:void 0,keyword:void 0,operator:void 0}),e.languages.objectpascal=e.languages.pascal}N4.displayName="pascaligo";N4.aliases=[];function N4(e){(function(t){var n=/\((?:[^()]|\((?:[^()]|\([^()]*\))*\))*\)/.source,r=/(?:\b\w+(?:<braces>)?|<braces>)/.source.replace(/<braces>/g,function(){return n}),a=t.languages.pascaligo={comment:/\(\*[\s\S]+?\*\)|\/\/.*/,string:{pattern:/(["'`])(?:\\[\s\S]|(?!\1)[^\\])*\1|\^[a-z]/i,greedy:!0},"class-name":[{pattern:RegExp(/(\btype\s+\w+\s+is\s+)<type>/.source.replace(/<type>/g,function(){return r}),"i"),lookbehind:!0,inside:null},{pattern:RegExp(/<type>(?=\s+is\b)/.source.replace(/<type>/g,function(){return r}),"i"),inside:null},{pattern:RegExp(/(:\s*)<type>/.source.replace(/<type>/g,function(){return r})),lookbehind:!0,inside:null}],keyword:{pattern:/(^|[^&])\b(?:begin|block|case|const|else|end|fail|for|from|function|if|is|nil|of|remove|return|skip|then|type|var|while|with)\b/i,lookbehind:!0},boolean:{pattern:/(^|[^&])\b(?:False|True)\b/i,lookbehind:!0},builtin:{pattern:/(^|[^&])\b(?:bool|int|list|map|nat|record|string|unit)\b/i,lookbehind:!0},function:/\b\w+(?=\s*\()/,number:[/%[01]+|&[0-7]+|\$[a-f\d]+/i,/\b\d+(?:\.\d+)?(?:e[+-]?\d+)?(?:mtz|n)?/i],operator:/->|=\/=|\.\.|\*\*|:=|<[<=>]?|>[>=]?|[+\-*\/]=?|[@^=|]|\b(?:and|mod|or)\b/,punctuation:/\(\.|\.\)|[()\[\]:;,.{}]/},i=["comment","keyword","builtin","operator","punctuation"].reduce(function(o,l){return o[l]=a[l],o},{});a["class-name"].forEach(function(o){o.inside=i})})(e)}O4.displayName="psl";O4.aliases=[];function O4(e){e.languages.psl={comment:{pattern:/#.*/,greedy:!0},string:{pattern:/"(?:\\.|[^\\"])*"/,greedy:!0,inside:{symbol:/\\[ntrbA-Z"\\]/}},"heredoc-string":{pattern:/<<<([a-zA-Z_]\w*)[\r\n](?:.*[\r\n])*?\1\b/,alias:"string",greedy:!0},keyword:/\b(?:__multi|__single|case|default|do|else|elsif|exit|export|for|foreach|function|if|last|line|local|next|requires|return|switch|until|while|word)\b/,constant:/\b(?:ALARM|CHART_ADD_GRAPH|CHART_DELETE_GRAPH|CHART_DESTROY|CHART_LOAD|CHART_PRINT|EOF|OFFLINE|OK|PSL_PROF_LOG|R_CHECK_HORIZ|R_CHECK_VERT|R_CLICKER|R_COLUMN|R_FRAME|R_ICON|R_LABEL|R_LABEL_CENTER|R_LIST_MULTIPLE|R_LIST_MULTIPLE_ND|R_LIST_SINGLE|R_LIST_SINGLE_ND|R_MENU|R_POPUP|R_POPUP_SCROLLED|R_RADIO_HORIZ|R_RADIO_VERT|R_ROW|R_SCALE_HORIZ|R_SCALE_VERT|R_SEP_HORIZ|R_SEP_VERT|R_SPINNER|R_TEXT_FIELD|R_TEXT_FIELD_LABEL|R_TOGGLE|TRIM_LEADING|TRIM_LEADING_AND_TRAILING|TRIM_REDUNDANT|TRIM_TRAILING|VOID|WARN)\b/,boolean:/\b(?:FALSE|False|NO|No|TRUE|True|YES|Yes|false|no|true|yes)\b/,variable:/\b(?:PslDebug|errno|exit_status)\b/,builtin:{pattern:/\b(?:PslExecute|PslFunctionCall|PslFunctionExists|PslSetOptions|_snmp_debug|acos|add_diary|annotate|annotate_get|ascii_to_ebcdic|asctime|asin|atan|atexit|batch_set|blackout|cat|ceil|chan_exists|change_state|close|code_cvt|cond_signal|cond_wait|console_type|convert_base|convert_date|convert_locale_date|cos|cosh|create|date|dcget_text|destroy|destroy_lock|dget_text|difference|dump_hist|ebcdic_to_ascii|encrypt|event_archive|event_catalog_get|event_check|event_query|event_range_manage|event_range_query|event_report|event_schedule|event_trigger|event_trigger2|execute|exists|exp|fabs|file|floor|fmod|fopen|fseek|ftell|full_discovery|get|get_chan_info|get_ranges|get_text|get_vars|getenv|gethostinfo|getpid|getpname|grep|history|history_get_retention|in_transition|index|int|internal|intersection|is_var|isnumber|join|kill|length|lines|lock|lock_info|log|log10|loge|matchline|msg_check|msg_get_format|msg_get_severity|msg_printf|msg_sprintf|ntharg|nthargf|nthline|nthlinef|num_bytes|num_consoles|pconfig|popen|poplines|pow|print|printf|proc_exists|process|random|read|readln|refresh_parameters|remote_check|remote_close|remote_event_query|remote_event_trigger|remote_file_send|remote_open|remove|replace|rindex|sec_check_priv|sec_store_get|sec_store_set|set|set_alarm_ranges|set_locale|share|sin|sinh|sleep|snmp_agent_config|snmp_agent_start|snmp_agent_stop|snmp_close|snmp_config|snmp_get|snmp_get_next|snmp_h_get|snmp_h_get_next|snmp_h_set|snmp_open|snmp_set|snmp_trap_ignore|snmp_trap_listen|snmp_trap_raise_std_trap|snmp_trap_receive|snmp_trap_register_im|snmp_trap_send|snmp_walk|sopen|sort|splitline|sprintf|sqrt|srandom|str_repeat|strcasecmp|subset|substr|system|tail|tan|tanh|text_domain|time|tmpnam|tolower|toupper|trace_psl_process|trim|union|unique|unlock|unset|va_arg|va_start|write)\b/,alias:"builtin-function"},"foreach-variable":{pattern:/(\bforeach\s+(?:(?:\w+\b|"(?:\\.|[^\\"])*")\s+){0,2})[_a-zA-Z]\w*(?=\s*\()/,lookbehind:!0,greedy:!0},function:/\b[_a-z]\w*\b(?=\s*\()/i,number:/\b(?:0x[0-9a-f]+|\d+(?:\.\d+)?)\b/i,operator:/--|\+\+|&&=?|\|\|=?|<<=?|>>=?|[=!]~|[-+*/%&|^!=<>]=?|\.|[:?]/,punctuation:/[(){}\[\];,]/}}I4.displayName="pcaxis";I4.aliases=["px"];function I4(e){e.languages.pcaxis={string:/"[^"]*"/,keyword:{pattern:/((?:^|;)\s*)[-A-Z\d]+(?:\s*\[[-\w]+\])?(?:\s*\("[^"]*"(?:,\s*"[^"]*")*\))?(?=\s*=)/,lookbehind:!0,greedy:!0,inside:{keyword:/^[-A-Z\d]+/,language:{pattern:/^(\s*)\[[-\w]+\]/,lookbehind:!0,inside:{punctuation:/^\[|\]$/,property:/[-\w]+/}},"sub-key":{pattern:/^(\s*)\S[\s\S]*/,lookbehind:!0,inside:{parameter:{pattern:/"[^"]*"/,alias:"property"},punctuation:/^\(|\)$|,/}}}},operator:/=/,tlist:{pattern:/TLIST\s*\(\s*\w+(?:(?:\s*,\s*"[^"]*")+|\s*,\s*"[^"]*"-"[^"]*")?\s*\)/,greedy:!0,inside:{function:/^TLIST/,property:{pattern:/^(\s*\(\s*)\w+/,lookbehind:!0},string:/"[^"]*"/,punctuation:/[(),]/,operator:/-/}},punctuation:/[;,]/,number:{pattern:/(^|\s)\d+(?:\.\d+)?(?!\S)/,lookbehind:!0},boolean:/NO|YES/},e.languages.px=e.languages.pcaxis}L4.displayName="peoplecode";L4.aliases=["pcode"];function L4(e){e.languages.peoplecode={comment:RegExp([/\/\*[\s\S]*?\*\//.source,/\bREM[^;]*;/.source,/<\*(?:[^<*]|\*(?!>)|<(?!\*)|<\*(?:(?!\*>)[\s\S])*\*>)*\*>/.source,/\/\+[\s\S]*?\+\//.source].join("|")),string:{pattern:/'(?:''|[^'\r\n])*'(?!')|"(?:""|[^"\r\n])*"(?!")/,greedy:!0},variable:/%\w+/,"function-definition":{pattern:/((?:^|[^\w-])(?:function|method)\s+)\w+/i,lookbehind:!0,alias:"function"},"class-name":{pattern:/((?:^|[^-\w])(?:as|catch|class|component|create|extends|global|implements|instance|local|of|property|returns)\s+)\w+(?::\w+)*/i,lookbehind:!0,inside:{punctuation:/:/}},keyword:/\b(?:abstract|alias|as|catch|class|component|constant|create|declare|else|end-(?:class|evaluate|for|function|get|if|method|set|try|while)|evaluate|extends|for|function|get|global|if|implements|import|instance|library|local|method|null|of|out|peopleCode|private|program|property|protected|readonly|ref|repeat|returns?|set|step|then|throw|to|try|until|value|when(?:-other)?|while)\b/i,"operator-keyword":{pattern:/\b(?:and|not|or)\b/i,alias:"operator"},function:/[_a-z]\w*(?=\s*\()/i,boolean:/\b(?:false|true)\b/i,number:/\b\d+(?:\.\d+)?\b/,operator:/<>|[<>]=?|!=|\*\*|[-+*/|=@]/,punctuation:/[:.;,()[\]]/},e.languages.pcode=e.languages.peoplecode}D4.displayName="perl";D4.aliases=[];function D4(e){(function(t){var n=/(?:\((?:[^()\\]|\\[\s\S])*\)|\{(?:[^{}\\]|\\[\s\S])*\}|\[(?:[^[\]\\]|\\[\s\S])*\]|<(?:[^<>\\]|\\[\s\S])*>)/.source;t.languages.perl={comment:[{pattern:/(^\s*)=\w[\s\S]*?=cut.*/m,lookbehind:!0,greedy:!0},{pattern:/(^|[^\\$])#.*/,lookbehind:!0,greedy:!0}],string:[{pattern:RegExp(/\b(?:q|qq|qw|qx)(?![a-zA-Z0-9])\s*/.source+"(?:"+[/([^a-zA-Z0-9\s{(\[<])(?:(?!\1)[^\\]|\\[\s\S])*\1/.source,/([a-zA-Z0-9])(?:(?!\2)[^\\]|\\[\s\S])*\2/.source,n].join("|")+")"),greedy:!0},{pattern:/("|`)(?:(?!\1)[^\\]|\\[\s\S])*\1/,greedy:!0},{pattern:/'(?:[^'\\\r\n]|\\.)*'/,greedy:!0}],regex:[{pattern:RegExp(/\b(?:m|qr)(?![a-zA-Z0-9])\s*/.source+"(?:"+[/([^a-zA-Z0-9\s{(\[<])(?:(?!\1)[^\\]|\\[\s\S])*\1/.source,/([a-zA-Z0-9])(?:(?!\2)[^\\]|\\[\s\S])*\2/.source,n].join("|")+")"+/[msixpodualngc]*/.source),greedy:!0},{pattern:RegExp(/(^|[^-])\b(?:s|tr|y)(?![a-zA-Z0-9])\s*/.source+"(?:"+[/([^a-zA-Z0-9\s{(\[<])(?:(?!\2)[^\\]|\\[\s\S])*\2(?:(?!\2)[^\\]|\\[\s\S])*\2/.source,/([a-zA-Z0-9])(?:(?!\3)[^\\]|\\[\s\S])*\3(?:(?!\3)[^\\]|\\[\s\S])*\3/.source,n+/\s*/.source+n].join("|")+")"+/[msixpodualngcer]*/.source),lookbehind:!0,greedy:!0},{pattern:/\/(?:[^\/\\\r\n]|\\.)*\/[msixpodualngc]*(?=\s*(?:$|[\r\n,.;})&|\-+*~<>!?^]|(?:and|cmp|eq|ge|gt|le|lt|ne|not|or|x|xor)\b))/,greedy:!0}],variable:[/[&*$@%]\{\^[A-Z]+\}/,/[&*$@%]\^[A-Z_]/,/[&*$@%]#?(?=\{)/,/[&*$@%]#?(?:(?:::)*'?(?!\d)[\w$]+(?![\w$]))+(?:::)*/,/[&*$@%]\d+/,/(?!%=)[$@%][!"#$%&'()*+,\-.\/:;<=>?@[\\\]^_`{|}~]/],filehandle:{pattern:/<(?![<=])\S*?>|\b_\b/,alias:"symbol"},"v-string":{pattern:/v\d+(?:\.\d+)*|\d+(?:\.\d+){2,}/,alias:"string"},function:{pattern:/(\bsub[ \t]+)\w+/,lookbehind:!0},keyword:/\b(?:any|break|continue|default|delete|die|do|else|elsif|eval|for|foreach|given|goto|if|last|local|my|next|our|package|print|redo|require|return|say|state|sub|switch|undef|unless|until|use|when|while)\b/,number:/\b(?:0x[\dA-Fa-f](?:_?[\dA-Fa-f])*|0b[01](?:_?[01])*|(?:(?:\d(?:_?\d)*)?\.)?\d(?:_?\d)*(?:[Ee][+-]?\d+)?)\b/,operator:/-[rwxoRWXOezsfdlpSbctugkTBMAC]\b|\+[+=]?|-[-=>]?|\*\*?=?|\/\/?=?|=[=~>]?|~[~=]?|\|\|?=?|&&?=?|<(?:=>?|<=?)?|>>?=?|![~=]?|[%^]=?|\.(?:=|\.\.?)?|[\\?]|\bx(?:=|\b)|\b(?:and|cmp|eq|ge|gt|le|lt|ne|not|or|xor)\b/,punctuation:/[{}[\];(),:]/}})(e)}M4.displayName="phpdoc";M4.aliases=[];function M4(e){e.register(Au),e.register(Cu),(function(t){var n=/(?:\b[a-zA-Z]\w*|[|\\[\]])+/.source;t.languages.phpdoc=t.languages.extend("javadoclike",{parameter:{pattern:RegExp("(@(?:global|param|property(?:-read|-write)?|var)\\s+(?:"+n+"\\s+)?)\\$\\w+"),lookbehind:!0}}),t.languages.insertBefore("phpdoc","keyword",{"class-name":[{pattern:RegExp("(@(?:global|package|param|property(?:-read|-write)?|return|subpackage|throws|var)\\s+)"+n),lookbehind:!0,inside:{keyword:/\b(?:array|bool|boolean|callback|double|false|float|int|integer|mixed|null|object|resource|self|string|true|void)\b/,punctuation:/[|\\[\]()]/}}]}),t.languages.javadoclike.addSupport("php",t.languages.phpdoc)})(e)}B4.displayName="php-extras";B4.aliases=[];function B4(e){e.register(Cu),e.languages.insertBefore("php","variable",{this:{pattern:/\$this\b/,alias:"keyword"},global:/\$(?:GLOBALS|HTTP_RAW_POST_DATA|_(?:COOKIE|ENV|FILES|GET|POST|REQUEST|SERVER|SESSION)|argc|argv|http_response_header|php_errormsg)\b/,scope:{pattern:/\b[\w\\]+::/,inside:{keyword:/\b(?:parent|self|static)\b/,punctuation:/::|\\/}}})}F4.displayName="plant-uml";F4.aliases=["plantuml"];function F4(e){(function(t){var n=/\$\w+|%[a-z]+%/,r=/\[[^[\]]*\]/.source,a=/(?:[drlu]|do|down|le|left|ri|right|up)/.source,i="(?:-+"+a+"-+|\\.+"+a+"\\.+|-+(?:"+r+"-*)?|"+r+"-+|\\.+(?:"+r+"\\.*)?|"+r+"\\.+)",o=/(?:<{1,2}|\/{1,2}|\\{1,2}|<\||[#*^+}xo])/.source,l=/(?:>{1,2}|\/{1,2}|\\{1,2}|\|>|[#*^+{xo])/.source,u=/[[?]?[ox]?/.source,d=/[ox]?[\]?]?/.source,h=u+"(?:"+i+l+"|"+o+i+"(?:"+l+")?)"+d;t.languages["plant-uml"]={comment:{pattern:/(^[ \t]*)(?:'.*|\/'[\s\S]*?'\/)/m,lookbehind:!0,greedy:!0},preprocessor:{pattern:/(^[ \t]*)!.*/m,lookbehind:!0,greedy:!0,alias:"property",inside:{variable:n}},delimiter:{pattern:/(^[ \t]*)@(?:end|start)uml\b/m,lookbehind:!0,greedy:!0,alias:"punctuation"},arrow:{pattern:RegExp(/(^|[^-.<>?|\\[\]ox])/.source+h+/(?![-.<>?|\\\]ox])/.source),lookbehind:!0,greedy:!0,alias:"operator",inside:{expression:{pattern:/(\[)[^[\]]+(?=\])/,lookbehind:!0,inside:null},punctuation:/\[(?=$|\])|^\]/}},string:{pattern:/"[^"]*"/,greedy:!0},text:{pattern:/(\[[ \t]*[\r\n]+(?![\r\n]))[^\]]*(?=\])/,lookbehind:!0,greedy:!0,alias:"string"},keyword:[{pattern:/^([ \t]*)(?:abstract\s+class|end\s+(?:box|fork|group|merge|note|ref|split|title)|(?:fork|split)(?:\s+again)?|activate|actor|agent|alt|annotation|artifact|autoactivate|autonumber|backward|binary|boundary|box|break|caption|card|case|circle|class|clock|cloud|collections|component|concise|control|create|critical|database|deactivate|destroy|detach|diamond|else|elseif|end|end[hr]note|endif|endswitch|endwhile|entity|enum|file|folder|footer|frame|group|[hr]?note|header|hexagon|hide|if|interface|label|legend|loop|map|namespace|network|newpage|node|nwdiag|object|opt|package|page|par|participant|person|queue|rectangle|ref|remove|repeat|restore|return|robust|scale|set|show|skinparam|stack|start|state|stop|storage|switch|title|together|usecase|usecase\/|while)(?=\s|$)/m,lookbehind:!0,greedy:!0},/\b(?:elseif|equals|not|while)(?=\s*\()/,/\b(?:as|is|then)\b/],divider:{pattern:/^==.+==$/m,greedy:!0,alias:"important"},time:{pattern:/@(?:\d+(?:[:/]\d+){2}|[+-]?\d+|:[a-z]\w*(?:[+-]\d+)?)\b/i,greedy:!0,alias:"number"},color:{pattern:/#(?:[a-z_]+|[a-fA-F0-9]+)\b/,alias:"symbol"},variable:n,punctuation:/[:,;()[\]{}]|\.{3}/},t.languages["plant-uml"].arrow.inside.expression.inside=t.languages["plant-uml"],t.languages.plantuml=t.languages["plant-uml"]})(e)}z4.displayName="plsql";z4.aliases=[];function z4(e){e.register(ip),e.languages.plsql=e.languages.extend("sql",{comment:{pattern:/\/\*[\s\S]*?\*\/|--.*/,greedy:!0},keyword:/\b(?:A|ACCESSIBLE|ADD|AGENT|AGGREGATE|ALL|ALTER|AND|ANY|ARRAY|AS|ASC|AT|ATTRIBUTE|AUTHID|AVG|BEGIN|BETWEEN|BFILE_BASE|BINARY|BLOB_BASE|BLOCK|BODY|BOTH|BOUND|BULK|BY|BYTE|C|CALL|CALLING|CASCADE|CASE|CHAR|CHARACTER|CHARSET|CHARSETFORM|CHARSETID|CHAR_BASE|CHECK|CLOB_BASE|CLONE|CLOSE|CLUSTER|CLUSTERS|COLAUTH|COLLECT|COLUMNS|COMMENT|COMMIT|COMMITTED|COMPILED|COMPRESS|CONNECT|CONSTANT|CONSTRUCTOR|CONTEXT|CONTINUE|CONVERT|COUNT|CRASH|CREATE|CREDENTIAL|CURRENT|CURSOR|CUSTOMDATUM|DANGLING|DATA|DATE|DATE_BASE|DAY|DECLARE|DEFAULT|DEFINE|DELETE|DESC|DETERMINISTIC|DIRECTORY|DISTINCT|DOUBLE|DROP|DURATION|ELEMENT|ELSE|ELSIF|EMPTY|END|ESCAPE|EXCEPT|EXCEPTION|EXCEPTIONS|EXCLUSIVE|EXECUTE|EXISTS|EXIT|EXTERNAL|FETCH|FINAL|FIRST|FIXED|FLOAT|FOR|FORALL|FORCE|FROM|FUNCTION|GENERAL|GOTO|GRANT|GROUP|HASH|HAVING|HEAP|HIDDEN|HOUR|IDENTIFIED|IF|IMMEDIATE|IMMUTABLE|IN|INCLUDING|INDEX|INDEXES|INDICATOR|INDICES|INFINITE|INSERT|INSTANTIABLE|INT|INTERFACE|INTERSECT|INTERVAL|INTO|INVALIDATE|IS|ISOLATION|JAVA|LANGUAGE|LARGE|LEADING|LENGTH|LEVEL|LIBRARY|LIKE|LIKE2|LIKE4|LIKEC|LIMIT|LIMITED|LOCAL|LOCK|LONG|LOOP|MAP|MAX|MAXLEN|MEMBER|MERGE|MIN|MINUS|MINUTE|MOD|MODE|MODIFY|MONTH|MULTISET|MUTABLE|NAME|NAN|NATIONAL|NATIVE|NCHAR|NEW|NOCOMPRESS|NOCOPY|NOT|NOWAIT|NULL|NUMBER_BASE|OBJECT|OCICOLL|OCIDATE|OCIDATETIME|OCIDURATION|OCIINTERVAL|OCILOBLOCATOR|OCINUMBER|OCIRAW|OCIREF|OCIREFCURSOR|OCIROWID|OCISTRING|OCITYPE|OF|OLD|ON|ONLY|OPAQUE|OPEN|OPERATOR|OPTION|OR|ORACLE|ORADATA|ORDER|ORGANIZATION|ORLANY|ORLVARY|OTHERS|OUT|OVERLAPS|OVERRIDING|PACKAGE|PARALLEL_ENABLE|PARAMETER|PARAMETERS|PARENT|PARTITION|PASCAL|PERSISTABLE|PIPE|PIPELINED|PLUGGABLE|POLYMORPHIC|PRAGMA|PRECISION|PRIOR|PRIVATE|PROCEDURE|PUBLIC|RAISE|RANGE|RAW|READ|RECORD|REF|REFERENCE|RELIES_ON|REM|REMAINDER|RENAME|RESOURCE|RESULT|RESULT_CACHE|RETURN|RETURNING|REVERSE|REVOKE|ROLLBACK|ROW|SAMPLE|SAVE|SAVEPOINT|SB1|SB2|SB4|SECOND|SEGMENT|SELECT|SELF|SEPARATE|SEQUENCE|SERIALIZABLE|SET|SHARE|SHORT|SIZE|SIZE_T|SOME|SPARSE|SQL|SQLCODE|SQLDATA|SQLNAME|SQLSTATE|STANDARD|START|STATIC|STDDEV|STORED|STRING|STRUCT|STYLE|SUBMULTISET|SUBPARTITION|SUBSTITUTABLE|SUBTYPE|SUM|SYNONYM|TABAUTH|TABLE|TDO|THE|THEN|TIME|TIMESTAMP|TIMEZONE_ABBR|TIMEZONE_HOUR|TIMEZONE_MINUTE|TIMEZONE_REGION|TO|TRAILING|TRANSACTION|TRANSACTIONAL|TRUSTED|TYPE|UB1|UB2|UB4|UNDER|UNION|UNIQUE|UNPLUG|UNSIGNED|UNTRUSTED|UPDATE|USE|USING|VALIST|VALUE|VALUES|VARIABLE|VARIANCE|VARRAY|VARYING|VIEW|VIEWS|VOID|WHEN|WHERE|WHILE|WITH|WORK|WRAPPED|WRITE|YEAR|ZONE)\b/i,operator:/:=?|=>|[<>^~!]=|\.\.|\|\||\*\*|[-+*/%<>=@]/}),e.languages.insertBefore("plsql","operator",{label:{pattern:/<<\s*\w+\s*>>/,alias:"symbol"}})}$4.displayName="powerquery";$4.aliases=["mscript","pq"];function $4(e){e.languages.powerquery={comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?\*\/|\/\/.*)/,lookbehind:!0,greedy:!0},"quoted-identifier":{pattern:/#"(?:[^"\r\n]|"")*"(?!")/,greedy:!0},string:{pattern:/(?:#!)?"(?:[^"\r\n]|"")*"(?!")/,greedy:!0},constant:[/\bDay\.(?:Friday|Monday|Saturday|Sunday|Thursday|Tuesday|Wednesday)\b/,/\bTraceLevel\.(?:Critical|Error|Information|Verbose|Warning)\b/,/\bOccurrence\.(?:All|First|Last)\b/,/\bOrder\.(?:Ascending|Descending)\b/,/\bRoundingMode\.(?:AwayFromZero|Down|ToEven|TowardZero|Up)\b/,/\bMissingField\.(?:Error|Ignore|UseNull)\b/,/\bQuoteStyle\.(?:Csv|None)\b/,/\bJoinKind\.(?:FullOuter|Inner|LeftAnti|LeftOuter|RightAnti|RightOuter)\b/,/\bGroupKind\.(?:Global|Local)\b/,/\bExtraValues\.(?:Error|Ignore|List)\b/,/\bJoinAlgorithm\.(?:Dynamic|LeftHash|LeftIndex|PairwiseHash|RightHash|RightIndex|SortMerge)\b/,/\bJoinSide\.(?:Left|Right)\b/,/\bPrecision\.(?:Decimal|Double)\b/,/\bRelativePosition\.From(?:End|Start)\b/,/\bTextEncoding\.(?:Ascii|BigEndianUnicode|Unicode|Utf16|Utf8|Windows)\b/,/\b(?:Any|Binary|Date|DateTime|DateTimeZone|Duration|Function|Int16|Int32|Int64|Int8|List|Logical|None|Number|Record|Table|Text|Time)\.Type\b/,/\bnull\b/],boolean:/\b(?:false|true)\b/,keyword:/\b(?:and|as|each|else|error|if|in|is|let|meta|not|nullable|optional|or|otherwise|section|shared|then|try|type)\b|#(?:binary|date|datetime|datetimezone|duration|infinity|nan|sections|shared|table|time)\b/,function:{pattern:/(^|[^#\w.])[a-z_][\w.]*(?=\s*\()/i,lookbehind:!0},"data-type":{pattern:/\b(?:any|anynonnull|binary|date|datetime|datetimezone|duration|function|list|logical|none|number|record|table|text|time)\b/,alias:"class-name"},number:{pattern:/\b0x[\da-f]+\b|(?:[+-]?(?:\b\d+\.)?\b\d+|[+-]\.\d+|(^|[^.])\B\.\d+)(?:e[+-]?\d+)?\b/i,lookbehind:!0},operator:/[-+*\/&?@^]|<(?:=>?|>)?|>=?|=>?|\.\.\.?/,punctuation:/[,;\[\](){}]/},e.languages.pq=e.languages.powerquery,e.languages.mscript=e.languages.powerquery}P4.displayName="powershell";P4.aliases=[];function P4(e){(function(t){var n=t.languages.powershell={comment:[{pattern:/(^|[^`])<#[\s\S]*?#>/,lookbehind:!0},{pattern:/(^|[^`])#.*/,lookbehind:!0}],string:[{pattern:/"(?:`[\s\S]|[^`"])*"/,greedy:!0,inside:null},{pattern:/'(?:[^']|'')*'/,greedy:!0}],namespace:/\[[a-z](?:\[(?:\[[^\]]*\]|[^\[\]])*\]|[^\[\]])*\]/i,boolean:/\$(?:false|true)\b/i,variable:/\$\w+\b/,function:[/\b(?:Add|Approve|Assert|Backup|Block|Checkpoint|Clear|Close|Compare|Complete|Compress|Confirm|Connect|Convert|ConvertFrom|ConvertTo|Copy|Debug|Deny|Disable|Disconnect|Dismount|Edit|Enable|Enter|Exit|Expand|Export|Find|ForEach|Format|Get|Grant|Group|Hide|Import|Initialize|Install|Invoke|Join|Limit|Lock|Measure|Merge|Move|New|Open|Optimize|Out|Ping|Pop|Protect|Publish|Push|Read|Receive|Redo|Register|Remove|Rename|Repair|Request|Reset|Resize|Resolve|Restart|Restore|Resume|Revoke|Save|Search|Select|Send|Set|Show|Skip|Sort|Split|Start|Step|Stop|Submit|Suspend|Switch|Sync|Tee|Test|Trace|Unblock|Undo|Uninstall|Unlock|Unprotect|Unpublish|Unregister|Update|Use|Wait|Watch|Where|Write)-[a-z]+\b/i,/\b(?:ac|cat|chdir|clc|cli|clp|clv|compare|copy|cp|cpi|cpp|cvpa|dbp|del|diff|dir|ebp|echo|epal|epcsv|epsn|erase|fc|fl|ft|fw|gal|gbp|gc|gci|gcs|gdr|gi|gl|gm|gp|gps|group|gsv|gu|gv|gwmi|iex|ii|ipal|ipcsv|ipsn|irm|iwmi|iwr|kill|lp|ls|measure|mi|mount|move|mp|mv|nal|ndr|ni|nv|ogv|popd|ps|pushd|pwd|rbp|rd|rdr|ren|ri|rm|rmdir|rni|rnp|rp|rv|rvpa|rwmi|sal|saps|sasv|sbp|sc|select|set|shcm|si|sl|sleep|sls|sort|sp|spps|spsv|start|sv|swmi|tee|trcm|type|write)\b/i],keyword:/\b(?:Begin|Break|Catch|Class|Continue|Data|Define|Do|DynamicParam|Else|ElseIf|End|Exit|Filter|Finally|For|ForEach|From|Function|If|InlineScript|Parallel|Param|Process|Return|Sequence|Switch|Throw|Trap|Try|Until|Using|Var|While|Workflow)\b/i,operator:{pattern:/(^|\W)(?:!|-(?:b?(?:and|x?or)|as|(?:Not)?(?:Contains|In|Like|Match)|eq|ge|gt|is(?:Not)?|Join|le|lt|ne|not|Replace|sh[lr])\b|-[-=]?|\+[+=]?|[*\/%]=?)/i,lookbehind:!0},punctuation:/[|{}[\];(),.]/};n.string[0].inside={function:{pattern:/(^|[^`])\$\((?:\$\([^\r\n()]*\)|(?!\$\()[^\r\n)])*\)/,lookbehind:!0,inside:n},boolean:n.boolean,variable:n.variable}})(e)}U4.displayName="processing";U4.aliases=[];function U4(e){e.register(Mt),e.languages.processing=e.languages.extend("clike",{keyword:/\b(?:break|case|catch|class|continue|default|else|extends|final|for|if|implements|import|new|null|private|public|return|static|super|switch|this|try|void|while)\b/,function:/\b\w+(?=\s*\()/,operator:/<[<=]?|>[>=]?|&&?|\|\|?|[%?]|[!=+\-*\/]=?/}),e.languages.insertBefore("processing","number",{constant:/\b(?!XML\b)[A-Z][A-Z\d_]+\b/,type:{pattern:/\b(?:boolean|byte|char|color|double|float|int|[A-Z]\w*)\b/,alias:"class-name"}})}j4.displayName="prolog";j4.aliases=[];function j4(e){e.languages.prolog={comment:{pattern:/\/\*[\s\S]*?\*\/|%.*/,greedy:!0},string:{pattern:/(["'])(?:\1\1|\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1(?!\1)/,greedy:!0},builtin:/\b(?:fx|fy|xf[xy]?|yfx?)\b/,function:/\b[a-z]\w*(?:(?=\()|\/\d+)/,number:/\b\d+(?:\.\d*)?/,operator:/[:\\=><\-?*@\/;+^|!$.]+|\b(?:is|mod|not|xor)\b/,punctuation:/[(){}\[\],]/}}H4.displayName="promql";H4.aliases=[];function H4(e){(function(t){var n=["sum","min","max","avg","group","stddev","stdvar","count","count_values","bottomk","topk","quantile"],r=["on","ignoring","group_right","group_left","by","without"],a=["offset"],i=n.concat(r,a);t.languages.promql={comment:{pattern:/(^[ \t]*)#.*/m,lookbehind:!0},"vector-match":{pattern:new RegExp("((?:"+r.join("|")+")\\s*)\\([^)]*\\)"),lookbehind:!0,inside:{"label-key":{pattern:/\b[^,]+\b/,alias:"attr-name"},punctuation:/[(),]/}},"context-labels":{pattern:/\{[^{}]*\}/,inside:{"label-key":{pattern:/\b[a-z_]\w*(?=\s*(?:=|![=~]))/,alias:"attr-name"},"label-value":{pattern:/(["'`])(?:\\[\s\S]|(?!\1)[^\\])*\1/,greedy:!0,alias:"attr-value"},punctuation:/\{|\}|=~?|![=~]|,/}},"context-range":[{pattern:/\[[\w\s:]+\]/,inside:{punctuation:/\[|\]|:/,"range-duration":{pattern:/\b(?:\d+(?:[smhdwy]|ms))+\b/i,alias:"number"}}},{pattern:/(\boffset\s+)\w+/,lookbehind:!0,inside:{"range-duration":{pattern:/\b(?:\d+(?:[smhdwy]|ms))+\b/i,alias:"number"}}}],keyword:new RegExp("\\b(?:"+i.join("|")+")\\b","i"),function:/\b[a-z_]\w*(?=\s*\()/i,number:/[-+]?(?:(?:\b\d+(?:\.\d+)?|\B\.\d+)(?:e[-+]?\d+)?\b|\b(?:0x[0-9a-f]+|nan|inf)\b)/i,operator:/[\^*/%+-]|==|!=|<=|<|>=|>|\b(?:and|or|unless)\b/i,punctuation:/[{};()`,.[\]]/}})(e)}G4.displayName="properties";G4.aliases=[];function G4(e){e.languages.properties={comment:/^[ \t]*[#!].*$/m,value:{pattern:/(^[ \t]*(?:\\(?:\r\n|[\s\S])|[^\\\s:=])+(?: *[=:] *(?! )| ))(?:\\(?:\r\n|[\s\S])|[^\\\r\n])+/m,lookbehind:!0,alias:"attr-value"},key:{pattern:/^[ \t]*(?:\\(?:\r\n|[\s\S])|[^\\\s:=])+(?= *[=:]| )/m,alias:"attr-name"},punctuation:/[=:]/}}q4.displayName="protobuf";q4.aliases=[];function q4(e){e.register(Mt),(function(t){var n=/\b(?:bool|bytes|double|s?fixed(?:32|64)|float|[su]?int(?:32|64)|string)\b/;t.languages.protobuf=t.languages.extend("clike",{"class-name":[{pattern:/(\b(?:enum|extend|message|service)\s+)[A-Za-z_]\w*(?=\s*\{)/,lookbehind:!0},{pattern:/(\b(?:rpc\s+\w+|returns)\s*\(\s*(?:stream\s+)?)\.?[A-Za-z_]\w*(?:\.[A-Za-z_]\w*)*(?=\s*\))/,lookbehind:!0}],keyword:/\b(?:enum|extend|extensions|import|message|oneof|option|optional|package|public|repeated|required|reserved|returns|rpc(?=\s+\w)|service|stream|syntax|to)\b(?!\s*=\s*\d)/,function:/\b[a-z_]\w*(?=\s*\()/i}),t.languages.insertBefore("protobuf","operator",{map:{pattern:/\bmap<\s*[\w.]+\s*,\s*[\w.]+\s*>(?=\s+[a-z_]\w*\s*[=;])/i,alias:"class-name",inside:{punctuation:/[<>.,]/,builtin:n}},builtin:n,"positional-class-name":{pattern:/(?:\b|\B\.)[a-z_]\w*(?:\.[a-z_]\w*)*(?=\s+[a-z_]\w*\s*[=;])/i,alias:"class-name",inside:{punctuation:/\./}},annotation:{pattern:/(\[\s*)[a-z_]\w*(?=\s*=)/i,lookbehind:!0}})})(e)}W4.displayName="stylus";W4.aliases=[];function W4(e){(function(t){var n={pattern:/(\b\d+)(?:%|[a-z]+)/,lookbehind:!0},r={pattern:/(^|[^\w.-])-?(?:\d+(?:\.\d+)?|\.\d+)/,lookbehind:!0},a={comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?\*\/|\/\/.*)/,lookbehind:!0},url:{pattern:/\burl\((["']?).*?\1\)/i,greedy:!0},string:{pattern:/("|')(?:(?!\1)[^\\\r\n]|\\(?:\r\n|[\s\S]))*\1/,greedy:!0},interpolation:null,func:null,important:/\B!(?:important|optional)\b/i,keyword:{pattern:/(^|\s+)(?:(?:else|for|if|return|unless)(?=\s|$)|@[\w-]+)/,lookbehind:!0},hexcode:/#[\da-f]{3,6}/i,color:[/\b(?:AliceBlue|AntiqueWhite|Aqua|Aquamarine|Azure|Beige|Bisque|Black|BlanchedAlmond|Blue|BlueViolet|Brown|BurlyWood|CadetBlue|Chartreuse|Chocolate|Coral|CornflowerBlue|Cornsilk|Crimson|Cyan|DarkBlue|DarkCyan|DarkGoldenRod|DarkGr[ae]y|DarkGreen|DarkKhaki|DarkMagenta|DarkOliveGreen|DarkOrange|DarkOrchid|DarkRed|DarkSalmon|DarkSeaGreen|DarkSlateBlue|DarkSlateGr[ae]y|DarkTurquoise|DarkViolet|DeepPink|DeepSkyBlue|DimGr[ae]y|DodgerBlue|FireBrick|FloralWhite|ForestGreen|Fuchsia|Gainsboro|GhostWhite|Gold|GoldenRod|Gr[ae]y|Green|GreenYellow|HoneyDew|HotPink|IndianRed|Indigo|Ivory|Khaki|Lavender|LavenderBlush|LawnGreen|LemonChiffon|LightBlue|LightCoral|LightCyan|LightGoldenRodYellow|LightGr[ae]y|LightGreen|LightPink|LightSalmon|LightSeaGreen|LightSkyBlue|LightSlateGr[ae]y|LightSteelBlue|LightYellow|Lime|LimeGreen|Linen|Magenta|Maroon|MediumAquaMarine|MediumBlue|MediumOrchid|MediumPurple|MediumSeaGreen|MediumSlateBlue|MediumSpringGreen|MediumTurquoise|MediumVioletRed|MidnightBlue|MintCream|MistyRose|Moccasin|NavajoWhite|Navy|OldLace|Olive|OliveDrab|Orange|OrangeRed|Orchid|PaleGoldenRod|PaleGreen|PaleTurquoise|PaleVioletRed|PapayaWhip|PeachPuff|Peru|Pink|Plum|PowderBlue|Purple|Red|RosyBrown|RoyalBlue|SaddleBrown|Salmon|SandyBrown|SeaGreen|SeaShell|Sienna|Silver|SkyBlue|SlateBlue|SlateGr[ae]y|Snow|SpringGreen|SteelBlue|Tan|Teal|Thistle|Tomato|Transparent|Turquoise|Violet|Wheat|White|WhiteSmoke|Yellow|YellowGreen)\b/i,{pattern:/\b(?:hsl|rgb)\(\s*\d{1,3}\s*,\s*\d{1,3}%?\s*,\s*\d{1,3}%?\s*\)\B|\b(?:hsl|rgb)a\(\s*\d{1,3}\s*,\s*\d{1,3}%?\s*,\s*\d{1,3}%?\s*,\s*(?:0|0?\.\d+|1)\s*\)\B/i,inside:{unit:n,number:r,function:/[\w-]+(?=\()/,punctuation:/[(),]/}}],entity:/\\[\da-f]{1,8}/i,unit:n,boolean:/\b(?:false|true)\b/,operator:[/~|[+!\/%<>?=]=?|[-:]=|\*[*=]?|\.{2,3}|&&|\|\||\B-\B|\b(?:and|in|is(?: a| defined| not|nt)?|not|or)\b/],number:r,punctuation:/[{}()\[\];:,]/};a.interpolation={pattern:/\{[^\r\n}:]+\}/,alias:"variable",inside:{delimiter:{pattern:/^\{|\}$/,alias:"punctuation"},rest:a}},a.func={pattern:/[\w-]+\([^)]*\).*/,inside:{function:/^[^(]+/,rest:a}},t.languages.stylus={"atrule-declaration":{pattern:/(^[ \t]*)@.+/m,lookbehind:!0,inside:{atrule:/^@[\w-]+/,rest:a}},"variable-declaration":{pattern:/(^[ \t]*)[\w$-]+\s*.?=[ \t]*(?:\{[^{}]*\}|\S.*|$)/m,lookbehind:!0,inside:{variable:/^\S+/,rest:a}},statement:{pattern:/(^[ \t]*)(?:else|for|if|return|unless)[ \t].+/m,lookbehind:!0,inside:{keyword:/^\S+/,rest:a}},"property-declaration":{pattern:/((?:^|\{)([ \t]*))(?:[\w-]|\{[^}\r\n]+\})+(?:\s*:\s*|[ \t]+)(?!\s)[^{\r\n]*(?:;|[^{\r\n,]$(?!(?:\r?\n|\r)(?:\{|\2[ \t])))/m,lookbehind:!0,inside:{property:{pattern:/^[^\s:]+/,inside:{interpolation:a.interpolation}},rest:a}},selector:{pattern:/(^[ \t]*)(?:(?=\S)(?:[^{}\r\n:()]|::?[\w-]+(?:\([^)\r\n]*\)|(?![\w-]))|\{[^}\r\n]+\})+)(?:(?:\r?\n|\r)(?:\1(?:(?=\S)(?:[^{}\r\n:()]|::?[\w-]+(?:\([^)\r\n]*\)|(?![\w-]))|\{[^}\r\n]+\})+)))*(?:,$|\{|(?=(?:\r?\n|\r)(?:\{|\1[ \t])))/m,lookbehind:!0,inside:{interpolation:a.interpolation,comment:a.comment,punctuation:/[{},]/}},func:a.func,string:a.string,comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?\*\/|\/\/.*)/,lookbehind:!0,greedy:!0},interpolation:a.interpolation,punctuation:/[{}()\[\];:.]/}})(e)}V4.displayName="twig";V4.aliases=[];function V4(e){e.register(Er),e.languages.twig={comment:/^\{#[\s\S]*?#\}$/,"tag-name":{pattern:/(^\{%-?\s*)\w+/,lookbehind:!0,alias:"keyword"},delimiter:{pattern:/^\{[{%]-?|-?[%}]\}$/,alias:"punctuation"},string:{pattern:/("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,inside:{punctuation:/^['"]|['"]$/}},keyword:/\b(?:even|if|odd)\b/,boolean:/\b(?:false|null|true)\b/,number:/\b0x[\dA-Fa-f]+|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee][-+]?\d+)?/,operator:[{pattern:/(\s)(?:and|b-and|b-or|b-xor|ends with|in|is|matches|not|or|same as|starts with)(?=\s)/,lookbehind:!0},/[=<>]=?|!=|\*\*?|\/\/?|\?:?|[-+~%|]/],punctuation:/[()\[\]{}:.,]/},e.hooks.add("before-tokenize",function(t){if(t.language==="twig"){var n=/\{(?:#[\s\S]*?#|%[\s\S]*?%|\{[\s\S]*?\})\}/g;e.languages["markup-templating"].buildPlaceholders(t,"twig",n)}}),e.hooks.add("after-tokenize",function(t){e.languages["markup-templating"].tokenizePlaceholders(t,"twig")})}Y4.displayName="pug";Y4.aliases=[];function Y4(e){e.register(wr),e.register(cr),(function(t){t.languages.pug={comment:{pattern:/(^([\t ]*))\/\/.*(?:(?:\r?\n|\r)\2[\t ].+)*/m,lookbehind:!0},"multiline-script":{pattern:/(^([\t ]*)script\b.*\.[\t ]*)(?:(?:\r?\n|\r(?!\n))(?:\2[\t ].+|\s*?(?=\r?\n|\r)))+/m,lookbehind:!0,inside:t.languages.javascript},filter:{pattern:/(^([\t ]*)):.+(?:(?:\r?\n|\r(?!\n))(?:\2[\t ].+|\s*?(?=\r?\n|\r)))+/m,lookbehind:!0,inside:{"filter-name":{pattern:/^:[\w-]+/,alias:"variable"},text:/\S[\s\S]*/}},"multiline-plain-text":{pattern:/(^([\t ]*)[\w\-#.]+\.[\t ]*)(?:(?:\r?\n|\r(?!\n))(?:\2[\t ].+|\s*?(?=\r?\n|\r)))+/m,lookbehind:!0},markup:{pattern:/(^[\t ]*)<.+/m,lookbehind:!0,inside:t.languages.markup},doctype:{pattern:/((?:^|\n)[\t ]*)doctype(?: .+)?/,lookbehind:!0},"flow-control":{pattern:/(^[\t ]*)(?:case|default|each|else|if|unless|when|while)\b(?: .+)?/m,lookbehind:!0,inside:{each:{pattern:/^each .+? in\b/,inside:{keyword:/\b(?:each|in)\b/,punctuation:/,/}},branch:{pattern:/^(?:case|default|else|if|unless|when|while)\b/,alias:"keyword"},rest:t.languages.javascript}},keyword:{pattern:/(^[\t ]*)(?:append|block|extends|include|prepend)\b.+/m,lookbehind:!0},mixin:[{pattern:/(^[\t ]*)mixin .+/m,lookbehind:!0,inside:{keyword:/^mixin/,function:/\w+(?=\s*\(|\s*$)/,punctuation:/[(),.]/}},{pattern:/(^[\t ]*)\+.+/m,lookbehind:!0,inside:{name:{pattern:/^\+\w+/,alias:"function"},rest:t.languages.javascript}}],script:{pattern:/(^[\t ]*script(?:(?:&[^(]+)?\([^)]+\))*[\t ]).+/m,lookbehind:!0,inside:t.languages.javascript},"plain-text":{pattern:/(^[\t ]*(?!-)[\w\-#.]*[\w\-](?:(?:&[^(]+)?\([^)]+\))*\/?[\t ]).+/m,lookbehind:!0},tag:{pattern:/(^[\t ]*)(?!-)[\w\-#.]*[\w\-](?:(?:&[^(]+)?\([^)]+\))*\/?:?/m,lookbehind:!0,inside:{attributes:[{pattern:/&[^(]+\([^)]+\)/,inside:t.languages.javascript},{pattern:/\([^)]+\)/,inside:{"attr-value":{pattern:/(=\s*(?!\s))(?:\{[^}]*\}|[^,)\r\n]+)/,lookbehind:!0,inside:t.languages.javascript},"attr-name":/[\w-]+(?=\s*!?=|\s*[,)])/,punctuation:/[!=(),]+/}}],punctuation:/:/,"attr-id":/#[\w\-]+/,"attr-class":/\.[\w\-]+/}},code:[{pattern:/(^[\t ]*(?:-|!?=)).+/m,lookbehind:!0,inside:t.languages.javascript}],punctuation:/[.\-!=|]+/};for(var n=/(^([\t ]*)):<filter_name>(?:(?:\r?\n|\r(?!\n))(?:\2[\t ].+|\s*?(?=\r?\n|\r)))+/.source,r=[{filter:"atpl",language:"twig"},{filter:"coffee",language:"coffeescript"},"ejs","handlebars","less","livescript","markdown",{filter:"sass",language:"scss"},"stylus"],a={},i=0,o=r.length;i<o;i++){var l=r[i];l=typeof l=="string"?{filter:l,language:l}:l,t.languages[l.language]&&(a["filter-"+l.filter]={pattern:RegExp(n.replace("<filter_name>",function(){return l.filter}),"m"),lookbehind:!0,inside:{"filter-name":{pattern:/^:[\w-]+/,alias:"variable"},text:{pattern:/\S[\s\S]*/,alias:[l.language,"language-"+l.language],inside:t.languages[l.language]}}})}t.languages.insertBefore("pug","filter",a)})(e)}X4.displayName="puppet";X4.aliases=[];function X4(e){(function(t){t.languages.puppet={heredoc:[{pattern:/(@\("([^"\r\n\/):]+)"(?:\/[nrts$uL]*)?\).*(?:\r?\n|\r))(?:.*(?:\r?\n|\r(?!\n)))*?[ \t]*(?:\|[ \t]*)?(?:-[ \t]*)?\2/,lookbehind:!0,alias:"string",inside:{punctuation:/(?=\S).*\S(?= *$)/}},{pattern:/(@\(([^"\r\n\/):]+)(?:\/[nrts$uL]*)?\).*(?:\r?\n|\r))(?:.*(?:\r?\n|\r(?!\n)))*?[ \t]*(?:\|[ \t]*)?(?:-[ \t]*)?\2/,lookbehind:!0,greedy:!0,alias:"string",inside:{punctuation:/(?=\S).*\S(?= *$)/}},{pattern:/@\("?(?:[^"\r\n\/):]+)"?(?:\/[nrts$uL]*)?\)/,alias:"string",inside:{punctuation:{pattern:/(\().+?(?=\))/,lookbehind:!0}}}],"multiline-comment":{pattern:/(^|[^\\])\/\*[\s\S]*?\*\//,lookbehind:!0,greedy:!0,alias:"comment"},regex:{pattern:/((?:\bnode\s+|[~=\(\[\{,]\s*|[=+]>\s*|^\s*))\/(?:[^\/\\]|\\[\s\S])+\/(?:[imx]+\b|\B)/,lookbehind:!0,greedy:!0,inside:{"extended-regex":{pattern:/^\/(?:[^\/\\]|\\[\s\S])+\/[im]*x[im]*$/,inside:{comment:/#.*/}}}},comment:{pattern:/(^|[^\\])#.*/,lookbehind:!0,greedy:!0},string:{pattern:/(["'])(?:\$\{(?:[^'"}]|(["'])(?:(?!\2)[^\\]|\\[\s\S])*\2)+\}|\$(?!\{)|(?!\1)[^\\$]|\\[\s\S])*\1/,greedy:!0,inside:{"double-quoted":{pattern:/^"[\s\S]*"$/,inside:{}}}},variable:{pattern:/\$(?:::)?\w+(?:::\w+)*/,inside:{punctuation:/::/}},"attr-name":/(?:\b\w+|\*)(?=\s*=>)/,function:[{pattern:/(\.)(?!\d)\w+/,lookbehind:!0},/\b(?:contain|debug|err|fail|include|info|notice|realize|require|tag|warning)\b|\b(?!\d)\w+(?=\()/],number:/\b(?:0x[a-f\d]+|\d+(?:\.\d+)?(?:e-?\d+)?)\b/i,boolean:/\b(?:false|true)\b/,keyword:/\b(?:application|attr|case|class|consumes|default|define|else|elsif|function|if|import|inherits|node|private|produces|type|undef|unless)\b/,datatype:{pattern:/\b(?:Any|Array|Boolean|Callable|Catalogentry|Class|Collection|Data|Default|Enum|Float|Hash|Integer|NotUndef|Numeric|Optional|Pattern|Regexp|Resource|Runtime|Scalar|String|Struct|Tuple|Type|Undef|Variant)\b/,alias:"symbol"},operator:/=[=~>]?|![=~]?|<(?:<\|?|[=~|-])?|>[>=]?|->?|~>|\|>?>?|[*\/%+?]|\b(?:and|in|or)\b/,punctuation:/[\[\]{}().,;]|:+/};var n=[{pattern:/(^|[^\\])\$\{(?:[^'"{}]|\{[^}]*\}|(["'])(?:(?!\2)[^\\]|\\[\s\S])*\2)+\}/,lookbehind:!0,inside:{"short-variable":{pattern:/(^\$\{)(?!\w+\()(?:::)?\w+(?:::\w+)*/,lookbehind:!0,alias:"variable",inside:{punctuation:/::/}},delimiter:{pattern:/^\$/,alias:"variable"},rest:t.languages.puppet}},{pattern:/(^|[^\\])\$(?:::)?\w+(?:::\w+)*/,lookbehind:!0,alias:"variable",inside:{punctuation:/::/}}];t.languages.puppet.heredoc[0].inside.interpolation=n,t.languages.puppet.string.inside["double-quoted"].inside.interpolation=n})(e)}K4.displayName="pure";K4.aliases=[];function K4(e){(function(t){t.languages.pure={comment:[{pattern:/(^|[^\\])\/\*[\s\S]*?\*\//,lookbehind:!0},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0},/#!.+/],"inline-lang":{pattern:/%<[\s\S]+?%>/,greedy:!0,inside:{lang:{pattern:/(^%< *)-\*-.+?-\*-/,lookbehind:!0,alias:"comment"},delimiter:{pattern:/^%<.*|%>$/,alias:"punctuation"}}},string:{pattern:/"(?:\\.|[^"\\\r\n])*"/,greedy:!0},number:{pattern:/((?:\.\.)?)(?:\b(?:inf|nan)\b|\b0x[\da-f]+|(?:\b(?:0b)?\d+(?:\.\d+)?|\B\.\d+)(?:e[+-]?\d+)?L?)/i,lookbehind:!0},keyword:/\b(?:NULL|ans|break|bt|case|catch|cd|clear|const|def|del|dump|else|end|exit|extern|false|force|help|if|infix[lr]?|interface|let|ls|mem|namespace|nonfix|of|otherwise|outfix|override|postfix|prefix|private|public|pwd|quit|run|save|show|stats|then|throw|trace|true|type|underride|using|when|with)\b/,function:/\b(?:abs|add_(?:addr|constdef|(?:fundef|interface|macdef|typedef)(?:_at)?|vardef)|all|any|applp?|arity|bigintp?|blob(?:_crc|_size|p)?|boolp?|byte_c?string(?:_pointer)?|byte_(?:matrix|pointer)|calloc|cat|catmap|ceil|char[ps]?|check_ptrtag|chr|clear_sentry|clearsym|closurep?|cmatrixp?|cols?|colcat(?:map)?|colmap|colrev|colvector(?:p|seq)?|complex(?:_float_(?:matrix|pointer)|_matrix(?:_view)?|_pointer|p)?|conj|cookedp?|cst|cstring(?:_(?:dup|list|vector))?|curry3?|cyclen?|del_(?:constdef|fundef|interface|macdef|typedef|vardef)|delete|diag(?:mat)?|dim|dmatrixp?|do|double(?:_matrix(?:_view)?|_pointer|p)?|dowith3?|drop|dropwhile|eval(?:cmd)?|exactp|filter|fix|fixity|flip|float(?:_matrix|_pointer)|floor|fold[lr]1?|frac|free|funp?|functionp?|gcd|get(?:_(?:byte|constdef|double|float|fundef|int(?:64)?|interface(?:_typedef)?|long|macdef|pointer|ptrtag|sentry|short|string|typedef|vardef))?|globsym|hash|head|id|im|imatrixp?|index|inexactp|infp|init|insert|int(?:_matrix(?:_view)?|_pointer|p)?|int64_(?:matrix|pointer)|integerp?|iteraten?|iterwhile|join|keys?|lambdap?|last(?:err(?:pos)?)?|lcd|list[2p]?|listmap|make_ptrtag|malloc|map|matcat|matrixp?|max|member|min|nanp|nargs|nmatrixp?|null|numberp?|ord|pack(?:ed)?|pointer(?:_cast|_tag|_type|p)?|pow|pred|ptrtag|put(?:_(?:byte|double|float|int(?:64)?|long|pointer|short|string))?|rationalp?|re|realp?|realloc|recordp?|redim|reduce(?:_with)?|refp?|repeatn?|reverse|rlistp?|round|rows?|rowcat(?:map)?|rowmap|rowrev|rowvector(?:p|seq)?|same|scan[lr]1?|sentry|sgn|short_(?:matrix|pointer)|slice|smatrixp?|sort|split|str|strcat|stream|stride|string(?:_(?:dup|list|vector)|p)?|subdiag(?:mat)?|submat|subseq2?|substr|succ|supdiag(?:mat)?|symbolp?|tail|take|takewhile|thunkp?|transpose|trunc|tuplep?|typep|ubyte|uint(?:64)?|ulong|uncurry3?|unref|unzip3?|update|ushort|vals?|varp?|vector(?:p|seq)?|void|zip3?|zipwith3?)\b/,special:{pattern:/\b__[a-z]+__\b/i,alias:"builtin"},operator:/(?:[!"#$%&'*+,\-.\/:<=>?@\\^`|~\u00a1-\u00bf\u00d7-\u00f7\u20d0-\u2bff]|\b_+\b)+|\b(?:and|div|mod|not|or)\b/,punctuation:/[(){}\[\];,|]/};var n=["c",{lang:"c++",alias:"cpp"},"fortran"],r=/%< *-\*- *<lang>\d* *-\*-[\s\S]+?%>/.source;n.forEach(function(a){var i=a;if(typeof a!="string"&&(i=a.alias,a=a.lang),t.languages[i]){var o={};o["inline-lang-"+i]={pattern:RegExp(r.replace("<lang>",a.replace(/([.+*?\/\\(){}\[\]])/g,"\\$1")),"i"),inside:t.util.clone(t.languages.pure["inline-lang"].inside)},o["inline-lang-"+i].inside.rest=t.util.clone(t.languages[i]),t.languages.insertBefore("pure","inline-lang",o)}}),t.languages.c&&(t.languages.pure["inline-lang"].inside.rest=t.util.clone(t.languages.c))})(e)}Z4.displayName="purebasic";Z4.aliases=["pbfasm"];function Z4(e){e.register(Mt),e.languages.purebasic=e.languages.extend("clike",{comment:/;.*/,keyword:/\b(?:align|and|as|break|calldebugger|case|compilercase|compilerdefault|compilerelse|compilerelseif|compilerendif|compilerendselect|compilererror|compilerif|compilerselect|continue|data|datasection|debug|debuglevel|declare|declarec|declarecdll|declaredll|declaremodule|default|define|dim|disableasm|disabledebugger|disableexplicit|else|elseif|enableasm|enabledebugger|enableexplicit|end|enddatasection|enddeclaremodule|endenumeration|endif|endimport|endinterface|endmacro|endmodule|endprocedure|endselect|endstructure|endstructureunion|endwith|enumeration|extends|fakereturn|for|foreach|forever|global|gosub|goto|if|import|importc|includebinary|includefile|includepath|interface|macro|module|newlist|newmap|next|not|or|procedure|procedurec|procedurecdll|proceduredll|procedurereturn|protected|prototype|prototypec|read|redim|repeat|restore|return|runtime|select|shared|static|step|structure|structureunion|swap|threaded|to|until|wend|while|with|xincludefile|xor)\b/i,function:/\b\w+(?:\.\w+)?\s*(?=\()/,number:/(?:\$[\da-f]+|\b-?(?:\d+(?:\.\d+)?|\.\d+)(?:e[+-]?\d+)?)\b/i,operator:/(?:@\*?|\?|\*)\w+\$?|-[>-]?|\+\+?|!=?|<<?=?|>>?=?|==?|&&?|\|?\||[~^%?*/@]/}),e.languages.insertBefore("purebasic","keyword",{tag:/#\w+\$?/,asm:{pattern:/(^[\t ]*)!.*/m,lookbehind:!0,alias:"tag",inside:{comment:/;.*/,string:{pattern:/(["'`])(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0},"label-reference-anonymous":{pattern:/(!\s*j[a-z]+\s+)@[fb]/i,lookbehind:!0,alias:"fasm-label"},"label-reference-addressed":{pattern:/(!\s*j[a-z]+\s+)[A-Z._?$@][\w.?$@~#]*/i,lookbehind:!0,alias:"fasm-label"},keyword:[/\b(?:extern|global)\b[^;\r\n]*/i,/\b(?:CPU|DEFAULT|FLOAT)\b.*/],function:{pattern:/^([\t ]*!\s*)[\da-z]+(?=\s|$)/im,lookbehind:!0},"function-inline":{pattern:/(:\s*)[\da-z]+(?=\s)/i,lookbehind:!0,alias:"function"},label:{pattern:/^([\t ]*!\s*)[A-Za-z._?$@][\w.?$@~#]*(?=:)/m,lookbehind:!0,alias:"fasm-label"},register:/\b(?:st\d|[xyz]mm\d\d?|[cdt]r\d|r\d\d?[bwd]?|[er]?[abcd]x|[abcd][hl]|[er]?(?:bp|di|si|sp)|[cdefgs]s|mm\d+)\b/i,number:/(?:\b|-|(?=\$))(?:0[hx](?:[\da-f]*\.)?[\da-f]+(?:p[+-]?\d+)?|\d[\da-f]+[hx]|\$\d[\da-f]*|0[oq][0-7]+|[0-7]+[oq]|0[by][01]+|[01]+[by]|0[dt]\d+|(?:\d+(?:\.\d+)?|\.\d+)(?:\.?e[+-]?\d+)?[dt]?)\b/i,operator:/[\[\]*+\-/%<>=&|$!,.:]/}}}),delete e.languages.purebasic["class-name"],delete e.languages.purebasic.boolean,e.languages.pbfasm=e.languages.purebasic}Q4.displayName="purescript";Q4.aliases=["purs"];function Q4(e){e.register(op),e.languages.purescript=e.languages.extend("haskell",{keyword:/\b(?:ado|case|class|data|derive|do|else|forall|if|in|infixl|infixr|instance|let|module|newtype|of|primitive|then|type|where)\b|∀/,"import-statement":{pattern:/(^[\t ]*)import\s+[A-Z][\w']*(?:\.[A-Z][\w']*)*(?:\s+as\s+[A-Z][\w']*(?:\.[A-Z][\w']*)*)?(?:\s+hiding\b)?/m,lookbehind:!0,inside:{keyword:/\b(?:as|hiding|import)\b/,punctuation:/\./}},builtin:/\b(?:absurd|add|ap|append|apply|between|bind|bottom|clamp|compare|comparing|compose|conj|const|degree|discard|disj|div|eq|flap|flip|gcd|identity|ifM|join|lcm|liftA1|liftM1|map|max|mempty|min|mod|mul|negate|not|notEq|one|otherwise|recip|show|sub|top|unit|unless|unlessM|void|when|whenM|zero)\b/,operator:[e.languages.haskell.operator[0],e.languages.haskell.operator[2],/[\xa2-\xa6\xa8\xa9\xac\xae-\xb1\xb4\xb8\xd7\xf7\u02c2-\u02c5\u02d2-\u02df\u02e5-\u02eb\u02ed\u02ef-\u02ff\u0375\u0384\u0385\u03f6\u0482\u058d-\u058f\u0606-\u0608\u060b\u060e\u060f\u06de\u06e9\u06fd\u06fe\u07f6\u07fe\u07ff\u09f2\u09f3\u09fa\u09fb\u0af1\u0b70\u0bf3-\u0bfa\u0c7f\u0d4f\u0d79\u0e3f\u0f01-\u0f03\u0f13\u0f15-\u0f17\u0f1a-\u0f1f\u0f34\u0f36\u0f38\u0fbe-\u0fc5\u0fc7-\u0fcc\u0fce\u0fcf\u0fd5-\u0fd8\u109e\u109f\u1390-\u1399\u166d\u17db\u1940\u19de-\u19ff\u1b61-\u1b6a\u1b74-\u1b7c\u1fbd\u1fbf-\u1fc1\u1fcd-\u1fcf\u1fdd-\u1fdf\u1fed-\u1fef\u1ffd\u1ffe\u2044\u2052\u207a-\u207c\u208a-\u208c\u20a0-\u20bf\u2100\u2101\u2103-\u2106\u2108\u2109\u2114\u2116-\u2118\u211e-\u2123\u2125\u2127\u2129\u212e\u213a\u213b\u2140-\u2144\u214a-\u214d\u214f\u218a\u218b\u2190-\u2307\u230c-\u2328\u232b-\u2426\u2440-\u244a\u249c-\u24e9\u2500-\u2767\u2794-\u27c4\u27c7-\u27e5\u27f0-\u2982\u2999-\u29d7\u29dc-\u29fb\u29fe-\u2b73\u2b76-\u2b95\u2b97-\u2bff\u2ce5-\u2cea\u2e50\u2e51\u2e80-\u2e99\u2e9b-\u2ef3\u2f00-\u2fd5\u2ff0-\u2ffb\u3004\u3012\u3013\u3020\u3036\u3037\u303e\u303f\u309b\u309c\u3190\u3191\u3196-\u319f\u31c0-\u31e3\u3200-\u321e\u322a-\u3247\u3250\u3260-\u327f\u328a-\u32b0\u32c0-\u33ff\u4dc0-\u4dff\ua490-\ua4c6\ua700-\ua716\ua720\ua721\ua789\ua78a\ua828-\ua82b\ua836-\ua839\uaa77-\uaa79\uab5b\uab6a\uab6b\ufb29\ufbb2-\ufbc1\ufdfc\ufdfd\ufe62\ufe64-\ufe66\ufe69\uff04\uff0b\uff1c-\uff1e\uff3e\uff40\uff5c\uff5e\uffe0-\uffe6\uffe8-\uffee\ufffc\ufffd]/]}),e.languages.purs=e.languages.purescript}Mg.displayName="python";Mg.aliases=["py"];function Mg(e){e.languages.python={comment:{pattern:/(^|[^\\])#.*/,lookbehind:!0,greedy:!0},"string-interpolation":{pattern:/(?:f|fr|rf)(?:("""|''')[\s\S]*?\1|("|')(?:\\.|(?!\2)[^\\\r\n])*\2)/i,greedy:!0,inside:{interpolation:{pattern:/((?:^|[^{])(?:\{\{)*)\{(?!\{)(?:[^{}]|\{(?!\{)(?:[^{}]|\{(?!\{)(?:[^{}])+\})+\})+\}/,lookbehind:!0,inside:{"format-spec":{pattern:/(:)[^:(){}]+(?=\}$)/,lookbehind:!0},"conversion-option":{pattern:/![sra](?=[:}]$)/,alias:"punctuation"},rest:null}},string:/[\s\S]+/}},"triple-quoted-string":{pattern:/(?:[rub]|br|rb)?("""|''')[\s\S]*?\1/i,greedy:!0,alias:"string"},string:{pattern:/(?:[rub]|br|rb)?("|')(?:\\.|(?!\1)[^\\\r\n])*\1/i,greedy:!0},function:{pattern:/((?:^|\s)def[ \t]+)[a-zA-Z_]\w*(?=\s*\()/g,lookbehind:!0},"class-name":{pattern:/(\bclass\s+)\w+/i,lookbehind:!0},decorator:{pattern:/(^[\t ]*)@\w+(?:\.\w+)*/m,lookbehind:!0,alias:["annotation","punctuation"],inside:{punctuation:/\./}},keyword:/\b(?:_(?=\s*:)|and|as|assert|async|await|break|case|class|continue|def|del|elif|else|except|exec|finally|for|from|global|if|import|in|is|lambda|match|nonlocal|not|or|pass|print|raise|return|try|while|with|yield)\b/,builtin:/\b(?:__import__|abs|all|any|apply|ascii|basestring|bin|bool|buffer|bytearray|bytes|callable|chr|classmethod|cmp|coerce|compile|complex|delattr|dict|dir|divmod|enumerate|eval|execfile|file|filter|float|format|frozenset|getattr|globals|hasattr|hash|help|hex|id|input|int|intern|isinstance|issubclass|iter|len|list|locals|long|map|max|memoryview|min|next|object|oct|open|ord|pow|property|range|raw_input|reduce|reload|repr|reversed|round|set|setattr|slice|sorted|staticmethod|str|sum|super|tuple|type|unichr|unicode|vars|xrange|zip)\b/,boolean:/\b(?:False|None|True)\b/,number:/\b0(?:b(?:_?[01])+|o(?:_?[0-7])+|x(?:_?[a-f0-9])+)\b|(?:\b\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\B\.\d+(?:_\d+)*)(?:e[+-]?\d+(?:_\d+)*)?j?(?!\w)/i,operator:/[-+%=]=?|!=|:=|\*\*?=?|\/\/?=?|<[<=>]?|>[=>]?|[&|^~]/,punctuation:/[{}[\];(),.:]/},e.languages.python["string-interpolation"].inside.interpolation.inside.rest=e.languages.python,e.languages.py=e.languages.python}J4.displayName="qsharp";J4.aliases=["qs"];function J4(e){e.register(Mt),(function(t){function n(b,y){return b.replace(/<<(\d+)>>/g,function(v,w){return"(?:"+y[+w]+")"})}function r(b,y,v){return RegExp(n(b,y),"")}function a(b,y){for(var v=0;v<y;v++)b=b.replace(/<<self>>/g,function(){return"(?:"+b+")"});return b.replace(/<<self>>/g,"[^\\s\\S]")}var i={type:"Adj BigInt Bool Ctl Double false Int One Pauli PauliI PauliX PauliY PauliZ Qubit Range Result String true Unit Zero",other:"Adjoint adjoint apply as auto body borrow borrowing Controlled controlled distribute elif else fail fixup for function if in internal intrinsic invert is let mutable namespace new newtype open operation repeat return self set until use using while within"};function o(b){return"\\b(?:"+b.trim().replace(/ /g,"|")+")\\b"}var l=RegExp(o(i.type+" "+i.other)),u=/\b[A-Za-z_]\w*\b/.source,d=n(/<<0>>(?:\s*\.\s*<<0>>)*/.source,[u]),h={keyword:l,punctuation:/[<>()?,.:[\]]/},f=/"(?:\\.|[^\\"])*"/.source;t.languages.qsharp=t.languages.extend("clike",{comment:/\/\/.*/,string:[{pattern:r(/(^|[^$\\])<<0>>/.source,[f]),lookbehind:!0,greedy:!0}],"class-name":[{pattern:r(/(\b(?:as|open)\s+)<<0>>(?=\s*(?:;|as\b))/.source,[d]),lookbehind:!0,inside:h},{pattern:r(/(\bnamespace\s+)<<0>>(?=\s*\{)/.source,[d]),lookbehind:!0,inside:h}],keyword:l,number:/(?:\b0(?:x[\da-f]+|b[01]+|o[0-7]+)|(?:\B\.\d+|\b\d+(?:\.\d*)?)(?:e[-+]?\d+)?)l?\b/i,operator:/\band=|\bor=|\band\b|\bnot\b|\bor\b|<[-=]|[-=]>|>>>=?|<<<=?|\^\^\^=?|\|\|\|=?|&&&=?|w\/=?|~~~|[*\/+\-^=!%]=?/,punctuation:/::|[{}[\];(),.:]/}),t.languages.insertBefore("qsharp","number",{range:{pattern:/\.\./,alias:"operator"}});var m=a(n(/\{(?:[^"{}]|<<0>>|<<self>>)*\}/.source,[f]),2);t.languages.insertBefore("qsharp","string",{"interpolation-string":{pattern:r(/\$"(?:\\.|<<0>>|[^\\"{])*"/.source,[m]),greedy:!0,inside:{interpolation:{pattern:r(/((?:^|[^\\])(?:\\\\)*)<<0>>/.source,[m]),lookbehind:!0,inside:{punctuation:/^\{|\}$/,expression:{pattern:/[\s\S]+/,alias:"language-qsharp",inside:t.languages.qsharp}}},string:/[\s\S]+/}}})})(e),e.languages.qs=e.languages.qsharp}eT.displayName="q";eT.aliases=[];function eT(e){e.languages.q={string:/"(?:\\.|[^"\\\r\n])*"/,comment:[{pattern:/([\t )\]}])\/.*/,lookbehind:!0,greedy:!0},{pattern:/(^|\r?\n|\r)\/[\t ]*(?:(?:\r?\n|\r)(?:.*(?:\r?\n|\r(?!\n)))*?(?:\\(?=[\t ]*(?:\r?\n|\r))|$)|\S.*)/,lookbehind:!0,greedy:!0},{pattern:/^\\[\t ]*(?:\r?\n|\r)[\s\S]+/m,greedy:!0},{pattern:/^#!.+/m,greedy:!0}],symbol:/`(?::\S+|[\w.]*)/,datetime:{pattern:/0N[mdzuvt]|0W[dtz]|\d{4}\.\d\d(?:m|\.\d\d(?:T(?:\d\d(?::\d\d(?::\d\d(?:[.:]\d\d\d)?)?)?)?)?[dz]?)|\d\d:\d\d(?::\d\d(?:[.:]\d\d\d)?)?[uvt]?/,alias:"number"},number:/\b(?![01]:)(?:0N[hje]?|0W[hj]?|0[wn]|0x[\da-fA-F]+|\d+(?:\.\d*)?(?:e[+-]?\d+)?[hjfeb]?)/,keyword:/\\\w+\b|\b(?:abs|acos|aj0?|all|and|any|asc|asin|asof|atan|attr|avgs?|binr?|by|ceiling|cols|cor|cos|count|cov|cross|csv|cut|delete|deltas|desc|dev|differ|distinct|div|do|dsave|ej|enlist|eval|except|exec|exit|exp|fby|fills|first|fkeys|flip|floor|from|get|getenv|group|gtime|hclose|hcount|hdel|hopen|hsym|iasc|identity|idesc|if|ij|in|insert|inter|inv|keys?|last|like|list|ljf?|load|log|lower|lsq|ltime|ltrim|mavg|maxs?|mcount|md5|mdev|med|meta|mins?|mmax|mmin|mmu|mod|msum|neg|next|not|null|or|over|parse|peach|pj|plist|prds?|prev|prior|rand|rank|ratios|raze|read0|read1|reciprocal|reval|reverse|rload|rotate|rsave|rtrim|save|scan|scov|sdev|select|set|setenv|show|signum|sin|sqrt|ssr?|string|sublist|sums?|sv|svar|system|tables|tan|til|trim|txf|type|uj|ungroup|union|update|upper|upsert|value|var|views?|vs|wavg|where|while|within|wj1?|wsum|ww|xasc|xbar|xcols?|xdesc|xexp|xgroup|xkey|xlog|xprev|xrank)\b/,adverb:{pattern:/['\/\\]:?|\beach\b/,alias:"function"},verb:{pattern:/(?:\B\.\B|\b[01]:|<[=>]?|>=?|[:+\-*%,!?~=|$&#@^]):?|\b_\b:?/,alias:"operator"},punctuation:/[(){}\[\];.]/}}tT.displayName="qml";tT.aliases=[];function tT(e){e.register(wr),(function(t){for(var n=/"(?:\\.|[^\\"\r\n])*"|'(?:\\.|[^\\'\r\n])*'/.source,r=/\/\/.*(?!.)|\/\*(?:[^*]|\*(?!\/))*\*\//.source,a=/(?:[^\\()[\]{}"'/]|<string>|\/(?![*/])|<comment>|\(<expr>*\)|\[<expr>*\]|\{<expr>*\}|\\[\s\S])/.source.replace(/<string>/g,function(){return n}).replace(/<comment>/g,function(){return r}),i=0;i<2;i++)a=a.replace(/<expr>/g,function(){return a});a=a.replace(/<expr>/g,"[^\\s\\S]"),t.languages.qml={comment:{pattern:/\/\/.*|\/\*[\s\S]*?\*\//,greedy:!0},"javascript-function":{pattern:RegExp(/((?:^|;)[ \t]*)function\s+(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*\s*\(<js>*\)\s*\{<js>*\}/.source.replace(/<js>/g,function(){return a}),"m"),lookbehind:!0,greedy:!0,alias:"language-javascript",inside:t.languages.javascript},"class-name":{pattern:/((?:^|[:;])[ \t]*)(?!\d)\w+(?=[ \t]*\{|[ \t]+on\b)/m,lookbehind:!0},property:[{pattern:/((?:^|[;{])[ \t]*)(?!\d)\w+(?:\.\w+)*(?=[ \t]*:)/m,lookbehind:!0},{pattern:/((?:^|[;{])[ \t]*)property[ \t]+(?!\d)\w+(?:\.\w+)*[ \t]+(?!\d)\w+(?:\.\w+)*(?=[ \t]*:)/m,lookbehind:!0,inside:{keyword:/^property/,property:/\w+(?:\.\w+)*/}}],"javascript-expression":{pattern:RegExp(/(:[ \t]*)(?![\s;}[])(?:(?!$|[;}])<js>)+/.source.replace(/<js>/g,function(){return a}),"m"),lookbehind:!0,greedy:!0,alias:"language-javascript",inside:t.languages.javascript},string:{pattern:/"(?:\\.|[^\\"\r\n])*"/,greedy:!0},keyword:/\b(?:as|import|on)\b/,punctuation:/[{}[\]:;,]/}})(e)}nT.displayName="qore";nT.aliases=[];function nT(e){e.register(Mt),e.languages.qore=e.languages.extend("clike",{comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?\*\/|(?:\/\/|#).*)/,lookbehind:!0},string:{pattern:/("|')(?:\\[\s\S]|(?!\1)[^\\])*\1/,greedy:!0},keyword:/\b(?:abstract|any|assert|binary|bool|boolean|break|byte|case|catch|char|class|code|const|continue|data|default|do|double|else|enum|extends|final|finally|float|for|goto|hash|if|implements|import|inherits|instanceof|int|interface|long|my|native|new|nothing|null|object|our|own|private|reference|rethrow|return|short|soft(?:bool|date|float|int|list|number|string)|static|strictfp|string|sub|super|switch|synchronized|this|throw|throws|transient|try|void|volatile|while)\b/,boolean:/\b(?:false|true)\b/i,function:/\$?\b(?!\d)\w+(?=\()/,number:/\b(?:0b[01]+|0x(?:[\da-f]*\.)?[\da-fp\-]+|(?:\d+(?:\.\d+)?|\.\d+)(?:e\d+)?[df]|(?:\d+(?:\.\d+)?|\.\d+))\b/i,operator:{pattern:/(^|[^.])(?:\+[+=]?|-[-=]?|[!=](?:==?|~)?|>>?=?|<(?:=>?|<=?)?|&[&=]?|\|[|=]?|[*\/%^]=?|[~?])/,lookbehind:!0},variable:/\$(?!\d)\w+\b/})}rT.displayName="r";rT.aliases=[];function rT(e){e.languages.r={comment:/#.*/,string:{pattern:/(['"])(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0},"percent-operator":{pattern:/%[^%\s]*%/,alias:"operator"},boolean:/\b(?:FALSE|TRUE)\b/,ellipsis:/\.\.(?:\.|\d+)/,number:[/\b(?:Inf|NaN)\b/,/(?:\b0x[\dA-Fa-f]+(?:\.\d*)?|\b\d+(?:\.\d*)?|\B\.\d+)(?:[EePp][+-]?\d+)?[iL]?/],keyword:/\b(?:NA|NA_character_|NA_complex_|NA_integer_|NA_real_|NULL|break|else|for|function|if|in|next|repeat|while)\b/,operator:/->?>?|<(?:=|<?-)?|[>=!]=?|::?|&&?|\|\|?|[+*\/^$@~]/,punctuation:/[(){}\[\],;]/}}aT.displayName="racket";aT.aliases=["rkt"];function aT(e){e.register(cp),e.languages.racket=e.languages.extend("scheme",{"lambda-parameter":{pattern:/([(\[]lambda\s+[(\[])[^()\[\]'\s]+/,lookbehind:!0}}),e.languages.insertBefore("racket","string",{lang:{pattern:/^#lang.+/m,greedy:!0,alias:"keyword"}}),e.languages.rkt=e.languages.racket}iT.displayName="cshtml";iT.aliases=["razor"];function iT(e){e.register(ku),e.register(cr),(function(t){var n=/\/(?![/*])|\/\/.*[\r\n]|\/\*[^*]*(?:\*(?!\/)[^*]*)*\*\//.source,r=/@(?!")|"(?:[^\r\n\\"]|\\.)*"|@"(?:[^\\"]|""|\\[\s\S])*"(?!")/.source+"|"+/'(?:(?:[^\r\n'\\]|\\.|\\[Uux][\da-fA-F]{1,8})'|(?=[^\\](?!')))/.source;function a(k,R){for(var I=0;I<R;I++)k=k.replace(/<self>/g,function(){return"(?:"+k+")"});return k.replace(/<self>/g,"[^\\s\\S]").replace(/<str>/g,"(?:"+r+")").replace(/<comment>/g,"(?:"+n+")")}var i=a(/\((?:[^()'"@/]|<str>|<comment>|<self>)*\)/.source,2),o=a(/\[(?:[^\[\]'"@/]|<str>|<comment>|<self>)*\]/.source,1),l=a(/\{(?:[^{}'"@/]|<str>|<comment>|<self>)*\}/.source,2),u=a(/<(?:[^<>'"@/]|<comment>|<self>)*>/.source,1),d=/@/.source+/(?:await\b\s*)?/.source+"(?:"+/(?!await\b)\w+\b/.source+"|"+i+")(?:"+/[?!]?\.\w+\b/.source+"|(?:"+u+")?"+i+"|"+o+")*"+/(?![?!\.(\[]|<(?!\/))/.source,h=/@(?![\w()])/.source+"|"+d,f="(?:"+/"[^"@]*"|'[^'@]*'|[^\s'"@>=]+(?=[\s>])/.source+`|["'][^"'@]*(?:(?:`+h+`)[^"'@]*)+["'])`,m=/(?:\s(?:\s*[^\s>\/=]+(?:\s*=\s*<tagAttrValue>|(?=[\s/>])))+)?/.source.replace(/<tagAttrValue>/,f),b=/(?!\d)[^\s>\/=$<%]+/.source+m+/\s*\/?>/.source,y=/\B@?/.source+"(?:"+/<([a-zA-Z][\w:]*)/.source+m+/\s*>/.source+"(?:"+(/[^<]/.source+"|"+/<\/?(?!\1\b)/.source+b+"|"+a(/<\1/.source+m+/\s*>/.source+"(?:"+(/[^<]/.source+"|"+/<\/?(?!\1\b)/.source+b+"|<self>")+")*"+/<\/\1\s*>/.source,2))+")*"+/<\/\1\s*>/.source+"|"+/</.source+b+")";t.languages.cshtml=t.languages.extend("markup",{});var v=t.languages.insertBefore("csharp","string",{html:{pattern:RegExp(y),greedy:!0,inside:t.languages.cshtml}},{csharp:t.languages.extend("csharp",{})}),w={pattern:/\S[\s\S]*/,alias:"language-csharp",inside:v},S={pattern:RegExp(/(^|[^@])/.source+d),lookbehind:!0,greedy:!0,alias:"variable",inside:{keyword:/^@/,csharp:w}};t.languages.cshtml.tag.pattern=RegExp(/<\/?/.source+b),t.languages.cshtml.tag.inside["attr-value"].pattern=RegExp(/=\s*/.source+f),t.languages.insertBefore("inside","punctuation",{value:S},t.languages.cshtml.tag.inside["attr-value"]),t.languages.insertBefore("cshtml","prolog",{"razor-comment":{pattern:/@\*[\s\S]*?\*@/,greedy:!0,alias:"comment"},block:{pattern:RegExp(/(^|[^@])@/.source+"(?:"+[l,/(?:code|functions)\s*/.source+l,/(?:for|foreach|lock|switch|using|while)\s*/.source+i+/\s*/.source+l,/do\s*/.source+l+/\s*while\s*/.source+i+/(?:\s*;)?/.source,/try\s*/.source+l+/\s*catch\s*/.source+i+/\s*/.source+l+/\s*finally\s*/.source+l,/if\s*/.source+i+/\s*/.source+l+"(?:"+/\s*else/.source+"(?:"+/\s+if\s*/.source+i+")?"+/\s*/.source+l+")*",/helper\s+\w+\s*/.source+i+/\s*/.source+l].join("|")+")"),lookbehind:!0,greedy:!0,inside:{keyword:/^@\w*/,csharp:w}},directive:{pattern:/^([ \t]*)@(?:addTagHelper|attribute|implements|inherits|inject|layout|model|namespace|page|preservewhitespace|removeTagHelper|section|tagHelperPrefix|using)(?=\s).*/m,lookbehind:!0,greedy:!0,inside:{keyword:/^@\w+/,csharp:w}},value:S,"delegate-operator":{pattern:/(^|[^@])@(?=<)/,lookbehind:!0,alias:"operator"}}),t.languages.razor=t.languages.cshtml})(e)}Bg.displayName="jsx";Bg.aliases=[];function Bg(e){e.register(wr),e.register(cr),(function(t){var n=t.util.clone(t.languages.javascript),r=/(?:\s|\/\/.*(?!.)|\/\*(?:[^*]|\*(?!\/))\*\/)/.source,a=/(?:\{(?:\{(?:\{[^{}]*\}|[^{}])*\}|[^{}])*\})/.source,i=/(?:\{<S>*\.{3}(?:[^{}]|<BRACES>)*\})/.source;function o(d,h){return d=d.replace(/<S>/g,function(){return r}).replace(/<BRACES>/g,function(){return a}).replace(/<SPREAD>/g,function(){return i}),RegExp(d,h)}i=o(i).source,t.languages.jsx=t.languages.extend("markup",n),t.languages.jsx.tag.pattern=o(/<\/?(?:[\w.:-]+(?:<S>+(?:[\w.:$-]+(?:=(?:"(?:\\[\s\S]|[^\\"])*"|'(?:\\[\s\S]|[^\\'])*'|[^\s{'"/>=]+|<BRACES>))?|<SPREAD>))*<S>*\/?)?>/.source),t.languages.jsx.tag.inside.tag.pattern=/^<\/?[^\s>\/]*/,t.languages.jsx.tag.inside["attr-value"].pattern=/=(?!\{)(?:"(?:\\[\s\S]|[^\\"])*"|'(?:\\[\s\S]|[^\\'])*'|[^\s'">]+)/,t.languages.jsx.tag.inside.tag.inside["class-name"]=/^[A-Z]\w*(?:\.[A-Z]\w*)*$/,t.languages.jsx.tag.inside.comment=n.comment,t.languages.insertBefore("inside","attr-name",{spread:{pattern:o(/<SPREAD>/.source),inside:t.languages.jsx}},t.languages.jsx.tag),t.languages.insertBefore("inside","special-attr",{script:{pattern:o(/=<BRACES>/.source),alias:"language-javascript",inside:{"script-punctuation":{pattern:/^=(?=\{)/,alias:"punctuation"},rest:t.languages.jsx}}},t.languages.jsx.tag);var l=function(d){return d?typeof d=="string"?d:typeof d.content=="string"?d.content:d.content.map(l).join(""):""},u=function(d){for(var h=[],f=0;f<d.length;f++){var m=d[f],b=!1;if(typeof m!="string"&&(m.type==="tag"&&m.content[0]&&m.content[0].type==="tag"?m.content[0].content[0].content==="</"?h.length>0&&h[h.length-1].tagName===l(m.content[0].content[1])&&h.pop():m.content[m.content.length-1].content==="/>"||h.push({tagName:l(m.content[0].content[1]),openedBraces:0}):h.length>0&&m.type==="punctuation"&&m.content==="{"?h[h.length-1].openedBraces++:h.length>0&&h[h.length-1].openedBraces>0&&m.type==="punctuation"&&m.content==="}"?h[h.length-1].openedBraces--:b=!0),(b||typeof m=="string")&&h.length>0&&h[h.length-1].openedBraces===0){var y=l(m);f<d.length-1&&(typeof d[f+1]=="string"||d[f+1].type==="plain-text")&&(y+=l(d[f+1]),d.splice(f+1,1)),f>0&&(typeof d[f-1]=="string"||d[f-1].type==="plain-text")&&(y=l(d[f-1])+y,d.splice(f-1,1),f--),d[f]=new t.Token("plain-text",y,null,y)}m.content&&typeof m.content!="string"&&u(m.content)}};t.hooks.add("after-tokenize",function(d){d.language!=="jsx"&&d.language!=="tsx"||u(d.tokens)})})(e)}oT.displayName="tsx";oT.aliases=[];function oT(e){e.register(Bg),e.register(lp),(function(t){var n=t.util.clone(t.languages.typescript);t.languages.tsx=t.languages.extend("jsx",n),delete t.languages.tsx.parameter,delete t.languages.tsx["literal-property"];var r=t.languages.tsx.tag;r.pattern=RegExp(/(^|[^\w$]|(?=<\/))/.source+"(?:"+r.pattern.source+")",r.pattern.flags),r.lookbehind=!0})(e)}sT.displayName="reason";sT.aliases=[];function sT(e){e.register(Mt),e.languages.reason=e.languages.extend("clike",{string:{pattern:/"(?:\\(?:\r\n|[\s\S])|[^\\\r\n"])*"/,greedy:!0},"class-name":/\b[A-Z]\w*/,keyword:/\b(?:and|as|assert|begin|class|constraint|do|done|downto|else|end|exception|external|for|fun|function|functor|if|in|include|inherit|initializer|lazy|let|method|module|mutable|new|nonrec|object|of|open|or|private|rec|sig|struct|switch|then|to|try|type|val|virtual|when|while|with)\b/,operator:/\.{3}|:[:=]|\|>|->|=(?:==?|>)?|<=?|>=?|[|^?'#!~`]|[+\-*\/]\.?|\b(?:asr|land|lor|lsl|lsr|lxor|mod)\b/}),e.languages.insertBefore("reason","class-name",{char:{pattern:/'(?:\\x[\da-f]{2}|\\o[0-3][0-7][0-7]|\\\d{3}|\\.|[^'\\\r\n])'/,greedy:!0},constructor:/\b[A-Z]\w*\b(?!\s*\.)/,label:{pattern:/\b[a-z]\w*(?=::)/,alias:"symbol"}}),delete e.languages.reason.function}lT.displayName="rego";lT.aliases=[];function lT(e){e.languages.rego={comment:/#.*/,property:{pattern:/(^|[^\\.])(?:"(?:\\.|[^\\"\r\n])*"|`[^`]*`|\b[a-z_]\w*\b)(?=\s*:(?!=))/i,lookbehind:!0,greedy:!0},string:{pattern:/(^|[^\\])"(?:\\.|[^\\"\r\n])*"|`[^`]*`/,lookbehind:!0,greedy:!0},keyword:/\b(?:as|default|else|import|not|null|package|set(?=\s*\()|some|with)\b/,boolean:/\b(?:false|true)\b/,function:{pattern:/\b[a-z_]\w*\b(?:\s*\.\s*\b[a-z_]\w*\b)*(?=\s*\()/i,inside:{namespace:/\b\w+\b(?=\s*\.)/,punctuation:/\./}},number:/-?\b\d+(?:\.\d+)?(?:e[+-]?\d+)?\b/i,operator:/[-+*/%|&]|[<>:=]=?|!=|\b_\b/,punctuation:/[,;.\[\]{}()]/}}cT.displayName="renpy";cT.aliases=["rpy"];function cT(e){e.languages.renpy={comment:{pattern:/(^|[^\\])#.+/,lookbehind:!0},string:{pattern:/("""|''')[\s\S]+?\1|("|')(?:\\.|(?!\2)[^\\])*\2|(?:^#?(?:(?:[0-9a-fA-F]){3}|[0-9a-fA-F]{6})$)/m,greedy:!0},function:/\b[a-z_]\w*(?=\()/i,property:/\b(?:Update|UpdateVersion|action|activate_sound|adv_nvl_transition|after_load_transition|align|alpha|alt|anchor|antialias|area|auto|background|bar_invert|bar_resizing|bar_vertical|black_color|bold|bottom_bar|bottom_gutter|bottom_margin|bottom_padding|box_reverse|box_wrap|can_update|caret|child|color|crop|default_afm_enable|default_afm_time|default_fullscreen|default_text_cps|developer|directory_name|drag_handle|drag_joined|drag_name|drag_raise|draggable|dragged|drop_shadow|drop_shadow_color|droppable|dropped|easein|easeout|edgescroll|end_game_transition|end_splash_transition|enter_replay_transition|enter_sound|enter_transition|enter_yesno_transition|executable_name|exit_replay_transition|exit_sound|exit_transition|exit_yesno_transition|fadein|fadeout|first_indent|first_spacing|fit_first|focus|focus_mask|font|foreground|game_main_transition|get_installed_packages|google_play_key|google_play_salt|ground|has_music|has_sound|has_voice|height|help|hinting|hover|hover_background|hover_color|hover_sound|hovered|hyperlink_functions|idle|idle_color|image_style|include_update|insensitive|insensitive_background|insensitive_color|inside|intra_transition|italic|justify|kerning|keyboard_focus|language|layer_clipping|layers|layout|left_bar|left_gutter|left_margin|left_padding|length|line_leading|line_overlap_split|line_spacing|linear|main_game_transition|main_menu_music|maximum|min_width|minimum|minwidth|modal|mouse|mousewheel|name|narrator_menu|newline_indent|nvl_adv_transition|offset|order_reverse|outlines|overlay_functions|pos|position|prefix|radius|range|rest_indent|right_bar|right_gutter|right_margin|right_padding|rotate|rotate_pad|ruby_style|sample_sound|save_directory|say_attribute_transition|screen_height|screen_width|scrollbars|selected_hover|selected_hover_color|selected_idle|selected_idle_color|selected_insensitive|show_side_image|show_two_window|side_spacing|side_xpos|side_ypos|size|size_group|slow_cps|slow_cps_multiplier|spacing|strikethrough|subpixel|text_align|text_style|text_xpos|text_y_fudge|text_ypos|thumb|thumb_offset|thumb_shadow|thumbnail_height|thumbnail_width|time|top_bar|top_gutter|top_margin|top_padding|translations|underline|unscrollable|update|value|version|version_name|version_tuple|vertical|width|window_hide_transition|window_icon|window_left_padding|window_show_transition|window_title|windows_icon|xadjustment|xalign|xanchor|xanchoraround|xaround|xcenter|xfill|xinitial|xmargin|xmaximum|xminimum|xoffset|xofsset|xpadding|xpos|xsize|xzoom|yadjustment|yalign|yanchor|yanchoraround|yaround|ycenter|yfill|yinitial|ymargin|ymaximum|yminimum|yoffset|ypadding|ypos|ysize|ysizexysize|yzoom|zoom|zorder)\b/,tag:/\b(?:bar|block|button|buttoscreenn|drag|draggroup|fixed|frame|grid|[hv]box|hotbar|hotspot|image|imagebutton|imagemap|input|key|label|menu|mm_menu_frame|mousearea|nvl|parallel|screen|self|side|tag|text|textbutton|timer|vbar|viewport|window)\b|\$/,keyword:/\b(?:None|add|adjustment|alignaround|allow|angle|animation|around|as|assert|behind|box_layout|break|build|cache|call|center|changed|child_size|choice|circles|class|clear|clicked|clipping|clockwise|config|contains|continue|corner1|corner2|counterclockwise|def|default|define|del|delay|disabled|disabled_text|dissolve|elif|else|event|except|exclude|exec|expression|fade|finally|for|from|function|global|gm_root|has|hide|id|if|import|in|init|is|jump|knot|lambda|left|less_rounded|mm_root|movie|music|null|on|onlayer|pass|pause|persistent|play|print|python|queue|raise|random|renpy|repeat|return|right|rounded_window|scene|scope|set|show|slow|slow_abortable|slow_done|sound|stop|store|style|style_group|substitute|suffix|theme|transform|transform_anchor|transpose|try|ui|unhovered|updater|use|voice|while|widget|widget_hover|widget_selected|widget_text|yield)\b/,boolean:/\b(?:[Ff]alse|[Tt]rue)\b/,number:/(?:\b(?:0[bo])?(?:(?:\d|0x[\da-f])[\da-f]*(?:\.\d*)?)|\B\.\d+)(?:e[+-]?\d+)?j?/i,operator:/[-+%=]=?|!=|\*\*?=?|\/\/?=?|<[<=>]?|>[=>]?|[&|^~]|\b(?:and|at|not|or|with)\b/,punctuation:/[{}[\];(),.:]/},e.languages.rpy=e.languages.renpy}uT.displayName="rescript";uT.aliases=["res"];function uT(e){e.languages.rescript={comment:{pattern:/\/\/.*|\/\*[\s\S]*?(?:\*\/|$)/,greedy:!0},char:{pattern:/'(?:[^\r\n\\]|\\(?:.|\w+))'/,greedy:!0},string:{pattern:/"(?:\\(?:\r\n|[\s\S])|[^\\\r\n"])*"/,greedy:!0},"class-name":/\b[A-Z]\w*|@[a-z.]*|#[A-Za-z]\w*|#\d/,function:{pattern:/[a-zA-Z]\w*(?=\()|(\.)[a-z]\w*/,lookbehind:!0},number:/(?:\b0x(?:[\da-f]+(?:\.[\da-f]*)?|\.[\da-f]+)(?:p[+-]?\d+)?|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?)[ful]{0,4}/i,boolean:/\b(?:false|true)\b/,"attr-value":/[A-Za-z]\w*(?==)/,constant:{pattern:/(\btype\s+)[a-z]\w*/,lookbehind:!0},tag:{pattern:/(<)[a-z]\w*|(?:<\/)[a-z]\w*/,lookbehind:!0,inside:{operator:/<|>|\//}},keyword:/\b(?:and|as|assert|begin|bool|class|constraint|do|done|downto|else|end|exception|external|float|for|fun|function|if|in|include|inherit|initializer|int|lazy|let|method|module|mutable|new|nonrec|object|of|open|or|private|rec|string|switch|then|to|try|type|when|while|with)\b/,operator:/\.{3}|:[:=]?|\|>|->|=(?:==?|>)?|<=?|>=?|[|^?'#!~`]|[+\-*\/]\.?|\b(?:asr|land|lor|lsl|lsr|lxor|mod)\b/,punctuation:/[(){}[\],;.]/},e.languages.insertBefore("rescript","string",{"template-string":{pattern:/`(?:\\[\s\S]|\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}|(?!\$\{)[^\\`])*`/,greedy:!0,inside:{"template-punctuation":{pattern:/^`|`$/,alias:"string"},interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}/,lookbehind:!0,inside:{"interpolation-punctuation":{pattern:/^\$\{|\}$/,alias:"tag"},rest:e.languages.rescript}},string:/[\s\S]+/}}}),e.languages.res=e.languages.rescript}dT.displayName="rest";dT.aliases=[];function dT(e){e.languages.rest={table:[{pattern:/(^[\t ]*)(?:\+[=-]+)+\+(?:\r?\n|\r)(?:\1[+|].+[+|](?:\r?\n|\r))+\1(?:\+[=-]+)+\+/m,lookbehind:!0,inside:{punctuation:/\||(?:\+[=-]+)+\+/}},{pattern:/(^[\t ]*)=+ [ =]*=(?:(?:\r?\n|\r)\1.+)+(?:\r?\n|\r)\1=+ [ =]*=(?=(?:\r?\n|\r){2}|\s*$)/m,lookbehind:!0,inside:{punctuation:/[=-]+/}}],"substitution-def":{pattern:/(^[\t ]*\.\. )\|(?:[^|\s](?:[^|]*[^|\s])?)\| [^:]+::/m,lookbehind:!0,inside:{substitution:{pattern:/^\|(?:[^|\s]|[^|\s][^|]*[^|\s])\|/,alias:"attr-value",inside:{punctuation:/^\||\|$/}},directive:{pattern:/( )(?! )[^:]+::/,lookbehind:!0,alias:"function",inside:{punctuation:/::$/}}}},"link-target":[{pattern:/(^[\t ]*\.\. )\[[^\]]+\]/m,lookbehind:!0,alias:"string",inside:{punctuation:/^\[|\]$/}},{pattern:/(^[\t ]*\.\. )_(?:`[^`]+`|(?:[^:\\]|\\.)+):/m,lookbehind:!0,alias:"string",inside:{punctuation:/^_|:$/}}],directive:{pattern:/(^[\t ]*\.\. )[^:]+::/m,lookbehind:!0,alias:"function",inside:{punctuation:/::$/}},comment:{pattern:/(^[\t ]*\.\.)(?:(?: .+)?(?:(?:\r?\n|\r).+)+| .+)(?=(?:\r?\n|\r){2}|$)/m,lookbehind:!0},title:[{pattern:/^(([!"#$%&'()*+,\-.\/:;<=>?@\[\\\]^_`{|}~])\2+)(?:\r?\n|\r).+(?:\r?\n|\r)\1$/m,inside:{punctuation:/^[!"#$%&'()*+,\-.\/:;<=>?@\[\\\]^_`{|}~]+|[!"#$%&'()*+,\-.\/:;<=>?@\[\\\]^_`{|}~]+$/,important:/.+/}},{pattern:/(^|(?:\r?\n|\r){2}).+(?:\r?\n|\r)([!"#$%&'()*+,\-.\/:;<=>?@\[\\\]^_`{|}~])\2+(?=\r?\n|\r|$)/,lookbehind:!0,inside:{punctuation:/[!"#$%&'()*+,\-.\/:;<=>?@\[\\\]^_`{|}~]+$/,important:/.+/}}],hr:{pattern:/((?:\r?\n|\r){2})([!"#$%&'()*+,\-.\/:;<=>?@\[\\\]^_`{|}~])\2{3,}(?=(?:\r?\n|\r){2})/,lookbehind:!0,alias:"punctuation"},field:{pattern:/(^[\t ]*):[^:\r\n]+:(?= )/m,lookbehind:!0,alias:"attr-name"},"command-line-option":{pattern:/(^[\t ]*)(?:[+-][a-z\d]|(?:--|\/)[a-z\d-]+)(?:[ =](?:[a-z][\w-]*|<[^<>]+>))?(?:, (?:[+-][a-z\d]|(?:--|\/)[a-z\d-]+)(?:[ =](?:[a-z][\w-]*|<[^<>]+>))?)*(?=(?:\r?\n|\r)? {2,}\S)/im,lookbehind:!0,alias:"symbol"},"literal-block":{pattern:/::(?:\r?\n|\r){2}([ \t]+)(?![ \t]).+(?:(?:\r?\n|\r)\1.+)*/,inside:{"literal-block-punctuation":{pattern:/^::/,alias:"punctuation"}}},"quoted-literal-block":{pattern:/::(?:\r?\n|\r){2}([!"#$%&'()*+,\-.\/:;<=>?@\[\\\]^_`{|}~]).*(?:(?:\r?\n|\r)\1.*)*/,inside:{"literal-block-punctuation":{pattern:/^(?:::|([!"#$%&'()*+,\-.\/:;<=>?@\[\\\]^_`{|}~])\1*)/m,alias:"punctuation"}}},"list-bullet":{pattern:/(^[\t ]*)(?:[*+\-•‣⁃]|\(?(?:\d+|[a-z]|[ivxdclm]+)\)|(?:\d+|[a-z]|[ivxdclm]+)\.)(?= )/im,lookbehind:!0,alias:"punctuation"},"doctest-block":{pattern:/(^[\t ]*)>>> .+(?:(?:\r?\n|\r).+)*/m,lookbehind:!0,inside:{punctuation:/^>>>/}},inline:[{pattern:/(^|[\s\-:\/'"<(\[{])(?::[^:]+:`.*?`|`.*?`:[^:]+:|(\*\*?|``?|\|)(?!\s)(?:(?!\2).)*\S\2(?=[\s\-.,:;!?\\\/'")\]}]|$))/m,lookbehind:!0,inside:{bold:{pattern:/(^\*\*).+(?=\*\*$)/,lookbehind:!0},italic:{pattern:/(^\*).+(?=\*$)/,lookbehind:!0},"inline-literal":{pattern:/(^``).+(?=``$)/,lookbehind:!0,alias:"symbol"},role:{pattern:/^:[^:]+:|:[^:]+:$/,alias:"function",inside:{punctuation:/^:|:$/}},"interpreted-text":{pattern:/(^`).+(?=`$)/,lookbehind:!0,alias:"attr-value"},substitution:{pattern:/(^\|).+(?=\|$)/,lookbehind:!0,alias:"attr-value"},punctuation:/\*\*?|``?|\|/}}],link:[{pattern:/\[[^\[\]]+\]_(?=[\s\-.,:;!?\\\/'")\]}]|$)/,alias:"string",inside:{punctuation:/^\[|\]_$/}},{pattern:/(?:\b[a-z\d]+(?:[_.:+][a-z\d]+)*_?_|`[^`]+`_?_|_`[^`]+`)(?=[\s\-.,:;!?\\\/'")\]}]|$)/i,alias:"string",inside:{punctuation:/^_?`|`$|`?_?_$/}}],punctuation:{pattern:/(^[\t ]*)(?:\|(?= |$)|(?:---?|—|\.\.|__)(?= )|\.\.$)/m,lookbehind:!0}}}hT.displayName="rip";hT.aliases=[];function hT(e){e.languages.rip={comment:{pattern:/#.*/,greedy:!0},char:{pattern:/\B`[^\s`'",.:;#\/\\()<>\[\]{}]\b/,greedy:!0},string:{pattern:/("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0},regex:{pattern:/(^|[^/])\/(?!\/)(?:\[[^\n\r\]]*\]|\\.|[^/\\\r\n\[])+\/(?=\s*(?:$|[\r\n,.;})]))/,lookbehind:!0,greedy:!0},keyword:/(?:=>|->)|\b(?:case|catch|class|else|exit|finally|if|raise|return|switch|try)\b/,builtin:/@|\bSystem\b/,boolean:/\b(?:false|true)\b/,date:/\b\d{4}-\d{2}-\d{2}\b/,time:/\b\d{2}:\d{2}:\d{2}\b/,datetime:/\b\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}\b/,symbol:/:[^\d\s`'",.:;#\/\\()<>\[\]{}][^\s`'",.:;#\/\\()<>\[\]{}]*/,number:/[+-]?\b(?:\d+\.\d+|\d+)\b/,punctuation:/(?:\.{2,3})|[`,.:;=\/\\()<>\[\]{}]/,reference:/[^\d\s`'",.:;#\/\\()<>\[\]{}][^\s`'",.:;#\/\\()<>\[\]{}]*/}}pT.displayName="roboconf";pT.aliases=[];function pT(e){e.languages.roboconf={comment:/#.*/,keyword:{pattern:/(^|\s)(?:(?:external|import)\b|(?:facet|instance of)(?=[ \t]+[\w-]+[ \t]*\{))/,lookbehind:!0},component:{pattern:/[\w-]+(?=[ \t]*\{)/,alias:"variable"},property:/[\w.-]+(?=[ \t]*:)/,value:{pattern:/(=[ \t]*(?![ \t]))[^,;]+/,lookbehind:!0,alias:"attr-value"},optional:{pattern:/\(optional\)/,alias:"builtin"},wildcard:{pattern:/(\.)\*/,lookbehind:!0,alias:"operator"},punctuation:/[{},.;:=]/}}fT.displayName="robotframework";fT.aliases=["robot"];function fT(e){(function(t){var n={pattern:/(^[ \t]*| {2}|\t)#.*/m,lookbehind:!0,greedy:!0},r={pattern:/((?:^|[^\\])(?:\\{2})*)[$@&%]\{(?:[^{}\r\n]|\{[^{}\r\n]*\})*\}/,lookbehind:!0,inside:{punctuation:/^[$@&%]\{|\}$/}};function a(u,d){var h={};h["section-header"]={pattern:/^ ?\*{3}.+?\*{3}/,alias:"keyword"};for(var f in d)h[f]=d[f];return h.tag={pattern:/([\r\n](?: {2}|\t)[ \t]*)\[[-\w]+\]/,lookbehind:!0,inside:{punctuation:/\[|\]/}},h.variable=r,h.comment=n,{pattern:RegExp(/^ ?\*{3}[ \t]*<name>[ \t]*\*{3}(?:.|[\r\n](?!\*{3}))*/.source.replace(/<name>/g,function(){return u}),"im"),alias:"section",inside:h}}var i={pattern:/(\[Documentation\](?: {2}|\t)[ \t]*)(?![ \t]|#)(?:.|(?:\r\n?|\n)[ \t]*\.{3})+/,lookbehind:!0,alias:"string"},o={pattern:/([\r\n] ?)(?!#)(?:\S(?:[ \t]\S)*)+/,lookbehind:!0,alias:"function",inside:{variable:r}},l={pattern:/([\r\n](?: {2}|\t)[ \t]*)(?!\[|\.{3}|#)(?:\S(?:[ \t]\S)*)+/,lookbehind:!0,inside:{variable:r}};t.languages.robotframework={settings:a("Settings",{documentation:{pattern:/([\r\n] ?Documentation(?: {2}|\t)[ \t]*)(?![ \t]|#)(?:.|(?:\r\n?|\n)[ \t]*\.{3})+/,lookbehind:!0,alias:"string"},property:{pattern:/([\r\n] ?)(?!\.{3}|#)(?:\S(?:[ \t]\S)*)+/,lookbehind:!0}}),variables:a("Variables"),"test-cases":a("Test Cases",{"test-name":o,documentation:i,property:l}),keywords:a("Keywords",{"keyword-name":o,documentation:i,property:l}),tasks:a("Tasks",{"task-name":o,documentation:i,property:l}),comment:n},t.languages.robot=t.languages.robotframework})(e)}mT.displayName="rust";mT.aliases=[];function mT(e){(function(t){for(var n=/\/\*(?:[^*/]|\*(?!\/)|\/(?!\*)|<self>)*\*\//.source,r=0;r<2;r++)n=n.replace(/<self>/g,function(){return n});n=n.replace(/<self>/g,function(){return/[^\s\S]/.source}),t.languages.rust={comment:[{pattern:RegExp(/(^|[^\\])/.source+n),lookbehind:!0,greedy:!0},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0,greedy:!0}],string:{pattern:/b?"(?:\\[\s\S]|[^\\"])*"|b?r(#*)"(?:[^"]|"(?!\1))*"\1/,greedy:!0},char:{pattern:/b?'(?:\\(?:x[0-7][\da-fA-F]|u\{(?:[\da-fA-F]_*){1,6}\}|.)|[^\\\r\n\t'])'/,greedy:!0},attribute:{pattern:/#!?\[(?:[^\[\]"]|"(?:\\[\s\S]|[^\\"])*")*\]/,greedy:!0,alias:"attr-name",inside:{string:null}},"closure-params":{pattern:/([=(,:]\s*|\bmove\s*)\|[^|]*\||\|[^|]*\|(?=\s*(?:\{|->))/,lookbehind:!0,greedy:!0,inside:{"closure-punctuation":{pattern:/^\||\|$/,alias:"punctuation"},rest:null}},"lifetime-annotation":{pattern:/'\w+/,alias:"symbol"},"fragment-specifier":{pattern:/(\$\w+:)[a-z]+/,lookbehind:!0,alias:"punctuation"},variable:/\$\w+/,"function-definition":{pattern:/(\bfn\s+)\w+/,lookbehind:!0,alias:"function"},"type-definition":{pattern:/(\b(?:enum|struct|trait|type|union)\s+)\w+/,lookbehind:!0,alias:"class-name"},"module-declaration":[{pattern:/(\b(?:crate|mod)\s+)[a-z][a-z_\d]*/,lookbehind:!0,alias:"namespace"},{pattern:/(\b(?:crate|self|super)\s*)::\s*[a-z][a-z_\d]*\b(?:\s*::(?:\s*[a-z][a-z_\d]*\s*::)*)?/,lookbehind:!0,alias:"namespace",inside:{punctuation:/::/}}],keyword:[/\b(?:Self|abstract|as|async|await|become|box|break|const|continue|crate|do|dyn|else|enum|extern|final|fn|for|if|impl|in|let|loop|macro|match|mod|move|mut|override|priv|pub|ref|return|self|static|struct|super|trait|try|type|typeof|union|unsafe|unsized|use|virtual|where|while|yield)\b/,/\b(?:bool|char|f(?:32|64)|[ui](?:8|16|32|64|128|size)|str)\b/],function:/\b[a-z_]\w*(?=\s*(?:::\s*<|\())/,macro:{pattern:/\b\w+!/,alias:"property"},constant:/\b[A-Z_][A-Z_\d]+\b/,"class-name":/\b[A-Z]\w*\b/,namespace:{pattern:/(?:\b[a-z][a-z_\d]*\s*::\s*)*\b[a-z][a-z_\d]*\s*::(?!\s*<)/,inside:{punctuation:/::/}},number:/\b(?:0x[\dA-Fa-f](?:_?[\dA-Fa-f])*|0o[0-7](?:_?[0-7])*|0b[01](?:_?[01])*|(?:(?:\d(?:_?\d)*)?\.)?\d(?:_?\d)*(?:[Ee][+-]?\d+)?)(?:_?(?:f32|f64|[iu](?:8|16|32|64|size)?))?\b/,boolean:/\b(?:false|true)\b/,punctuation:/->|\.\.=|\.{1,3}|::|[{}[\];(),:]/,operator:/[-+*\/%!^]=?|=[=>]?|&[&=]?|\|[|=]?|<<?=?|>>?=?|[@?]/},t.languages.rust["closure-params"].inside.rest=t.languages.rust,t.languages.rust.attribute.inside.string=t.languages.rust.string})(e)}gT.displayName="sas";gT.aliases=[];function gT(e){(function(t){var n=/(?:"(?:""|[^"])*"(?!")|'(?:''|[^'])*'(?!'))/.source,r=/\b(?:\d[\da-f]*x|\d+(?:\.\d+)?(?:e[+-]?\d+)?)\b/i,a={pattern:RegExp(n+"[bx]"),alias:"number"},i={pattern:/&[a-z_]\w*/i},o={pattern:/((?:^|\s|=|\())%(?:ABORT|BY|CMS|COPY|DISPLAY|DO|ELSE|END|EVAL|GLOBAL|GO|GOTO|IF|INC|INCLUDE|INDEX|INPUT|KTRIM|LENGTH|LET|LIST|LOCAL|PUT|QKTRIM|QSCAN|QSUBSTR|QSYSFUNC|QUPCASE|RETURN|RUN|SCAN|SUBSTR|SUPERQ|SYMDEL|SYMEXIST|SYMGLOBL|SYMLOCAL|SYSCALL|SYSEVALF|SYSEXEC|SYSFUNC|SYSGET|SYSRPUT|THEN|TO|TSO|UNQUOTE|UNTIL|UPCASE|WHILE|WINDOW)\b/i,lookbehind:!0,alias:"keyword"},l={pattern:/(^|\s)(?:proc\s+\w+|data(?!=)|quit|run)\b/i,alias:"keyword",lookbehind:!0},u=[/\/\*[\s\S]*?\*\//,{pattern:/(^[ \t]*|;\s*)\*[^;]*;/m,lookbehind:!0}],d={pattern:RegExp(n),greedy:!0},h=/[$%@.(){}\[\];,\\]/,f={pattern:/%?\b\w+(?=\()/,alias:"keyword"},m={function:f,"arg-value":{pattern:/(=\s*)[A-Z\.]+/i,lookbehind:!0},operator:/=/,"macro-variable":i,arg:{pattern:/[A-Z]+/i,alias:"keyword"},number:r,"numeric-constant":a,punctuation:h,string:d},b={pattern:/\b(?:format|put)\b=?[\w'$.]+/i,inside:{keyword:/^(?:format|put)(?==)/i,equals:/=/,format:{pattern:/(?:\w|\$\d)+\.\d?/,alias:"number"}}},y={pattern:/\b(?:format|put)\s+[\w']+(?:\s+[$.\w]+)+(?=;)/i,inside:{keyword:/^(?:format|put)/i,format:{pattern:/[\w$]+\.\d?/,alias:"number"}}},v={pattern:/((?:^|\s)=?)(?:catname|checkpoint execute_always|dm|endsas|filename|footnote|%include|libname|%list|lock|missing|options|page|resetline|%run|sasfile|skip|sysecho|title\d?)\b/i,lookbehind:!0,alias:"keyword"},w={pattern:/(^|\s)(?:submit(?:\s+(?:load|norun|parseonly))?|endsubmit)\b/i,lookbehind:!0,alias:"keyword"},S=/aStore|accessControl|aggregation|audio|autotune|bayesianNetClassifier|bioMedImage|boolRule|builtins|cardinality|cdm|clustering|conditionalRandomFields|configuration|copula|countreg|dataDiscovery|dataPreprocess|dataSciencePilot|dataStep|decisionTree|deduplication|deepLearn|deepNeural|deepRnn|ds2|ecm|entityRes|espCluster|explainModel|factmac|fastKnn|fcmpact|fedSql|freqTab|gVarCluster|gam|gleam|graphSemiSupLearn|hiddenMarkovModel|hyperGroup|ica|image|iml|kernalPca|langModel|ldaTopic|loadStreams|mbc|mixed|mlTools|modelPublishing|network|neuralNet|nmf|nonParametricBayes|nonlinear|optNetwork|optimization|panel|pca|percentile|phreg|pls|qkb|qlim|quantreg|recommend|regression|reinforcementLearn|robustPca|ruleMining|sampling|sandwich|sccasl|search(?:Analytics)?|sentimentAnalysis|sequence|session(?:Prop)?|severity|simSystem|simple|smartData|sparkEmbeddedProcess|sparseML|spatialreg|spc|stabilityMonitoring|svDataDescription|svm|table|text(?:Filters|Frequency|Mining|Parse|Rule(?:Develop|Score)|Topic|Util)|timeData|transpose|tsInfo|tsReconcile|uniTimeSeries|varReduce/.source,k={pattern:RegExp(/(^|\s)(?:action\s+)?(?:<act>)\.[a-z]+\b[^;]+/.source.replace(/<act>/g,function(){return S}),"i"),lookbehind:!0,inside:{keyword:RegExp(/(?:<act>)\.[a-z]+\b/.source.replace(/<act>/g,function(){return S}),"i"),action:{pattern:/(?:action)/i,alias:"keyword"},comment:u,function:f,"arg-value":m["arg-value"],operator:m.operator,argument:m.arg,number:r,"numeric-constant":a,punctuation:h,string:d}},R={pattern:/((?:^|\s)=?)(?:after|analysis|and|array|barchart|barwidth|begingraph|by|call|cas|cbarline|cfill|class(?:lev)?|close|column|computed?|contains|continue|data(?==)|define|delete|describe|document|do\s+over|do|dol|drop|dul|else|end(?:comp|source)?|entryTitle|eval(?:uate)?|exec(?:ute)?|exit|file(?:name)?|fill(?:attrs)?|flist|fnc|function(?:list)?|global|goto|group(?:by)?|headline|headskip|histogram|if|infile|keep|keylabel|keyword|label|layout|leave|legendlabel|length|libname|loadactionset|merge|midpoints|_?null_|name|noobs|nowd|ods|options|or|otherwise|out(?:put)?|over(?:lay)?|plot|print|put|raise|ranexp|rannor|rbreak|retain|return|select|session|sessref|set|source|statgraph|sum|summarize|table|temp|terminate|then\s+do|then|title\d?|to|var|when|where|xaxisopts|y2axisopts|yaxisopts)\b/i,lookbehind:!0};t.languages.sas={datalines:{pattern:/^([ \t]*)(?:cards|(?:data)?lines);[\s\S]+?^[ \t]*;/im,lookbehind:!0,alias:"string",inside:{keyword:{pattern:/^(?:cards|(?:data)?lines)/i},punctuation:/;/}},"proc-sql":{pattern:/(^proc\s+(?:fed)?sql(?:\s+[\w|=]+)?;)[\s\S]+?(?=^(?:proc\s+\w+|data|quit|run);|(?![\s\S]))/im,lookbehind:!0,inside:{sql:{pattern:RegExp(/^[ \t]*(?:select|alter\s+table|(?:create|describe|drop)\s+(?:index|table(?:\s+constraints)?|view)|create\s+unique\s+index|insert\s+into|update)(?:<str>|[^;"'])+;/.source.replace(/<str>/g,function(){return n}),"im"),alias:"language-sql",inside:t.languages.sql},"global-statements":v,"sql-statements":{pattern:/(^|\s)(?:disconnect\s+from|begin|commit|exec(?:ute)?|reset|rollback|validate)\b/i,lookbehind:!0,alias:"keyword"},number:r,"numeric-constant":a,punctuation:h,string:d}},"proc-groovy":{pattern:/(^proc\s+groovy(?:\s+[\w|=]+)?;)[\s\S]+?(?=^(?:proc\s+\w+|data|quit|run);|(?![\s\S]))/im,lookbehind:!0,inside:{comment:u,groovy:{pattern:RegExp(/(^[ \t]*submit(?:\s+(?:load|norun|parseonly))?)(?:<str>|[^"'])+?(?=endsubmit;)/.source.replace(/<str>/g,function(){return n}),"im"),lookbehind:!0,alias:"language-groovy",inside:t.languages.groovy},keyword:R,"submit-statement":w,"global-statements":v,number:r,"numeric-constant":a,punctuation:h,string:d}},"proc-lua":{pattern:/(^proc\s+lua(?:\s+[\w|=]+)?;)[\s\S]+?(?=^(?:proc\s+\w+|data|quit|run);|(?![\s\S]))/im,lookbehind:!0,inside:{comment:u,lua:{pattern:RegExp(/(^[ \t]*submit(?:\s+(?:load|norun|parseonly))?)(?:<str>|[^"'])+?(?=endsubmit;)/.source.replace(/<str>/g,function(){return n}),"im"),lookbehind:!0,alias:"language-lua",inside:t.languages.lua},keyword:R,"submit-statement":w,"global-statements":v,number:r,"numeric-constant":a,punctuation:h,string:d}},"proc-cas":{pattern:/(^proc\s+cas(?:\s+[\w|=]+)?;)[\s\S]+?(?=^(?:proc\s+\w+|quit|data);|(?![\s\S]))/im,lookbehind:!0,inside:{comment:u,"statement-var":{pattern:/((?:^|\s)=?)saveresult\s[^;]+/im,lookbehind:!0,inside:{statement:{pattern:/^saveresult\s+\S+/i,inside:{keyword:/^(?:saveresult)/i}},rest:m}},"cas-actions":k,statement:{pattern:/((?:^|\s)=?)(?:default|(?:un)?set|on|output|upload)[^;]+/im,lookbehind:!0,inside:m},step:l,keyword:R,function:f,format:b,altformat:y,"global-statements":v,number:r,"numeric-constant":a,punctuation:h,string:d}},"proc-args":{pattern:RegExp(/(^proc\s+\w+\s+)(?!\s)(?:[^;"']|<str>)+;/.source.replace(/<str>/g,function(){return n}),"im"),lookbehind:!0,inside:m},"macro-keyword":o,"macro-variable":i,"macro-string-functions":{pattern:/((?:^|\s|=))%(?:BQUOTE|NRBQUOTE|NRQUOTE|NRSTR|QUOTE|STR)\(.*?(?:[^%]\))/i,lookbehind:!0,inside:{function:{pattern:/%(?:BQUOTE|NRBQUOTE|NRQUOTE|NRSTR|QUOTE|STR)/i,alias:"keyword"},"macro-keyword":o,"macro-variable":i,"escaped-char":{pattern:/%['"()<>=¬^~;,#]/},punctuation:h}},"macro-declaration":{pattern:/^%macro[^;]+(?=;)/im,inside:{keyword:/%macro/i}},"macro-end":{pattern:/^%mend[^;]+(?=;)/im,inside:{keyword:/%mend/i}},macro:{pattern:/%_\w+(?=\()/,alias:"keyword"},input:{pattern:/\binput\s[-\w\s/*.$&]+;/i,inside:{input:{alias:"keyword",pattern:/^input/i},comment:u,number:r,"numeric-constant":a}},"options-args":{pattern:/(^options)[-'"|/\\<>*+=:()\w\s]*(?=;)/im,lookbehind:!0,inside:m},"cas-actions":k,comment:u,function:f,format:b,altformat:y,"numeric-constant":a,datetime:{pattern:RegExp(n+"(?:dt?|t)"),alias:"number"},string:d,step:l,keyword:R,"operator-keyword":{pattern:/\b(?:eq|ge|gt|in|le|lt|ne|not)\b/i,alias:"operator"},number:r,operator:/\*\*?|\|\|?|!!?|¦¦?|<[>=]?|>[<=]?|[-+\/=&]|[~¬^]=?/,punctuation:h}})(e)}bT.displayName="sass";bT.aliases=[];function bT(e){e.register(Ll),(function(t){t.languages.sass=t.languages.extend("css",{comment:{pattern:/^([ \t]*)\/[\/*].*(?:(?:\r?\n|\r)\1[ \t].+)*/m,lookbehind:!0,greedy:!0}}),t.languages.insertBefore("sass","atrule",{"atrule-line":{pattern:/^(?:[ \t]*)[@+=].+/m,greedy:!0,inside:{atrule:/(?:@[\w-]+|[+=])/}}}),delete t.languages.sass.atrule;var n=/\$[-\w]+|#\{\$[-\w]+\}/,r=[/[+*\/%]|[=!]=|<=?|>=?|\b(?:and|not|or)\b/,{pattern:/(\s)-(?=\s)/,lookbehind:!0}];t.languages.insertBefore("sass","property",{"variable-line":{pattern:/^[ \t]*\$.+/m,greedy:!0,inside:{punctuation:/:/,variable:n,operator:r}},"property-line":{pattern:/^[ \t]*(?:[^:\s]+ *:.*|:[^:\s].*)/m,greedy:!0,inside:{property:[/[^:\s]+(?=\s*:)/,{pattern:/(:)[^:\s]+/,lookbehind:!0}],punctuation:/:/,variable:n,operator:r,important:t.languages.sass.important}}}),delete t.languages.sass.property,delete t.languages.sass.important,t.languages.insertBefore("sass","punctuation",{selector:{pattern:/^([ \t]*)\S(?:,[^,\r\n]+|[^,\r\n]*)(?:,[^,\r\n]+)*(?:,(?:\r?\n|\r)\1[ \t]+\S(?:,[^,\r\n]+|[^,\r\n]*)(?:,[^,\r\n]+)*)*/m,lookbehind:!0,greedy:!0}})})(e)}yT.displayName="shell-session";yT.aliases=["sh-session","shellsession"];function yT(e){e.register(Ng),(function(t){var n=[/"(?:\\[\s\S]|\$\([^)]+\)|\$(?!\()|`[^`]+`|[^"\\`$])*"/.source,/'[^']*'/.source,/\$'(?:[^'\\]|\\[\s\S])*'/.source,/<<-?\s*(["']?)(\w+)\1\s[\s\S]*?[\r\n]\2/.source].join("|");t.languages["shell-session"]={command:{pattern:RegExp(/^/.source+"(?:"+(/[^\s@:$#%*!/\\]+@[^\r\n@:$#%*!/\\]+(?::[^\0-\x1F$#%*?"<>:;|]+)?/.source+"|"+/[/~.][^\0-\x1F$#%*?"<>@:;|]*/.source)+")?"+/[$#%](?=\s)/.source+/(?:[^\\\r\n \t'"<$]|[ \t](?:(?!#)|#.*$)|\\(?:[^\r]|\r\n?)|\$(?!')|<(?!<)|<<str>>)+/.source.replace(/<<str>>/g,function(){return n}),"m"),greedy:!0,inside:{info:{pattern:/^[^#$%]+/,alias:"punctuation",inside:{user:/^[^\s@:$#%*!/\\]+@[^\r\n@:$#%*!/\\]+/,punctuation:/:/,path:/[\s\S]+/}},bash:{pattern:/(^[$#%]\s*)\S[\s\S]*/,lookbehind:!0,alias:"language-bash",inside:t.languages.bash},"shell-symbol":{pattern:/^[$#%]/,alias:"important"}}},output:/.(?:.*(?:[\r\n]|.$))*/},t.languages["sh-session"]=t.languages.shellsession=t.languages["shell-session"]})(e)}vT.displayName="smali";vT.aliases=[];function vT(e){e.languages.smali={comment:/#.*/,string:{pattern:/"(?:[^\r\n\\"]|\\.)*"|'(?:[^\r\n\\']|\\(?:.|u[\da-fA-F]{4}))'/,greedy:!0},"class-name":{pattern:/(^|[^L])L(?:(?:\w+|`[^`\r\n]*`)\/)*(?:[\w$]+|`[^`\r\n]*`)(?=\s*;)/,lookbehind:!0,inside:{"class-name":{pattern:/(^L|\/)(?:[\w$]+|`[^`\r\n]*`)$/,lookbehind:!0},namespace:{pattern:/^(L)(?:(?:\w+|`[^`\r\n]*`)\/)+/,lookbehind:!0,inside:{punctuation:/\//}},builtin:/^L/}},builtin:[{pattern:/([();\[])[BCDFIJSVZ]+/,lookbehind:!0},{pattern:/([\w$>]:)[BCDFIJSVZ]/,lookbehind:!0}],keyword:[{pattern:/(\.end\s+)[\w-]+/,lookbehind:!0},{pattern:/(^|[^\w.-])\.(?!\d)[\w-]+/,lookbehind:!0},{pattern:/(^|[^\w.-])(?:abstract|annotation|bridge|constructor|enum|final|interface|private|protected|public|runtime|static|synthetic|system|transient)(?![\w.-])/,lookbehind:!0}],function:{pattern:/(^|[^\w.-])(?:\w+|<[\w$-]+>)(?=\()/,lookbehind:!0},field:{pattern:/[\w$]+(?=:)/,alias:"variable"},register:{pattern:/(^|[^\w.-])[vp]\d(?![\w.-])/,lookbehind:!0,alias:"variable"},boolean:{pattern:/(^|[^\w.-])(?:false|true)(?![\w.-])/,lookbehind:!0},number:{pattern:/(^|[^/\w.-])-?(?:NAN|INFINITY|0x(?:[\dA-F]+(?:\.[\dA-F]*)?|\.[\dA-F]+)(?:p[+-]?[\dA-F]+)?|(?:\d+(?:\.\d*)?|\.\d+)(?:e[+-]?\d+)?)[dflst]?(?![\w.-])/i,lookbehind:!0},label:{pattern:/(:)\w+/,lookbehind:!0,alias:"property"},operator:/->|\.\.|[\[=]/,punctuation:/[{}(),;:]/}}xT.displayName="smalltalk";xT.aliases=[];function xT(e){e.languages.smalltalk={comment:{pattern:/"(?:""|[^"])*"/,greedy:!0},char:{pattern:/\$./,greedy:!0},string:{pattern:/'(?:''|[^'])*'/,greedy:!0},symbol:/#[\da-z]+|#(?:-|([+\/\\*~<>=@%|&?!])\1?)|#(?=\()/i,"block-arguments":{pattern:/(\[\s*):[^\[|]*\|/,lookbehind:!0,inside:{variable:/:[\da-z]+/i,punctuation:/\|/}},"temporary-variables":{pattern:/\|[^|]+\|/,inside:{variable:/[\da-z]+/i,punctuation:/\|/}},keyword:/\b(?:new|nil|self|super)\b/,boolean:/\b(?:false|true)\b/,number:[/\d+r-?[\dA-Z]+(?:\.[\dA-Z]+)?(?:e-?\d+)?/,/\b\d+(?:\.\d+)?(?:e-?\d+)?/],operator:/[<=]=?|:=|~[~=]|\/\/?|\\\\|>[>=]?|[!^+\-*&|,@]/,punctuation:/[.;:?\[\](){}]/}}ST.displayName="smarty";ST.aliases=[];function ST(e){e.register(Er),(function(t){t.languages.smarty={comment:{pattern:/^\{\*[\s\S]*?\*\}/,greedy:!0},"embedded-php":{pattern:/^\{php\}[\s\S]*?\{\/php\}/,greedy:!0,inside:{smarty:{pattern:/^\{php\}|\{\/php\}$/,inside:null},php:{pattern:/[\s\S]+/,alias:"language-php",inside:t.languages.php}}},string:[{pattern:/"(?:\\.|[^"\\\r\n])*"/,greedy:!0,inside:{interpolation:{pattern:/\{[^{}]*\}|`[^`]*`/,inside:{"interpolation-punctuation":{pattern:/^[{`]|[`}]$/,alias:"punctuation"},expression:{pattern:/[\s\S]+/,inside:null}}},variable:/\$\w+/}},{pattern:/'(?:\\.|[^'\\\r\n])*'/,greedy:!0}],keyword:{pattern:/(^\{\/?)[a-z_]\w*\b(?!\()/i,lookbehind:!0,greedy:!0},delimiter:{pattern:/^\{\/?|\}$/,greedy:!0,alias:"punctuation"},number:/\b0x[\dA-Fa-f]+|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee][-+]?\d+)?/,variable:[/\$(?!\d)\w+/,/#(?!\d)\w+#/,{pattern:/(\.|->|\w\s*=)(?!\d)\w+\b(?!\()/,lookbehind:!0},{pattern:/(\[)(?!\d)\w+(?=\])/,lookbehind:!0}],function:{pattern:/(\|\s*)@?[a-z_]\w*|\b[a-z_]\w*(?=\()/i,lookbehind:!0},"attr-name":/\b[a-z_]\w*(?=\s*=)/i,boolean:/\b(?:false|no|off|on|true|yes)\b/,punctuation:/[\[\](){}.,:`]|->/,operator:[/[+\-*\/%]|==?=?|[!<>]=?|&&|\|\|?/,/\bis\s+(?:not\s+)?(?:div|even|odd)(?:\s+by)?\b/,/\b(?:and|eq|gt?e|gt|lt?e|lt|mod|neq?|not|or)\b/]},t.languages.smarty["embedded-php"].inside.smarty.inside=t.languages.smarty,t.languages.smarty.string[0].inside.interpolation.inside.expression.inside=t.languages.smarty;var n=/"(?:\\.|[^"\\\r\n])*"|'(?:\\.|[^'\\\r\n])*'/,r=RegExp(/\{\*[\s\S]*?\*\}/.source+"|"+/\{php\}[\s\S]*?\{\/php\}/.source+"|"+/\{(?:[^{}"']|<str>|\{(?:[^{}"']|<str>|\{(?:[^{}"']|<str>)*\})*\})*\}/.source.replace(/<str>/g,function(){return n.source}),"g");t.hooks.add("before-tokenize",function(a){var i="{literal}",o="{/literal}",l=!1;t.languages["markup-templating"].buildPlaceholders(a,"smarty",r,function(u){return u===o&&(l=!1),l?!1:(u===i&&(l=!0),!0)})}),t.hooks.add("after-tokenize",function(a){t.languages["markup-templating"].tokenizePlaceholders(a,"smarty")})})(e)}wT.displayName="sml";wT.aliases=["smlnj"];function wT(e){(function(t){var n=/\b(?:abstype|and|andalso|as|case|datatype|do|else|end|eqtype|exception|fn|fun|functor|handle|if|in|include|infix|infixr|let|local|nonfix|of|op|open|orelse|raise|rec|sharing|sig|signature|struct|structure|then|type|val|where|while|with|withtype)\b/i;t.languages.sml={comment:/\(\*(?:[^*(]|\*(?!\))|\((?!\*)|\(\*(?:[^*(]|\*(?!\))|\((?!\*))*\*\))*\*\)/,string:{pattern:/#?"(?:[^"\\]|\\.)*"/,greedy:!0},"class-name":[{pattern:RegExp(/((?:^|[^:]):\s*)<TERMINAL>(?:\s*(?:(?:\*|->)\s*<TERMINAL>|,\s*<TERMINAL>(?:(?=<NOT-LAST>)|(?!<NOT-LAST>)\s+<LONG-ID>)))*/.source.replace(/<NOT-LAST>/g,function(){return/\s*(?:[*,]|->)/.source}).replace(/<TERMINAL>/g,function(){return/(?:'[\w']*|<LONG-ID>|\((?:[^()]|\([^()]*\))*\)|\{(?:[^{}]|\{[^{}]*\})*\})(?:\s+<LONG-ID>)*/.source}).replace(/<LONG-ID>/g,function(){return/(?!<KEYWORD>)[a-z\d_][\w'.]*/.source}).replace(/<KEYWORD>/g,function(){return n.source}),"i"),lookbehind:!0,greedy:!0,inside:null},{pattern:/((?:^|[^\w'])(?:datatype|exception|functor|signature|structure|type)\s+)[a-z_][\w'.]*/i,lookbehind:!0}],function:{pattern:/((?:^|[^\w'])fun\s+)[a-z_][\w'.]*/i,lookbehind:!0},keyword:n,variable:{pattern:/(^|[^\w'])'[\w']*/,lookbehind:!0},number:/~?\b(?:\d+(?:\.\d+)?(?:e~?\d+)?|0x[\da-f]+)\b/i,word:{pattern:/\b0w(?:\d+|x[\da-f]+)\b/i,alias:"constant"},boolean:/\b(?:false|true)\b/i,operator:/\.\.\.|:[>=:]|=>?|->|[<>]=?|[!+\-*/^#|@~]/,punctuation:/[(){}\[\].:,;]/},t.languages.sml["class-name"][0].inside=t.languages.sml,t.languages.smlnj=t.languages.sml})(e)}ET.displayName="solidity";ET.aliases=["sol"];function ET(e){e.register(Mt),e.languages.solidity=e.languages.extend("clike",{"class-name":{pattern:/(\b(?:contract|enum|interface|library|new|struct|using)\s+)(?!\d)[\w$]+/,lookbehind:!0},keyword:/\b(?:_|anonymous|as|assembly|assert|break|calldata|case|constant|constructor|continue|contract|default|delete|do|else|emit|enum|event|external|for|from|function|if|import|indexed|inherited|interface|internal|is|let|library|mapping|memory|modifier|new|payable|pragma|private|public|pure|require|returns?|revert|selfdestruct|solidity|storage|struct|suicide|switch|this|throw|using|var|view|while)\b/,operator:/=>|->|:=|=:|\*\*|\+\+|--|\|\||&&|<<=?|>>=?|[-+*/%^&|<>!=]=?|[~?]/}),e.languages.insertBefore("solidity","keyword",{builtin:/\b(?:address|bool|byte|u?int(?:8|16|24|32|40|48|56|64|72|80|88|96|104|112|120|128|136|144|152|160|168|176|184|192|200|208|216|224|232|240|248|256)?|string|bytes(?:[1-9]|[12]\d|3[0-2])?)\b/}),e.languages.insertBefore("solidity","number",{version:{pattern:/([<>]=?|\^)\d+\.\d+\.\d+\b/,lookbehind:!0,alias:"number"}}),e.languages.sol=e.languages.solidity}kT.displayName="solution-file";kT.aliases=["sln"];function kT(e){(function(t){var n={pattern:/\{[\da-f]{8}-[\da-f]{4}-[\da-f]{4}-[\da-f]{4}-[\da-f]{12}\}/i,alias:"constant",inside:{punctuation:/[{}]/}};t.languages["solution-file"]={comment:{pattern:/#.*/,greedy:!0},string:{pattern:/"[^"\r\n]*"|'[^'\r\n]*'/,greedy:!0,inside:{guid:n}},object:{pattern:/^([ \t]*)(?:([A-Z]\w*)\b(?=.*(?:\r\n?|\n)(?:\1[ \t].*(?:\r\n?|\n))*\1End\2(?=[ \t]*$))|End[A-Z]\w*(?=[ \t]*$))/m,lookbehind:!0,greedy:!0,alias:"keyword"},property:{pattern:/^([ \t]*)(?!\s)[^\r\n"#=()]*[^\s"#=()](?=\s*=)/m,lookbehind:!0,inside:{guid:n}},guid:n,number:/\b\d+(?:\.\d+)*\b/,boolean:/\b(?:FALSE|TRUE)\b/,operator:/=/,punctuation:/[(),]/},t.languages.sln=t.languages["solution-file"]})(e)}TT.displayName="soy";TT.aliases=[];function TT(e){e.register(Er),(function(t){var n=/(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,r=/\b\d+(?:\.\d+)?(?:[eE][+-]?\d+)?\b|\b0x[\dA-F]+\b/;t.languages.soy={comment:[/\/\*[\s\S]*?\*\//,{pattern:/(\s)\/\/.*/,lookbehind:!0,greedy:!0}],"command-arg":{pattern:/(\{+\/?\s*(?:alias|call|delcall|delpackage|deltemplate|namespace|template)\s+)\.?[\w.]+/,lookbehind:!0,alias:"string",inside:{punctuation:/\./}},parameter:{pattern:/(\{+\/?\s*@?param\??\s+)\.?[\w.]+/,lookbehind:!0,alias:"variable"},keyword:[{pattern:/(\{+\/?[^\S\r\n]*)(?:\\[nrt]|alias|call|case|css|default|delcall|delpackage|deltemplate|else(?:if)?|fallbackmsg|for(?:each)?|if(?:empty)?|lb|let|literal|msg|namespace|nil|@?param\??|rb|sp|switch|template|xid)/,lookbehind:!0},/\b(?:any|as|attributes|bool|css|float|html|in|int|js|list|map|null|number|string|uri)\b/],delimiter:{pattern:/^\{+\/?|\/?\}+$/,alias:"punctuation"},property:/\w+(?==)/,variable:{pattern:/\$[^\W\d]\w*(?:\??(?:\.\w+|\[[^\]]+\]))*/,inside:{string:{pattern:n,greedy:!0},number:r,punctuation:/[\[\].?]/}},string:{pattern:n,greedy:!0},function:[/\w+(?=\()/,{pattern:/(\|[^\S\r\n]*)\w+/,lookbehind:!0}],boolean:/\b(?:false|true)\b/,number:r,operator:/\?:?|<=?|>=?|==?|!=|[+*/%-]|\b(?:and|not|or)\b/,punctuation:/[{}()\[\]|.,:]/},t.hooks.add("before-tokenize",function(a){var i=/\{\{.+?\}\}|\{.+?\}|\s\/\/.*|\/\*[\s\S]*?\*\//g,o="{literal}",l="{/literal}",u=!1;t.languages["markup-templating"].buildPlaceholders(a,"soy",i,function(d){return d===l&&(u=!1),u?!1:(d===o&&(u=!0),!0)})}),t.hooks.add("after-tokenize",function(a){t.languages["markup-templating"].tokenizePlaceholders(a,"soy")})})(e)}Fg.displayName="turtle";Fg.aliases=["trig"];function Fg(e){e.languages.turtle={comment:{pattern:/#.*/,greedy:!0},"multiline-string":{pattern:/"""(?:(?:""?)?(?:[^"\\]|\\.))*"""|'''(?:(?:''?)?(?:[^'\\]|\\.))*'''/,greedy:!0,alias:"string",inside:{comment:/#.*/}},string:{pattern:/"(?:[^\\"\r\n]|\\.)*"|'(?:[^\\'\r\n]|\\.)*'/,greedy:!0},url:{pattern:/<(?:[^\x00-\x20<>"{}|^`\\]|\\(?:u[\da-fA-F]{4}|U[\da-fA-F]{8}))*>/,greedy:!0,inside:{punctuation:/[<>]/}},function:{pattern:/(?:(?![-.\d\xB7])[-.\w\xB7\xC0-\uFFFD]+)?:(?:(?![-.])(?:[-.:\w\xC0-\uFFFD]|%[\da-f]{2}|\\.)+)?/i,inside:{"local-name":{pattern:/([^:]*:)[\s\S]+/,lookbehind:!0},prefix:{pattern:/[\s\S]+/,inside:{punctuation:/:/}}}},number:/[+-]?\b\d+(?:\.\d*)?(?:e[+-]?\d+)?/i,punctuation:/[{}.,;()[\]]|\^\^/,boolean:/\b(?:false|true)\b/,keyword:[/(?:\ba|@prefix|@base)\b|=/,/\b(?:base|graph|prefix)\b/i],tag:{pattern:/@[a-z]+(?:-[a-z\d]+)*/i,inside:{punctuation:/@/}}},e.languages.trig=e.languages.turtle}_T.displayName="sparql";_T.aliases=["rq"];function _T(e){e.register(Fg),e.languages.sparql=e.languages.extend("turtle",{boolean:/\b(?:false|true)\b/i,variable:{pattern:/[?$]\w+/,greedy:!0}}),e.languages.insertBefore("sparql","punctuation",{keyword:[/\b(?:A|ADD|ALL|AS|ASC|ASK|BNODE|BY|CLEAR|CONSTRUCT|COPY|CREATE|DATA|DEFAULT|DELETE|DESC|DESCRIBE|DISTINCT|DROP|EXISTS|FILTER|FROM|GROUP|HAVING|INSERT|INTO|LIMIT|LOAD|MINUS|MOVE|NAMED|NOT|NOW|OFFSET|OPTIONAL|ORDER|RAND|REDUCED|SELECT|SEPARATOR|SERVICE|SILENT|STRUUID|UNION|USING|UUID|VALUES|WHERE)\b/i,/\b(?:ABS|AVG|BIND|BOUND|CEIL|COALESCE|CONCAT|CONTAINS|COUNT|DATATYPE|DAY|ENCODE_FOR_URI|FLOOR|GROUP_CONCAT|HOURS|IF|IRI|isBLANK|isIRI|isLITERAL|isNUMERIC|isURI|LANG|LANGMATCHES|LCASE|MAX|MD5|MIN|MINUTES|MONTH|REGEX|REPLACE|ROUND|sameTerm|SAMPLE|SECONDS|SHA1|SHA256|SHA384|SHA512|STR|STRAFTER|STRBEFORE|STRDT|STRENDS|STRLANG|STRLEN|STRSTARTS|SUBSTR|SUM|TIMEZONE|TZ|UCASE|URI|YEAR)\b(?=\s*\()/i,/\b(?:BASE|GRAPH|PREFIX)\b/i]}),e.languages.rq=e.languages.sparql}CT.displayName="splunk-spl";CT.aliases=[];function CT(e){e.languages["splunk-spl"]={comment:/`comment\("(?:\\.|[^\\"])*"\)`/,string:{pattern:/"(?:\\.|[^\\"])*"/,greedy:!0},keyword:/\b(?:abstract|accum|addcoltotals|addinfo|addtotals|analyzefields|anomalies|anomalousvalue|anomalydetection|append|appendcols|appendcsv|appendlookup|appendpipe|arules|associate|audit|autoregress|bin|bucket|bucketdir|chart|cluster|cofilter|collect|concurrency|contingency|convert|correlate|datamodel|dbinspect|dedup|delete|delta|diff|erex|eval|eventcount|eventstats|extract|fieldformat|fields|fieldsummary|filldown|fillnull|findtypes|folderize|foreach|format|from|gauge|gentimes|geom|geomfilter|geostats|head|highlight|history|iconify|input|inputcsv|inputlookup|iplocation|join|kmeans|kv|kvform|loadjob|localize|localop|lookup|makecontinuous|makemv|makeresults|map|mcollect|metadata|metasearch|meventcollect|mstats|multikv|multisearch|mvcombine|mvexpand|nomv|outlier|outputcsv|outputlookup|outputtext|overlap|pivot|predict|rangemap|rare|regex|relevancy|reltime|rename|replace|rest|return|reverse|rex|rtorder|run|savedsearch|script|scrub|search|searchtxn|selfjoin|sendemail|set|setfields|sichart|sirare|sistats|sitimechart|sitop|sort|spath|stats|strcat|streamstats|table|tags|tail|timechart|timewrap|top|transaction|transpose|trendline|tscollect|tstats|typeahead|typelearner|typer|union|uniq|untable|where|x11|xmlkv|xmlunescape|xpath|xyseries)\b/i,"operator-word":{pattern:/\b(?:and|as|by|not|or|xor)\b/i,alias:"operator"},function:/\b\w+(?=\s*\()/,property:/\b\w+(?=\s*=(?!=))/,date:{pattern:/\b\d{1,2}\/\d{1,2}\/\d{1,4}(?:(?::\d{1,2}){3})?\b/,alias:"number"},number:/\b\d+(?:\.\d+)?\b/,boolean:/\b(?:f|false|t|true)\b/i,operator:/[<>=]=?|[-+*/%|]/,punctuation:/[()[\],]/}}AT.displayName="sqf";AT.aliases=[];function AT(e){e.register(Mt),e.languages.sqf=e.languages.extend("clike",{string:{pattern:/"(?:(?:"")?[^"])*"(?!")|'(?:[^'])*'/,greedy:!0},keyword:/\b(?:breakOut|breakTo|call|case|catch|default|do|echo|else|execFSM|execVM|exitWith|for|forEach|forEachMember|forEachMemberAgent|forEachMemberTeam|from|goto|if|nil|preprocessFile|preprocessFileLineNumbers|private|scopeName|spawn|step|switch|then|throw|to|try|while|with)\b/i,boolean:/\b(?:false|true)\b/i,function:/\b(?:abs|accTime|acos|action|actionIDs|actionKeys|actionKeysImages|actionKeysNames|actionKeysNamesArray|actionName|actionParams|activateAddons|activatedAddons|activateKey|add3DENConnection|add3DENEventHandler|add3DENLayer|addAction|addBackpack|addBackpackCargo|addBackpackCargoGlobal|addBackpackGlobal|addCamShake|addCuratorAddons|addCuratorCameraArea|addCuratorEditableObjects|addCuratorEditingArea|addCuratorPoints|addEditorObject|addEventHandler|addForce|addForceGeneratorRTD|addGoggles|addGroupIcon|addHandgunItem|addHeadgear|addItem|addItemCargo|addItemCargoGlobal|addItemPool|addItemToBackpack|addItemToUniform|addItemToVest|addLiveStats|addMagazine|addMagazineAmmoCargo|addMagazineCargo|addMagazineCargoGlobal|addMagazineGlobal|addMagazinePool|addMagazines|addMagazineTurret|addMenu|addMenuItem|addMissionEventHandler|addMPEventHandler|addMusicEventHandler|addOwnedMine|addPlayerScores|addPrimaryWeaponItem|addPublicVariableEventHandler|addRating|addResources|addScore|addScoreSide|addSecondaryWeaponItem|addSwitchableUnit|addTeamMember|addToRemainsCollector|addTorque|addUniform|addVehicle|addVest|addWaypoint|addWeapon|addWeaponCargo|addWeaponCargoGlobal|addWeaponGlobal|addWeaponItem|addWeaponPool|addWeaponTurret|admin|agent|agents|AGLToASL|aimedAtTarget|aimPos|airDensityCurveRTD|airDensityRTD|airplaneThrottle|airportSide|AISFinishHeal|alive|all3DENEntities|allAirports|allControls|allCurators|allCutLayers|allDead|allDeadMen|allDisplays|allGroups|allMapMarkers|allMines|allMissionObjects|allow3DMode|allowCrewInImmobile|allowCuratorLogicIgnoreAreas|allowDamage|allowDammage|allowFileOperations|allowFleeing|allowGetIn|allowSprint|allPlayers|allSimpleObjects|allSites|allTurrets|allUnits|allUnitsUAV|allVariables|ammo|ammoOnPylon|animate|animateBay|animateDoor|animatePylon|animateSource|animationNames|animationPhase|animationSourcePhase|animationState|append|apply|armoryPoints|arrayIntersect|asin|ASLToAGL|ASLToATL|assert|assignAsCargo|assignAsCargoIndex|assignAsCommander|assignAsDriver|assignAsGunner|assignAsTurret|assignCurator|assignedCargo|assignedCommander|assignedDriver|assignedGunner|assignedItems|assignedTarget|assignedTeam|assignedVehicle|assignedVehicleRole|assignItem|assignTeam|assignToAirport|atan|atan2|atg|ATLToASL|attachedObject|attachedObjects|attachedTo|attachObject|attachTo|attackEnabled|backpack|backpackCargo|backpackContainer|backpackItems|backpackMagazines|backpackSpaceFor|behaviour|benchmark|binocular|blufor|boundingBox|boundingBoxReal|boundingCenter|briefingName|buildingExit|buildingPos|buldozer_EnableRoadDiag|buldozer_IsEnabledRoadDiag|buldozer_LoadNewRoads|buldozer_reloadOperMap|buttonAction|buttonSetAction|cadetMode|callExtension|camCommand|camCommit|camCommitPrepared|camCommitted|camConstuctionSetParams|camCreate|camDestroy|cameraEffect|cameraEffectEnableHUD|cameraInterest|cameraOn|cameraView|campaignConfigFile|camPreload|camPreloaded|camPrepareBank|camPrepareDir|camPrepareDive|camPrepareFocus|camPrepareFov|camPrepareFovRange|camPreparePos|camPrepareRelPos|camPrepareTarget|camSetBank|camSetDir|camSetDive|camSetFocus|camSetFov|camSetFovRange|camSetPos|camSetRelPos|camSetTarget|camTarget|camUseNVG|canAdd|canAddItemToBackpack|canAddItemToUniform|canAddItemToVest|cancelSimpleTaskDestination|canFire|canMove|canSlingLoad|canStand|canSuspend|canTriggerDynamicSimulation|canUnloadInCombat|canVehicleCargo|captive|captiveNum|cbChecked|cbSetChecked|ceil|channelEnabled|cheatsEnabled|checkAIFeature|checkVisibility|civilian|className|clear3DENAttribute|clear3DENInventory|clearAllItemsFromBackpack|clearBackpackCargo|clearBackpackCargoGlobal|clearForcesRTD|clearGroupIcons|clearItemCargo|clearItemCargoGlobal|clearItemPool|clearMagazineCargo|clearMagazineCargoGlobal|clearMagazinePool|clearOverlay|clearRadio|clearVehicleInit|clearWeaponCargo|clearWeaponCargoGlobal|clearWeaponPool|clientOwner|closeDialog|closeDisplay|closeOverlay|collapseObjectTree|collect3DENHistory|collectiveRTD|combatMode|commandArtilleryFire|commandChat|commander|commandFire|commandFollow|commandFSM|commandGetOut|commandingMenu|commandMove|commandRadio|commandStop|commandSuppressiveFire|commandTarget|commandWatch|comment|commitOverlay|compile|compileFinal|completedFSM|composeText|configClasses|configFile|configHierarchy|configName|configNull|configProperties|configSourceAddonList|configSourceMod|configSourceModList|confirmSensorTarget|connectTerminalToUAV|controlNull|controlsGroupCtrl|copyFromClipboard|copyToClipboard|copyWaypoints|cos|count|countEnemy|countFriendly|countSide|countType|countUnknown|create3DENComposition|create3DENEntity|createAgent|createCenter|createDialog|createDiaryLink|createDiaryRecord|createDiarySubject|createDisplay|createGearDialog|createGroup|createGuardedPoint|createLocation|createMarker|createMarkerLocal|createMenu|createMine|createMissionDisplay|createMPCampaignDisplay|createSimpleObject|createSimpleTask|createSite|createSoundSource|createTask|createTeam|createTrigger|createUnit|createVehicle|createVehicleCrew|createVehicleLocal|crew|ctAddHeader|ctAddRow|ctClear|ctCurSel|ctData|ctFindHeaderRows|ctFindRowHeader|ctHeaderControls|ctHeaderCount|ctRemoveHeaders|ctRemoveRows|ctrlActivate|ctrlAddEventHandler|ctrlAngle|ctrlAutoScrollDelay|ctrlAutoScrollRewind|ctrlAutoScrollSpeed|ctrlChecked|ctrlClassName|ctrlCommit|ctrlCommitted|ctrlCreate|ctrlDelete|ctrlEnable|ctrlEnabled|ctrlFade|ctrlHTMLLoaded|ctrlIDC|ctrlIDD|ctrlMapAnimAdd|ctrlMapAnimClear|ctrlMapAnimCommit|ctrlMapAnimDone|ctrlMapCursor|ctrlMapMouseOver|ctrlMapScale|ctrlMapScreenToWorld|ctrlMapWorldToScreen|ctrlModel|ctrlModelDirAndUp|ctrlModelScale|ctrlParent|ctrlParentControlsGroup|ctrlPosition|ctrlRemoveAllEventHandlers|ctrlRemoveEventHandler|ctrlScale|ctrlSetActiveColor|ctrlSetAngle|ctrlSetAutoScrollDelay|ctrlSetAutoScrollRewind|ctrlSetAutoScrollSpeed|ctrlSetBackgroundColor|ctrlSetChecked|ctrlSetDisabledColor|ctrlSetEventHandler|ctrlSetFade|ctrlSetFocus|ctrlSetFont|ctrlSetFontH1|ctrlSetFontH1B|ctrlSetFontH2|ctrlSetFontH2B|ctrlSetFontH3|ctrlSetFontH3B|ctrlSetFontH4|ctrlSetFontH4B|ctrlSetFontH5|ctrlSetFontH5B|ctrlSetFontH6|ctrlSetFontH6B|ctrlSetFontHeight|ctrlSetFontHeightH1|ctrlSetFontHeightH2|ctrlSetFontHeightH3|ctrlSetFontHeightH4|ctrlSetFontHeightH5|ctrlSetFontHeightH6|ctrlSetFontHeightSecondary|ctrlSetFontP|ctrlSetFontPB|ctrlSetFontSecondary|ctrlSetForegroundColor|ctrlSetModel|ctrlSetModelDirAndUp|ctrlSetModelScale|ctrlSetPixelPrecision|ctrlSetPosition|ctrlSetScale|ctrlSetStructuredText|ctrlSetText|ctrlSetTextColor|ctrlSetTextColorSecondary|ctrlSetTextSecondary|ctrlSetTooltip|ctrlSetTooltipColorBox|ctrlSetTooltipColorShade|ctrlSetTooltipColorText|ctrlShow|ctrlShown|ctrlText|ctrlTextHeight|ctrlTextSecondary|ctrlTextWidth|ctrlType|ctrlVisible|ctRowControls|ctRowCount|ctSetCurSel|ctSetData|ctSetHeaderTemplate|ctSetRowTemplate|ctSetValue|ctValue|curatorAddons|curatorCamera|curatorCameraArea|curatorCameraAreaCeiling|curatorCoef|curatorEditableObjects|curatorEditingArea|curatorEditingAreaType|curatorMouseOver|curatorPoints|curatorRegisteredObjects|curatorSelected|curatorWaypointCost|current3DENOperation|currentChannel|currentCommand|currentMagazine|currentMagazineDetail|currentMagazineDetailTurret|currentMagazineTurret|currentMuzzle|currentNamespace|currentTask|currentTasks|currentThrowable|currentVisionMode|currentWaypoint|currentWeapon|currentWeaponMode|currentWeaponTurret|currentZeroing|cursorObject|cursorTarget|customChat|customRadio|cutFadeOut|cutObj|cutRsc|cutText|damage|date|dateToNumber|daytime|deActivateKey|debriefingText|debugFSM|debugLog|deg|delete3DENEntities|deleteAt|deleteCenter|deleteCollection|deleteEditorObject|deleteGroup|deleteGroupWhenEmpty|deleteIdentity|deleteLocation|deleteMarker|deleteMarkerLocal|deleteRange|deleteResources|deleteSite|deleteStatus|deleteTeam|deleteVehicle|deleteVehicleCrew|deleteWaypoint|detach|detectedMines|diag_activeMissionFSMs|diag_activeScripts|diag_activeSQFScripts|diag_activeSQSScripts|diag_captureFrame|diag_captureFrameToFile|diag_captureSlowFrame|diag_codePerformance|diag_drawMode|diag_dynamicSimulationEnd|diag_enable|diag_enabled|diag_fps|diag_fpsMin|diag_frameNo|diag_lightNewLoad|diag_list|diag_log|diag_logSlowFrame|diag_mergeConfigFile|diag_recordTurretLimits|diag_setLightNew|diag_tickTime|diag_toggle|dialog|diarySubjectExists|didJIP|didJIPOwner|difficulty|difficultyEnabled|difficultyEnabledRTD|difficultyOption|direction|directSay|disableAI|disableCollisionWith|disableConversation|disableDebriefingStats|disableMapIndicators|disableNVGEquipment|disableRemoteSensors|disableSerialization|disableTIEquipment|disableUAVConnectability|disableUserInput|displayAddEventHandler|displayCtrl|displayNull|displayParent|displayRemoveAllEventHandlers|displayRemoveEventHandler|displaySetEventHandler|dissolveTeam|distance|distance2D|distanceSqr|distributionRegion|do3DENAction|doArtilleryFire|doFire|doFollow|doFSM|doGetOut|doMove|doorPhase|doStop|doSuppressiveFire|doTarget|doWatch|drawArrow|drawEllipse|drawIcon|drawIcon3D|drawLine|drawLine3D|drawLink|drawLocation|drawPolygon|drawRectangle|drawTriangle|driver|drop|dynamicSimulationDistance|dynamicSimulationDistanceCoef|dynamicSimulationEnabled|dynamicSimulationSystemEnabled|east|edit3DENMissionAttributes|editObject|editorSetEventHandler|effectiveCommander|emptyPositions|enableAI|enableAIFeature|enableAimPrecision|enableAttack|enableAudioFeature|enableAutoStartUpRTD|enableAutoTrimRTD|enableCamShake|enableCaustics|enableChannel|enableCollisionWith|enableCopilot|enableDebriefingStats|enableDiagLegend|enableDynamicSimulation|enableDynamicSimulationSystem|enableEndDialog|enableEngineArtillery|enableEnvironment|enableFatigue|enableGunLights|enableInfoPanelComponent|enableIRLasers|enableMimics|enablePersonTurret|enableRadio|enableReload|enableRopeAttach|enableSatNormalOnDetail|enableSaving|enableSentences|enableSimulation|enableSimulationGlobal|enableStamina|enableStressDamage|enableTeamSwitch|enableTraffic|enableUAVConnectability|enableUAVWaypoints|enableVehicleCargo|enableVehicleSensor|enableWeaponDisassembly|endl|endLoadingScreen|endMission|engineOn|enginesIsOnRTD|enginesPowerRTD|enginesRpmRTD|enginesTorqueRTD|entities|environmentEnabled|estimatedEndServerTime|estimatedTimeLeft|evalObjectArgument|everyBackpack|everyContainer|exec|execEditorScript|exp|expectedDestination|exportJIPMessages|eyeDirection|eyePos|face|faction|fadeMusic|fadeRadio|fadeSound|fadeSpeech|failMission|fillWeaponsFromPool|find|findCover|findDisplay|findEditorObject|findEmptyPosition|findEmptyPositionReady|findIf|findNearestEnemy|finishMissionInit|finite|fire|fireAtTarget|firstBackpack|flag|flagAnimationPhase|flagOwner|flagSide|flagTexture|fleeing|floor|flyInHeight|flyInHeightASL|fog|fogForecast|fogParams|forceAddUniform|forceAtPositionRTD|forcedMap|forceEnd|forceFlagTexture|forceFollowRoad|forceGeneratorRTD|forceMap|forceRespawn|forceSpeed|forceWalk|forceWeaponFire|forceWeatherChange|forgetTarget|format|formation|formationDirection|formationLeader|formationMembers|formationPosition|formationTask|formatText|formLeader|freeLook|fromEditor|fuel|fullCrew|gearIDCAmmoCount|gearSlotAmmoCount|gearSlotData|get3DENActionState|get3DENAttribute|get3DENCamera|get3DENConnections|get3DENEntity|get3DENEntityID|get3DENGrid|get3DENIconsVisible|get3DENLayerEntities|get3DENLinesVisible|get3DENMissionAttribute|get3DENMouseOver|get3DENSelected|getAimingCoef|getAllEnvSoundControllers|getAllHitPointsDamage|getAllOwnedMines|getAllSoundControllers|getAmmoCargo|getAnimAimPrecision|getAnimSpeedCoef|getArray|getArtilleryAmmo|getArtilleryComputerSettings|getArtilleryETA|getAssignedCuratorLogic|getAssignedCuratorUnit|getBackpackCargo|getBleedingRemaining|getBurningValue|getCameraViewDirection|getCargoIndex|getCenterOfMass|getClientState|getClientStateNumber|getCompatiblePylonMagazines|getConnectedUAV|getContainerMaxLoad|getCursorObjectParams|getCustomAimCoef|getDammage|getDescription|getDir|getDirVisual|getDLCAssetsUsage|getDLCAssetsUsageByName|getDLCs|getDLCUsageTime|getEditorCamera|getEditorMode|getEditorObjectScope|getElevationOffset|getEngineTargetRpmRTD|getEnvSoundController|getFatigue|getFieldManualStartPage|getForcedFlagTexture|getFriend|getFSMVariable|getFuelCargo|getGroupIcon|getGroupIconParams|getGroupIcons|getHideFrom|getHit|getHitIndex|getHitPointDamage|getItemCargo|getMagazineCargo|getMarkerColor|getMarkerPos|getMarkerSize|getMarkerType|getMass|getMissionConfig|getMissionConfigValue|getMissionDLCs|getMissionLayerEntities|getMissionLayers|getModelInfo|getMousePosition|getMusicPlayedTime|getNumber|getObjectArgument|getObjectChildren|getObjectDLC|getObjectMaterials|getObjectProxy|getObjectTextures|getObjectType|getObjectViewDistance|getOxygenRemaining|getPersonUsedDLCs|getPilotCameraDirection|getPilotCameraPosition|getPilotCameraRotation|getPilotCameraTarget|getPlateNumber|getPlayerChannel|getPlayerScores|getPlayerUID|getPlayerUIDOld|getPos|getPosASL|getPosASLVisual|getPosASLW|getPosATL|getPosATLVisual|getPosVisual|getPosWorld|getPylonMagazines|getRelDir|getRelPos|getRemoteSensorsDisabled|getRepairCargo|getResolution|getRotorBrakeRTD|getShadowDistance|getShotParents|getSlingLoad|getSoundController|getSoundControllerResult|getSpeed|getStamina|getStatValue|getSuppression|getTerrainGrid|getTerrainHeightASL|getText|getTotalDLCUsageTime|getTrimOffsetRTD|getUnitLoadout|getUnitTrait|getUserMFDText|getUserMFDValue|getVariable|getVehicleCargo|getWeaponCargo|getWeaponSway|getWingsOrientationRTD|getWingsPositionRTD|getWPPos|glanceAt|globalChat|globalRadio|goggles|group|groupChat|groupFromNetId|groupIconSelectable|groupIconsVisible|groupId|groupOwner|groupRadio|groupSelectedUnits|groupSelectUnit|grpNull|gunner|gusts|halt|handgunItems|handgunMagazine|handgunWeapon|handsHit|hasInterface|hasPilotCamera|hasWeapon|hcAllGroups|hcGroupParams|hcLeader|hcRemoveAllGroups|hcRemoveGroup|hcSelected|hcSelectGroup|hcSetGroup|hcShowBar|hcShownBar|headgear|hideBody|hideObject|hideObjectGlobal|hideSelection|hint|hintC|hintCadet|hintSilent|hmd|hostMission|htmlLoad|HUDMovementLevels|humidity|image|importAllGroups|importance|in|inArea|inAreaArray|incapacitatedState|independent|inflame|inflamed|infoPanel|infoPanelComponentEnabled|infoPanelComponents|infoPanels|inGameUISetEventHandler|inheritsFrom|initAmbientLife|inPolygon|inputAction|inRangeOfArtillery|insertEditorObject|intersect|is3DEN|is3DENMultiplayer|isAbleToBreathe|isAgent|isAimPrecisionEnabled|isArray|isAutoHoverOn|isAutonomous|isAutoStartUpEnabledRTD|isAutotest|isAutoTrimOnRTD|isBleeding|isBurning|isClass|isCollisionLightOn|isCopilotEnabled|isDamageAllowed|isDedicated|isDLCAvailable|isEngineOn|isEqualTo|isEqualType|isEqualTypeAll|isEqualTypeAny|isEqualTypeArray|isEqualTypeParams|isFilePatchingEnabled|isFlashlightOn|isFlatEmpty|isForcedWalk|isFormationLeader|isGroupDeletedWhenEmpty|isHidden|isInRemainsCollector|isInstructorFigureEnabled|isIRLaserOn|isKeyActive|isKindOf|isLaserOn|isLightOn|isLocalized|isManualFire|isMarkedForCollection|isMultiplayer|isMultiplayerSolo|isNil|isNull|isNumber|isObjectHidden|isObjectRTD|isOnRoad|isPipEnabled|isPlayer|isRealTime|isRemoteExecuted|isRemoteExecutedJIP|isServer|isShowing3DIcons|isSimpleObject|isSprintAllowed|isStaminaEnabled|isSteamMission|isStreamFriendlyUIEnabled|isStressDamageEnabled|isText|isTouchingGround|isTurnedOut|isTutHintsEnabled|isUAVConnectable|isUAVConnected|isUIContext|isUniformAllowed|isVehicleCargo|isVehicleRadarOn|isVehicleSensorEnabled|isWalking|isWeaponDeployed|isWeaponRested|itemCargo|items|itemsWithMagazines|join|joinAs|joinAsSilent|joinSilent|joinString|kbAddDatabase|kbAddDatabaseTargets|kbAddTopic|kbHasTopic|kbReact|kbRemoveTopic|kbTell|kbWasSaid|keyImage|keyName|knowsAbout|land|landAt|landResult|language|laserTarget|lbAdd|lbClear|lbColor|lbColorRight|lbCurSel|lbData|lbDelete|lbIsSelected|lbPicture|lbPictureRight|lbSelection|lbSetColor|lbSetColorRight|lbSetCurSel|lbSetData|lbSetPicture|lbSetPictureColor|lbSetPictureColorDisabled|lbSetPictureColorSelected|lbSetPictureRight|lbSetPictureRightColor|lbSetPictureRightColorDisabled|lbSetPictureRightColorSelected|lbSetSelectColor|lbSetSelectColorRight|lbSetSelected|lbSetText|lbSetTextRight|lbSetTooltip|lbSetValue|lbSize|lbSort|lbSortByValue|lbText|lbTextRight|lbValue|leader|leaderboardDeInit|leaderboardGetRows|leaderboardInit|leaderboardRequestRowsFriends|leaderboardRequestRowsGlobal|leaderboardRequestRowsGlobalAroundUser|leaderboardsRequestUploadScore|leaderboardsRequestUploadScoreKeepBest|leaderboardState|leaveVehicle|libraryCredits|libraryDisclaimers|lifeState|lightAttachObject|lightDetachObject|lightIsOn|lightnings|limitSpeed|linearConversion|lineBreak|lineIntersects|lineIntersectsObjs|lineIntersectsSurfaces|lineIntersectsWith|linkItem|list|listObjects|listRemoteTargets|listVehicleSensors|ln|lnbAddArray|lnbAddColumn|lnbAddRow|lnbClear|lnbColor|lnbColorRight|lnbCurSelRow|lnbData|lnbDeleteColumn|lnbDeleteRow|lnbGetColumnsPosition|lnbPicture|lnbPictureRight|lnbSetColor|lnbSetColorRight|lnbSetColumnsPos|lnbSetCurSelRow|lnbSetData|lnbSetPicture|lnbSetPictureColor|lnbSetPictureColorRight|lnbSetPictureColorSelected|lnbSetPictureColorSelectedRight|lnbSetPictureRight|lnbSetText|lnbSetTextRight|lnbSetValue|lnbSize|lnbSort|lnbSortByValue|lnbText|lnbTextRight|lnbValue|load|loadAbs|loadBackpack|loadFile|loadGame|loadIdentity|loadMagazine|loadOverlay|loadStatus|loadUniform|loadVest|local|localize|locationNull|locationPosition|lock|lockCameraTo|lockCargo|lockDriver|locked|lockedCargo|lockedDriver|lockedTurret|lockIdentity|lockTurret|lockWP|log|logEntities|logNetwork|logNetworkTerminate|lookAt|lookAtPos|magazineCargo|magazines|magazinesAllTurrets|magazinesAmmo|magazinesAmmoCargo|magazinesAmmoFull|magazinesDetail|magazinesDetailBackpack|magazinesDetailUniform|magazinesDetailVest|magazinesTurret|magazineTurretAmmo|mapAnimAdd|mapAnimClear|mapAnimCommit|mapAnimDone|mapCenterOnCamera|mapGridPosition|markAsFinishedOnSteam|markerAlpha|markerBrush|markerColor|markerDir|markerPos|markerShape|markerSize|markerText|markerType|max|members|menuAction|menuAdd|menuChecked|menuClear|menuCollapse|menuData|menuDelete|menuEnable|menuEnabled|menuExpand|menuHover|menuPicture|menuSetAction|menuSetCheck|menuSetData|menuSetPicture|menuSetValue|menuShortcut|menuShortcutText|menuSize|menuSort|menuText|menuURL|menuValue|min|mineActive|mineDetectedBy|missionConfigFile|missionDifficulty|missionName|missionNamespace|missionStart|missionVersion|modelToWorld|modelToWorldVisual|modelToWorldVisualWorld|modelToWorldWorld|modParams|moonIntensity|moonPhase|morale|move|move3DENCamera|moveInAny|moveInCargo|moveInCommander|moveInDriver|moveInGunner|moveInTurret|moveObjectToEnd|moveOut|moveTime|moveTo|moveToCompleted|moveToFailed|musicVolume|name|nameSound|nearEntities|nearestBuilding|nearestLocation|nearestLocations|nearestLocationWithDubbing|nearestObject|nearestObjects|nearestTerrainObjects|nearObjects|nearObjectsReady|nearRoads|nearSupplies|nearTargets|needReload|netId|netObjNull|newOverlay|nextMenuItemIndex|nextWeatherChange|nMenuItems|numberOfEnginesRTD|numberToDate|objectCurators|objectFromNetId|objectParent|objNull|objStatus|onBriefingGear|onBriefingGroup|onBriefingNotes|onBriefingPlan|onBriefingTeamSwitch|onCommandModeChanged|onDoubleClick|onEachFrame|onGroupIconClick|onGroupIconOverEnter|onGroupIconOverLeave|onHCGroupSelectionChanged|onMapSingleClick|onPlayerConnected|onPlayerDisconnected|onPreloadFinished|onPreloadStarted|onShowNewObject|onTeamSwitch|openCuratorInterface|openDLCPage|openDSInterface|openMap|openSteamApp|openYoutubeVideo|opfor|orderGetIn|overcast|overcastForecast|owner|param|params|parseNumber|parseSimpleArray|parseText|parsingNamespace|particlesQuality|pi|pickWeaponPool|pitch|pixelGrid|pixelGridBase|pixelGridNoUIScale|pixelH|pixelW|playableSlotsNumber|playableUnits|playAction|playActionNow|player|playerRespawnTime|playerSide|playersNumber|playGesture|playMission|playMove|playMoveNow|playMusic|playScriptedMission|playSound|playSound3D|position|positionCameraToWorld|posScreenToWorld|posWorldToScreen|ppEffectAdjust|ppEffectCommit|ppEffectCommitted|ppEffectCreate|ppEffectDestroy|ppEffectEnable|ppEffectEnabled|ppEffectForceInNVG|precision|preloadCamera|preloadObject|preloadSound|preloadTitleObj|preloadTitleRsc|primaryWeapon|primaryWeaponItems|primaryWeaponMagazine|priority|processDiaryLink|processInitCommands|productVersion|profileName|profileNamespace|profileNameSteam|progressLoadingScreen|progressPosition|progressSetPosition|publicVariable|publicVariableClient|publicVariableServer|pushBack|pushBackUnique|putWeaponPool|queryItemsPool|queryMagazinePool|queryWeaponPool|rad|radioChannelAdd|radioChannelCreate|radioChannelRemove|radioChannelSetCallSign|radioChannelSetLabel|radioVolume|rain|rainbow|random|rank|rankId|rating|rectangular|registeredTasks|registerTask|reload|reloadEnabled|remoteControl|remoteExec|remoteExecCall|remoteExecutedOwner|remove3DENConnection|remove3DENEventHandler|remove3DENLayer|removeAction|removeAll3DENEventHandlers|removeAllActions|removeAllAssignedItems|removeAllContainers|removeAllCuratorAddons|removeAllCuratorCameraAreas|removeAllCuratorEditingAreas|removeAllEventHandlers|removeAllHandgunItems|removeAllItems|removeAllItemsWithMagazines|removeAllMissionEventHandlers|removeAllMPEventHandlers|removeAllMusicEventHandlers|removeAllOwnedMines|removeAllPrimaryWeaponItems|removeAllWeapons|removeBackpack|removeBackpackGlobal|removeCuratorAddons|removeCuratorCameraArea|removeCuratorEditableObjects|removeCuratorEditingArea|removeDrawIcon|removeDrawLinks|removeEventHandler|removeFromRemainsCollector|removeGoggles|removeGroupIcon|removeHandgunItem|removeHeadgear|removeItem|removeItemFromBackpack|removeItemFromUniform|removeItemFromVest|removeItems|removeMagazine|removeMagazineGlobal|removeMagazines|removeMagazinesTurret|removeMagazineTurret|removeMenuItem|removeMissionEventHandler|removeMPEventHandler|removeMusicEventHandler|removeOwnedMine|removePrimaryWeaponItem|removeSecondaryWeaponItem|removeSimpleTask|removeSwitchableUnit|removeTeamMember|removeUniform|removeVest|removeWeapon|removeWeaponAttachmentCargo|removeWeaponCargo|removeWeaponGlobal|removeWeaponTurret|reportRemoteTarget|requiredVersion|resetCamShake|resetSubgroupDirection|resistance|resize|resources|respawnVehicle|restartEditorCamera|reveal|revealMine|reverse|reversedMouseY|roadAt|roadsConnectedTo|roleDescription|ropeAttachedObjects|ropeAttachedTo|ropeAttachEnabled|ropeAttachTo|ropeCreate|ropeCut|ropeDestroy|ropeDetach|ropeEndPosition|ropeLength|ropes|ropeUnwind|ropeUnwound|rotorsForcesRTD|rotorsRpmRTD|round|runInitScript|safeZoneH|safeZoneW|safeZoneWAbs|safeZoneX|safeZoneXAbs|safeZoneY|save3DENInventory|saveGame|saveIdentity|saveJoysticks|saveOverlay|saveProfileNamespace|saveStatus|saveVar|savingEnabled|say|say2D|say3D|score|scoreSide|screenshot|screenToWorld|scriptDone|scriptName|scriptNull|scudState|secondaryWeapon|secondaryWeaponItems|secondaryWeaponMagazine|select|selectBestPlaces|selectDiarySubject|selectedEditorObjects|selectEditorObject|selectionNames|selectionPosition|selectLeader|selectMax|selectMin|selectNoPlayer|selectPlayer|selectRandom|selectRandomWeighted|selectWeapon|selectWeaponTurret|sendAUMessage|sendSimpleCommand|sendTask|sendTaskResult|sendUDPMessage|serverCommand|serverCommandAvailable|serverCommandExecutable|serverName|serverTime|set|set3DENAttribute|set3DENAttributes|set3DENGrid|set3DENIconsVisible|set3DENLayer|set3DENLinesVisible|set3DENLogicType|set3DENMissionAttribute|set3DENMissionAttributes|set3DENModelsVisible|set3DENObjectType|set3DENSelected|setAccTime|setActualCollectiveRTD|setAirplaneThrottle|setAirportSide|setAmmo|setAmmoCargo|setAmmoOnPylon|setAnimSpeedCoef|setAperture|setApertureNew|setArmoryPoints|setAttributes|setAutonomous|setBehaviour|setBleedingRemaining|setBrakesRTD|setCameraInterest|setCamShakeDefParams|setCamShakeParams|setCamUseTI|setCaptive|setCenterOfMass|setCollisionLight|setCombatMode|setCompassOscillation|setConvoySeparation|setCuratorCameraAreaCeiling|setCuratorCoef|setCuratorEditingAreaType|setCuratorWaypointCost|setCurrentChannel|setCurrentTask|setCurrentWaypoint|setCustomAimCoef|setCustomWeightRTD|setDamage|setDammage|setDate|setDebriefingText|setDefaultCamera|setDestination|setDetailMapBlendPars|setDir|setDirection|setDrawIcon|setDriveOnPath|setDropInterval|setDynamicSimulationDistance|setDynamicSimulationDistanceCoef|setEditorMode|setEditorObjectScope|setEffectCondition|setEngineRpmRTD|setFace|setFaceAnimation|setFatigue|setFeatureType|setFlagAnimationPhase|setFlagOwner|setFlagSide|setFlagTexture|setFog|setForceGeneratorRTD|setFormation|setFormationTask|setFormDir|setFriend|setFromEditor|setFSMVariable|setFuel|setFuelCargo|setGroupIcon|setGroupIconParams|setGroupIconsSelectable|setGroupIconsVisible|setGroupId|setGroupIdGlobal|setGroupOwner|setGusts|setHideBehind|setHit|setHitIndex|setHitPointDamage|setHorizonParallaxCoef|setHUDMovementLevels|setIdentity|setImportance|setInfoPanel|setLeader|setLightAmbient|setLightAttenuation|setLightBrightness|setLightColor|setLightDayLight|setLightFlareMaxDistance|setLightFlareSize|setLightIntensity|setLightnings|setLightUseFlare|setLocalWindParams|setMagazineTurretAmmo|setMarkerAlpha|setMarkerAlphaLocal|setMarkerBrush|setMarkerBrushLocal|setMarkerColor|setMarkerColorLocal|setMarkerDir|setMarkerDirLocal|setMarkerPos|setMarkerPosLocal|setMarkerShape|setMarkerShapeLocal|setMarkerSize|setMarkerSizeLocal|setMarkerText|setMarkerTextLocal|setMarkerType|setMarkerTypeLocal|setMass|setMimic|setMousePosition|setMusicEffect|setMusicEventHandler|setName|setNameSound|setObjectArguments|setObjectMaterial|setObjectMaterialGlobal|setObjectProxy|setObjectTexture|setObjectTextureGlobal|setObjectViewDistance|setOvercast|setOwner|setOxygenRemaining|setParticleCircle|setParticleClass|setParticleFire|setParticleParams|setParticleRandom|setPilotCameraDirection|setPilotCameraRotation|setPilotCameraTarget|setPilotLight|setPiPEffect|setPitch|setPlateNumber|setPlayable|setPlayerRespawnTime|setPos|setPosASL|setPosASL2|setPosASLW|setPosATL|setPosition|setPosWorld|setPylonLoadOut|setPylonsPriority|setRadioMsg|setRain|setRainbow|setRandomLip|setRank|setRectangular|setRepairCargo|setRotorBrakeRTD|setShadowDistance|setShotParents|setSide|setSimpleTaskAlwaysVisible|setSimpleTaskCustomData|setSimpleTaskDescription|setSimpleTaskDestination|setSimpleTaskTarget|setSimpleTaskType|setSimulWeatherLayers|setSize|setSkill|setSlingLoad|setSoundEffect|setSpeaker|setSpeech|setSpeedMode|setStamina|setStaminaScheme|setStatValue|setSuppression|setSystemOfUnits|setTargetAge|setTaskMarkerOffset|setTaskResult|setTaskState|setTerrainGrid|setText|setTimeMultiplier|setTitleEffect|setToneMapping|setToneMappingParams|setTrafficDensity|setTrafficDistance|setTrafficGap|setTrafficSpeed|setTriggerActivation|setTriggerArea|setTriggerStatements|setTriggerText|setTriggerTimeout|setTriggerType|setType|setUnconscious|setUnitAbility|setUnitLoadout|setUnitPos|setUnitPosWeak|setUnitRank|setUnitRecoilCoefficient|setUnitTrait|setUnloadInCombat|setUserActionText|setUserMFDText|setUserMFDValue|setVariable|setVectorDir|setVectorDirAndUp|setVectorUp|setVehicleAmmo|setVehicleAmmoDef|setVehicleArmor|setVehicleCargo|setVehicleId|setVehicleInit|setVehicleLock|setVehiclePosition|setVehicleRadar|setVehicleReceiveRemoteTargets|setVehicleReportOwnPosition|setVehicleReportRemoteTargets|setVehicleTIPars|setVehicleVarName|setVelocity|setVelocityModelSpace|setVelocityTransformation|setViewDistance|setVisibleIfTreeCollapsed|setWantedRpmRTD|setWaves|setWaypointBehaviour|setWaypointCombatMode|setWaypointCompletionRadius|setWaypointDescription|setWaypointForceBehaviour|setWaypointFormation|setWaypointHousePosition|setWaypointLoiterRadius|setWaypointLoiterType|setWaypointName|setWaypointPosition|setWaypointScript|setWaypointSpeed|setWaypointStatements|setWaypointTimeout|setWaypointType|setWaypointVisible|setWeaponReloadingTime|setWind|setWindDir|setWindForce|setWindStr|setWingForceScaleRTD|setWPPos|show3DIcons|showChat|showCinemaBorder|showCommandingMenu|showCompass|showCuratorCompass|showGPS|showHUD|showLegend|showMap|shownArtilleryComputer|shownChat|shownCompass|shownCuratorCompass|showNewEditorObject|shownGPS|shownHUD|shownMap|shownPad|shownRadio|shownScoretable|shownUAVFeed|shownWarrant|shownWatch|showPad|showRadio|showScoretable|showSubtitles|showUAVFeed|showWarrant|showWatch|showWaypoint|showWaypoints|side|sideAmbientLife|sideChat|sideEmpty|sideEnemy|sideFriendly|sideLogic|sideRadio|sideUnknown|simpleTasks|simulationEnabled|simulCloudDensity|simulCloudOcclusion|simulInClouds|simulWeatherSync|sin|size|sizeOf|skill|skillFinal|skipTime|sleep|sliderPosition|sliderRange|sliderSetPosition|sliderSetRange|sliderSetSpeed|sliderSpeed|slingLoadAssistantShown|soldierMagazines|someAmmo|sort|soundVolume|speaker|speed|speedMode|splitString|sqrt|squadParams|stance|startLoadingScreen|stop|stopEngineRTD|stopped|str|sunOrMoon|supportInfo|suppressFor|surfaceIsWater|surfaceNormal|surfaceType|swimInDepth|switchableUnits|switchAction|switchCamera|switchGesture|switchLight|switchMove|synchronizedObjects|synchronizedTriggers|synchronizedWaypoints|synchronizeObjectsAdd|synchronizeObjectsRemove|synchronizeTrigger|synchronizeWaypoint|systemChat|systemOfUnits|tan|targetKnowledge|targets|targetsAggregate|targetsQuery|taskAlwaysVisible|taskChildren|taskCompleted|taskCustomData|taskDescription|taskDestination|taskHint|taskMarkerOffset|taskNull|taskParent|taskResult|taskState|taskType|teamMember|teamMemberNull|teamName|teams|teamSwitch|teamSwitchEnabled|teamType|terminate|terrainIntersect|terrainIntersectASL|terrainIntersectAtASL|text|textLog|textLogFormat|tg|time|timeMultiplier|titleCut|titleFadeOut|titleObj|titleRsc|titleText|toArray|toFixed|toLower|toString|toUpper|triggerActivated|triggerActivation|triggerArea|triggerAttachedVehicle|triggerAttachObject|triggerAttachVehicle|triggerDynamicSimulation|triggerStatements|triggerText|triggerTimeout|triggerTimeoutCurrent|triggerType|turretLocal|turretOwner|turretUnit|tvAdd|tvClear|tvCollapse|tvCollapseAll|tvCount|tvCurSel|tvData|tvDelete|tvExpand|tvExpandAll|tvPicture|tvPictureRight|tvSetColor|tvSetCurSel|tvSetData|tvSetPicture|tvSetPictureColor|tvSetPictureColorDisabled|tvSetPictureColorSelected|tvSetPictureRight|tvSetPictureRightColor|tvSetPictureRightColorDisabled|tvSetPictureRightColorSelected|tvSetSelectColor|tvSetText|tvSetTooltip|tvSetValue|tvSort|tvSortByValue|tvText|tvTooltip|tvValue|type|typeName|typeOf|UAVControl|uiNamespace|uiSleep|unassignCurator|unassignItem|unassignTeam|unassignVehicle|underwater|uniform|uniformContainer|uniformItems|uniformMagazines|unitAddons|unitAimPosition|unitAimPositionVisual|unitBackpack|unitIsUAV|unitPos|unitReady|unitRecoilCoefficient|units|unitsBelowHeight|unlinkItem|unlockAchievement|unregisterTask|updateDrawIcon|updateMenuItem|updateObjectTree|useAIOperMapObstructionTest|useAISteeringComponent|useAudioTimeForMoves|userInputDisabled|vectorAdd|vectorCos|vectorCrossProduct|vectorDiff|vectorDir|vectorDirVisual|vectorDistance|vectorDistanceSqr|vectorDotProduct|vectorFromTo|vectorMagnitude|vectorMagnitudeSqr|vectorModelToWorld|vectorModelToWorldVisual|vectorMultiply|vectorNormalized|vectorUp|vectorUpVisual|vectorWorldToModel|vectorWorldToModelVisual|vehicle|vehicleCargoEnabled|vehicleChat|vehicleRadio|vehicleReceiveRemoteTargets|vehicleReportOwnPosition|vehicleReportRemoteTargets|vehicles|vehicleVarName|velocity|velocityModelSpace|verifySignature|vest|vestContainer|vestItems|vestMagazines|viewDistance|visibleCompass|visibleGPS|visibleMap|visiblePosition|visiblePositionASL|visibleScoretable|visibleWatch|waitUntil|waves|waypointAttachedObject|waypointAttachedVehicle|waypointAttachObject|waypointAttachVehicle|waypointBehaviour|waypointCombatMode|waypointCompletionRadius|waypointDescription|waypointForceBehaviour|waypointFormation|waypointHousePosition|waypointLoiterRadius|waypointLoiterType|waypointName|waypointPosition|waypoints|waypointScript|waypointsEnabledUAV|waypointShow|waypointSpeed|waypointStatements|waypointTimeout|waypointTimeoutCurrent|waypointType|waypointVisible|weaponAccessories|weaponAccessoriesCargo|weaponCargo|weaponDirection|weaponInertia|weaponLowered|weapons|weaponsItems|weaponsItemsCargo|weaponState|weaponsTurret|weightRTD|west|WFSideText|wind|windDir|windRTD|windStr|wingsForcesRTD|worldName|worldSize|worldToModel|worldToModelVisual|worldToScreen)\b/i,number:/(?:\$|\b0x)[\da-f]+\b|(?:\B\.\d+|\b\d+(?:\.\d+)?)(?:e[+-]?\d+)?\b/i,operator:/##|>>|&&|\|\||[!=<>]=?|[-+*/%#^]|\b(?:and|mod|not|or)\b/i,"magic-variable":{pattern:/\b(?:this|thisList|thisTrigger|_exception|_fnc_scriptName|_fnc_scriptNameParent|_forEachIndex|_this|_thisEventHandler|_thisFSM|_thisScript|_x)\b/i,alias:"keyword"},constant:/\bDIK(?:_[a-z\d]+)+\b/i}),e.languages.insertBefore("sqf","string",{macro:{pattern:/(^[ \t]*)#[a-z](?:[^\r\n\\]|\\(?:\r\n|[\s\S]))*/im,lookbehind:!0,greedy:!0,alias:"property",inside:{directive:{pattern:/#[a-z]+\b/i,alias:"keyword"},comment:e.languages.sqf.comment}}}),delete e.languages.sqf["class-name"]}RT.displayName="squirrel";RT.aliases=[];function RT(e){e.register(Mt),e.languages.squirrel=e.languages.extend("clike",{comment:[e.languages.clike.comment[0],{pattern:/(^|[^\\:])(?:\/\/|#).*/,lookbehind:!0,greedy:!0}],string:{pattern:/(^|[^\\"'@])(?:@"(?:[^"]|"")*"(?!")|"(?:[^\\\r\n"]|\\.)*")/,lookbehind:!0,greedy:!0},"class-name":{pattern:/(\b(?:class|enum|extends|instanceof)\s+)\w+(?:\.\w+)*/,lookbehind:!0,inside:{punctuation:/\./}},keyword:/\b(?:__FILE__|__LINE__|base|break|case|catch|class|clone|const|constructor|continue|default|delete|else|enum|extends|for|foreach|function|if|in|instanceof|local|null|resume|return|static|switch|this|throw|try|typeof|while|yield)\b/,number:/\b(?:0x[0-9a-fA-F]+|\d+(?:\.(?:\d+|[eE][+-]?\d+))?)\b/,operator:/\+\+|--|<=>|<[-<]|>>>?|&&?|\|\|?|[-+*/%!=<>]=?|[~^]|::?/,punctuation:/[(){}\[\],;.]/}),e.languages.insertBefore("squirrel","string",{char:{pattern:/(^|[^\\"'])'(?:[^\\']|\\(?:[xuU][0-9a-fA-F]{0,8}|[\s\S]))'/,lookbehind:!0,greedy:!0}}),e.languages.insertBefore("squirrel","operator",{"attribute-punctuation":{pattern:/<\/|\/>/,alias:"important"},lambda:{pattern:/@(?=\()/,alias:"operator"}})}NT.displayName="stan";NT.aliases=[];function NT(e){(function(t){var n=/\b(?:algebra_solver|algebra_solver_newton|integrate_1d|integrate_ode|integrate_ode_bdf|integrate_ode_rk45|map_rect|ode_(?:adams|bdf|ckrk|rk45)(?:_tol)?|ode_adjoint_tol_ctl|reduce_sum|reduce_sum_static)\b/;t.languages.stan={comment:/\/\/.*|\/\*[\s\S]*?\*\/|#(?!include).*/,string:{pattern:/"[\x20\x21\x23-\x5B\x5D-\x7E]*"/,greedy:!0},directive:{pattern:/^([ \t]*)#include\b.*/m,lookbehind:!0,alias:"property"},"function-arg":{pattern:RegExp("("+n.source+/\s*\(\s*/.source+")"+/[a-zA-Z]\w*/.source),lookbehind:!0,alias:"function"},constraint:{pattern:/(\b(?:int|matrix|real|row_vector|vector)\s*)<[^<>]*>/,lookbehind:!0,inside:{expression:{pattern:/(=\s*)\S(?:\S|\s+(?!\s))*?(?=\s*(?:>$|,\s*\w+\s*=))/,lookbehind:!0,inside:null},property:/\b[a-z]\w*(?=\s*=)/i,operator:/=/,punctuation:/^<|>$|,/}},keyword:[{pattern:/\bdata(?=\s*\{)|\b(?:functions|generated|model|parameters|quantities|transformed)\b/,alias:"program-block"},/\b(?:array|break|cholesky_factor_corr|cholesky_factor_cov|complex|continue|corr_matrix|cov_matrix|data|else|for|if|in|increment_log_prob|int|matrix|ordered|positive_ordered|print|real|reject|return|row_vector|simplex|target|unit_vector|vector|void|while)\b/,n],function:/\b[a-z]\w*(?=\s*\()/i,number:/(?:\b\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\B\.\d+(?:_\d+)*)(?:E[+-]?\d+(?:_\d+)*)?i?(?!\w)/i,boolean:/\b(?:false|true)\b/,operator:/<-|\.[*/]=?|\|\|?|&&|[!=<>+\-*/]=?|['^%~?:]/,punctuation:/[()\[\]{},;]/},t.languages.stan.constraint.inside.expression.inside=t.languages.stan})(e)}OT.displayName="stata";OT.aliases=[];function OT(e){e.register(_u),e.register(Dg),e.register(Mg),e.languages.stata={comment:[{pattern:/(^[ \t]*)\*.*/m,lookbehind:!0,greedy:!0},{pattern:/(^|\s)\/\/.*|\/\*[\s\S]*?\*\//,lookbehind:!0,greedy:!0}],"string-literal":{pattern:/"[^"\r\n]*"|[‘`']".*?"[’`']/,greedy:!0,inside:{interpolation:{pattern:/\$\{[^{}]*\}|[‘`']\w[^’`'\r\n]*[’`']/,inside:{punctuation:/^\$\{|\}$/,expression:{pattern:/[\s\S]+/,inside:null}}},string:/[\s\S]+/}},mata:{pattern:/(^[ \t]*mata[ \t]*:)[\s\S]+?(?=^end\b)/m,lookbehind:!0,greedy:!0,alias:"language-mata",inside:e.languages.mata},java:{pattern:/(^[ \t]*java[ \t]*:)[\s\S]+?(?=^end\b)/m,lookbehind:!0,greedy:!0,alias:"language-java",inside:e.languages.java},python:{pattern:/(^[ \t]*python[ \t]*:)[\s\S]+?(?=^end\b)/m,lookbehind:!0,greedy:!0,alias:"language-python",inside:e.languages.python},command:{pattern:/(^[ \t]*(?:\.[ \t]+)?(?:(?:bayes|bootstrap|by|bysort|capture|collect|fmm|fp|frame|jackknife|mfp|mi|nestreg|noisily|permute|quietly|rolling|simulate|statsby|stepwise|svy|version|xi)\b[^:\r\n]*:[ \t]*|(?:capture|noisily|quietly|version)[ \t]+)?)[a-zA-Z]\w*/m,lookbehind:!0,greedy:!0,alias:"keyword"},variable:/\$\w+|[‘`']\w[^’`'\r\n]*[’`']/,keyword:/\b(?:bayes|bootstrap|by|bysort|capture|clear|collect|fmm|fp|frame|if|in|jackknife|mi[ \t]+estimate|mfp|nestreg|noisily|of|permute|quietly|rolling|simulate|sort|statsby|stepwise|svy|varlist|version|xi)\b/,boolean:/\b(?:off|on)\b/,number:/\b\d+(?:\.\d+)?\b|\B\.\d+/,function:/\b[a-z_]\w*(?=\()/i,operator:/\+\+|--|##?|[<>!=~]=?|[+\-*^&|/]/,punctuation:/[(){}[\],:]/},e.languages.stata["string-literal"].inside.interpolation.inside.expression.inside=e.languages.stata}IT.displayName="iecst";IT.aliases=[];function IT(e){e.languages.iecst={comment:[{pattern:/(^|[^\\])(?:\/\*[\s\S]*?(?:\*\/|$)|\(\*[\s\S]*?(?:\*\)|$)|\{[\s\S]*?(?:\}|$))/,lookbehind:!0,greedy:!0},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0,greedy:!0}],string:{pattern:/(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,greedy:!0},keyword:[/\b(?:END_)?(?:PROGRAM|CONFIGURATION|INTERFACE|FUNCTION_BLOCK|FUNCTION|ACTION|TRANSITION|TYPE|STRUCT|(?:INITIAL_)?STEP|NAMESPACE|LIBRARY|CHANNEL|FOLDER|RESOURCE|VAR_(?:ACCESS|CONFIG|EXTERNAL|GLOBAL|INPUT|IN_OUT|OUTPUT|TEMP)|VAR|METHOD|PROPERTY)\b/i,/\b(?:AT|BY|(?:END_)?(?:CASE|FOR|IF|REPEAT|WHILE)|CONSTANT|CONTINUE|DO|ELSE|ELSIF|EXIT|EXTENDS|FROM|GET|GOTO|IMPLEMENTS|JMP|NON_RETAIN|OF|PRIVATE|PROTECTED|PUBLIC|RETAIN|RETURN|SET|TASK|THEN|TO|UNTIL|USING|WITH|__CATCH|__ENDTRY|__FINALLY|__TRY)\b/],"class-name":/\b(?:ANY|ARRAY|BOOL|BYTE|U?(?:D|L|S)?INT|(?:D|L)?WORD|DATE(?:_AND_TIME)?|DT|L?REAL|POINTER|STRING|TIME(?:_OF_DAY)?|TOD)\b/,address:{pattern:/%[IQM][XBWDL][\d.]*|%[IQ][\d.]*/,alias:"symbol"},number:/\b(?:16#[\da-f]+|2#[01_]+|0x[\da-f]+)\b|\b(?:D|DT|T|TOD)#[\d_shmd:]*|\b[A-Z]*#[\d.,_]*|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?/i,boolean:/\b(?:FALSE|NULL|TRUE)\b/,operator:/S?R?:?=>?|&&?|\*\*?|<[=>]?|>=?|[-:^/+#]|\b(?:AND|EQ|EXPT|GE|GT|LE|LT|MOD|NE|NOT|OR|XOR)\b/,function:/\b[a-z_]\w*(?=\s*\()/i,punctuation:/[()[\].,;]/}}LT.displayName="supercollider";LT.aliases=["sclang"];function LT(e){e.languages.supercollider={comment:{pattern:/\/\/.*|\/\*(?:[^*/]|\*(?!\/)|\/(?!\*)|\/\*(?:[^*]|\*(?!\/))*\*\/)*\*\//,greedy:!0},string:{pattern:/(^|[^\\])"(?:[^"\\]|\\[\s\S])*"/,lookbehind:!0,greedy:!0},char:{pattern:/\$(?:[^\\\r\n]|\\.)/,greedy:!0},symbol:{pattern:/(^|[^\\])'(?:[^'\\]|\\[\s\S])*'|\\\w+/,lookbehind:!0,greedy:!0},keyword:/\b(?:_|arg|classvar|const|nil|var|while)\b/,boolean:/\b(?:false|true)\b/,label:{pattern:/\b[a-z_]\w*(?=\s*:)/,alias:"property"},number:/\b(?:inf|pi|0x[0-9a-fA-F]+|\d+(?:\.\d+)?(?:[eE][+-]?\d+)?(?:pi)?|\d+r[0-9a-zA-Z]+(?:\.[0-9a-zA-Z]+)?|\d+[sb]{1,4}\d*)\b/,"class-name":/\b[A-Z]\w*\b/,operator:/\.{2,3}|#(?![[{])|&&|[!=]==?|\+>>|\+{1,3}|-[->]|=>|>>|\?\?|@\|?@|\|(?:@|[!=]=)?\||!\?|<[!=>]|\*{1,2}|<{2,3}\*?|[-!%&/<>?@|=`]/,punctuation:/[{}()[\].:,;]|#[[{]/},e.languages.sclang=e.languages.supercollider}DT.displayName="swift";DT.aliases=[];function DT(e){e.languages.swift={comment:{pattern:/(^|[^\\:])(?:\/\/.*|\/\*(?:[^/*]|\/(?!\*)|\*(?!\/)|\/\*(?:[^*]|\*(?!\/))*\*\/)*\*\/)/,lookbehind:!0,greedy:!0},"string-literal":[{pattern:RegExp(/(^|[^"#])/.source+"(?:"+/"(?:\\(?:\((?:[^()]|\([^()]*\))*\)|\r\n|[^(])|[^\\\r\n"])*"/.source+"|"+/"""(?:\\(?:\((?:[^()]|\([^()]*\))*\)|[^(])|[^\\"]|"(?!""))*"""/.source+")"+/(?!["#])/.source),lookbehind:!0,greedy:!0,inside:{interpolation:{pattern:/(\\\()(?:[^()]|\([^()]*\))*(?=\))/,lookbehind:!0,inside:null},"interpolation-punctuation":{pattern:/^\)|\\\($/,alias:"punctuation"},punctuation:/\\(?=[\r\n])/,string:/[\s\S]+/}},{pattern:RegExp(/(^|[^"#])(#+)/.source+"(?:"+/"(?:\\(?:#+\((?:[^()]|\([^()]*\))*\)|\r\n|[^#])|[^\\\r\n])*?"/.source+"|"+/"""(?:\\(?:#+\((?:[^()]|\([^()]*\))*\)|[^#])|[^\\])*?"""/.source+")\\2"),lookbehind:!0,greedy:!0,inside:{interpolation:{pattern:/(\\#+\()(?:[^()]|\([^()]*\))*(?=\))/,lookbehind:!0,inside:null},"interpolation-punctuation":{pattern:/^\)|\\#+\($/,alias:"punctuation"},string:/[\s\S]+/}}],directive:{pattern:RegExp(/#/.source+"(?:"+(/(?:elseif|if)\b/.source+"(?:[ 	]*"+/(?:![ \t]*)?(?:\b\w+\b(?:[ \t]*\((?:[^()]|\([^()]*\))*\))?|\((?:[^()]|\([^()]*\))*\))(?:[ \t]*(?:&&|\|\|))?/.source+")+")+"|"+/(?:else|endif)\b/.source+")"),alias:"property",inside:{"directive-name":/^#\w+/,boolean:/\b(?:false|true)\b/,number:/\b\d+(?:\.\d+)*\b/,operator:/!|&&|\|\||[<>]=?/,punctuation:/[(),]/}},literal:{pattern:/#(?:colorLiteral|column|dsohandle|file(?:ID|Literal|Path)?|function|imageLiteral|line)\b/,alias:"constant"},"other-directive":{pattern:/#\w+\b/,alias:"property"},attribute:{pattern:/@\w+/,alias:"atrule"},"function-definition":{pattern:/(\bfunc\s+)\w+/,lookbehind:!0,alias:"function"},label:{pattern:/\b(break|continue)\s+\w+|\b[a-zA-Z_]\w*(?=\s*:\s*(?:for|repeat|while)\b)/,lookbehind:!0,alias:"important"},keyword:/\b(?:Any|Protocol|Self|Type|actor|as|assignment|associatedtype|associativity|async|await|break|case|catch|class|continue|convenience|default|defer|deinit|didSet|do|dynamic|else|enum|extension|fallthrough|fileprivate|final|for|func|get|guard|higherThan|if|import|in|indirect|infix|init|inout|internal|is|isolated|lazy|left|let|lowerThan|mutating|none|nonisolated|nonmutating|open|operator|optional|override|postfix|precedencegroup|prefix|private|protocol|public|repeat|required|rethrows|return|right|safe|self|set|some|static|struct|subscript|super|switch|throw|throws|try|typealias|unowned|unsafe|var|weak|where|while|willSet)\b/,boolean:/\b(?:false|true)\b/,nil:{pattern:/\bnil\b/,alias:"constant"},"short-argument":/\$\d+\b/,omit:{pattern:/\b_\b/,alias:"keyword"},number:/\b(?:[\d_]+(?:\.[\de_]+)?|0x[a-f0-9_]+(?:\.[a-f0-9p_]+)?|0b[01_]+|0o[0-7_]+)\b/i,"class-name":/\b[A-Z](?:[A-Z_\d]*[a-z]\w*)?\b/,function:/\b[a-z_]\w*(?=\s*\()/i,constant:/\b(?:[A-Z_]{2,}|k[A-Z][A-Za-z_]+)\b/,operator:/[-+*/%=!<>&|^~?]+|\.[.\-+*/%=!<>&|^~?]+/,punctuation:/[{}[\]();,.:\\]/},e.languages.swift["string-literal"].forEach(function(t){t.inside.interpolation.inside=e.languages.swift})}MT.displayName="systemd";MT.aliases=[];function MT(e){(function(t){var n={pattern:/^[;#].*/m,greedy:!0},r=/"(?:[^\r\n"\\]|\\(?:[^\r]|\r\n?))*"(?!\S)/.source;t.languages.systemd={comment:n,section:{pattern:/^\[[^\n\r\[\]]*\](?=[ \t]*$)/m,greedy:!0,inside:{punctuation:/^\[|\]$/,"section-name":{pattern:/[\s\S]+/,alias:"selector"}}},key:{pattern:/^[^\s=]+(?=[ \t]*=)/m,greedy:!0,alias:"attr-name"},value:{pattern:RegExp(/(=[ \t]*(?!\s))/.source+"(?:"+r+`|(?=[^"\r
]))(?:`+(/[^\s\\]/.source+'|[ 	]+(?:(?![ 	"])|'+r+")|"+/\\[\r\n]+(?:[#;].*[\r\n]+)*(?![#;])/.source)+")*"),lookbehind:!0,greedy:!0,alias:"attr-value",inside:{comment:n,quoted:{pattern:RegExp(/(^|\s)/.source+r),lookbehind:!0,greedy:!0},punctuation:/\\$/m,boolean:{pattern:/^(?:false|no|off|on|true|yes)$/,greedy:!0}}},punctuation:/=/}})(e)}up.displayName="t4-templating";up.aliases=[];function up(e){(function(t){function n(a,i,o){return{pattern:RegExp("<#"+a+"[\\s\\S]*?#>"),alias:"block",inside:{delimiter:{pattern:RegExp("^<#"+a+"|#>$"),alias:"important"},content:{pattern:/[\s\S]+/,inside:i,alias:o}}}}function r(a){var i=t.languages[a],o="language-"+a;return{block:{pattern:/<#[\s\S]+?#>/,inside:{directive:n("@",{"attr-value":{pattern:/=(?:("|')(?:\\[\s\S]|(?!\1)[^\\])*\1|[^\s'">=]+)/,inside:{punctuation:/^=|^["']|["']$/}},keyword:/\b\w+(?=\s)/,"attr-name":/\b\w+/}),expression:n("=",i,o),"class-feature":n("\\+",i,o),standard:n("",i,o)}}}}t.languages["t4-templating"]=Object.defineProperty({},"createT4",{value:r})})(e)}BT.displayName="t4-cs";BT.aliases=["t4"];function BT(e){e.register(ku),e.register(up),e.languages.t4=e.languages["t4-cs"]=e.languages["t4-templating"].createT4("csharp")}zg.displayName="vbnet";zg.aliases=[];function zg(e){e.register(Ig),e.languages.vbnet=e.languages.extend("basic",{comment:[{pattern:/(?:!|REM\b).+/i,inside:{keyword:/^REM/i}},{pattern:/(^|[^\\:])'.*/,lookbehind:!0,greedy:!0}],string:{pattern:/(^|[^"])"(?:""|[^"])*"(?!")/,lookbehind:!0,greedy:!0},keyword:/(?:\b(?:ADDHANDLER|ADDRESSOF|ALIAS|AND|ANDALSO|AS|BEEP|BLOAD|BOOLEAN|BSAVE|BYREF|BYTE|BYVAL|CALL(?: ABSOLUTE)?|CASE|CATCH|CBOOL|CBYTE|CCHAR|CDATE|CDBL|CDEC|CHAIN|CHAR|CHDIR|CINT|CLASS|CLEAR|CLNG|CLOSE|CLS|COBJ|COM|COMMON|CONST|CONTINUE|CSBYTE|CSHORT|CSNG|CSTR|CTYPE|CUINT|CULNG|CUSHORT|DATA|DATE|DECIMAL|DECLARE|DEF(?: FN| SEG|DBL|INT|LNG|SNG|STR)|DEFAULT|DELEGATE|DIM|DIRECTCAST|DO|DOUBLE|ELSE|ELSEIF|END|ENUM|ENVIRON|ERASE|ERROR|EVENT|EXIT|FALSE|FIELD|FILES|FINALLY|FOR(?: EACH)?|FRIEND|FUNCTION|GET|GETTYPE|GETXMLNAMESPACE|GLOBAL|GOSUB|GOTO|HANDLES|IF|IMPLEMENTS|IMPORTS|IN|INHERITS|INPUT|INTEGER|INTERFACE|IOCTL|IS|ISNOT|KEY|KILL|LET|LIB|LIKE|LINE INPUT|LOCATE|LOCK|LONG|LOOP|LSET|ME|MKDIR|MOD|MODULE|MUSTINHERIT|MUSTOVERRIDE|MYBASE|MYCLASS|NAME|NAMESPACE|NARROWING|NEW|NEXT|NOT|NOTHING|NOTINHERITABLE|NOTOVERRIDABLE|OBJECT|OF|OFF|ON(?: COM| ERROR| KEY| TIMER)?|OPEN|OPERATOR|OPTION(?: BASE)?|OPTIONAL|OR|ORELSE|OUT|OVERLOADS|OVERRIDABLE|OVERRIDES|PARAMARRAY|PARTIAL|POKE|PRIVATE|PROPERTY|PROTECTED|PUBLIC|PUT|RAISEEVENT|READ|READONLY|REDIM|REM|REMOVEHANDLER|RESTORE|RESUME|RETURN|RMDIR|RSET|RUN|SBYTE|SELECT(?: CASE)?|SET|SHADOWS|SHARED|SHELL|SHORT|SINGLE|SLEEP|STATIC|STEP|STOP|STRING|STRUCTURE|SUB|SWAP|SYNCLOCK|SYSTEM|THEN|THROW|TIMER|TO|TROFF|TRON|TRUE|TRY|TRYCAST|TYPE|TYPEOF|UINTEGER|ULONG|UNLOCK|UNTIL|USHORT|USING|VIEW PRINT|WAIT|WEND|WHEN|WHILE|WIDENING|WITH|WITHEVENTS|WRITE|WRITEONLY|XOR)|\B(?:#CONST|#ELSE|#ELSEIF|#END|#IF))(?:\$|\b)/i,punctuation:/[,;:(){}]/})}FT.displayName="t4-vb";FT.aliases=[];function FT(e){e.register(up),e.register(zg),e.languages["t4-vb"]=e.languages["t4-templating"].createT4("vbnet")}zT.displayName="tap";zT.aliases=[];function zT(e){e.register(Og),e.languages.tap={fail:/not ok[^#{\n\r]*/,pass:/ok[^#{\n\r]*/,pragma:/pragma [+-][a-z]+/,bailout:/bail out!.*/i,version:/TAP version \d+/i,plan:/\b\d+\.\.\d+(?: +#.*)?/,subtest:{pattern:/# Subtest(?:: .*)?/,greedy:!0},punctuation:/[{}]/,directive:/#.*/,yamlish:{pattern:/(^[ \t]*)---[\s\S]*?[\r\n][ \t]*\.\.\.$/m,lookbehind:!0,inside:e.languages.yaml,alias:"language-yaml"}}}$T.displayName="tcl";$T.aliases=[];function $T(e){e.languages.tcl={comment:{pattern:/(^|[^\\])#.*/,lookbehind:!0},string:{pattern:/"(?:[^"\\\r\n]|\\(?:\r\n|[\s\S]))*"/,greedy:!0},variable:[{pattern:/(\$)(?:::)?(?:[a-zA-Z0-9]+::)*\w+/,lookbehind:!0},{pattern:/(\$)\{[^}]+\}/,lookbehind:!0},{pattern:/(^[\t ]*set[ \t]+)(?:::)?(?:[a-zA-Z0-9]+::)*\w+/m,lookbehind:!0}],function:{pattern:/(^[\t ]*proc[ \t]+)\S+/m,lookbehind:!0},builtin:[{pattern:/(^[\t ]*)(?:break|class|continue|error|eval|exit|for|foreach|if|proc|return|switch|while)\b/m,lookbehind:!0},/\b(?:else|elseif)\b/],scope:{pattern:/(^[\t ]*)(?:global|upvar|variable)\b/m,lookbehind:!0,alias:"constant"},keyword:{pattern:/(^[\t ]*|\[)(?:Safe_Base|Tcl|after|append|apply|array|auto_(?:execok|import|load|mkindex|qualify|reset)|automkindex_old|bgerror|binary|catch|cd|chan|clock|close|concat|dde|dict|encoding|eof|exec|expr|fblocked|fconfigure|fcopy|file(?:event|name)?|flush|gets|glob|history|http|incr|info|interp|join|lappend|lassign|lindex|linsert|list|llength|load|lrange|lrepeat|lreplace|lreverse|lsearch|lset|lsort|math(?:func|op)|memory|msgcat|namespace|open|package|parray|pid|pkg_mkIndex|platform|puts|pwd|re_syntax|read|refchan|regexp|registry|regsub|rename|scan|seek|set|socket|source|split|string|subst|tcl(?:_endOfWord|_findLibrary|startOf(?:Next|Previous)Word|test|vars|wordBreak(?:After|Before))|tell|time|tm|trace|unknown|unload|unset|update|uplevel|vwait)\b/m,lookbehind:!0},operator:/!=?|\*\*?|==|&&?|\|\|?|<[=<]?|>[=>]?|[-+~\/%?^]|\b(?:eq|in|ne|ni)\b/,punctuation:/[{}()\[\]]/}}PT.displayName="tt2";PT.aliases=[];function PT(e){e.register(Mt),e.register(Er),(function(t){t.languages.tt2=t.languages.extend("clike",{comment:/#.*|\[%#[\s\S]*?%\]/,keyword:/\b(?:BLOCK|CALL|CASE|CATCH|CLEAR|DEBUG|DEFAULT|ELSE|ELSIF|END|FILTER|FINAL|FOREACH|GET|IF|IN|INCLUDE|INSERT|LAST|MACRO|META|NEXT|PERL|PROCESS|RAWPERL|RETURN|SET|STOP|SWITCH|TAGS|THROW|TRY|UNLESS|USE|WHILE|WRAPPER)\b/,punctuation:/[[\]{},()]/}),t.languages.insertBefore("tt2","number",{operator:/=[>=]?|!=?|<=?|>=?|&&|\|\|?|\b(?:and|not|or)\b/,variable:{pattern:/\b[a-z]\w*(?:\s*\.\s*(?:\d+|\$?[a-z]\w*))*\b/i}}),t.languages.insertBefore("tt2","keyword",{delimiter:{pattern:/^(?:\[%|%%)-?|-?%\]$/,alias:"punctuation"}}),t.languages.insertBefore("tt2","string",{"single-quoted-string":{pattern:/'[^\\']*(?:\\[\s\S][^\\']*)*'/,greedy:!0,alias:"string"},"double-quoted-string":{pattern:/"[^\\"]*(?:\\[\s\S][^\\"]*)*"/,greedy:!0,alias:"string",inside:{variable:{pattern:/\$(?:[a-z]\w*(?:\.(?:\d+|\$?[a-z]\w*))*)/i}}}}),delete t.languages.tt2.string,t.hooks.add("before-tokenize",function(n){var r=/\[%[\s\S]+?%\]/g;t.languages["markup-templating"].buildPlaceholders(n,"tt2",r)}),t.hooks.add("after-tokenize",function(n){t.languages["markup-templating"].tokenizePlaceholders(n,"tt2")})})(e)}UT.displayName="toml";UT.aliases=[];function UT(e){(function(t){var n=/(?:[\w-]+|'[^'\n\r]*'|"(?:\\.|[^\\"\r\n])*")/.source;function r(a){return a.replace(/__/g,function(){return n})}t.languages.toml={comment:{pattern:/#.*/,greedy:!0},table:{pattern:RegExp(r(/(^[\t ]*\[\s*(?:\[\s*)?)__(?:\s*\.\s*__)*(?=\s*\])/.source),"m"),lookbehind:!0,greedy:!0,alias:"class-name"},key:{pattern:RegExp(r(/(^[\t ]*|[{,]\s*)__(?:\s*\.\s*__)*(?=\s*=)/.source),"m"),lookbehind:!0,greedy:!0,alias:"property"},string:{pattern:/"""(?:\\[\s\S]|[^\\])*?"""|'''[\s\S]*?'''|'[^'\n\r]*'|"(?:\\.|[^\\"\r\n])*"/,greedy:!0},date:[{pattern:/\b\d{4}-\d{2}-\d{2}(?:[T\s]\d{2}:\d{2}:\d{2}(?:\.\d+)?(?:Z|[+-]\d{2}:\d{2})?)?\b/i,alias:"number"},{pattern:/\b\d{2}:\d{2}:\d{2}(?:\.\d+)?\b/,alias:"number"}],number:/(?:\b0(?:x[\da-zA-Z]+(?:_[\da-zA-Z]+)*|o[0-7]+(?:_[0-7]+)*|b[10]+(?:_[10]+)*))\b|[-+]?\b\d+(?:_\d+)*(?:\.\d+(?:_\d+)*)?(?:[eE][+-]?\d+(?:_\d+)*)?\b|[-+]?\b(?:inf|nan)\b/,boolean:/\b(?:false|true)\b/,punctuation:/[.,=[\]{}]/}})(e)}jT.displayName="tremor";jT.aliases=["trickle","troy"];function jT(e){(function(t){t.languages.tremor={comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?\*\/|(?:--|\/\/|#).*)/,lookbehind:!0},"interpolated-string":null,extractor:{pattern:/\b[a-z_]\w*\|(?:[^\r\n\\|]|\\(?:\r\n|[\s\S]))*\|/i,greedy:!0,inside:{regex:{pattern:/(^re)\|[\s\S]+/,lookbehind:!0},function:/^\w+/,value:/\|[\s\S]+/}},identifier:{pattern:/`[^`]*`/,greedy:!0},function:/\b[a-z_]\w*(?=\s*(?:::\s*<|\())\b/,keyword:/\b(?:args|as|by|case|config|connect|connector|const|copy|create|default|define|deploy|drop|each|emit|end|erase|event|flow|fn|for|from|group|having|insert|into|intrinsic|let|links|match|merge|mod|move|of|operator|patch|pipeline|recur|script|select|set|sliding|state|stream|to|tumbling|update|use|when|where|window|with)\b/,boolean:/\b(?:false|null|true)\b/i,number:/\b(?:0b[01_]*|0x[0-9a-fA-F_]*|\d[\d_]*(?:\.\d[\d_]*)?(?:[Ee][+-]?[\d_]+)?)\b/,"pattern-punctuation":{pattern:/%(?=[({[])/,alias:"punctuation"},operator:/[-+*\/%~!^]=?|=[=>]?|&[&=]?|\|[|=]?|<<?=?|>>?>?=?|(?:absent|and|not|or|present|xor)\b/,punctuation:/::|[;\[\]()\{\},.:]/};var n=/#\{(?:[^"{}]|\{[^{}]*\}|"(?:[^"\\\r\n]|\\(?:\r\n|[\s\S]))*")*\}/.source;t.languages.tremor["interpolated-string"]={pattern:RegExp(/(^|[^\\])/.source+'(?:"""(?:'+/[^"\\#]|\\[\s\S]|"(?!"")|#(?!\{)/.source+"|"+n+')*"""|"(?:'+/[^"\\\r\n#]|\\(?:\r\n|[\s\S])|#(?!\{)/.source+"|"+n+')*")'),lookbehind:!0,greedy:!0,inside:{interpolation:{pattern:RegExp(n),inside:{punctuation:/^#\{|\}$/,expression:{pattern:/[\s\S]+/,inside:t.languages.tremor}}},string:/[\s\S]+/}},t.languages.troy=t.languages.tremor,t.languages.trickle=t.languages.tremor})(e)}HT.displayName="typoscript";HT.aliases=["tsconfig"];function HT(e){(function(t){var n=/\b(?:ACT|ACTIFSUB|CARRAY|CASE|CLEARGIF|COA|COA_INT|CONSTANTS|CONTENT|CUR|EDITPANEL|EFFECT|EXT|FILE|FLUIDTEMPLATE|FORM|FRAME|FRAMESET|GIFBUILDER|GMENU|GMENU_FOLDOUT|GMENU_LAYERS|GP|HMENU|HRULER|HTML|IENV|IFSUB|IMAGE|IMGMENU|IMGMENUITEM|IMGTEXT|IMG_RESOURCE|INCLUDE_TYPOSCRIPT|JSMENU|JSMENUITEM|LLL|LOAD_REGISTER|NO|PAGE|RECORDS|RESTORE_REGISTER|TEMPLATE|TEXT|TMENU|TMENUITEM|TMENU_LAYERS|USER|USER_INT|_GIFBUILDER|global|globalString|globalVar)\b/;t.languages.typoscript={comment:[{pattern:/(^|[^\\])\/\*[\s\S]*?(?:\*\/|$)/,lookbehind:!0},{pattern:/(^|[^\\:= \t]|(?:^|[^= \t])[ \t]+)\/\/.*/,lookbehind:!0,greedy:!0},{pattern:/(^|[^"'])#.*/,lookbehind:!0,greedy:!0}],function:[{pattern:/<INCLUDE_TYPOSCRIPT:\s*source\s*=\s*(?:"[^"\r\n]*"|'[^'\r\n]*')\s*>/,inside:{string:{pattern:/"[^"\r\n]*"|'[^'\r\n]*'/,inside:{keyword:n}},keyword:{pattern:/INCLUDE_TYPOSCRIPT/}}},{pattern:/@import\s*(?:"[^"\r\n]*"|'[^'\r\n]*')/,inside:{string:/"[^"\r\n]*"|'[^'\r\n]*'/}}],string:{pattern:/^([^=]*=[< ]?)(?:(?!\]\n).)*/,lookbehind:!0,inside:{function:/\{\$.*\}/,keyword:n,number:/^\d+$/,punctuation:/[,|:]/}},keyword:n,number:{pattern:/\b\d+\s*[.{=]/,inside:{operator:/[.{=]/}},tag:{pattern:/\.?[-\w\\]+\.?/,inside:{punctuation:/\./}},punctuation:/[{}[\];(),.:|]/,operator:/[<>]=?|[!=]=?=?|--?|\+\+?|&&?|\|\|?|[?*/~^%]/},t.languages.tsconfig=t.languages.typoscript})(e)}GT.displayName="unrealscript";GT.aliases=["uc","uscript"];function GT(e){e.languages.unrealscript={comment:/\/\/.*|\/\*[\s\S]*?\*\//,string:{pattern:/(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,greedy:!0},category:{pattern:/(\b(?:(?:autoexpand|hide|show)categories|var)\s*\()[^()]+(?=\))/,lookbehind:!0,greedy:!0,alias:"property"},metadata:{pattern:/(\w\s*)<\s*\w+\s*=[^<>|=\r\n]+(?:\|\s*\w+\s*=[^<>|=\r\n]+)*>/,lookbehind:!0,greedy:!0,inside:{property:/\b\w+(?=\s*=)/,operator:/=/,punctuation:/[<>|]/}},macro:{pattern:/`\w+/,alias:"property"},"class-name":{pattern:/(\b(?:class|enum|extends|interface|state(?:\(\))?|struct|within)\s+)\w+/,lookbehind:!0},keyword:/\b(?:abstract|actor|array|auto|autoexpandcategories|bool|break|byte|case|class|classgroup|client|coerce|collapsecategories|config|const|continue|default|defaultproperties|delegate|dependson|deprecated|do|dontcollapsecategories|editconst|editinlinenew|else|enum|event|exec|export|extends|final|float|for|forcescriptorder|foreach|function|goto|guid|hidecategories|hidedropdown|if|ignores|implements|inherits|input|int|interface|iterator|latent|local|material|name|native|nativereplication|noexport|nontransient|noteditinlinenew|notplaceable|operator|optional|out|pawn|perobjectconfig|perobjectlocalized|placeable|postoperator|preoperator|private|protected|reliable|replication|return|server|showcategories|simulated|singular|state|static|string|struct|structdefault|structdefaultproperties|switch|texture|transient|travel|unreliable|until|var|vector|while|within)\b/,function:/\b[a-z_]\w*(?=\s*\()/i,boolean:/\b(?:false|true)\b/,number:/\b0x[\da-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?/i,operator:/>>|<<|--|\+\+|\*\*|[-+*/~!=<>$@]=?|&&?|\|\|?|\^\^?|[?:%]|\b(?:ClockwiseFrom|Cross|Dot)\b/,punctuation:/[()[\]{};,.]/},e.languages.uc=e.languages.uscript=e.languages.unrealscript}qT.displayName="uorazor";qT.aliases=[];function qT(e){e.languages.uorazor={"comment-hash":{pattern:/#.*/,alias:"comment",greedy:!0},"comment-slash":{pattern:/\/\/.*/,alias:"comment",greedy:!0},string:{pattern:/("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,inside:{punctuation:/^['"]|['"]$/},greedy:!0},"source-layers":{pattern:/\b(?:arms|backpack|blue|bracelet|cancel|clear|cloak|criminal|earrings|enemy|facialhair|friend|friendly|gloves|gray|grey|ground|hair|head|innerlegs|innertorso|innocent|lefthand|middletorso|murderer|neck|nonfriendly|onehandedsecondary|outerlegs|outertorso|pants|red|righthand|ring|self|shirt|shoes|talisman|waist)\b/i,alias:"function"},"source-commands":{pattern:/\b(?:alliance|attack|cast|clearall|clearignore|clearjournal|clearlist|clearsysmsg|createlist|createtimer|dclick|dclicktype|dclickvar|dress|dressconfig|drop|droprelloc|emote|getlabel|guild|gumpclose|gumpresponse|hotkey|ignore|lasttarget|lift|lifttype|menu|menuresponse|msg|org|organize|organizer|overhead|pause|poplist|potion|promptresponse|pushlist|removelist|removetimer|rename|restock|say|scav|scavenger|script|setability|setlasttarget|setskill|settimer|setvar|sysmsg|target|targetloc|targetrelloc|targettype|undress|unignore|unsetvar|useobject|useonce|useskill|usetype|virtue|wait|waitforgump|waitformenu|waitforprompt|waitforstat|waitforsysmsg|waitfortarget|walk|wfsysmsg|wft|whisper|yell)\b/,alias:"function"},"tag-name":{pattern:/(^\{%-?\s*)\w+/,lookbehind:!0,alias:"keyword"},delimiter:{pattern:/^\{[{%]-?|-?[%}]\}$/,alias:"punctuation"},function:/\b(?:atlist|close|closest|count|counter|counttype|dead|dex|diffhits|diffmana|diffstam|diffweight|find|findbuff|finddebuff|findlayer|findtype|findtypelist|followers|gumpexists|hidden|hits|hp|hue|human|humanoid|ingump|inlist|insysmessage|insysmsg|int|invul|lhandempty|list|listexists|mana|maxhits|maxhp|maxmana|maxstam|maxweight|monster|mounted|name|next|noto|paralyzed|poisoned|position|prev|previous|queued|rand|random|rhandempty|skill|stam|str|targetexists|timer|timerexists|varexist|warmode|weight)\b/,keyword:/\b(?:and|as|break|continue|else|elseif|endfor|endif|endwhile|for|if|loop|not|or|replay|stop|while)\b/,boolean:/\b(?:false|null|true)\b/,number:/\b0x[\dA-Fa-f]+|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee][-+]?\d+)?/,operator:[{pattern:/(\s)(?:and|b-and|b-or|b-xor|ends with|in|is|matches|not|or|same as|starts with)(?=\s)/,lookbehind:!0},/[=<>]=?|!=|\*\*?|\/\/?|\?:?|[-+~%|]/],punctuation:/[()\[\]{}:.,]/}}WT.displayName="v";WT.aliases=[];function WT(e){e.register(Mt),(function(t){var n={pattern:/[\s\S]+/,inside:null};t.languages.v=t.languages.extend("clike",{string:{pattern:/r?(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,alias:"quoted-string",greedy:!0,inside:{interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\$(?:\{[^{}]*\}|\w+(?:\.\w+(?:\([^\(\)]*\))?|\[[^\[\]]+\])*)/,lookbehind:!0,inside:{"interpolation-variable":{pattern:/^\$\w[\s\S]*$/,alias:"variable"},"interpolation-punctuation":{pattern:/^\$\{|\}$/,alias:"punctuation"},"interpolation-expression":n}}}},"class-name":{pattern:/(\b(?:enum|interface|struct|type)\s+)(?:C\.)?\w+/,lookbehind:!0},keyword:/(?:\b(?:__global|as|asm|assert|atomic|break|chan|const|continue|defer|else|embed|enum|fn|for|go(?:to)?|if|import|in|interface|is|lock|match|module|mut|none|or|pub|return|rlock|select|shared|sizeof|static|struct|type(?:of)?|union|unsafe)|\$(?:else|for|if)|#(?:flag|include))\b/,number:/\b(?:0x[a-f\d]+(?:_[a-f\d]+)*|0b[01]+(?:_[01]+)*|0o[0-7]+(?:_[0-7]+)*|\d+(?:_\d+)*(?:\.\d+(?:_\d+)*)?)\b/i,operator:/~|\?|[*\/%^!=]=?|\+[=+]?|-[=-]?|\|[=|]?|&(?:=|&|\^=?)?|>(?:>=?|=)?|<(?:<=?|=|-)?|:=|\.\.\.?/,builtin:/\b(?:any(?:_float|_int)?|bool|byte(?:ptr)?|charptr|f(?:32|64)|i(?:8|16|64|128|nt)|rune|size_t|string|u(?:16|32|64|128)|voidptr)\b/}),n.inside=t.languages.v,t.languages.insertBefore("v","string",{char:{pattern:/`(?:\\`|\\?[^`]{1,2})`/,alias:"rune"}}),t.languages.insertBefore("v","operator",{attribute:{pattern:/(^[\t ]*)\[(?:deprecated|direct_array_access|flag|inline|live|ref_only|typedef|unsafe_fn|windows_stdcall)\]/m,lookbehind:!0,alias:"annotation",inside:{punctuation:/[\[\]]/,keyword:/\w+/}},generic:{pattern:/<\w+>(?=\s*[\)\{])/,inside:{punctuation:/[<>]/,"class-name":/\w+/}}}),t.languages.insertBefore("v","function",{"generic-function":{pattern:/\b\w+\s*<\w+>(?=\()/,inside:{function:/^\w+/,generic:{pattern:/<\w+>/,inside:t.languages.v.generic.inside}}}})})(e)}VT.displayName="vala";VT.aliases=[];function VT(e){e.register(Mt),e.languages.vala=e.languages.extend("clike",{"class-name":[{pattern:/\b[A-Z]\w*(?:\.\w+)*\b(?=(?:\?\s+|\*?\s+\*?)\w)/,inside:{punctuation:/\./}},{pattern:/(\[)[A-Z]\w*(?:\.\w+)*\b/,lookbehind:!0,inside:{punctuation:/\./}},{pattern:/(\b(?:class|interface)\s+[A-Z]\w*(?:\.\w+)*\s*:\s*)[A-Z]\w*(?:\.\w+)*\b/,lookbehind:!0,inside:{punctuation:/\./}},{pattern:/((?:\b(?:class|enum|interface|new|struct)\s+)|(?:catch\s+\())[A-Z]\w*(?:\.\w+)*\b/,lookbehind:!0,inside:{punctuation:/\./}}],keyword:/\b(?:abstract|as|assert|async|base|bool|break|case|catch|char|class|const|construct|continue|default|delegate|delete|do|double|dynamic|else|ensures|enum|errordomain|extern|finally|float|for|foreach|get|if|in|inline|int|int16|int32|int64|int8|interface|internal|is|lock|long|namespace|new|null|out|override|owned|params|private|protected|public|ref|requires|return|set|short|signal|sizeof|size_t|ssize_t|static|string|struct|switch|this|throw|throws|try|typeof|uchar|uint|uint16|uint32|uint64|uint8|ulong|unichar|unowned|ushort|using|value|var|virtual|void|volatile|weak|while|yield)\b/i,function:/\b\w+(?=\s*\()/,number:/(?:\b0x[\da-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?)(?:f|u?l?)?/i,operator:/\+\+|--|&&|\|\||<<=?|>>=?|=>|->|~|[+\-*\/%&^|=!<>]=?|\?\??|\.\.\./,punctuation:/[{}[\];(),.:]/,constant:/\b[A-Z0-9_]+\b/}),e.languages.insertBefore("vala","string",{"raw-string":{pattern:/"""[\s\S]*?"""/,greedy:!0,alias:"string"},"template-string":{pattern:/@"[\s\S]*?"/,greedy:!0,inside:{interpolation:{pattern:/\$(?:\([^)]*\)|[a-zA-Z]\w*)/,inside:{delimiter:{pattern:/^\$\(?|\)$/,alias:"punctuation"},rest:e.languages.vala}},string:/[\s\S]+/}}}),e.languages.insertBefore("vala","keyword",{regex:{pattern:/\/(?:\[(?:[^\]\\\r\n]|\\.)*\]|\\.|[^/\\\[\r\n])+\/[imsx]{0,4}(?=\s*(?:$|[\r\n,.;})\]]))/,greedy:!0,inside:{"regex-source":{pattern:/^(\/)[\s\S]+(?=\/[a-z]*$)/,lookbehind:!0,alias:"language-regex",inside:e.languages.regex},"regex-delimiter":/^\//,"regex-flags":/^[a-z]+$/}}})}YT.displayName="velocity";YT.aliases=[];function YT(e){e.register(cr),(function(t){t.languages.velocity=t.languages.extend("markup",{});var n={variable:{pattern:/(^|[^\\](?:\\\\)*)\$!?(?:[a-z][\w-]*(?:\([^)]*\))?(?:\.[a-z][\w-]*(?:\([^)]*\))?|\[[^\]]+\])*|\{[^}]+\})/i,lookbehind:!0,inside:{}},string:{pattern:/"[^"]*"|'[^']*'/,greedy:!0},number:/\b\d+\b/,boolean:/\b(?:false|true)\b/,operator:/[=!<>]=?|[+*/%-]|&&|\|\||\.\.|\b(?:eq|g[et]|l[et]|n(?:e|ot))\b/,punctuation:/[(){}[\]:,.]/};n.variable.inside={string:n.string,function:{pattern:/([^\w-])[a-z][\w-]*(?=\()/,lookbehind:!0},number:n.number,boolean:n.boolean,punctuation:n.punctuation},t.languages.insertBefore("velocity","comment",{unparsed:{pattern:/(^|[^\\])#\[\[[\s\S]*?\]\]#/,lookbehind:!0,greedy:!0,inside:{punctuation:/^#\[\[|\]\]#$/}},"velocity-comment":[{pattern:/(^|[^\\])#\*[\s\S]*?\*#/,lookbehind:!0,greedy:!0,alias:"comment"},{pattern:/(^|[^\\])##.*/,lookbehind:!0,greedy:!0,alias:"comment"}],directive:{pattern:/(^|[^\\](?:\\\\)*)#@?(?:[a-z][\w-]*|\{[a-z][\w-]*\})(?:\s*\((?:[^()]|\([^()]*\))*\))?/i,lookbehind:!0,inside:{keyword:{pattern:/^#@?(?:[a-z][\w-]*|\{[a-z][\w-]*\})|\bin\b/,inside:{punctuation:/[{}]/}},rest:n}},variable:n.variable}),t.languages.velocity.tag.inside["attr-value"].inside.rest=t.languages.velocity})(e)}XT.displayName="verilog";XT.aliases=[];function XT(e){e.languages.verilog={comment:{pattern:/\/\/.*|\/\*[\s\S]*?\*\//,greedy:!0},string:{pattern:/"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"/,greedy:!0},"kernel-function":{pattern:/\B\$\w+\b/,alias:"property"},constant:/\B`\w+\b/,function:/\b\w+(?=\()/,keyword:/\b(?:alias|and|assert|assign|assume|automatic|before|begin|bind|bins|binsof|bit|break|buf|bufif0|bufif1|byte|case|casex|casez|cell|chandle|class|clocking|cmos|config|const|constraint|context|continue|cover|covergroup|coverpoint|cross|deassign|default|defparam|design|disable|dist|do|edge|else|end|endcase|endclass|endclocking|endconfig|endfunction|endgenerate|endgroup|endinterface|endmodule|endpackage|endprimitive|endprogram|endproperty|endsequence|endspecify|endtable|endtask|enum|event|expect|export|extends|extern|final|first_match|for|force|foreach|forever|fork|forkjoin|function|generate|genvar|highz0|highz1|if|iff|ifnone|ignore_bins|illegal_bins|import|incdir|include|initial|inout|input|inside|instance|int|integer|interface|intersect|join|join_any|join_none|large|liblist|library|local|localparam|logic|longint|macromodule|matches|medium|modport|module|nand|negedge|new|nmos|nor|noshowcancelled|not|notif0|notif1|null|or|output|package|packed|parameter|pmos|posedge|primitive|priority|program|property|protected|pull0|pull1|pulldown|pullup|pulsestyle_ondetect|pulsestyle_onevent|pure|rand|randc|randcase|randsequence|rcmos|real|realtime|ref|reg|release|repeat|return|rnmos|rpmos|rtran|rtranif0|rtranif1|scalared|sequence|shortint|shortreal|showcancelled|signed|small|solve|specify|specparam|static|string|strong0|strong1|struct|super|supply0|supply1|table|tagged|task|this|throughout|time|timeprecision|timeunit|tran|tranif0|tranif1|tri|tri0|tri1|triand|trior|trireg|type|typedef|union|unique|unsigned|use|uwire|var|vectored|virtual|void|wait|wait_order|wand|weak0|weak1|while|wildcard|wire|with|within|wor|xnor|xor)\b/,important:/\b(?:always|always_comb|always_ff|always_latch)\b(?: *@)?/,number:/\B##?\d+|(?:\b\d+)?'[odbh] ?[\da-fzx_?]+|\b(?:\d*[._])?\d+(?:e[-+]?\d+)?/i,operator:/[-+{}^~%*\/?=!<>&|]+/,punctuation:/[[\];(),.:]/}}KT.displayName="vhdl";KT.aliases=[];function KT(e){e.languages.vhdl={comment:/--.+/,"vhdl-vectors":{pattern:/\b[oxb]"[\da-f_]+"|"[01uxzwlh-]+"/i,alias:"number"},"quoted-function":{pattern:/"\S+?"(?=\()/,alias:"function"},string:/"(?:[^\\"\r\n]|\\(?:\r\n|[\s\S]))*"/,attribute:{pattern:/\b'\w+/,alias:"attr-name"},keyword:/\b(?:access|after|alias|all|architecture|array|assert|attribute|begin|block|body|buffer|bus|case|component|configuration|constant|disconnect|downto|else|elsif|end|entity|exit|file|for|function|generate|generic|group|guarded|if|impure|in|inertial|inout|is|label|library|linkage|literal|loop|map|new|next|null|of|on|open|others|out|package|port|postponed|private|procedure|process|pure|range|record|register|reject|report|return|select|severity|shared|signal|subtype|then|to|transport|type|unaffected|units|until|use|variable|view|wait|when|while|with)\b/i,boolean:/\b(?:false|true)\b/i,function:/\w+(?=\()/,number:/'[01uxzwlh-]'|\b(?:\d+#[\da-f_.]+#|\d[\d_.]*)(?:e[-+]?\d+)?/i,operator:/[<>]=?|:=|[-+*/&=]|\b(?:abs|and|mod|nand|nor|not|or|rem|rol|ror|sla|sll|sra|srl|xnor|xor)\b/i,punctuation:/[{}[\];(),.:]/}}ZT.displayName="vim";ZT.aliases=[];function ZT(e){e.languages.vim={string:/"(?:[^"\\\r\n]|\\.)*"|'(?:[^'\r\n]|'')*'/,comment:/".*/,function:/\b\w+(?=\()/,keyword:/\b(?:N|Next|P|Print|X|XMLent|XMLns|ab|abbreviate|abc|abclear|abo|aboveleft|al|all|ar|arga|argadd|argd|argdelete|argdo|arge|argedit|argg|argglobal|argl|arglocal|args|argu|argument|as|ascii|b|bN|bNext|ba|bad|badd|ball|bd|bdelete|be|bel|belowright|bf|bfirst|bl|blast|bm|bmodified|bn|bnext|bo|botright|bp|bprevious|br|brea|break|breaka|breakadd|breakd|breakdel|breakl|breaklist|brewind|bro|browse|bufdo|buffer|buffers|bun|bunload|bw|bwipeout|c|cN|cNext|cNfcNfile|ca|cabbrev|cabc|cabclear|cad|caddb|caddbuffer|caddexpr|caddf|caddfile|cal|call|cat|catch|cb|cbuffer|cc|ccl|cclose|cd|ce|center|cex|cexpr|cf|cfile|cfir|cfirst|cg|cgetb|cgetbuffer|cgete|cgetexpr|cgetfile|change|changes|chd|chdir|che|checkpath|checkt|checktime|cl|cla|clast|clist|clo|close|cmapc|cmapclear|cn|cnew|cnewer|cnext|cnf|cnfile|cnorea|cnoreabbrev|co|col|colder|colo|colorscheme|comc|comclear|comp|compiler|con|conf|confirm|continue|cope|copen|copy|cp|cpf|cpfile|cprevious|cq|cquit|cr|crewind|cu|cuna|cunabbrev|cunmap|cw|cwindow|d|debugg|debuggreedy|delc|delcommand|delete|delf|delfunction|delm|delmarks|di|diffg|diffget|diffoff|diffpatch|diffpu|diffput|diffsplit|diffthis|diffu|diffupdate|dig|digraphs|display|dj|djump|dl|dlist|dr|drop|ds|dsearch|dsp|dsplit|e|earlier|echoe|echoerr|echom|echomsg|echon|edit|el|else|elsei|elseif|em|emenu|en|endf|endfo|endfor|endfun|endfunction|endif|endt|endtry|endw|endwhile|ene|enew|ex|exi|exit|exu|exusage|f|file|files|filetype|fin|fina|finally|find|fini|finish|fir|first|fix|fixdel|fo|fold|foldc|foldclose|foldd|folddoc|folddoclosed|folddoopen|foldo|foldopen|for|fu|fun|function|go|goto|gr|grep|grepa|grepadd|h|ha|hardcopy|help|helpf|helpfind|helpg|helpgrep|helpt|helptags|hid|hide|his|history|ia|iabbrev|iabc|iabclear|if|ij|ijump|il|ilist|imapc|imapclear|in|inorea|inoreabbrev|isearch|isp|isplit|iu|iuna|iunabbrev|iunmap|j|join|ju|jumps|k|kee|keepalt|keepj|keepjumps|keepmarks|l|lN|lNext|lNf|lNfile|la|lad|laddb|laddbuffer|laddexpr|laddf|laddfile|lan|language|last|later|lb|lbuffer|lc|lcd|lch|lchdir|lcl|lclose|left|lefta|leftabove|let|lex|lexpr|lf|lfile|lfir|lfirst|lg|lgetb|lgetbuffer|lgete|lgetexpr|lgetfile|lgr|lgrep|lgrepa|lgrepadd|lh|lhelpgrep|list|ll|lla|llast|lli|llist|lm|lmak|lmake|lmap|lmapc|lmapclear|ln|lne|lnew|lnewer|lnext|lnf|lnfile|lnoremap|lo|loadview|loc|lockmarks|lockv|lockvar|lol|lolder|lop|lopen|lp|lpf|lpfile|lprevious|lr|lrewind|ls|lt|ltag|lu|lunmap|lv|lvimgrep|lvimgrepa|lvimgrepadd|lw|lwindow|m|ma|mak|make|mark|marks|mat|match|menut|menutranslate|mk|mkexrc|mks|mksession|mksp|mkspell|mkv|mkvie|mkview|mkvimrc|mod|mode|move|mz|mzf|mzfile|mzscheme|n|nbkey|new|next|nmapc|nmapclear|noh|nohlsearch|norea|noreabbrev|nu|number|nun|nunmap|o|omapc|omapclear|on|only|open|opt|options|ou|ounmap|p|pc|pclose|pe|ped|pedit|perl|perld|perldo|po|pop|popu|popup|pp|ppop|pre|preserve|prev|previous|print|prof|profd|profdel|profile|promptf|promptfind|promptr|promptrepl|ps|psearch|ptN|ptNext|pta|ptag|ptf|ptfirst|ptj|ptjump|ptl|ptlast|ptn|ptnext|ptp|ptprevious|ptr|ptrewind|pts|ptselect|pu|put|pw|pwd|py|pyf|pyfile|python|q|qa|qall|quit|quita|quitall|r|read|rec|recover|red|redi|redir|redo|redr|redraw|redraws|redrawstatus|reg|registers|res|resize|ret|retab|retu|return|rew|rewind|ri|right|rightb|rightbelow|ru|rub|ruby|rubyd|rubydo|rubyf|rubyfile|runtime|rv|rviminfo|sN|sNext|sa|sal|sall|san|sandbox|sargument|sav|saveas|sb|sbN|sbNext|sba|sball|sbf|sbfirst|sbl|sblast|sbm|sbmodified|sbn|sbnext|sbp|sbprevious|sbr|sbrewind|sbuffer|scrip|scripte|scriptencoding|scriptnames|se|set|setf|setfiletype|setg|setglobal|setl|setlocal|sf|sfind|sfir|sfirst|sh|shell|sign|sil|silent|sim|simalt|sl|sla|slast|sleep|sm|smagic|smap|smapc|smapclear|sme|smenu|sn|snext|sni|sniff|sno|snomagic|snor|snoremap|snoreme|snoremenu|so|sor|sort|source|sp|spe|spelld|spelldump|spellgood|spelli|spellinfo|spellr|spellrepall|spellu|spellundo|spellw|spellwrong|split|spr|sprevious|sre|srewind|st|sta|stag|star|startg|startgreplace|startinsert|startr|startreplace|stj|stjump|stop|stopi|stopinsert|sts|stselect|sun|sunhide|sunm|sunmap|sus|suspend|sv|sview|syncbind|t|tN|tNext|ta|tab|tabN|tabNext|tabc|tabclose|tabd|tabdo|tabe|tabedit|tabf|tabfind|tabfir|tabfirst|tabl|tablast|tabm|tabmove|tabn|tabnew|tabnext|tabo|tabonly|tabp|tabprevious|tabr|tabrewind|tabs|tag|tags|tc|tcl|tcld|tcldo|tclf|tclfile|te|tearoff|tf|tfirst|th|throw|tj|tjump|tl|tlast|tm|tmenu|tn|tnext|to|topleft|tp|tprevious|tr|trewind|try|ts|tselect|tu|tunmenu|u|una|unabbreviate|undo|undoj|undojoin|undol|undolist|unh|unhide|unlet|unlo|unlockvar|unm|unmap|up|update|ve|verb|verbose|version|vert|vertical|vi|vie|view|vim|vimgrep|vimgrepa|vimgrepadd|visual|viu|viusage|vmapc|vmapclear|vne|vnew|vs|vsplit|vu|vunmap|w|wN|wNext|wa|wall|wh|while|win|winc|wincmd|windo|winp|winpos|winsize|wn|wnext|wp|wprevious|wq|wqa|wqall|write|ws|wsverb|wv|wviminfo|x|xa|xall|xit|xm|xmap|xmapc|xmapclear|xme|xmenu|xn|xnoremap|xnoreme|xnoremenu|xu|xunmap|y|yank)\b/,builtin:/\b(?:acd|ai|akm|aleph|allowrevins|altkeymap|ambiwidth|ambw|anti|antialias|arab|arabic|arabicshape|ari|arshape|autochdir|autocmd|autoindent|autoread|autowrite|autowriteall|aw|awa|background|backspace|backup|backupcopy|backupdir|backupext|backupskip|balloondelay|ballooneval|balloonexpr|bdir|bdlay|beval|bex|bexpr|bg|bh|bin|binary|biosk|bioskey|bk|bkc|bomb|breakat|brk|browsedir|bs|bsdir|bsk|bt|bufhidden|buflisted|buftype|casemap|ccv|cdpath|cedit|cfu|ch|charconvert|ci|cin|cindent|cink|cinkeys|cino|cinoptions|cinw|cinwords|clipboard|cmdheight|cmdwinheight|cmp|cms|columns|com|comments|commentstring|compatible|complete|completefunc|completeopt|consk|conskey|copyindent|cot|cpo|cpoptions|cpt|cscopepathcomp|cscopeprg|cscopequickfix|cscopetag|cscopetagorder|cscopeverbose|cspc|csprg|csqf|cst|csto|csverb|cuc|cul|cursorcolumn|cursorline|cwh|debug|deco|def|define|delcombine|dex|dg|dict|dictionary|diff|diffexpr|diffopt|digraph|dip|dir|directory|dy|ea|ead|eadirection|eb|ed|edcompatible|ef|efm|ei|ek|enc|encoding|endofline|eol|ep|equalalways|equalprg|errorbells|errorfile|errorformat|esckeys|et|eventignore|expandtab|exrc|fcl|fcs|fdc|fde|fdi|fdl|fdls|fdm|fdn|fdo|fdt|fen|fenc|fencs|fex|ff|ffs|fileencoding|fileencodings|fileformat|fileformats|fillchars|fk|fkmap|flp|fml|fmr|foldcolumn|foldenable|foldexpr|foldignore|foldlevel|foldlevelstart|foldmarker|foldmethod|foldminlines|foldnestmax|foldtext|formatexpr|formatlistpat|formatoptions|formatprg|fp|fs|fsync|ft|gcr|gd|gdefault|gfm|gfn|gfs|gfw|ghr|gp|grepformat|grepprg|gtl|gtt|guicursor|guifont|guifontset|guifontwide|guiheadroom|guioptions|guipty|guitablabel|guitabtooltip|helpfile|helpheight|helplang|hf|hh|hi|hidden|highlight|hk|hkmap|hkmapp|hkp|hl|hlg|hls|hlsearch|ic|icon|iconstring|ignorecase|im|imactivatekey|imak|imc|imcmdline|imd|imdisable|imi|iminsert|ims|imsearch|inc|include|includeexpr|incsearch|inde|indentexpr|indentkeys|indk|inex|inf|infercase|insertmode|invacd|invai|invakm|invallowrevins|invaltkeymap|invanti|invantialias|invar|invarab|invarabic|invarabicshape|invari|invarshape|invautochdir|invautoindent|invautoread|invautowrite|invautowriteall|invaw|invawa|invbackup|invballooneval|invbeval|invbin|invbinary|invbiosk|invbioskey|invbk|invbl|invbomb|invbuflisted|invcf|invci|invcin|invcindent|invcompatible|invconfirm|invconsk|invconskey|invcopyindent|invcp|invcscopetag|invcscopeverbose|invcst|invcsverb|invcuc|invcul|invcursorcolumn|invcursorline|invdeco|invdelcombine|invdg|invdiff|invdigraph|invdisable|invea|inveb|inved|invedcompatible|invek|invendofline|inveol|invequalalways|inverrorbells|invesckeys|invet|invex|invexpandtab|invexrc|invfen|invfk|invfkmap|invfoldenable|invgd|invgdefault|invguipty|invhid|invhidden|invhk|invhkmap|invhkmapp|invhkp|invhls|invhlsearch|invic|invicon|invignorecase|invim|invimc|invimcmdline|invimd|invincsearch|invinf|invinfercase|invinsertmode|invis|invjoinspaces|invjs|invlazyredraw|invlbr|invlinebreak|invlisp|invlist|invloadplugins|invlpl|invlz|invma|invmacatsui|invmagic|invmh|invml|invmod|invmodeline|invmodifiable|invmodified|invmore|invmousef|invmousefocus|invmousehide|invnu|invnumber|invodev|invopendevice|invpaste|invpi|invpreserveindent|invpreviewwindow|invprompt|invpvw|invreadonly|invremap|invrestorescreen|invrevins|invri|invrightleft|invrightleftcmd|invrl|invrlc|invro|invrs|invru|invruler|invsb|invsc|invscb|invscrollbind|invscs|invsecure|invsft|invshellslash|invshelltemp|invshiftround|invshortname|invshowcmd|invshowfulltag|invshowmatch|invshowmode|invsi|invsm|invsmartcase|invsmartindent|invsmarttab|invsmd|invsn|invsol|invspell|invsplitbelow|invsplitright|invspr|invsr|invssl|invsta|invstartofline|invstmp|invswapfile|invswf|invta|invtagbsearch|invtagrelative|invtagstack|invtbi|invtbidi|invtbs|invtermbidi|invterse|invtextauto|invtextmode|invtf|invtgst|invtildeop|invtimeout|invtitle|invto|invtop|invtr|invttimeout|invttybuiltin|invttyfast|invtx|invvb|invvisualbell|invwa|invwarn|invwb|invweirdinvert|invwfh|invwfw|invwildmenu|invwinfixheight|invwinfixwidth|invwiv|invwmnu|invwrap|invwrapscan|invwrite|invwriteany|invwritebackup|invws|isf|isfname|isi|isident|isk|iskeyword|isprint|joinspaces|js|key|keymap|keymodel|keywordprg|km|kmp|kp|langmap|langmenu|laststatus|lazyredraw|lbr|lcs|linebreak|lines|linespace|lisp|lispwords|listchars|loadplugins|lpl|lsp|lz|macatsui|magic|makeef|makeprg|matchpairs|matchtime|maxcombine|maxfuncdepth|maxmapdepth|maxmem|maxmempattern|maxmemtot|mco|mef|menuitems|mfd|mh|mis|mkspellmem|ml|mls|mm|mmd|mmp|mmt|modeline|modelines|modifiable|modified|more|mouse|mousef|mousefocus|mousehide|mousem|mousemodel|mouses|mouseshape|mouset|mousetime|mp|mps|msm|mzq|mzquantum|nf|noacd|noai|noakm|noallowrevins|noaltkeymap|noanti|noantialias|noar|noarab|noarabic|noarabicshape|noari|noarshape|noautochdir|noautoindent|noautoread|noautowrite|noautowriteall|noaw|noawa|nobackup|noballooneval|nobeval|nobin|nobinary|nobiosk|nobioskey|nobk|nobl|nobomb|nobuflisted|nocf|noci|nocin|nocindent|nocompatible|noconfirm|noconsk|noconskey|nocopyindent|nocp|nocscopetag|nocscopeverbose|nocst|nocsverb|nocuc|nocul|nocursorcolumn|nocursorline|nodeco|nodelcombine|nodg|nodiff|nodigraph|nodisable|noea|noeb|noed|noedcompatible|noek|noendofline|noeol|noequalalways|noerrorbells|noesckeys|noet|noex|noexpandtab|noexrc|nofen|nofk|nofkmap|nofoldenable|nogd|nogdefault|noguipty|nohid|nohidden|nohk|nohkmap|nohkmapp|nohkp|nohls|noic|noicon|noignorecase|noim|noimc|noimcmdline|noimd|noincsearch|noinf|noinfercase|noinsertmode|nois|nojoinspaces|nojs|nolazyredraw|nolbr|nolinebreak|nolisp|nolist|noloadplugins|nolpl|nolz|noma|nomacatsui|nomagic|nomh|noml|nomod|nomodeline|nomodifiable|nomodified|nomore|nomousef|nomousefocus|nomousehide|nonu|nonumber|noodev|noopendevice|nopaste|nopi|nopreserveindent|nopreviewwindow|noprompt|nopvw|noreadonly|noremap|norestorescreen|norevins|nori|norightleft|norightleftcmd|norl|norlc|noro|nors|noru|noruler|nosb|nosc|noscb|noscrollbind|noscs|nosecure|nosft|noshellslash|noshelltemp|noshiftround|noshortname|noshowcmd|noshowfulltag|noshowmatch|noshowmode|nosi|nosm|nosmartcase|nosmartindent|nosmarttab|nosmd|nosn|nosol|nospell|nosplitbelow|nosplitright|nospr|nosr|nossl|nosta|nostartofline|nostmp|noswapfile|noswf|nota|notagbsearch|notagrelative|notagstack|notbi|notbidi|notbs|notermbidi|noterse|notextauto|notextmode|notf|notgst|notildeop|notimeout|notitle|noto|notop|notr|nottimeout|nottybuiltin|nottyfast|notx|novb|novisualbell|nowa|nowarn|nowb|noweirdinvert|nowfh|nowfw|nowildmenu|nowinfixheight|nowinfixwidth|nowiv|nowmnu|nowrap|nowrapscan|nowrite|nowriteany|nowritebackup|nows|nrformats|numberwidth|nuw|odev|oft|ofu|omnifunc|opendevice|operatorfunc|opfunc|osfiletype|pa|para|paragraphs|paste|pastetoggle|patchexpr|patchmode|path|pdev|penc|pex|pexpr|pfn|ph|pheader|pi|pm|pmbcs|pmbfn|popt|preserveindent|previewheight|previewwindow|printdevice|printencoding|printexpr|printfont|printheader|printmbcharset|printmbfont|printoptions|prompt|pt|pumheight|pvh|pvw|qe|quoteescape|readonly|remap|report|restorescreen|revins|rightleft|rightleftcmd|rl|rlc|ro|rs|rtp|ruf|ruler|rulerformat|runtimepath|sbo|sc|scb|scr|scroll|scrollbind|scrolljump|scrolloff|scrollopt|scs|sect|sections|secure|sel|selection|selectmode|sessionoptions|sft|shcf|shellcmdflag|shellpipe|shellquote|shellredir|shellslash|shelltemp|shelltype|shellxquote|shiftround|shiftwidth|shm|shortmess|shortname|showbreak|showcmd|showfulltag|showmatch|showmode|showtabline|shq|si|sidescroll|sidescrolloff|siso|sj|slm|smartcase|smartindent|smarttab|smc|smd|softtabstop|sol|spc|spell|spellcapcheck|spellfile|spelllang|spellsuggest|spf|spl|splitbelow|splitright|sps|sr|srr|ss|ssl|ssop|stal|startofline|statusline|stl|stmp|su|sua|suffixes|suffixesadd|sw|swapfile|swapsync|swb|swf|switchbuf|sws|sxq|syn|synmaxcol|syntax|t_AB|t_AF|t_AL|t_CS|t_CV|t_Ce|t_Co|t_Cs|t_DL|t_EI|t_F1|t_F2|t_F3|t_F4|t_F5|t_F6|t_F7|t_F8|t_F9|t_IE|t_IS|t_K1|t_K3|t_K4|t_K5|t_K6|t_K7|t_K8|t_K9|t_KA|t_KB|t_KC|t_KD|t_KE|t_KF|t_KG|t_KH|t_KI|t_KJ|t_KK|t_KL|t_RI|t_RV|t_SI|t_Sb|t_Sf|t_WP|t_WS|t_ZH|t_ZR|t_al|t_bc|t_cd|t_ce|t_cl|t_cm|t_cs|t_da|t_db|t_dl|t_fs|t_k1|t_k2|t_k3|t_k4|t_k5|t_k6|t_k7|t_k8|t_k9|t_kB|t_kD|t_kI|t_kN|t_kP|t_kb|t_kd|t_ke|t_kh|t_kl|t_kr|t_ks|t_ku|t_le|t_mb|t_md|t_me|t_mr|t_ms|t_nd|t_op|t_se|t_so|t_sr|t_te|t_ti|t_ts|t_ue|t_us|t_ut|t_vb|t_ve|t_vi|t_vs|t_xs|tabline|tabpagemax|tabstop|tagbsearch|taglength|tagrelative|tagstack|tal|tb|tbi|tbidi|tbis|tbs|tenc|term|termbidi|termencoding|terse|textauto|textmode|textwidth|tgst|thesaurus|tildeop|timeout|timeoutlen|title|titlelen|titleold|titlestring|toolbar|toolbariconsize|top|tpm|tsl|tsr|ttimeout|ttimeoutlen|ttm|tty|ttybuiltin|ttyfast|ttym|ttymouse|ttyscroll|ttytype|tw|tx|uc|ul|undolevels|updatecount|updatetime|ut|vb|vbs|vdir|verbosefile|vfile|viewdir|viewoptions|viminfo|virtualedit|visualbell|vop|wak|warn|wb|wc|wcm|wd|weirdinvert|wfh|wfw|whichwrap|wi|wig|wildchar|wildcharm|wildignore|wildmenu|wildmode|wildoptions|wim|winaltkeys|window|winfixheight|winfixwidth|winheight|winminheight|winminwidth|winwidth|wiv|wiw|wm|wmh|wmnu|wmw|wop|wrap|wrapmargin|wrapscan|writeany|writebackup|writedelay|ww)\b/,number:/\b(?:0x[\da-f]+|\d+(?:\.\d+)?)\b/i,operator:/\|\||&&|[-+.]=?|[=!](?:[=~][#?]?)?|[<>]=?[#?]?|[*\/%?]|\b(?:is(?:not)?)\b/,punctuation:/[{}[\](),;:]/}}QT.displayName="visual-basic";QT.aliases=["vb","vba"];function QT(e){e.languages["visual-basic"]={comment:{pattern:/(?:['‘’]|REM\b)(?:[^\r\n_]|_(?:\r\n?|\n)?)*/i,inside:{keyword:/^REM/i}},directive:{pattern:/#(?:Const|Else|ElseIf|End|ExternalChecksum|ExternalSource|If|Region)(?:\b_[ \t]*(?:\r\n?|\n)|.)+/i,alias:"property",greedy:!0},string:{pattern:/\$?["“”](?:["“”]{2}|[^"“”])*["“”]C?/i,greedy:!0},date:{pattern:/#[ \t]*(?:\d+([/-])\d+\1\d+(?:[ \t]+(?:\d+[ \t]*(?:AM|PM)|\d+:\d+(?::\d+)?(?:[ \t]*(?:AM|PM))?))?|\d+[ \t]*(?:AM|PM)|\d+:\d+(?::\d+)?(?:[ \t]*(?:AM|PM))?)[ \t]*#/i,alias:"number"},number:/(?:(?:\b\d+(?:\.\d+)?|\.\d+)(?:E[+-]?\d+)?|&[HO][\dA-F]+)(?:[FRD]|U?[ILS])?/i,boolean:/\b(?:False|Nothing|True)\b/i,keyword:/\b(?:AddHandler|AddressOf|Alias|And(?:Also)?|As|Boolean|ByRef|Byte|ByVal|Call|Case|Catch|C(?:Bool|Byte|Char|Date|Dbl|Dec|Int|Lng|Obj|SByte|Short|Sng|Str|Type|UInt|ULng|UShort)|Char|Class|Const|Continue|Currency|Date|Decimal|Declare|Default|Delegate|Dim|DirectCast|Do|Double|Each|Else(?:If)?|End(?:If)?|Enum|Erase|Error|Event|Exit|Finally|For|Friend|Function|Get(?:Type|XMLNamespace)?|Global|GoSub|GoTo|Handles|If|Implements|Imports|In|Inherits|Integer|Interface|Is|IsNot|Let|Lib|Like|Long|Loop|Me|Mod|Module|Must(?:Inherit|Override)|My(?:Base|Class)|Namespace|Narrowing|New|Next|Not(?:Inheritable|Overridable)?|Object|Of|On|Operator|Option(?:al)?|Or(?:Else)?|Out|Overloads|Overridable|Overrides|ParamArray|Partial|Private|Property|Protected|Public|RaiseEvent|ReadOnly|ReDim|RemoveHandler|Resume|Return|SByte|Select|Set|Shadows|Shared|short|Single|Static|Step|Stop|String|Structure|Sub|SyncLock|Then|Throw|To|Try|TryCast|Type|TypeOf|U(?:Integer|Long|Short)|Until|Using|Variant|Wend|When|While|Widening|With(?:Events)?|WriteOnly|Xor)\b/i,operator:/[+\-*/\\^<=>&#@$%!]|\b_(?=[ \t]*[\r\n])/,punctuation:/[{}().,:?]/},e.languages.vb=e.languages["visual-basic"],e.languages.vba=e.languages["visual-basic"]}JT.displayName="warpscript";JT.aliases=[];function JT(e){e.languages.warpscript={comment:/#.*|\/\/.*|\/\*[\s\S]*?\*\//,string:{pattern:/"(?:[^"\\\r\n]|\\.)*"|'(?:[^'\\\r\n]|\\.)*'|<'(?:[^\\']|'(?!>)|\\.)*'>/,greedy:!0},variable:/\$\S+/,macro:{pattern:/@\S+/,alias:"property"},keyword:/\b(?:BREAK|CHECKMACRO|CONTINUE|CUDF|DEFINED|DEFINEDMACRO|EVAL|FAIL|FOR|FOREACH|FORSTEP|IFT|IFTE|MSGFAIL|NRETURN|RETHROW|RETURN|SWITCH|TRY|UDF|UNTIL|WHILE)\b/,number:/[+-]?\b(?:NaN|Infinity|\d+(?:\.\d*)?(?:[Ee][+-]?\d+)?|0x[\da-fA-F]+|0b[01]+)\b/,boolean:/\b(?:F|T|false|true)\b/,punctuation:/<%|%>|[{}[\]()]/,operator:/==|&&?|\|\|?|\*\*?|>>>?|<<|[<>!~]=?|[-/%^]|\+!?|\b(?:AND|NOT|OR)\b/}}e_.displayName="wasm";e_.aliases=[];function e_(e){e.languages.wasm={comment:[/\(;[\s\S]*?;\)/,{pattern:/;;.*/,greedy:!0}],string:{pattern:/"(?:\\[\s\S]|[^"\\])*"/,greedy:!0},keyword:[{pattern:/\b(?:align|offset)=/,inside:{operator:/=/}},{pattern:/\b(?:(?:f32|f64|i32|i64)(?:\.(?:abs|add|and|ceil|clz|const|convert_[su]\/i(?:32|64)|copysign|ctz|demote\/f64|div(?:_[su])?|eqz?|extend_[su]\/i32|floor|ge(?:_[su])?|gt(?:_[su])?|le(?:_[su])?|load(?:(?:8|16|32)_[su])?|lt(?:_[su])?|max|min|mul|neg?|nearest|or|popcnt|promote\/f32|reinterpret\/[fi](?:32|64)|rem_[su]|rot[lr]|shl|shr_[su]|sqrt|store(?:8|16|32)?|sub|trunc(?:_[su]\/f(?:32|64))?|wrap\/i64|xor))?|memory\.(?:grow|size))\b/,inside:{punctuation:/\./}},/\b(?:anyfunc|block|br(?:_if|_table)?|call(?:_indirect)?|data|drop|elem|else|end|export|func|get_(?:global|local)|global|if|import|local|loop|memory|module|mut|nop|offset|param|result|return|select|set_(?:global|local)|start|table|tee_local|then|type|unreachable)\b/],variable:/\$[\w!#$%&'*+\-./:<=>?@\\^`|~]+/,number:/[+-]?\b(?:\d(?:_?\d)*(?:\.\d(?:_?\d)*)?(?:[eE][+-]?\d(?:_?\d)*)?|0x[\da-fA-F](?:_?[\da-fA-F])*(?:\.[\da-fA-F](?:_?[\da-fA-D])*)?(?:[pP][+-]?\d(?:_?\d)*)?)\b|\binf\b|\bnan(?::0x[\da-fA-F](?:_?[\da-fA-D])*)?\b/,punctuation:/[()]/}}t_.displayName="web-idl";t_.aliases=["webidl"];function t_(e){(function(t){var n=/(?:\B-|\b_|\b)[A-Za-z][\w-]*(?![\w-])/.source,r="(?:"+/\b(?:unsigned\s+)?long\s+long(?![\w-])/.source+"|"+/\b(?:unrestricted|unsigned)\s+[a-z]+(?![\w-])/.source+"|"+/(?!(?:unrestricted|unsigned)\b)/.source+n+/(?:\s*<(?:[^<>]|<[^<>]*>)*>)?/.source+")"+/(?:\s*\?)?/.source,a={};t.languages["web-idl"]={comment:{pattern:/\/\/.*|\/\*[\s\S]*?\*\//,greedy:!0},string:{pattern:/"[^"]*"/,greedy:!0},namespace:{pattern:RegExp(/(\bnamespace\s+)/.source+n),lookbehind:!0},"class-name":[{pattern:/(^|[^\w-])(?:iterable|maplike|setlike)\s*<(?:[^<>]|<[^<>]*>)*>/,lookbehind:!0,inside:a},{pattern:RegExp(/(\b(?:attribute|const|deleter|getter|optional|setter)\s+)/.source+r),lookbehind:!0,inside:a},{pattern:RegExp("("+/\bcallback\s+/.source+n+/\s*=\s*/.source+")"+r),lookbehind:!0,inside:a},{pattern:RegExp(/(\btypedef\b\s*)/.source+r),lookbehind:!0,inside:a},{pattern:RegExp(/(\b(?:callback|dictionary|enum|interface(?:\s+mixin)?)\s+)(?!(?:interface|mixin)\b)/.source+n),lookbehind:!0},{pattern:RegExp(/(:\s*)/.source+n),lookbehind:!0},RegExp(n+/(?=\s+(?:implements|includes)\b)/.source),{pattern:RegExp(/(\b(?:implements|includes)\s+)/.source+n),lookbehind:!0},{pattern:RegExp(r+"(?="+/\s*(?:\.{3}\s*)?/.source+n+/\s*[(),;=]/.source+")"),inside:a}],builtin:/\b(?:ArrayBuffer|BigInt64Array|BigUint64Array|ByteString|DOMString|DataView|Float32Array|Float64Array|FrozenArray|Int16Array|Int32Array|Int8Array|ObservableArray|Promise|USVString|Uint16Array|Uint32Array|Uint8Array|Uint8ClampedArray)\b/,keyword:[/\b(?:async|attribute|callback|const|constructor|deleter|dictionary|enum|getter|implements|includes|inherit|interface|mixin|namespace|null|optional|or|partial|readonly|required|setter|static|stringifier|typedef|unrestricted)\b/,/\b(?:any|bigint|boolean|byte|double|float|iterable|long|maplike|object|octet|record|sequence|setlike|short|symbol|undefined|unsigned|void)\b/],boolean:/\b(?:false|true)\b/,number:{pattern:/(^|[^\w-])-?(?:0x[0-9a-f]+|(?:\d+(?:\.\d*)?|\.\d+)(?:e[+-]?\d+)?|NaN|Infinity)(?![\w-])/i,lookbehind:!0},operator:/\.{3}|[=:?<>-]/,punctuation:/[(){}[\].,;]/};for(var i in t.languages["web-idl"])i!=="class-name"&&(a[i]=t.languages["web-idl"][i]);t.languages.webidl=t.languages["web-idl"]})(e)}n_.displayName="wgsl";n_.aliases=[];function n_(e){e.languages.wgsl={comment:{pattern:/\/\/.*|\/\*[\s\S]*?(?:\*\/|$)/,greedy:!0},"builtin-attribute":{pattern:/(@)builtin\(.*?\)/,lookbehind:!0,inside:{attribute:{pattern:/^builtin/,alias:"attr-name"},punctuation:/[(),]/,"built-in-values":{pattern:/\b(?:frag_depth|front_facing|global_invocation_id|instance_index|local_invocation_id|local_invocation_index|num_workgroups|position|sample_index|sample_mask|vertex_index|workgroup_id)\b/,alias:"attr-value"}}},attributes:{pattern:/(@)(?:align|binding|compute|const|fragment|group|id|interpolate|invariant|location|size|vertex|workgroup_size)/i,lookbehind:!0,alias:"attr-name"},functions:{pattern:/\b(fn\s+)[_a-zA-Z]\w*(?=[(<])/,lookbehind:!0,alias:"function"},keyword:/\b(?:bitcast|break|case|const|continue|continuing|default|discard|else|enable|fallthrough|fn|for|function|if|let|loop|private|return|storage|struct|switch|type|uniform|var|while|workgroup)\b/,builtin:/\b(?:abs|acos|acosh|all|any|array|asin|asinh|atan|atan2|atanh|atomic|atomicAdd|atomicAnd|atomicCompareExchangeWeak|atomicExchange|atomicLoad|atomicMax|atomicMin|atomicOr|atomicStore|atomicSub|atomicXor|bool|ceil|clamp|cos|cosh|countLeadingZeros|countOneBits|countTrailingZeros|cross|degrees|determinant|distance|dot|dpdx|dpdxCoarse|dpdxFine|dpdy|dpdyCoarse|dpdyFine|exp|exp2|extractBits|f32|f64|faceForward|firstLeadingBit|floor|fma|fract|frexp|fwidth|fwidthCoarse|fwidthFine|i32|i64|insertBits|inverseSqrt|ldexp|length|log|log2|mat[2-4]x[2-4]|max|min|mix|modf|normalize|override|pack2x16float|pack2x16snorm|pack2x16unorm|pack4x8snorm|pack4x8unorm|pow|ptr|quantizeToF16|radians|reflect|refract|reverseBits|round|sampler|sampler_comparison|select|shiftLeft|shiftRight|sign|sin|sinh|smoothstep|sqrt|staticAssert|step|storageBarrier|tan|tanh|textureDimensions|textureGather|textureGatherCompare|textureLoad|textureNumLayers|textureNumLevels|textureNumSamples|textureSample|textureSampleBias|textureSampleCompare|textureSampleCompareLevel|textureSampleGrad|textureSampleLevel|textureStore|texture_1d|texture_2d|texture_2d_array|texture_3d|texture_cube|texture_cube_array|texture_depth_2d|texture_depth_2d_array|texture_depth_cube|texture_depth_cube_array|texture_depth_multisampled_2d|texture_multisampled_2d|texture_storage_1d|texture_storage_2d|texture_storage_2d_array|texture_storage_3d|transpose|trunc|u32|u64|unpack2x16float|unpack2x16snorm|unpack2x16unorm|unpack4x8snorm|unpack4x8unorm|vec[2-4]|workgroupBarrier)\b/,"function-calls":{pattern:/\b[_a-z]\w*(?=\()/i,alias:"function"},"class-name":/\b(?:[A-Z][A-Za-z0-9]*)\b/,"bool-literal":{pattern:/\b(?:false|true)\b/,alias:"boolean"},"hex-int-literal":{pattern:/\b0[xX][0-9a-fA-F]+[iu]?\b(?![.pP])/,alias:"number"},"hex-float-literal":{pattern:/\b0[xX][0-9a-fA-F]*(?:\.[0-9a-fA-F]*)?(?:[pP][+-]?\d+[fh]?)?/,alias:"number"},"decimal-float-literal":[{pattern:/\d*\.\d+(?:[eE](?:\+|-)?\d+)?[fh]?/,alias:"number"},{pattern:/\d+\.\d*(?:[eE](?:\+|-)?\d+)?[fh]?/,alias:"number"},{pattern:/\d+[eE](?:\+|-)?\d+[fh]?/,alias:"number"},{pattern:/\b\d+[fh]\b/,alias:"number"}],"int-literal":{pattern:/\b\d+[iu]?\b/,alias:"number"},operator:[{pattern:/(?:\^|~|\|(?!\|)|\|\||&&|<<|>>|!)(?!=)/},{pattern:/&(?![&=])/},{pattern:/(?:\+=|-=|\*=|\/=|%=|\^=|&=|\|=|<<=|>>=)/},{pattern:/(^|[^<>=!])=(?![=>])/,lookbehind:!0},{pattern:/(?:==|!=|<=|\+\+|--|(^|[^=])>=)/,lookbehind:!0},{pattern:/(?:(?:[+%]|(?:\*(?!\w)))(?!=))|(?:-(?!>))|(?:\/(?!\/))/},{pattern:/->/}],punctuation:/[@(){}[\],;<>:.]/}}r_.displayName="wiki";r_.aliases=[];function r_(e){e.register(cr),e.languages.wiki=e.languages.extend("markup",{"block-comment":{pattern:/(^|[^\\])\/\*[\s\S]*?\*\//,lookbehind:!0,alias:"comment"},heading:{pattern:/^(=+)[^=\r\n].*?\1/m,inside:{punctuation:/^=+|=+$/,important:/.+/}},emphasis:{pattern:/('{2,5}).+?\1/,inside:{"bold-italic":{pattern:/(''''').+?(?=\1)/,lookbehind:!0,alias:["bold","italic"]},bold:{pattern:/(''')[^'](?:.*?[^'])?(?=\1)/,lookbehind:!0},italic:{pattern:/('')[^'](?:.*?[^'])?(?=\1)/,lookbehind:!0},punctuation:/^''+|''+$/}},hr:{pattern:/^-{4,}/m,alias:"punctuation"},url:[/ISBN +(?:97[89][ -]?)?(?:\d[ -]?){9}[\dx]\b|(?:PMID|RFC) +\d+/i,/\[\[.+?\]\]|\[.+?\]/],variable:[/__[A-Z]+__/,/\{{3}.+?\}{3}/,/\{\{.+?\}\}/],symbol:[/^#redirect/im,/~{3,5}/],"table-tag":{pattern:/((?:^|[|!])[|!])[^|\r\n]+\|(?!\|)/m,lookbehind:!0,inside:{"table-bar":{pattern:/\|$/,alias:"punctuation"},rest:e.languages.markup.tag.inside}},punctuation:/^(?:\{\||\|\}|\|-|[*#:;!|])|\|\||!!/m}),e.languages.insertBefore("wiki","tag",{nowiki:{pattern:/<(nowiki|pre|source)\b[^>]*>[\s\S]*?<\/\1>/i,inside:{tag:{pattern:/<(?:nowiki|pre|source)\b[^>]*>|<\/(?:nowiki|pre|source)>/i,inside:e.languages.markup.tag.inside}}}})}a_.displayName="wolfram";a_.aliases=["mathematica","nb","wl"];function a_(e){e.languages.wolfram={comment:/\(\*(?:\(\*(?:[^*]|\*(?!\)))*\*\)|(?!\(\*)[\s\S])*?\*\)/,string:{pattern:/"(?:\\.|[^"\\\r\n])*"/,greedy:!0},keyword:/\b(?:Abs|AbsArg|Accuracy|Block|Do|For|Function|If|Manipulate|Module|Nest|NestList|None|Return|Switch|Table|Which|While)\b/,context:{pattern:/\b\w+`+\w*/,alias:"class-name"},blank:{pattern:/\b\w+_\b/,alias:"regex"},"global-variable":{pattern:/\$\w+/,alias:"variable"},boolean:/\b(?:False|True)\b/,number:/(?:\b(?=\d)|\B(?=\.))(?:0[bo])?(?:(?:\d|0x[\da-f])[\da-f]*(?:\.\d*)?|\.\d+)(?:e[+-]?\d+)?j?\b/i,operator:/\/\.|;|=\.|\^=|\^:=|:=|<<|>>|<\||\|>|:>|\|->|->|<-|@@@|@@|@|\/@|=!=|===|==|=|\+|-|\[\/-+%=\]=?|!=|\*\*?=?|\/\/?=?|<[<=>]?|>[=>]?|[&|^~]/,punctuation:/[{}[\];(),.:]/},e.languages.mathematica=e.languages.wolfram,e.languages.wl=e.languages.wolfram,e.languages.nb=e.languages.wolfram}i_.displayName="wren";i_.aliases=[];function i_(e){e.languages.wren={comment:[{pattern:/\/\*(?:[^*/]|\*(?!\/)|\/(?!\*)|\/\*(?:[^*/]|\*(?!\/)|\/(?!\*)|\/\*(?:[^*/]|\*(?!\/)|\/(?!\*))*\*\/)*\*\/)*\*\//,greedy:!0},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0,greedy:!0}],"triple-quoted-string":{pattern:/"""[\s\S]*?"""/,greedy:!0,alias:"string"},"string-literal":null,hashbang:{pattern:/^#!\/.+/,greedy:!0,alias:"comment"},attribute:{pattern:/#!?[ \t\u3000]*\w+/,alias:"keyword"},"class-name":[{pattern:/(\bclass\s+)\w+/,lookbehind:!0},/\b[A-Z][a-z\d_]*\b/],constant:/\b[A-Z][A-Z\d_]*\b/,null:{pattern:/\bnull\b/,alias:"keyword"},keyword:/\b(?:as|break|class|construct|continue|else|for|foreign|if|import|in|is|return|static|super|this|var|while)\b/,boolean:/\b(?:false|true)\b/,number:/\b(?:0x[\da-f]+|\d+(?:\.\d+)?(?:e[+-]?\d+)?)\b/i,function:/\b[a-z_]\w*(?=\s*[({])/i,operator:/<<|>>|[=!<>]=?|&&|\|\||[-+*/%~^&|?:]|\.{2,3}/,punctuation:/[\[\](){}.,;]/},e.languages.wren["string-literal"]={pattern:/(^|[^\\"])"(?:[^\\"%]|\\[\s\S]|%(?!\()|%\((?:[^()]|\((?:[^()]|\([^)]*\))*\))*\))*"/,lookbehind:!0,greedy:!0,inside:{interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)%\((?:[^()]|\((?:[^()]|\([^)]*\))*\))*\)/,lookbehind:!0,inside:{expression:{pattern:/^(%\()[\s\S]+(?=\)$)/,lookbehind:!0,inside:e.languages.wren},"interpolation-punctuation":{pattern:/^%\(|\)$/,alias:"punctuation"}}},string:/[\s\S]+/}}}o_.displayName="xeora";o_.aliases=["xeoracube"];function o_(e){e.register(cr),(function(t){t.languages.xeora=t.languages.extend("markup",{constant:{pattern:/\$(?:DomainContents|PageRenderDuration)\$/,inside:{punctuation:{pattern:/\$/}}},variable:{pattern:/\$@?(?:#+|[-+*~=^])?[\w.]+\$/,inside:{punctuation:{pattern:/[$.]/},operator:{pattern:/#+|[-+*~=^@]/}}},"function-inline":{pattern:/\$F:[-\w.]+\?[-\w.]+(?:,(?:(?:@[-#]*\w+\.[\w+.]\.*)*\|)*(?:(?:[\w+]|[-#*.~^]+[\w+]|=\S)(?:[^$=]|=+[^=])*=*|(?:@[-#]*\w+\.[\w+.]\.*)+(?:(?:[\w+]|[-#*~^][-#*.~^]*[\w+]|=\S)(?:[^$=]|=+[^=])*=*)?)?)?\$/,inside:{variable:{pattern:/(?:[,|])@?(?:#+|[-+*~=^])?[\w.]+/,inside:{punctuation:{pattern:/[,.|]/},operator:{pattern:/#+|[-+*~=^@]/}}},punctuation:{pattern:/\$\w:|[$:?.,|]/}},alias:"function"},"function-block":{pattern:/\$XF:\{[-\w.]+\?[-\w.]+(?:,(?:(?:@[-#]*\w+\.[\w+.]\.*)*\|)*(?:(?:[\w+]|[-#*.~^]+[\w+]|=\S)(?:[^$=]|=+[^=])*=*|(?:@[-#]*\w+\.[\w+.]\.*)+(?:(?:[\w+]|[-#*~^][-#*.~^]*[\w+]|=\S)(?:[^$=]|=+[^=])*=*)?)?)?\}:XF\$/,inside:{punctuation:{pattern:/[$:{}?.,|]/}},alias:"function"},"directive-inline":{pattern:/\$\w(?:#\d+\+?)?(?:\[[-\w.]+\])?:[-\/\w.]+\$/,inside:{punctuation:{pattern:/\$(?:\w:|C(?:\[|#\d))?|[:{[\]]/,inside:{tag:{pattern:/#\d/}}}},alias:"function"},"directive-block-open":{pattern:/\$\w+:\{|\$\w(?:#\d+\+?)?(?:\[[-\w.]+\])?:[-\w.]+:\{(?:![A-Z]+)?/,inside:{punctuation:{pattern:/\$(?:\w:|C(?:\[|#\d))?|[:{[\]]/,inside:{tag:{pattern:/#\d/}}},attribute:{pattern:/![A-Z]+$/,inside:{punctuation:{pattern:/!/}},alias:"keyword"}},alias:"function"},"directive-block-separator":{pattern:/\}:[-\w.]+:\{/,inside:{punctuation:{pattern:/[:{}]/}},alias:"function"},"directive-block-close":{pattern:/\}:[-\w.]+\$/,inside:{punctuation:{pattern:/[:{}$]/}},alias:"function"}}),t.languages.insertBefore("inside","punctuation",{variable:t.languages.xeora["function-inline"].inside.variable},t.languages.xeora["function-block"]),t.languages.xeoracube=t.languages.xeora})(e)}s_.displayName="xml-doc";s_.aliases=[];function s_(e){e.register(cr),(function(t){function n(o,l){t.languages[o]&&t.languages.insertBefore(o,"comment",{"doc-comment":l})}var r=t.languages.markup.tag,a={pattern:/\/\/\/.*/,greedy:!0,alias:"comment",inside:{tag:r}},i={pattern:/'''.*/,greedy:!0,alias:"comment",inside:{tag:r}};n("csharp",a),n("fsharp",a),n("vbnet",i)})(e)}l_.displayName="xojo";l_.aliases=[];function l_(e){e.languages.xojo={comment:{pattern:/(?:'|\/\/|Rem\b).+/i,greedy:!0},string:{pattern:/"(?:""|[^"])*"/,greedy:!0},number:[/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:E[+-]?\d+)?/i,/&[bchou][a-z\d]+/i],directive:{pattern:/#(?:Else|ElseIf|Endif|If|Pragma)\b/i,alias:"property"},keyword:/\b(?:AddHandler|App|Array|As(?:signs)?|Auto|Boolean|Break|By(?:Ref|Val)|Byte|Call|Case|Catch|CFStringRef|CGFloat|Class|Color|Const|Continue|CString|Currency|CurrentMethodName|Declare|Delegate|Dim|Do(?:uble|wnTo)?|Each|Else(?:If)?|End|Enumeration|Event|Exception|Exit|Extends|False|Finally|For|Function|Get|GetTypeInfo|Global|GOTO|If|Implements|In|Inherits|Int(?:8|16|32|64|eger|erface)?|Lib|Loop|Me|Module|Next|Nil|Object|Optional|OSType|ParamArray|Private|Property|Protected|PString|Ptr|Raise(?:Event)?|ReDim|RemoveHandler|Return|Select(?:or)?|Self|Set|Shared|Short|Single|Soft|Static|Step|String|Sub|Super|Text|Then|To|True|Try|Ubound|UInt(?:8|16|32|64|eger)?|Until|Using|Var(?:iant)?|Wend|While|WindowPtr|WString)\b/i,operator:/<[=>]?|>=?|[+\-*\/\\^=]|\b(?:AddressOf|And|Ctype|IsA?|Mod|New|Not|Or|WeakAddressOf|Xor)\b/i,punctuation:/[.,;:()]/}}c_.displayName="xquery";c_.aliases=[];function c_(e){e.register(cr),(function(t){t.languages.xquery=t.languages.extend("markup",{"xquery-comment":{pattern:/\(:[\s\S]*?:\)/,greedy:!0,alias:"comment"},string:{pattern:/(["'])(?:\1\1|(?!\1)[\s\S])*\1/,greedy:!0},extension:{pattern:/\(#.+?#\)/,alias:"symbol"},variable:/\$[-\w:]+/,axis:{pattern:/(^|[^-])(?:ancestor(?:-or-self)?|attribute|child|descendant(?:-or-self)?|following(?:-sibling)?|parent|preceding(?:-sibling)?|self)(?=::)/,lookbehind:!0,alias:"operator"},"keyword-operator":{pattern:/(^|[^:-])\b(?:and|castable as|div|eq|except|ge|gt|idiv|instance of|intersect|is|le|lt|mod|ne|or|union)\b(?=$|[^:-])/,lookbehind:!0,alias:"operator"},keyword:{pattern:/(^|[^:-])\b(?:as|ascending|at|base-uri|boundary-space|case|cast as|collation|construction|copy-namespaces|declare|default|descending|else|empty (?:greatest|least)|encoding|every|external|for|function|if|import|in|inherit|lax|let|map|module|namespace|no-inherit|no-preserve|option|order(?: by|ed|ing)?|preserve|return|satisfies|schema|some|stable|strict|strip|then|to|treat as|typeswitch|unordered|validate|variable|version|where|xquery)\b(?=$|[^:-])/,lookbehind:!0},function:/[\w-]+(?::[\w-]+)*(?=\s*\()/,"xquery-element":{pattern:/(element\s+)[\w-]+(?::[\w-]+)*/,lookbehind:!0,alias:"tag"},"xquery-attribute":{pattern:/(attribute\s+)[\w-]+(?::[\w-]+)*/,lookbehind:!0,alias:"attr-name"},builtin:{pattern:/(^|[^:-])\b(?:attribute|comment|document|element|processing-instruction|text|xs:(?:ENTITIES|ENTITY|ID|IDREFS?|NCName|NMTOKENS?|NOTATION|Name|QName|anyAtomicType|anyType|anyURI|base64Binary|boolean|byte|date|dateTime|dayTimeDuration|decimal|double|duration|float|gDay|gMonth|gMonthDay|gYear|gYearMonth|hexBinary|int|integer|language|long|negativeInteger|nonNegativeInteger|nonPositiveInteger|normalizedString|positiveInteger|short|string|time|token|unsigned(?:Byte|Int|Long|Short)|untyped(?:Atomic)?|yearMonthDuration))\b(?=$|[^:-])/,lookbehind:!0},number:/\b\d+(?:\.\d+)?(?:E[+-]?\d+)?/,operator:[/[+*=?|@]|\.\.?|:=|!=|<[=<]?|>[=>]?/,{pattern:/(\s)-(?=\s)/,lookbehind:!0}],punctuation:/[[\](){},;:/]/}),t.languages.xquery.tag.pattern=/<\/?(?!\d)[^\s>\/=$<%]+(?:\s+[^\s>\/=]+(?:=(?:("|')(?:\\[\s\S]|\{(?!\{)(?:\{(?:\{[^{}]*\}|[^{}])*\}|[^{}])+\}|(?!\1)[^\\])*\1|[^\s'">=]+))?)*\s*\/?>/,t.languages.xquery.tag.inside["attr-value"].pattern=/=(?:("|')(?:\\[\s\S]|\{(?!\{)(?:\{(?:\{[^{}]*\}|[^{}])*\}|[^{}])+\}|(?!\1)[^\\])*\1|[^\s'">=]+)/,t.languages.xquery.tag.inside["attr-value"].inside.punctuation=/^="|"$/,t.languages.xquery.tag.inside["attr-value"].inside.expression={pattern:/\{(?!\{)(?:\{(?:\{[^{}]*\}|[^{}])*\}|[^{}])+\}/,inside:t.languages.xquery,alias:"language-xquery"};var n=function(a){return typeof a=="string"?a:typeof a.content=="string"?a.content:a.content.map(n).join("")},r=function(a){for(var i=[],o=0;o<a.length;o++){var l=a[o],u=!1;if(typeof l!="string"&&(l.type==="tag"&&l.content[0]&&l.content[0].type==="tag"?l.content[0].content[0].content==="</"?i.length>0&&i[i.length-1].tagName===n(l.content[0].content[1])&&i.pop():l.content[l.content.length-1].content==="/>"||i.push({tagName:n(l.content[0].content[1]),openedBraces:0}):i.length>0&&l.type==="punctuation"&&l.content==="{"&&(!a[o+1]||a[o+1].type!=="punctuation"||a[o+1].content!=="{")&&(!a[o-1]||a[o-1].type!=="plain-text"||a[o-1].content!=="{")?i[i.length-1].openedBraces++:i.length>0&&i[i.length-1].openedBraces>0&&l.type==="punctuation"&&l.content==="}"?i[i.length-1].openedBraces--:l.type!=="comment"&&(u=!0)),(u||typeof l=="string")&&i.length>0&&i[i.length-1].openedBraces===0){var d=n(l);o<a.length-1&&(typeof a[o+1]=="string"||a[o+1].type==="plain-text")&&(d+=n(a[o+1]),a.splice(o+1,1)),o>0&&(typeof a[o-1]=="string"||a[o-1].type==="plain-text")&&(d=n(a[o-1])+d,a.splice(o-1,1),o--),/^\s+$/.test(d)?a[o]=d:a[o]=new t.Token("plain-text",d,null,d)}l.content&&typeof l.content!="string"&&r(l.content)}};t.hooks.add("after-tokenize",function(a){a.language==="xquery"&&r(a.tokens)})})(e)}u_.displayName="yang";u_.aliases=[];function u_(e){e.languages.yang={comment:/\/\*[\s\S]*?\*\/|\/\/.*/,string:{pattern:/"(?:[^\\"]|\\.)*"|'[^']*'/,greedy:!0},keyword:{pattern:/(^|[{};\r\n][ \t]*)[a-z_][\w.-]*/i,lookbehind:!0},namespace:{pattern:/(\s)[a-z_][\w.-]*(?=:)/i,lookbehind:!0},boolean:/\b(?:false|true)\b/,operator:/\+/,punctuation:/[{};:]/}}d_.displayName="zig";d_.aliases=[];function d_(e){(function(t){function n(d){return function(){return d}}var r=/\b(?:align|allowzero|and|anyframe|anytype|asm|async|await|break|cancel|catch|comptime|const|continue|defer|else|enum|errdefer|error|export|extern|fn|for|if|inline|linksection|nakedcc|noalias|nosuspend|null|or|orelse|packed|promise|pub|resume|return|stdcallcc|struct|suspend|switch|test|threadlocal|try|undefined|union|unreachable|usingnamespace|var|volatile|while)\b/,a="\\b(?!"+r.source+")(?!\\d)\\w+\\b",i=/align\s*\((?:[^()]|\([^()]*\))*\)/.source,o=/(?:\?|\bpromise->|(?:\[[^[\]]*\]|\*(?!\*)|\*\*)(?:\s*<ALIGN>|\s*const\b|\s*volatile\b|\s*allowzero\b)*)/.source.replace(/<ALIGN>/g,n(i)),l=/(?:\bpromise\b|(?:\berror\.)?<ID>(?:\.<ID>)*(?!\s+<ID>))/.source.replace(/<ID>/g,n(a)),u="(?!\\s)(?:!?\\s*(?:"+o+"\\s*)*"+l+")+";t.languages.zig={comment:[{pattern:/\/\/[/!].*/,alias:"doc-comment"},/\/{2}.*/],string:[{pattern:/(^|[^\\@])c?"(?:[^"\\\r\n]|\\.)*"/,lookbehind:!0,greedy:!0},{pattern:/([\r\n])([ \t]+c?\\{2}).*(?:(?:\r\n?|\n)\2.*)*/,lookbehind:!0,greedy:!0}],char:{pattern:/(^|[^\\])'(?:[^'\\\r\n]|[\uD800-\uDFFF]{2}|\\(?:.|x[a-fA-F\d]{2}|u\{[a-fA-F\d]{1,6}\}))'/,lookbehind:!0,greedy:!0},builtin:/\B@(?!\d)\w+(?=\s*\()/,label:{pattern:/(\b(?:break|continue)\s*:\s*)\w+\b|\b(?!\d)\w+\b(?=\s*:\s*(?:\{|while\b))/,lookbehind:!0},"class-name":[/\b(?!\d)\w+(?=\s*=\s*(?:(?:extern|packed)\s+)?(?:enum|struct|union)\s*[({])/,{pattern:RegExp(/(:\s*)<TYPE>(?=\s*(?:<ALIGN>\s*)?[=;,)])|<TYPE>(?=\s*(?:<ALIGN>\s*)?\{)/.source.replace(/<TYPE>/g,n(u)).replace(/<ALIGN>/g,n(i))),lookbehind:!0,inside:null},{pattern:RegExp(/(\)\s*)<TYPE>(?=\s*(?:<ALIGN>\s*)?;)/.source.replace(/<TYPE>/g,n(u)).replace(/<ALIGN>/g,n(i))),lookbehind:!0,inside:null}],"builtin-type":{pattern:/\b(?:anyerror|bool|c_u?(?:int|long|longlong|short)|c_longdouble|c_void|comptime_(?:float|int)|f(?:16|32|64|128)|[iu](?:8|16|32|64|128|size)|noreturn|type|void)\b/,alias:"keyword"},keyword:r,function:/\b(?!\d)\w+(?=\s*\()/,number:/\b(?:0b[01]+|0o[0-7]+|0x[a-fA-F\d]+(?:\.[a-fA-F\d]*)?(?:[pP][+-]?[a-fA-F\d]+)?|\d+(?:\.\d*)?(?:[eE][+-]?\d+)?)\b/,boolean:/\b(?:false|true)\b/,operator:/\.[*?]|\.{2,3}|[-=]>|\*\*|\+\+|\|\||(?:<<|>>|[-+*]%|[-+*/%^&|<>!=])=?|[?~]/,punctuation:/[.:,;(){}[\]]/},t.languages.zig["class-name"].forEach(function(d){d.inside===null&&(d.inside=t.languages.zig)})})(e)}K.register(cr);K.register(Ll);K.register(Mt);K.register(hw);K.register(wr);K.register(pw);K.register(fw);K.register(mw);K.register(gw);K.register(bw);K.register(yw);K.register(vw);K.register(xw);K.register(ip);K.register(Sw);K.register(ww);K.register(Ew);K.register(kw);K.register($i);K.register(Eu);K.register(Tw);K.register(_w);K.register(Cw);K.register(Ng);K.register(Og);K.register(Aw);K.register(Rw);K.register(Nw);K.register(ku);K.register(Ow);K.register(Iw);K.register(Lw);K.register(Dw);K.register(Mw);K.register(Bw);K.register(Fw);K.register(zw);K.register(Ig);K.register($w);K.register(Pw);K.register(Uw);K.register(jw);K.register(Hw);K.register(Gw);K.register(qw);K.register(Ww);K.register(Vw);K.register(Yw);K.register(Xw);K.register(Kw);K.register(Zw);K.register(Qw);K.register(Jw);K.register(eE);K.register(tE);K.register(nE);K.register(rE);K.register(aE);K.register(iE);K.register(oE);K.register(sE);K.register(lE);K.register(cE);K.register(Tu);K.register(uE);K.register(dE);K.register(hE);K.register(pE);K.register(fE);K.register(mE);K.register(gE);K.register(bE);K.register(yE);K.register(vE);K.register(xE);K.register(Er);K.register(SE);K.register(wE);K.register(EE);K.register(kE);K.register(TE);K.register(_E);K.register(CE);K.register(AE);K.register(RE);K.register(NE);K.register(Lg);K.register(OE);K.register(IE);K.register(LE);K.register(DE);K.register(ME);K.register(BE);K.register(FE);K.register(zE);K.register($E);K.register(PE);K.register(UE);K.register(jE);K.register(HE);K.register(GE);K.register(qE);K.register(WE);K.register(VE);K.register(YE);K.register(XE);K.register(KE);K.register(ZE);K.register(QE);K.register(JE);K.register(ek);K.register(tk);K.register(nk);K.register(rk);K.register(ak);K.register(ik);K.register(ok);K.register(sk);K.register(lk);K.register(op);K.register(ck);K.register(uk);K.register(dk);K.register(hk);K.register(pk);K.register(fk);K.register(sp);K.register(mk);K.register(gk);K.register(bk);K.register(yk);K.register(vk);K.register(xk);K.register(Sk);K.register(wk);K.register(Ek);K.register(kk);K.register(Tk);K.register(_u);K.register(Cu);K.register(Au);K.register(_k);K.register(Ck);K.register(Ak);K.register(Rk);K.register(Nk);K.register(Ok);K.register(Ik);K.register(lp);K.register(Lk);K.register(Dk);K.register(Mk);K.register(Bk);K.register(Fk);K.register(zk);K.register($k);K.register(Pk);K.register(Uk);K.register(jk);K.register(Hk);K.register(Gk);K.register(qk);K.register(Wk);K.register(cp);K.register(Vk);K.register(Yk);K.register(Xk);K.register(Kk);K.register(Zk);K.register(Qk);K.register(Jk);K.register(e4);K.register(t4);K.register(Dg);K.register(n4);K.register(r4);K.register(a4);K.register(i4);K.register(o4);K.register(s4);K.register(l4);K.register(c4);K.register(u4);K.register(d4);K.register(h4);K.register(p4);K.register(f4);K.register(m4);K.register(g4);K.register(b4);K.register(y4);K.register(v4);K.register(x4);K.register(S4);K.register(w4);K.register(E4);K.register(k4);K.register(T4);K.register(_4);K.register(C4);K.register(A4);K.register(R4);K.register(N4);K.register(O4);K.register(I4);K.register(L4);K.register(D4);K.register(M4);K.register(B4);K.register(F4);K.register(z4);K.register($4);K.register(P4);K.register(U4);K.register(j4);K.register(H4);K.register(G4);K.register(q4);K.register(W4);K.register(V4);K.register(Y4);K.register(X4);K.register(K4);K.register(Z4);K.register(Q4);K.register(Mg);K.register(J4);K.register(eT);K.register(tT);K.register(nT);K.register(rT);K.register(aT);K.register(iT);K.register(Bg);K.register(oT);K.register(sT);K.register(lT);K.register(cT);K.register(uT);K.register(dT);K.register(hT);K.register(pT);K.register(fT);K.register(mT);K.register(gT);K.register(bT);K.register(yT);K.register(vT);K.register(xT);K.register(ST);K.register(wT);K.register(ET);K.register(kT);K.register(TT);K.register(Fg);K.register(_T);K.register(CT);K.register(AT);K.register(RT);K.register(NT);K.register(OT);K.register(IT);K.register(LT);K.register(DT);K.register(MT);K.register(up);K.register(BT);K.register(zg);K.register(FT);K.register(zT);K.register($T);K.register(PT);K.register(UT);K.register(jT);K.register(HT);K.register(GT);K.register(qT);K.register(WT);K.register(VT);K.register(YT);K.register(XT);K.register(KT);K.register(ZT);K.register(QT);K.register(JT);K.register(e_);K.register(t_);K.register(n_);K.register(r_);K.register(a_);K.register(i_);K.register(o_);K.register(s_);K.register(l_);K.register(c_);K.register(u_);K.register(d_);var e9=Ole(K,Jle);e9.supportedLanguages=Dle;const ece={'code[class*="language-"]':{background:"hsl(220, 13%, 18%)",color:"hsl(220, 14%, 71%)",textShadow:"0 1px rgba(0, 0, 0, 0.3)",fontFamily:'"Fira Code", "Fira Mono", Menlo, Consolas, "DejaVu Sans Mono", monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"2",OTabSize:"2",tabSize:"2",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{background:"hsl(220, 13%, 18%)",color:"hsl(220, 14%, 71%)",textShadow:"0 1px rgba(0, 0, 0, 0.3)",fontFamily:'"Fira Code", "Fira Mono", Menlo, Consolas, "DejaVu Sans Mono", monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"2",OTabSize:"2",tabSize:"2",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:"0.5em 0",overflow:"auto",borderRadius:"0.3em"},'code[class*="language-"]::-moz-selection':{background:"hsl(220, 13%, 28%)",color:"inherit",textShadow:"none"},'code[class*="language-"] *::-moz-selection':{background:"hsl(220, 13%, 28%)",color:"inherit",textShadow:"none"},'pre[class*="language-"] *::-moz-selection':{background:"hsl(220, 13%, 28%)",color:"inherit",textShadow:"none"},'code[class*="language-"]::selection':{background:"hsl(220, 13%, 28%)",color:"inherit",textShadow:"none"},'code[class*="language-"] *::selection':{background:"hsl(220, 13%, 28%)",color:"inherit",textShadow:"none"},'pre[class*="language-"] *::selection':{background:"hsl(220, 13%, 28%)",color:"inherit",textShadow:"none"},':not(pre) > code[class*="language-"]':{padding:"0.2em 0.3em",borderRadius:"0.3em",whiteSpace:"normal"},comment:{color:"hsl(220, 10%, 40%)",fontStyle:"italic"},prolog:{color:"hsl(220, 10%, 40%)"},cdata:{color:"hsl(220, 10%, 40%)"},doctype:{color:"hsl(220, 14%, 71%)"},punctuation:{color:"hsl(220, 14%, 71%)"},entity:{color:"hsl(220, 14%, 71%)",cursor:"help"},"attr-name":{color:"hsl(29, 54%, 61%)"},"class-name":{color:"hsl(29, 54%, 61%)"},boolean:{color:"hsl(29, 54%, 61%)"},constant:{color:"hsl(29, 54%, 61%)"},number:{color:"hsl(29, 54%, 61%)"},atrule:{color:"hsl(29, 54%, 61%)"},keyword:{color:"hsl(286, 60%, 67%)"},property:{color:"hsl(355, 65%, 65%)"},tag:{color:"hsl(355, 65%, 65%)"},symbol:{color:"hsl(355, 65%, 65%)"},deleted:{color:"hsl(355, 65%, 65%)"},important:{color:"hsl(355, 65%, 65%)"},selector:{color:"hsl(95, 38%, 62%)"},string:{color:"hsl(95, 38%, 62%)"},char:{color:"hsl(95, 38%, 62%)"},builtin:{color:"hsl(95, 38%, 62%)"},inserted:{color:"hsl(95, 38%, 62%)"},regex:{color:"hsl(95, 38%, 62%)"},"attr-value":{color:"hsl(95, 38%, 62%)"},"attr-value > .token.punctuation":{color:"hsl(95, 38%, 62%)"},variable:{color:"hsl(207, 82%, 66%)"},operator:{color:"hsl(207, 82%, 66%)"},function:{color:"hsl(207, 82%, 66%)"},url:{color:"hsl(187, 47%, 55%)"},"attr-value > .token.punctuation.attr-equals":{color:"hsl(220, 14%, 71%)"},"special-attr > .token.attr-value > .token.value.css":{color:"hsl(220, 14%, 71%)"},".language-css .token.selector":{color:"hsl(355, 65%, 65%)"},".language-css .token.property":{color:"hsl(220, 14%, 71%)"},".language-css .token.function":{color:"hsl(187, 47%, 55%)"},".language-css .token.url > .token.function":{color:"hsl(187, 47%, 55%)"},".language-css .token.url > .token.string.url":{color:"hsl(95, 38%, 62%)"},".language-css .token.important":{color:"hsl(286, 60%, 67%)"},".language-css .token.atrule .token.rule":{color:"hsl(286, 60%, 67%)"},".language-javascript .token.operator":{color:"hsl(286, 60%, 67%)"},".language-javascript .token.template-string > .token.interpolation > .token.interpolation-punctuation.punctuation":{color:"hsl(5, 48%, 51%)"},".language-json .token.operator":{color:"hsl(220, 14%, 71%)"},".language-json .token.null.keyword":{color:"hsl(29, 54%, 61%)"},".language-markdown .token.url":{color:"hsl(220, 14%, 71%)"},".language-markdown .token.url > .token.operator":{color:"hsl(220, 14%, 71%)"},".language-markdown .token.url-reference.url > .token.string":{color:"hsl(220, 14%, 71%)"},".language-markdown .token.url > .token.content":{color:"hsl(207, 82%, 66%)"},".language-markdown .token.url > .token.url":{color:"hsl(187, 47%, 55%)"},".language-markdown .token.url-reference.url":{color:"hsl(187, 47%, 55%)"},".language-markdown .token.blockquote.punctuation":{color:"hsl(220, 10%, 40%)",fontStyle:"italic"},".language-markdown .token.hr.punctuation":{color:"hsl(220, 10%, 40%)",fontStyle:"italic"},".language-markdown .token.code-snippet":{color:"hsl(95, 38%, 62%)"},".language-markdown .token.bold .token.content":{color:"hsl(29, 54%, 61%)"},".language-markdown .token.italic .token.content":{color:"hsl(286, 60%, 67%)"},".language-markdown .token.strike .token.content":{color:"hsl(355, 65%, 65%)"},".language-markdown .token.strike .token.punctuation":{color:"hsl(355, 65%, 65%)"},".language-markdown .token.list.punctuation":{color:"hsl(355, 65%, 65%)"},".language-markdown .token.title.important > .token.punctuation":{color:"hsl(355, 65%, 65%)"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},namespace:{Opacity:"0.8"},"token.tab:not(:empty):before":{color:"hsla(220, 14%, 71%, 0.15)",textShadow:"none"},"token.cr:before":{color:"hsla(220, 14%, 71%, 0.15)",textShadow:"none"},"token.lf:before":{color:"hsla(220, 14%, 71%, 0.15)",textShadow:"none"},"token.space:before":{color:"hsla(220, 14%, 71%, 0.15)",textShadow:"none"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item":{marginRight:"0.4em"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > button":{background:"hsl(220, 13%, 26%)",color:"hsl(220, 9%, 55%)",padding:"0.1em 0.4em",borderRadius:"0.3em"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > a":{background:"hsl(220, 13%, 26%)",color:"hsl(220, 9%, 55%)",padding:"0.1em 0.4em",borderRadius:"0.3em"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > span":{background:"hsl(220, 13%, 26%)",color:"hsl(220, 9%, 55%)",padding:"0.1em 0.4em",borderRadius:"0.3em"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > button:hover":{background:"hsl(220, 13%, 28%)",color:"hsl(220, 14%, 71%)"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > button:focus":{background:"hsl(220, 13%, 28%)",color:"hsl(220, 14%, 71%)"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > a:hover":{background:"hsl(220, 13%, 28%)",color:"hsl(220, 14%, 71%)"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > a:focus":{background:"hsl(220, 13%, 28%)",color:"hsl(220, 14%, 71%)"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > span:hover":{background:"hsl(220, 13%, 28%)",color:"hsl(220, 14%, 71%)"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > span:focus":{background:"hsl(220, 13%, 28%)",color:"hsl(220, 14%, 71%)"},".line-highlight.line-highlight":{background:"hsla(220, 100%, 80%, 0.04)"},".line-highlight.line-highlight:before":{background:"hsl(220, 13%, 26%)",color:"hsl(220, 14%, 71%)",padding:"0.1em 0.6em",borderRadius:"0.3em",boxShadow:"0 2px 0 0 rgba(0, 0, 0, 0.2)"},".line-highlight.line-highlight[data-end]:after":{background:"hsl(220, 13%, 26%)",color:"hsl(220, 14%, 71%)",padding:"0.1em 0.6em",borderRadius:"0.3em",boxShadow:"0 2px 0 0 rgba(0, 0, 0, 0.2)"},"pre[id].linkable-line-numbers.linkable-line-numbers span.line-numbers-rows > span:hover:before":{backgroundColor:"hsla(220, 100%, 80%, 0.04)"},".line-numbers.line-numbers .line-numbers-rows":{borderRightColor:"hsla(220, 14%, 71%, 0.15)"},".command-line .command-line-prompt":{borderRightColor:"hsla(220, 14%, 71%, 0.15)"},".line-numbers .line-numbers-rows > span:before":{color:"hsl(220, 14%, 45%)"},".command-line .command-line-prompt > span:before":{color:"hsl(220, 14%, 45%)"},".rainbow-braces .token.token.punctuation.brace-level-1":{color:"hsl(355, 65%, 65%)"},".rainbow-braces .token.token.punctuation.brace-level-5":{color:"hsl(355, 65%, 65%)"},".rainbow-braces .token.token.punctuation.brace-level-9":{color:"hsl(355, 65%, 65%)"},".rainbow-braces .token.token.punctuation.brace-level-2":{color:"hsl(95, 38%, 62%)"},".rainbow-braces .token.token.punctuation.brace-level-6":{color:"hsl(95, 38%, 62%)"},".rainbow-braces .token.token.punctuation.brace-level-10":{color:"hsl(95, 38%, 62%)"},".rainbow-braces .token.token.punctuation.brace-level-3":{color:"hsl(207, 82%, 66%)"},".rainbow-braces .token.token.punctuation.brace-level-7":{color:"hsl(207, 82%, 66%)"},".rainbow-braces .token.token.punctuation.brace-level-11":{color:"hsl(207, 82%, 66%)"},".rainbow-braces .token.token.punctuation.brace-level-4":{color:"hsl(286, 60%, 67%)"},".rainbow-braces .token.token.punctuation.brace-level-8":{color:"hsl(286, 60%, 67%)"},".rainbow-braces .token.token.punctuation.brace-level-12":{color:"hsl(286, 60%, 67%)"},"pre.diff-highlight > code .token.token.deleted:not(.prefix)":{backgroundColor:"hsla(353, 100%, 66%, 0.15)"},"pre > code.diff-highlight .token.token.deleted:not(.prefix)":{backgroundColor:"hsla(353, 100%, 66%, 0.15)"},"pre.diff-highlight > code .token.token.deleted:not(.prefix)::-moz-selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre.diff-highlight > code .token.token.deleted:not(.prefix) *::-moz-selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre > code.diff-highlight .token.token.deleted:not(.prefix)::-moz-selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre > code.diff-highlight .token.token.deleted:not(.prefix) *::-moz-selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre.diff-highlight > code .token.token.deleted:not(.prefix)::selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre.diff-highlight > code .token.token.deleted:not(.prefix) *::selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre > code.diff-highlight .token.token.deleted:not(.prefix)::selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre > code.diff-highlight .token.token.deleted:not(.prefix) *::selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre.diff-highlight > code .token.token.inserted:not(.prefix)":{backgroundColor:"hsla(137, 100%, 55%, 0.15)"},"pre > code.diff-highlight .token.token.inserted:not(.prefix)":{backgroundColor:"hsla(137, 100%, 55%, 0.15)"},"pre.diff-highlight > code .token.token.inserted:not(.prefix)::-moz-selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre.diff-highlight > code .token.token.inserted:not(.prefix) *::-moz-selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre > code.diff-highlight .token.token.inserted:not(.prefix)::-moz-selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre > code.diff-highlight .token.token.inserted:not(.prefix) *::-moz-selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre.diff-highlight > code .token.token.inserted:not(.prefix)::selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre.diff-highlight > code .token.token.inserted:not(.prefix) *::selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre > code.diff-highlight .token.token.inserted:not(.prefix)::selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre > code.diff-highlight .token.token.inserted:not(.prefix) *::selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},".prism-previewer.prism-previewer:before":{borderColor:"hsl(224, 13%, 17%)"},".prism-previewer-gradient.prism-previewer-gradient div":{borderColor:"hsl(224, 13%, 17%)",borderRadius:"0.3em"},".prism-previewer-color.prism-previewer-color:before":{borderRadius:"0.3em"},".prism-previewer-easing.prism-previewer-easing:before":{borderRadius:"0.3em"},".prism-previewer.prism-previewer:after":{borderTopColor:"hsl(224, 13%, 17%)"},".prism-previewer-flipped.prism-previewer-flipped.after":{borderBottomColor:"hsl(224, 13%, 17%)"},".prism-previewer-angle.prism-previewer-angle:before":{background:"hsl(219, 13%, 22%)"},".prism-previewer-time.prism-previewer-time:before":{background:"hsl(219, 13%, 22%)"},".prism-previewer-easing.prism-previewer-easing":{background:"hsl(219, 13%, 22%)"},".prism-previewer-angle.prism-previewer-angle circle":{stroke:"hsl(220, 14%, 71%)",strokeOpacity:"1"},".prism-previewer-time.prism-previewer-time circle":{stroke:"hsl(220, 14%, 71%)",strokeOpacity:"1"},".prism-previewer-easing.prism-previewer-easing circle":{stroke:"hsl(220, 14%, 71%)",fill:"transparent"},".prism-previewer-easing.prism-previewer-easing path":{stroke:"hsl(220, 14%, 71%)"},".prism-previewer-easing.prism-previewer-easing line":{stroke:"hsl(220, 14%, 71%)"}},tce={javascript:"js",typescript:"ts",python:"py",ruby:"rb",rust:"rs",csharp:"cs",cpp:"cpp",java:"java",go:"go",html:"html",css:"css",json:"json",yaml:"yaml",yml:"yml",markdown:"md",bash:"sh",shell:"sh",sql:"sql",xml:"xml",toml:"toml"};function jx({language:e,value:t}){const[n,r]=_.useState(!1),a=async()=>{await navigator.clipboard.writeText(t),r(!0),setTimeout(()=>r(!1),2e3)},i=()=>{const o=tce[e]??e??"txt",l=new Blob([t],{type:"text/plain"}),u=URL.createObjectURL(l),d=document.createElement("a");d.href=u,d.download=`code.${o}`,d.click(),URL.revokeObjectURL(u)};return T.jsxs("div",{className:"group relative my-4 overflow-hidden rounded-lg border border-border",children:[T.jsxs("div",{className:"flex items-center justify-between bg-zinc-800 px-4 py-1.5 text-xs text-zinc-400",children:[T.jsx("span",{children:e||"text"}),T.jsxs("div",{className:"flex gap-1",children:[T.jsx(kt,{variant:"ghost",size:"icon",className:"h-6 w-6 text-zinc-400 hover:text-zinc-200",onClick:a,"aria-label":"Copy code",children:n?T.jsx(rg,{className:"h-3.5 w-3.5"}):T.jsx(Q2,{className:"h-3.5 w-3.5"})}),T.jsx(kt,{variant:"ghost",size:"icon",className:"h-6 w-6 text-zinc-400 hover:text-zinc-200",onClick:i,"aria-label":"Download code",children:T.jsx(bO,{className:"h-3.5 w-3.5"})})]})]}),T.jsx(e9,{language:e,style:ece,customStyle:{margin:0,borderRadius:0,fontSize:"0.8125rem",lineHeight:"1.5"},children:t})]})}var M0={exports:{}},nce=M0.exports,n7;function rce(){return n7||(n7=1,(function(e,t){(function(n,r){e.exports=r()})(nce,(function(){var n=1e3,r=6e4,a=36e5,i="millisecond",o="second",l="minute",u="hour",d="day",h="week",f="month",m="quarter",b="year",y="date",v="Invalid Date",w=/^(\d{4})[-/]?(\d{1,2})?[-/]?(\d{0,2})[Tt\s]*(\d{1,2})?:?(\d{1,2})?:?(\d{1,2})?[.:]?(\d+)?$/,S=/\[([^\]]+)]|Y{1,4}|M{1,4}|D{1,2}|d{1,4}|H{1,2}|h{1,2}|a|A|m{1,2}|s{1,2}|Z{1,2}|SSS/g,k={name:"en",weekdays:"Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),months:"January_February_March_April_May_June_July_August_September_October_November_December".split("_"),ordinal:function(q){var X=["th","st","nd","rd"],$=q%100;return"["+q+(X[($-20)%10]||X[$]||X[0])+"]"}},R=function(q,X,$){var Q=String(q);return!Q||Q.length>=X?q:""+Array(X+1-Q.length).join($)+q},I={s:R,z:function(q){var X=-q.utcOffset(),$=Math.abs(X),Q=Math.floor($/60),J=$%60;return(X<=0?"+":"-")+R(Q,2,"0")+":"+R(J,2,"0")},m:function q(X,$){if(X.date()<$.date())return-q($,X);var Q=12*($.year()-X.year())+($.month()-X.month()),J=X.clone().add(Q,f),ie=$-J<0,F=X.clone().add(Q+(ie?-1:1),f);return+(-(Q+($-J)/(ie?J-F:F-J))||0)},a:function(q){return q<0?Math.ceil(q)||0:Math.floor(q)},p:function(q){return{M:f,y:b,w:h,d,D:y,h:u,m:l,s:o,ms:i,Q:m}[q]||String(q||"").toLowerCase().replace(/s$/,"")},u:function(q){return q===void 0}},L="en",A={};A[L]=k;var M="$isDayjsObject",P=function(q){return q instanceof Z||!(!q||!q[M])},G=function q(X,$,Q){var J;if(!X)return L;if(typeof X=="string"){var ie=X.toLowerCase();A[ie]&&(J=ie),$&&(A[ie]=$,J=ie);var F=X.split("-");if(!J&&F.length>1)return q(F[0])}else{var Y=X.name;A[Y]=X,J=Y}return!Q&&J&&(L=J),J||!Q&&L},B=function(q,X){if(P(q))return q.clone();var $=typeof X=="object"?X:{};return $.date=q,$.args=arguments,new Z($)},H=I;H.l=G,H.i=P,H.w=function(q,X){return B(q,{locale:X.$L,utc:X.$u,x:X.$x,$offset:X.$offset})};var Z=(function(){function q($){this.$L=G($.locale,null,!0),this.parse($),this.$x=this.$x||$.x||{},this[M]=!0}var X=q.prototype;return X.parse=function($){this.$d=(function(Q){var J=Q.date,ie=Q.utc;if(J===null)return new Date(NaN);if(H.u(J))return new Date;if(J instanceof Date)return new Date(J);if(typeof J=="string"&&!/Z$/i.test(J)){var F=J.match(w);if(F){var Y=F[2]-1||0,oe=(F[7]||"0").substring(0,3);return ie?new Date(Date.UTC(F[1],Y,F[3]||1,F[4]||0,F[5]||0,F[6]||0,oe)):new Date(F[1],Y,F[3]||1,F[4]||0,F[5]||0,F[6]||0,oe)}}return new Date(J)})($),this.init()},X.init=function(){var $=this.$d;this.$y=$.getFullYear(),this.$M=$.getMonth(),this.$D=$.getDate(),this.$W=$.getDay(),this.$H=$.getHours(),this.$m=$.getMinutes(),this.$s=$.getSeconds(),this.$ms=$.getMilliseconds()},X.$utils=function(){return H},X.isValid=function(){return this.$d.toString()!==v},X.isSame=function($,Q){var J=B($);return this.startOf(Q)<=J&&J<=this.endOf(Q)},X.isAfter=function($,Q){return B($)<this.startOf(Q)},X.isBefore=function($,Q){return this.endOf(Q)<B($)},X.$g=function($,Q,J){return H.u($)?this[Q]:this.set(J,$)},X.unix=function(){return Math.floor(this.valueOf()/1e3)},X.valueOf=function(){return this.$d.getTime()},X.startOf=function($,Q){var J=this,ie=!!H.u(Q)||Q,F=H.p($),Y=function(ve,De){var Le=H.w(J.$u?Date.UTC(J.$y,De,ve):new Date(J.$y,De,ve),J);return ie?Le:Le.endOf(d)},oe=function(ve,De){return H.w(J.toDate()[ve].apply(J.toDate("s"),(ie?[0,0,0,0]:[23,59,59,999]).slice(De)),J)},U=this.$W,be=this.$M,ge=this.$D,fe="set"+(this.$u?"UTC":"");switch(F){case b:return ie?Y(1,0):Y(31,11);case f:return ie?Y(1,be):Y(0,be+1);case h:var Ee=this.$locale().weekStart||0,Ae=(U<Ee?U+7:U)-Ee;return Y(ie?ge-Ae:ge+(6-Ae),be);case d:case y:return oe(fe+"Hours",0);case u:return oe(fe+"Minutes",1);case l:return oe(fe+"Seconds",2);case o:return oe(fe+"Milliseconds",3);default:return this.clone()}},X.endOf=function($){return this.startOf($,!1)},X.$set=function($,Q){var J,ie=H.p($),F="set"+(this.$u?"UTC":""),Y=(J={},J[d]=F+"Date",J[y]=F+"Date",J[f]=F+"Month",J[b]=F+"FullYear",J[u]=F+"Hours",J[l]=F+"Minutes",J[o]=F+"Seconds",J[i]=F+"Milliseconds",J)[ie],oe=ie===d?this.$D+(Q-this.$W):Q;if(ie===f||ie===b){var U=this.clone().set(y,1);U.$d[Y](oe),U.init(),this.$d=U.set(y,Math.min(this.$D,U.daysInMonth())).$d}else Y&&this.$d[Y](oe);return this.init(),this},X.set=function($,Q){return this.clone().$set($,Q)},X.get=function($){return this[H.p($)]()},X.add=function($,Q){var J,ie=this;$=Number($);var F=H.p(Q),Y=function(be){var ge=B(ie);return H.w(ge.date(ge.date()+Math.round(be*$)),ie)};if(F===f)return this.set(f,this.$M+$);if(F===b)return this.set(b,this.$y+$);if(F===d)return Y(1);if(F===h)return Y(7);var oe=(J={},J[l]=r,J[u]=a,J[o]=n,J)[F]||1,U=this.$d.getTime()+$*oe;return H.w(U,this)},X.subtract=function($,Q){return this.add(-1*$,Q)},X.format=function($){var Q=this,J=this.$locale();if(!this.isValid())return J.invalidDate||v;var ie=$||"YYYY-MM-DDTHH:mm:ssZ",F=H.z(this),Y=this.$H,oe=this.$m,U=this.$M,be=J.weekdays,ge=J.months,fe=J.meridiem,Ee=function(De,Le,rt,Xe){return De&&(De[Le]||De(Q,ie))||rt[Le].slice(0,Xe)},Ae=function(De){return H.s(Y%12||12,De,"0")},ve=fe||function(De,Le,rt){var Xe=De<12?"AM":"PM";return rt?Xe.toLowerCase():Xe};return ie.replace(S,(function(De,Le){return Le||(function(rt){switch(rt){case"YY":return String(Q.$y).slice(-2);case"YYYY":return H.s(Q.$y,4,"0");case"M":return U+1;case"MM":return H.s(U+1,2,"0");case"MMM":return Ee(J.monthsShort,U,ge,3);case"MMMM":return Ee(ge,U);case"D":return Q.$D;case"DD":return H.s(Q.$D,2,"0");case"d":return String(Q.$W);case"dd":return Ee(J.weekdaysMin,Q.$W,be,2);case"ddd":return Ee(J.weekdaysShort,Q.$W,be,3);case"dddd":return be[Q.$W];case"H":return String(Y);case"HH":return H.s(Y,2,"0");case"h":return Ae(1);case"hh":return Ae(2);case"a":return ve(Y,oe,!0);case"A":return ve(Y,oe,!1);case"m":return String(oe);case"mm":return H.s(oe,2,"0");case"s":return String(Q.$s);case"ss":return H.s(Q.$s,2,"0");case"SSS":return H.s(Q.$ms,3,"0");case"Z":return F}return null})(De)||F.replace(":","")}))},X.utcOffset=function(){return 15*-Math.round(this.$d.getTimezoneOffset()/15)},X.diff=function($,Q,J){var ie,F=this,Y=H.p(Q),oe=B($),U=(oe.utcOffset()-this.utcOffset())*r,be=this-oe,ge=function(){return H.m(F,oe)};switch(Y){case b:ie=ge()/12;break;case f:ie=ge();break;case m:ie=ge()/3;break;case h:ie=(be-U)/6048e5;break;case d:ie=(be-U)/864e5;break;case u:ie=be/a;break;case l:ie=be/r;break;case o:ie=be/n;break;default:ie=be}return J?ie:H.a(ie)},X.daysInMonth=function(){return this.endOf(f).$D},X.$locale=function(){return A[this.$L]},X.locale=function($,Q){if(!$)return this.$L;var J=this.clone(),ie=G($,Q,!0);return ie&&(J.$L=ie),J},X.clone=function(){return H.w(this.$d,this)},X.toDate=function(){return new Date(this.valueOf())},X.toJSON=function(){return this.isValid()?this.toISOString():null},X.toISOString=function(){return this.$d.toISOString()},X.toString=function(){return this.$d.toUTCString()},q})(),V=Z.prototype;return B.prototype=V,[["$ms",i],["$s",o],["$m",l],["$H",u],["$W",d],["$M",f],["$y",b],["$D",y]].forEach((function(q){V[q[1]]=function(X){return this.$g(X,q[0],q[1])}})),B.extend=function(q,X){return q.$i||(q(X,Z,B),q.$i=!0),B},B.locale=G,B.isDayjs=P,B.unix=function(q){return B(1e3*q)},B.en=A[L],B.Ls=A,B.p={},B}))})(M0)),M0.exports}var ace=rce();const ice=qh(ace);var t9=Object.defineProperty,N=(e,t)=>t9(e,"name",{value:t,configurable:!0}),oce=(e,t)=>{for(var n in t)t9(e,n,{get:t[n],enumerable:!0})},fo={trace:0,debug:1,info:2,warn:3,error:4,fatal:5},we={trace:N((...e)=>{},"trace"),debug:N((...e)=>{},"debug"),info:N((...e)=>{},"info"),warn:N((...e)=>{},"warn"),error:N((...e)=>{},"error"),fatal:N((...e)=>{},"fatal")},h_=N(function(e="fatal"){let t=fo.fatal;typeof e=="string"?e.toLowerCase()in fo&&(t=fo[e]):typeof e=="number"&&(t=e),we.trace=()=>{},we.debug=()=>{},we.info=()=>{},we.warn=()=>{},we.error=()=>{},we.fatal=()=>{},t<=fo.fatal&&(we.fatal=console.error?console.error.bind(console,Ba("FATAL"),"color: orange"):console.log.bind(console,"\x1B[35m",Ba("FATAL"))),t<=fo.error&&(we.error=console.error?console.error.bind(console,Ba("ERROR"),"color: orange"):console.log.bind(console,"\x1B[31m",Ba("ERROR"))),t<=fo.warn&&(we.warn=console.warn?console.warn.bind(console,Ba("WARN"),"color: orange"):console.log.bind(console,"\x1B[33m",Ba("WARN"))),t<=fo.info&&(we.info=console.info?console.info.bind(console,Ba("INFO"),"color: lightblue"):console.log.bind(console,"\x1B[34m",Ba("INFO"))),t<=fo.debug&&(we.debug=console.debug?console.debug.bind(console,Ba("DEBUG"),"color: lightgreen"):console.log.bind(console,"\x1B[32m",Ba("DEBUG"))),t<=fo.trace&&(we.trace=console.debug?console.debug.bind(console,Ba("TRACE"),"color: lightgreen"):console.log.bind(console,"\x1B[32m",Ba("TRACE")))},"setLogLevel"),Ba=N(e=>`%c${ice().format("ss.SSS")} : ${e} : `,"format");const B0={min:{r:0,g:0,b:0,s:0,l:0,a:0},max:{r:255,g:255,b:255,h:360,s:100,l:100,a:1},clamp:{r:e=>e>=255?255:e<0?0:e,g:e=>e>=255?255:e<0?0:e,b:e=>e>=255?255:e<0?0:e,h:e=>e%360,s:e=>e>=100?100:e<0?0:e,l:e=>e>=100?100:e<0?0:e,a:e=>e>=1?1:e<0?0:e},toLinear:e=>{const t=e/255;return e>.03928?Math.pow((t+.055)/1.055,2.4):t/12.92},hue2rgb:(e,t,n)=>(n<0&&(n+=1),n>1&&(n-=1),n<1/6?e+(t-e)*6*n:n<1/2?t:n<2/3?e+(t-e)*(2/3-n)*6:e),hsl2rgb:({h:e,s:t,l:n},r)=>{if(!t)return n*2.55;e/=360,t/=100,n/=100;const a=n<.5?n*(1+t):n+t-n*t,i=2*n-a;switch(r){case"r":return B0.hue2rgb(i,a,e+1/3)*255;case"g":return B0.hue2rgb(i,a,e)*255;case"b":return B0.hue2rgb(i,a,e-1/3)*255}},rgb2hsl:({r:e,g:t,b:n},r)=>{e/=255,t/=255,n/=255;const a=Math.max(e,t,n),i=Math.min(e,t,n),o=(a+i)/2;if(r==="l")return o*100;if(a===i)return 0;const l=a-i,u=o>.5?l/(2-a-i):l/(a+i);if(r==="s")return u*100;switch(a){case e:return((t-n)/l+(t<n?6:0))*60;case t:return((n-e)/l+2)*60;case n:return((e-t)/l+4)*60;default:return-1}}},sce={clamp:(e,t,n)=>t>n?Math.min(t,Math.max(n,e)):Math.min(n,Math.max(t,e)),round:e=>Math.round(e*1e10)/1e10},lce={dec2hex:e=>{const t=Math.round(e).toString(16);return t.length>1?t:`0${t}`}},pt={channel:B0,lang:sce,unit:lce},ps={};for(let e=0;e<=255;e++)ps[e]=pt.unit.dec2hex(e);const hr={ALL:0,RGB:1,HSL:2};class cce{constructor(){this.type=hr.ALL}get(){return this.type}set(t){if(this.type&&this.type!==t)throw new Error("Cannot change both RGB and HSL channels at the same time");this.type=t}reset(){this.type=hr.ALL}is(t){return this.type===t}}class uce{constructor(t,n){this.color=n,this.changed=!1,this.data=t,this.type=new cce}set(t,n){return this.color=n,this.changed=!1,this.data=t,this.type.type=hr.ALL,this}_ensureHSL(){const t=this.data,{h:n,s:r,l:a}=t;n===void 0&&(t.h=pt.channel.rgb2hsl(t,"h")),r===void 0&&(t.s=pt.channel.rgb2hsl(t,"s")),a===void 0&&(t.l=pt.channel.rgb2hsl(t,"l"))}_ensureRGB(){const t=this.data,{r:n,g:r,b:a}=t;n===void 0&&(t.r=pt.channel.hsl2rgb(t,"r")),r===void 0&&(t.g=pt.channel.hsl2rgb(t,"g")),a===void 0&&(t.b=pt.channel.hsl2rgb(t,"b"))}get r(){const t=this.data,n=t.r;return!this.type.is(hr.HSL)&&n!==void 0?n:(this._ensureHSL(),pt.channel.hsl2rgb(t,"r"))}get g(){const t=this.data,n=t.g;return!this.type.is(hr.HSL)&&n!==void 0?n:(this._ensureHSL(),pt.channel.hsl2rgb(t,"g"))}get b(){const t=this.data,n=t.b;return!this.type.is(hr.HSL)&&n!==void 0?n:(this._ensureHSL(),pt.channel.hsl2rgb(t,"b"))}get h(){const t=this.data,n=t.h;return!this.type.is(hr.RGB)&&n!==void 0?n:(this._ensureRGB(),pt.channel.rgb2hsl(t,"h"))}get s(){const t=this.data,n=t.s;return!this.type.is(hr.RGB)&&n!==void 0?n:(this._ensureRGB(),pt.channel.rgb2hsl(t,"s"))}get l(){const t=this.data,n=t.l;return!this.type.is(hr.RGB)&&n!==void 0?n:(this._ensureRGB(),pt.channel.rgb2hsl(t,"l"))}get a(){return this.data.a}set r(t){this.type.set(hr.RGB),this.changed=!0,this.data.r=t}set g(t){this.type.set(hr.RGB),this.changed=!0,this.data.g=t}set b(t){this.type.set(hr.RGB),this.changed=!0,this.data.b=t}set h(t){this.type.set(hr.HSL),this.changed=!0,this.data.h=t}set s(t){this.type.set(hr.HSL),this.changed=!0,this.data.s=t}set l(t){this.type.set(hr.HSL),this.changed=!0,this.data.l=t}set a(t){this.changed=!0,this.data.a=t}}const $g=new uce({r:0,g:0,b:0,a:0},"transparent"),$c={re:/^#((?:[a-f0-9]{2}){2,4}|[a-f0-9]{3})$/i,parse:e=>{if(e.charCodeAt(0)!==35)return;const t=e.match($c.re);if(!t)return;const n=t[1],r=parseInt(n,16),a=n.length,i=a%4===0,o=a>4,l=o?1:17,u=o?8:4,d=i?0:-1,h=o?255:15;return $g.set({r:(r>>u*(d+3)&h)*l,g:(r>>u*(d+2)&h)*l,b:(r>>u*(d+1)&h)*l,a:i?(r&h)*l/255:1},e)},stringify:e=>{const{r:t,g:n,b:r,a}=e;return a<1?`#${ps[Math.round(t)]}${ps[Math.round(n)]}${ps[Math.round(r)]}${ps[Math.round(a*255)]}`:`#${ps[Math.round(t)]}${ps[Math.round(n)]}${ps[Math.round(r)]}`}},ul={re:/^hsla?\(\s*?(-?(?:\d+(?:\.\d+)?|(?:\.\d+))(?:e-?\d+)?(?:deg|grad|rad|turn)?)\s*?(?:,|\s)\s*?(-?(?:\d+(?:\.\d+)?|(?:\.\d+))(?:e-?\d+)?%)\s*?(?:,|\s)\s*?(-?(?:\d+(?:\.\d+)?|(?:\.\d+))(?:e-?\d+)?%)(?:\s*?(?:,|\/)\s*?\+?(-?(?:\d+(?:\.\d+)?|(?:\.\d+))(?:e-?\d+)?(%)?))?\s*?\)$/i,hueRe:/^(.+?)(deg|grad|rad|turn)$/i,_hue2deg:e=>{const t=e.match(ul.hueRe);if(t){const[,n,r]=t;switch(r){case"grad":return pt.channel.clamp.h(parseFloat(n)*.9);case"rad":return pt.channel.clamp.h(parseFloat(n)*180/Math.PI);case"turn":return pt.channel.clamp.h(parseFloat(n)*360)}}return pt.channel.clamp.h(parseFloat(e))},parse:e=>{const t=e.charCodeAt(0);if(t!==104&&t!==72)return;const n=e.match(ul.re);if(!n)return;const[,r,a,i,o,l]=n;return $g.set({h:ul._hue2deg(r),s:pt.channel.clamp.s(parseFloat(a)),l:pt.channel.clamp.l(parseFloat(i)),a:o?pt.channel.clamp.a(l?parseFloat(o)/100:parseFloat(o)):1},e)},stringify:e=>{const{h:t,s:n,l:r,a}=e;return a<1?`hsla(${pt.lang.round(t)}, ${pt.lang.round(n)}%, ${pt.lang.round(r)}%, ${a})`:`hsl(${pt.lang.round(t)}, ${pt.lang.round(n)}%, ${pt.lang.round(r)}%)`}},hh={colors:{aliceblue:"#f0f8ff",antiquewhite:"#faebd7",aqua:"#00ffff",aquamarine:"#7fffd4",azure:"#f0ffff",beige:"#f5f5dc",bisque:"#ffe4c4",black:"#000000",blanchedalmond:"#ffebcd",blue:"#0000ff",blueviolet:"#8a2be2",brown:"#a52a2a",burlywood:"#deb887",cadetblue:"#5f9ea0",chartreuse:"#7fff00",chocolate:"#d2691e",coral:"#ff7f50",cornflowerblue:"#6495ed",cornsilk:"#fff8dc",crimson:"#dc143c",cyanaqua:"#00ffff",darkblue:"#00008b",darkcyan:"#008b8b",darkgoldenrod:"#b8860b",darkgray:"#a9a9a9",darkgreen:"#006400",darkgrey:"#a9a9a9",darkkhaki:"#bdb76b",darkmagenta:"#8b008b",darkolivegreen:"#556b2f",darkorange:"#ff8c00",darkorchid:"#9932cc",darkred:"#8b0000",darksalmon:"#e9967a",darkseagreen:"#8fbc8f",darkslateblue:"#483d8b",darkslategray:"#2f4f4f",darkslategrey:"#2f4f4f",darkturquoise:"#00ced1",darkviolet:"#9400d3",deeppink:"#ff1493",deepskyblue:"#00bfff",dimgray:"#696969",dimgrey:"#696969",dodgerblue:"#1e90ff",firebrick:"#b22222",floralwhite:"#fffaf0",forestgreen:"#228b22",fuchsia:"#ff00ff",gainsboro:"#dcdcdc",ghostwhite:"#f8f8ff",gold:"#ffd700",goldenrod:"#daa520",gray:"#808080",green:"#008000",greenyellow:"#adff2f",grey:"#808080",honeydew:"#f0fff0",hotpink:"#ff69b4",indianred:"#cd5c5c",indigo:"#4b0082",ivory:"#fffff0",khaki:"#f0e68c",lavender:"#e6e6fa",lavenderblush:"#fff0f5",lawngreen:"#7cfc00",lemonchiffon:"#fffacd",lightblue:"#add8e6",lightcoral:"#f08080",lightcyan:"#e0ffff",lightgoldenrodyellow:"#fafad2",lightgray:"#d3d3d3",lightgreen:"#90ee90",lightgrey:"#d3d3d3",lightpink:"#ffb6c1",lightsalmon:"#ffa07a",lightseagreen:"#20b2aa",lightskyblue:"#87cefa",lightslategray:"#778899",lightslategrey:"#778899",lightsteelblue:"#b0c4de",lightyellow:"#ffffe0",lime:"#00ff00",limegreen:"#32cd32",linen:"#faf0e6",magenta:"#ff00ff",maroon:"#800000",mediumaquamarine:"#66cdaa",mediumblue:"#0000cd",mediumorchid:"#ba55d3",mediumpurple:"#9370db",mediumseagreen:"#3cb371",mediumslateblue:"#7b68ee",mediumspringgreen:"#00fa9a",mediumturquoise:"#48d1cc",mediumvioletred:"#c71585",midnightblue:"#191970",mintcream:"#f5fffa",mistyrose:"#ffe4e1",moccasin:"#ffe4b5",navajowhite:"#ffdead",navy:"#000080",oldlace:"#fdf5e6",olive:"#808000",olivedrab:"#6b8e23",orange:"#ffa500",orangered:"#ff4500",orchid:"#da70d6",palegoldenrod:"#eee8aa",palegreen:"#98fb98",paleturquoise:"#afeeee",palevioletred:"#db7093",papayawhip:"#ffefd5",peachpuff:"#ffdab9",peru:"#cd853f",pink:"#ffc0cb",plum:"#dda0dd",powderblue:"#b0e0e6",purple:"#800080",rebeccapurple:"#663399",red:"#ff0000",rosybrown:"#bc8f8f",royalblue:"#4169e1",saddlebrown:"#8b4513",salmon:"#fa8072",sandybrown:"#f4a460",seagreen:"#2e8b57",seashell:"#fff5ee",sienna:"#a0522d",silver:"#c0c0c0",skyblue:"#87ceeb",slateblue:"#6a5acd",slategray:"#708090",slategrey:"#708090",snow:"#fffafa",springgreen:"#00ff7f",tan:"#d2b48c",teal:"#008080",thistle:"#d8bfd8",transparent:"#00000000",turquoise:"#40e0d0",violet:"#ee82ee",wheat:"#f5deb3",white:"#ffffff",whitesmoke:"#f5f5f5",yellow:"#ffff00",yellowgreen:"#9acd32"},parse:e=>{e=e.toLowerCase();const t=hh.colors[e];if(t)return $c.parse(t)},stringify:e=>{const t=$c.stringify(e);for(const n in hh.colors)if(hh.colors[n]===t)return n}},Jd={re:/^rgba?\(\s*?(-?(?:\d+(?:\.\d+)?|(?:\.\d+))(?:e\d+)?(%?))\s*?(?:,|\s)\s*?(-?(?:\d+(?:\.\d+)?|(?:\.\d+))(?:e\d+)?(%?))\s*?(?:,|\s)\s*?(-?(?:\d+(?:\.\d+)?|(?:\.\d+))(?:e\d+)?(%?))(?:\s*?(?:,|\/)\s*?\+?(-?(?:\d+(?:\.\d+)?|(?:\.\d+))(?:e\d+)?(%?)))?\s*?\)$/i,parse:e=>{const t=e.charCodeAt(0);if(t!==114&&t!==82)return;const n=e.match(Jd.re);if(!n)return;const[,r,a,i,o,l,u,d,h]=n;return $g.set({r:pt.channel.clamp.r(a?parseFloat(r)*2.55:parseFloat(r)),g:pt.channel.clamp.g(o?parseFloat(i)*2.55:parseFloat(i)),b:pt.channel.clamp.b(u?parseFloat(l)*2.55:parseFloat(l)),a:d?pt.channel.clamp.a(h?parseFloat(d)/100:parseFloat(d)):1},e)},stringify:e=>{const{r:t,g:n,b:r,a}=e;return a<1?`rgba(${pt.lang.round(t)}, ${pt.lang.round(n)}, ${pt.lang.round(r)}, ${pt.lang.round(a)})`:`rgb(${pt.lang.round(t)}, ${pt.lang.round(n)}, ${pt.lang.round(r)})`}},Ni={format:{keyword:hh,hex:$c,rgb:Jd,rgba:Jd,hsl:ul,hsla:ul},parse:e=>{if(typeof e!="string")return e;const t=$c.parse(e)||Jd.parse(e)||ul.parse(e)||hh.parse(e);if(t)return t;throw new Error(`Unsupported color format: "${e}"`)},stringify:e=>!e.changed&&e.color?e.color:e.type.is(hr.HSL)||e.data.r===void 0?ul.stringify(e):e.a<1||!Number.isInteger(e.r)||!Number.isInteger(e.g)||!Number.isInteger(e.b)?Jd.stringify(e):$c.stringify(e)},n9=(e,t)=>{const n=Ni.parse(e);for(const r in t)n[r]=pt.channel.clamp[r](t[r]);return Ni.stringify(n)},ph=(e,t,n=0,r=1)=>{if(typeof e!="number")return n9(e,{a:t});const a=$g.set({r:pt.channel.clamp.r(e),g:pt.channel.clamp.g(t),b:pt.channel.clamp.b(n),a:pt.channel.clamp.a(r)});return Ni.stringify(a)},dce=e=>{const{r:t,g:n,b:r}=Ni.parse(e),a=.2126*pt.channel.toLinear(t)+.7152*pt.channel.toLinear(n)+.0722*pt.channel.toLinear(r);return pt.lang.round(a)},hce=e=>dce(e)>=.5,dp=e=>!hce(e),r9=(e,t,n)=>{const r=Ni.parse(e),a=r[t],i=pt.channel.clamp[t](a+n);return a!==i&&(r[t]=i),Ni.stringify(r)},Ue=(e,t)=>r9(e,"l",t),nt=(e,t)=>r9(e,"l",-t),le=(e,t)=>{const n=Ni.parse(e),r={};for(const a in t)t[a]&&(r[a]=n[a]+t[a]);return n9(e,r)},pce=(e,t,n=50)=>{const{r,g:a,b:i,a:o}=Ni.parse(e),{r:l,g:u,b:d,a:h}=Ni.parse(t),f=n/100,m=f*2-1,b=o-h,v=((m*b===-1?m:(m+b)/(1+m*b))+1)/2,w=1-v,S=r*v+l*w,k=a*v+u*w,R=i*v+d*w,I=o*f+h*(1-f);return ph(S,k,R,I)},Me=(e,t=100)=>{const n=Ni.parse(e);return n.r=255-n.r,n.g=255-n.g,n.b=255-n.b,pce(n,e,t)};/*! @license DOMPurify 3.3.2 | (c) Cure53 and other contributors | Released under the Apache license 2.0 and Mozilla Public License 2.0 | github.com/cure53/DOMPurify/blob/3.3.2/LICENSE */const{entries:a9,setPrototypeOf:r7,isFrozen:fce,getPrototypeOf:mce,getOwnPropertyDescriptor:gce}=Object;let{freeze:Fr,seal:Ga,create:F0}=Object,{apply:Hx,construct:Gx}=typeof Reflect<"u"&&Reflect;Fr||(Fr=function(t){return t});Ga||(Ga=function(t){return t});Hx||(Hx=function(t,n){for(var r=arguments.length,a=new Array(r>2?r-2:0),i=2;i<r;i++)a[i-2]=arguments[i];return t.apply(n,a)});Gx||(Gx=function(t){for(var n=arguments.length,r=new Array(n>1?n-1:0),a=1;a<n;a++)r[a-1]=arguments[a];return new t(...r)});const h0=zr(Array.prototype.forEach),bce=zr(Array.prototype.lastIndexOf),a7=zr(Array.prototype.pop),zd=zr(Array.prototype.push),yce=zr(Array.prototype.splice),z0=zr(String.prototype.toLowerCase),Iv=zr(String.prototype.toString),Lv=zr(String.prototype.match),$d=zr(String.prototype.replace),vce=zr(String.prototype.indexOf),xce=zr(String.prototype.trim),ha=zr(Object.prototype.hasOwnProperty),Nr=zr(RegExp.prototype.test),Pd=Sce(TypeError);function zr(e){return function(t){t instanceof RegExp&&(t.lastIndex=0);for(var n=arguments.length,r=new Array(n>1?n-1:0),a=1;a<n;a++)r[a-1]=arguments[a];return Hx(e,t,r)}}function Sce(e){return function(){for(var t=arguments.length,n=new Array(t),r=0;r<t;r++)n[r]=arguments[r];return Gx(e,n)}}function Ct(e,t){let n=arguments.length>2&&arguments[2]!==void 0?arguments[2]:z0;r7&&r7(e,null);let r=t.length;for(;r--;){let a=t[r];if(typeof a=="string"){const i=n(a);i!==a&&(fce(t)||(t[r]=i),a=i)}e[a]=!0}return e}function wce(e){for(let t=0;t<e.length;t++)ha(e,t)||(e[t]=null);return e}function bi(e){const t=F0(null);for(const[n,r]of a9(e))ha(e,n)&&(Array.isArray(r)?t[n]=wce(r):r&&typeof r=="object"&&r.constructor===Object?t[n]=bi(r):t[n]=r);return t}function Ud(e,t){for(;e!==null;){const r=gce(e,t);if(r){if(r.get)return zr(r.get);if(typeof r.value=="function")return zr(r.value)}e=mce(e)}function n(){return null}return n}const i7=Fr(["a","abbr","acronym","address","area","article","aside","audio","b","bdi","bdo","big","blink","blockquote","body","br","button","canvas","caption","center","cite","code","col","colgroup","content","data","datalist","dd","decorator","del","details","dfn","dialog","dir","div","dl","dt","element","em","fieldset","figcaption","figure","font","footer","form","h1","h2","h3","h4","h5","h6","head","header","hgroup","hr","html","i","img","input","ins","kbd","label","legend","li","main","map","mark","marquee","menu","menuitem","meter","nav","nobr","ol","optgroup","option","output","p","picture","pre","progress","q","rp","rt","ruby","s","samp","search","section","select","shadow","slot","small","source","spacer","span","strike","strong","style","sub","summary","sup","table","tbody","td","template","textarea","tfoot","th","thead","time","tr","track","tt","u","ul","var","video","wbr"]),Dv=Fr(["svg","a","altglyph","altglyphdef","altglyphitem","animatecolor","animatemotion","animatetransform","circle","clippath","defs","desc","ellipse","enterkeyhint","exportparts","filter","font","g","glyph","glyphref","hkern","image","inputmode","line","lineargradient","marker","mask","metadata","mpath","part","path","pattern","polygon","polyline","radialgradient","rect","stop","style","switch","symbol","text","textpath","title","tref","tspan","view","vkern"]),Mv=Fr(["feBlend","feColorMatrix","feComponentTransfer","feComposite","feConvolveMatrix","feDiffuseLighting","feDisplacementMap","feDistantLight","feDropShadow","feFlood","feFuncA","feFuncB","feFuncG","feFuncR","feGaussianBlur","feImage","feMerge","feMergeNode","feMorphology","feOffset","fePointLight","feSpecularLighting","feSpotLight","feTile","feTurbulence"]),Ece=Fr(["animate","color-profile","cursor","discard","font-face","font-face-format","font-face-name","font-face-src","font-face-uri","foreignobject","hatch","hatchpath","mesh","meshgradient","meshpatch","meshrow","missing-glyph","script","set","solidcolor","unknown","use"]),Bv=Fr(["math","menclose","merror","mfenced","mfrac","mglyph","mi","mlabeledtr","mmultiscripts","mn","mo","mover","mpadded","mphantom","mroot","mrow","ms","mspace","msqrt","mstyle","msub","msup","msubsup","mtable","mtd","mtext","mtr","munder","munderover","mprescripts"]),kce=Fr(["maction","maligngroup","malignmark","mlongdiv","mscarries","mscarry","msgroup","mstack","msline","msrow","semantics","annotation","annotation-xml","mprescripts","none"]),o7=Fr(["#text"]),s7=Fr(["accept","action","align","alt","autocapitalize","autocomplete","autopictureinpicture","autoplay","background","bgcolor","border","capture","cellpadding","cellspacing","checked","cite","class","clear","color","cols","colspan","controls","controlslist","coords","crossorigin","datetime","decoding","default","dir","disabled","disablepictureinpicture","disableremoteplayback","download","draggable","enctype","enterkeyhint","exportparts","face","for","headers","height","hidden","high","href","hreflang","id","inert","inputmode","integrity","ismap","kind","label","lang","list","loading","loop","low","max","maxlength","media","method","min","minlength","multiple","muted","name","nonce","noshade","novalidate","nowrap","open","optimum","part","pattern","placeholder","playsinline","popover","popovertarget","popovertargetaction","poster","preload","pubdate","radiogroup","readonly","rel","required","rev","reversed","role","rows","rowspan","spellcheck","scope","selected","shape","size","sizes","slot","span","srclang","start","src","srcset","step","style","summary","tabindex","title","translate","type","usemap","valign","value","width","wrap","xmlns","slot"]),Fv=Fr(["accent-height","accumulate","additive","alignment-baseline","amplitude","ascent","attributename","attributetype","azimuth","basefrequency","baseline-shift","begin","bias","by","class","clip","clippathunits","clip-path","clip-rule","color","color-interpolation","color-interpolation-filters","color-profile","color-rendering","cx","cy","d","dx","dy","diffuseconstant","direction","display","divisor","dur","edgemode","elevation","end","exponent","fill","fill-opacity","fill-rule","filter","filterunits","flood-color","flood-opacity","font-family","font-size","font-size-adjust","font-stretch","font-style","font-variant","font-weight","fx","fy","g1","g2","glyph-name","glyphref","gradientunits","gradienttransform","height","href","id","image-rendering","in","in2","intercept","k","k1","k2","k3","k4","kerning","keypoints","keysplines","keytimes","lang","lengthadjust","letter-spacing","kernelmatrix","kernelunitlength","lighting-color","local","marker-end","marker-mid","marker-start","markerheight","markerunits","markerwidth","maskcontentunits","maskunits","max","mask","mask-type","media","method","mode","min","name","numoctaves","offset","operator","opacity","order","orient","orientation","origin","overflow","paint-order","path","pathlength","patterncontentunits","patterntransform","patternunits","points","preservealpha","preserveaspectratio","primitiveunits","r","rx","ry","radius","refx","refy","repeatcount","repeatdur","restart","result","rotate","scale","seed","shape-rendering","slope","specularconstant","specularexponent","spreadmethod","startoffset","stddeviation","stitchtiles","stop-color","stop-opacity","stroke-dasharray","stroke-dashoffset","stroke-linecap","stroke-linejoin","stroke-miterlimit","stroke-opacity","stroke","stroke-width","style","surfacescale","systemlanguage","tabindex","tablevalues","targetx","targety","transform","transform-origin","text-anchor","text-decoration","text-rendering","textlength","type","u1","u2","unicode","values","viewbox","visibility","version","vert-adv-y","vert-origin-x","vert-origin-y","width","word-spacing","wrap","writing-mode","xchannelselector","ychannelselector","x","x1","x2","xmlns","y","y1","y2","z","zoomandpan"]),l7=Fr(["accent","accentunder","align","bevelled","close","columnsalign","columnlines","columnspan","denomalign","depth","dir","display","displaystyle","encoding","fence","frame","height","href","id","largeop","length","linethickness","lspace","lquote","mathbackground","mathcolor","mathsize","mathvariant","maxsize","minsize","movablelimits","notation","numalign","open","rowalign","rowlines","rowspacing","rowspan","rspace","rquote","scriptlevel","scriptminsize","scriptsizemultiplier","selection","separator","separators","stretchy","subscriptshift","supscriptshift","symmetric","voffset","width","xmlns"]),p0=Fr(["xlink:href","xml:id","xlink:title","xml:space","xmlns:xlink"]),Tce=Ga(/\{\{[\w\W]*|[\w\W]*\}\}/gm),_ce=Ga(/<%[\w\W]*|[\w\W]*%>/gm),Cce=Ga(/\$\{[\w\W]*/gm),Ace=Ga(/^data-[\-\w.\u00B7-\uFFFF]+$/),Rce=Ga(/^aria-[\-\w]+$/),i9=Ga(/^(?:(?:(?:f|ht)tps?|mailto|tel|callto|sms|cid|xmpp|matrix):|[^a-z]|[a-z+.\-]+(?:[^a-z+.\-:]|$))/i),Nce=Ga(/^(?:\w+script|data):/i),Oce=Ga(/[\u0000-\u0020\u00A0\u1680\u180E\u2000-\u2029\u205F\u3000]/g),o9=Ga(/^html$/i),Ice=Ga(/^[a-z][.\w]*(-[.\w]+)+$/i);var c7=Object.freeze({__proto__:null,ARIA_ATTR:Rce,ATTR_WHITESPACE:Oce,CUSTOM_ELEMENT:Ice,DATA_ATTR:Ace,DOCTYPE_NAME:o9,ERB_EXPR:_ce,IS_ALLOWED_URI:i9,IS_SCRIPT_OR_DATA:Nce,MUSTACHE_EXPR:Tce,TMPLIT_EXPR:Cce});const jd={element:1,text:3,progressingInstruction:7,comment:8,document:9},Lce=function(){return typeof window>"u"?null:window},Dce=function(t,n){if(typeof t!="object"||typeof t.createPolicy!="function")return null;let r=null;const a="data-tt-policy-suffix";n&&n.hasAttribute(a)&&(r=n.getAttribute(a));const i="dompurify"+(r?"#"+r:"");try{return t.createPolicy(i,{createHTML(o){return o},createScriptURL(o){return o}})}catch{return console.warn("TrustedTypes policy "+i+" could not be created."),null}},u7=function(){return{afterSanitizeAttributes:[],afterSanitizeElements:[],afterSanitizeShadowDOM:[],beforeSanitizeAttributes:[],beforeSanitizeElements:[],beforeSanitizeShadowDOM:[],uponSanitizeAttribute:[],uponSanitizeElement:[],uponSanitizeShadowNode:[]}};function s9(){let e=arguments.length>0&&arguments[0]!==void 0?arguments[0]:Lce();const t=Ke=>s9(Ke);if(t.version="3.3.2",t.removed=[],!e||!e.document||e.document.nodeType!==jd.document||!e.Element)return t.isSupported=!1,t;let{document:n}=e;const r=n,a=r.currentScript,{DocumentFragment:i,HTMLTemplateElement:o,Node:l,Element:u,NodeFilter:d,NamedNodeMap:h=e.NamedNodeMap||e.MozNamedAttrMap,HTMLFormElement:f,DOMParser:m,trustedTypes:b}=e,y=u.prototype,v=Ud(y,"cloneNode"),w=Ud(y,"remove"),S=Ud(y,"nextSibling"),k=Ud(y,"childNodes"),R=Ud(y,"parentNode");if(typeof o=="function"){const Ke=n.createElement("template");Ke.content&&Ke.content.ownerDocument&&(n=Ke.content.ownerDocument)}let I,L="";const{implementation:A,createNodeIterator:M,createDocumentFragment:P,getElementsByTagName:G}=n,{importNode:B}=r;let H=u7();t.isSupported=typeof a9=="function"&&typeof R=="function"&&A&&A.createHTMLDocument!==void 0;const{MUSTACHE_EXPR:Z,ERB_EXPR:V,TMPLIT_EXPR:q,DATA_ATTR:X,ARIA_ATTR:$,IS_SCRIPT_OR_DATA:Q,ATTR_WHITESPACE:J,CUSTOM_ELEMENT:ie}=c7;let{IS_ALLOWED_URI:F}=c7,Y=null;const oe=Ct({},[...i7,...Dv,...Mv,...Bv,...o7]);let U=null;const be=Ct({},[...s7,...Fv,...l7,...p0]);let ge=Object.seal(F0(null,{tagNameCheck:{writable:!0,configurable:!1,enumerable:!0,value:null},attributeNameCheck:{writable:!0,configurable:!1,enumerable:!0,value:null},allowCustomizedBuiltInElements:{writable:!0,configurable:!1,enumerable:!0,value:!1}})),fe=null,Ee=null;const Ae=Object.seal(F0(null,{tagCheck:{writable:!0,configurable:!1,enumerable:!0,value:null},attributeCheck:{writable:!0,configurable:!1,enumerable:!0,value:null}}));let ve=!0,De=!0,Le=!1,rt=!0,Xe=!1,gt=!0,Xt=!1,er=!1,Tr=!1,Hn=!1,Cn=!1,Zn=!1,wa=!0,di=!1;const qe="user-content-";let yt=!0,ur=!1,me={},Te=null;const We=Ct({},["annotation-xml","audio","colgroup","desc","foreignobject","head","iframe","math","mi","mn","mo","ms","mtext","noembed","noframes","noscript","plaintext","script","style","svg","template","thead","title","video","xmp"]);let ut=null;const It=Ct({},["audio","video","img","source","image","track"]);let En=null;const _r=Ct({},["alt","class","for","id","label","name","pattern","placeholder","role","summary","title","value","style","xmlns"]),In="http://www.w3.org/1998/Math/MathML",hn="http://www.w3.org/2000/svg",pn="http://www.w3.org/1999/xhtml";let zt=pn,Ea=!1,Cr=null;const wb=Ct({},[In,hn,pn],Iv);let Hi=Ct({},["mi","mo","mn","ms","mtext"]),Gi=Ct({},["annotation-xml"]);const zl=Ct({},["title","style","font","a","script"]);let na=null;const $l=["application/xhtml+xml","text/html"],Fs="text/html";let An=null,qi=null;const Mu=n.createElement("form"),Fo=function(re){return re instanceof RegExp||re instanceof Function},Bu=function(){let re=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{};if(!(qi&&qi===re)){if((!re||typeof re!="object")&&(re={}),re=bi(re),na=$l.indexOf(re.PARSER_MEDIA_TYPE)===-1?Fs:re.PARSER_MEDIA_TYPE,An=na==="application/xhtml+xml"?Iv:z0,Y=ha(re,"ALLOWED_TAGS")?Ct({},re.ALLOWED_TAGS,An):oe,U=ha(re,"ALLOWED_ATTR")?Ct({},re.ALLOWED_ATTR,An):be,Cr=ha(re,"ALLOWED_NAMESPACES")?Ct({},re.ALLOWED_NAMESPACES,Iv):wb,En=ha(re,"ADD_URI_SAFE_ATTR")?Ct(bi(_r),re.ADD_URI_SAFE_ATTR,An):_r,ut=ha(re,"ADD_DATA_URI_TAGS")?Ct(bi(It),re.ADD_DATA_URI_TAGS,An):It,Te=ha(re,"FORBID_CONTENTS")?Ct({},re.FORBID_CONTENTS,An):We,fe=ha(re,"FORBID_TAGS")?Ct({},re.FORBID_TAGS,An):bi({}),Ee=ha(re,"FORBID_ATTR")?Ct({},re.FORBID_ATTR,An):bi({}),me=ha(re,"USE_PROFILES")?re.USE_PROFILES:!1,ve=re.ALLOW_ARIA_ATTR!==!1,De=re.ALLOW_DATA_ATTR!==!1,Le=re.ALLOW_UNKNOWN_PROTOCOLS||!1,rt=re.ALLOW_SELF_CLOSE_IN_ATTR!==!1,Xe=re.SAFE_FOR_TEMPLATES||!1,gt=re.SAFE_FOR_XML!==!1,Xt=re.WHOLE_DOCUMENT||!1,Hn=re.RETURN_DOM||!1,Cn=re.RETURN_DOM_FRAGMENT||!1,Zn=re.RETURN_TRUSTED_TYPE||!1,Tr=re.FORCE_BODY||!1,wa=re.SANITIZE_DOM!==!1,di=re.SANITIZE_NAMED_PROPS||!1,yt=re.KEEP_CONTENT!==!1,ur=re.IN_PLACE||!1,F=re.ALLOWED_URI_REGEXP||i9,zt=re.NAMESPACE||pn,Hi=re.MATHML_TEXT_INTEGRATION_POINTS||Hi,Gi=re.HTML_INTEGRATION_POINTS||Gi,ge=re.CUSTOM_ELEMENT_HANDLING||{},re.CUSTOM_ELEMENT_HANDLING&&Fo(re.CUSTOM_ELEMENT_HANDLING.tagNameCheck)&&(ge.tagNameCheck=re.CUSTOM_ELEMENT_HANDLING.tagNameCheck),re.CUSTOM_ELEMENT_HANDLING&&Fo(re.CUSTOM_ELEMENT_HANDLING.attributeNameCheck)&&(ge.attributeNameCheck=re.CUSTOM_ELEMENT_HANDLING.attributeNameCheck),re.CUSTOM_ELEMENT_HANDLING&&typeof re.CUSTOM_ELEMENT_HANDLING.allowCustomizedBuiltInElements=="boolean"&&(ge.allowCustomizedBuiltInElements=re.CUSTOM_ELEMENT_HANDLING.allowCustomizedBuiltInElements),Xe&&(De=!1),Cn&&(Hn=!0),me&&(Y=Ct({},o7),U=F0(null),me.html===!0&&(Ct(Y,i7),Ct(U,s7)),me.svg===!0&&(Ct(Y,Dv),Ct(U,Fv),Ct(U,p0)),me.svgFilters===!0&&(Ct(Y,Mv),Ct(U,Fv),Ct(U,p0)),me.mathMl===!0&&(Ct(Y,Bv),Ct(U,l7),Ct(U,p0))),ha(re,"ADD_TAGS")||(Ae.tagCheck=null),ha(re,"ADD_ATTR")||(Ae.attributeCheck=null),re.ADD_TAGS&&(typeof re.ADD_TAGS=="function"?Ae.tagCheck=re.ADD_TAGS:(Y===oe&&(Y=bi(Y)),Ct(Y,re.ADD_TAGS,An))),re.ADD_ATTR&&(typeof re.ADD_ATTR=="function"?Ae.attributeCheck=re.ADD_ATTR:(U===be&&(U=bi(U)),Ct(U,re.ADD_ATTR,An))),re.ADD_URI_SAFE_ATTR&&Ct(En,re.ADD_URI_SAFE_ATTR,An),re.FORBID_CONTENTS&&(Te===We&&(Te=bi(Te)),Ct(Te,re.FORBID_CONTENTS,An)),re.ADD_FORBID_CONTENTS&&(Te===We&&(Te=bi(Te)),Ct(Te,re.ADD_FORBID_CONTENTS,An)),yt&&(Y["#text"]=!0),Xt&&Ct(Y,["html","head","body"]),Y.table&&(Ct(Y,["tbody"]),delete fe.tbody),re.TRUSTED_TYPES_POLICY){if(typeof re.TRUSTED_TYPES_POLICY.createHTML!="function")throw Pd('TRUSTED_TYPES_POLICY configuration option must provide a "createHTML" hook.');if(typeof re.TRUSTED_TYPES_POLICY.createScriptURL!="function")throw Pd('TRUSTED_TYPES_POLICY configuration option must provide a "createScriptURL" hook.');I=re.TRUSTED_TYPES_POLICY,L=I.createHTML("")}else I===void 0&&(I=Dce(b,a)),I!==null&&typeof L=="string"&&(L=I.createHTML(""));Fr&&Fr(re),qi=re}},Fu=Ct({},[...Dv,...Mv,...Ece]),zu=Ct({},[...Bv,...kce]),_p=function(re){let _e=R(re);(!_e||!_e.tagName)&&(_e={namespaceURI:zt,tagName:"template"});const $e=z0(re.tagName),Vt=z0(_e.tagName);return Cr[re.namespaceURI]?re.namespaceURI===hn?_e.namespaceURI===pn?$e==="svg":_e.namespaceURI===In?$e==="svg"&&(Vt==="annotation-xml"||Hi[Vt]):!!Fu[$e]:re.namespaceURI===In?_e.namespaceURI===pn?$e==="math":_e.namespaceURI===hn?$e==="math"&&Gi[Vt]:!!zu[$e]:re.namespaceURI===pn?_e.namespaceURI===hn&&!Gi[Vt]||_e.namespaceURI===In&&!Hi[Vt]?!1:!zu[$e]&&(zl[$e]||!Fu[$e]):!!(na==="application/xhtml+xml"&&Cr[re.namespaceURI]):!1},Ur=function(re){zd(t.removed,{element:re});try{R(re).removeChild(re)}catch{w(re)}},Ya=function(re,_e){try{zd(t.removed,{attribute:_e.getAttributeNode(re),from:_e})}catch{zd(t.removed,{attribute:null,from:_e})}if(_e.removeAttribute(re),re==="is")if(Hn||Cn)try{Ur(_e)}catch{}else try{_e.setAttribute(re,"")}catch{}},$u=function(re){let _e=null,$e=null;if(Tr)re="<remove></remove>"+re;else{const Tt=Lv(re,/^[\r\n\t ]+/);$e=Tt&&Tt[0]}na==="application/xhtml+xml"&&zt===pn&&(re='<html xmlns="http://www.w3.org/1999/xhtml"><head></head><body>'+re+"</body></html>");const Vt=I?I.createHTML(re):re;if(zt===pn)try{_e=new m().parseFromString(Vt,na)}catch{}if(!_e||!_e.documentElement){_e=A.createDocument(zt,"template",null);try{_e.documentElement.innerHTML=Ea?L:Vt}catch{}}const xn=_e.body||_e.documentElement;return re&&$e&&xn.insertBefore(n.createTextNode($e),xn.childNodes[0]||null),zt===pn?G.call(_e,Xt?"html":"body")[0]:Xt?_e.documentElement:xn},Pu=function(re){return M.call(re.ownerDocument||re,re,d.SHOW_ELEMENT|d.SHOW_COMMENT|d.SHOW_TEXT|d.SHOW_PROCESSING_INSTRUCTION|d.SHOW_CDATA_SECTION,null)},ka=function(re){return re instanceof f&&(typeof re.nodeName!="string"||typeof re.textContent!="string"||typeof re.removeChild!="function"||!(re.attributes instanceof h)||typeof re.removeAttribute!="function"||typeof re.setAttribute!="function"||typeof re.namespaceURI!="string"||typeof re.insertBefore!="function"||typeof re.hasChildNodes!="function")},Ln=function(re){return typeof l=="function"&&re instanceof l};function fn(Ke,re,_e){h0(Ke,$e=>{$e.call(t,re,_e,qi)})}const Wi=function(re){let _e=null;if(fn(H.beforeSanitizeElements,re,null),ka(re))return Ur(re),!0;const $e=An(re.nodeName);if(fn(H.uponSanitizeElement,re,{tagName:$e,allowedTags:Y}),gt&&re.hasChildNodes()&&!Ln(re.firstElementChild)&&Nr(/<[/\w!]/g,re.innerHTML)&&Nr(/<[/\w!]/g,re.textContent)||re.nodeType===jd.progressingInstruction||gt&&re.nodeType===jd.comment&&Nr(/<[/\w]/g,re.data))return Ur(re),!0;if(!(Ae.tagCheck instanceof Function&&Ae.tagCheck($e))&&(!Y[$e]||fe[$e])){if(!fe[$e]&&Cp($e)&&(ge.tagNameCheck instanceof RegExp&&Nr(ge.tagNameCheck,$e)||ge.tagNameCheck instanceof Function&&ge.tagNameCheck($e)))return!1;if(yt&&!Te[$e]){const Vt=R(re)||re.parentNode,xn=k(re)||re.childNodes;if(xn&&Vt){const Tt=xn.length;for(let tr=Tt-1;tr>=0;--tr){const Ta=v(xn[tr],!0);Ta.__removalCount=(re.__removalCount||0)+1,Vt.insertBefore(Ta,S(re))}}}return Ur(re),!0}return re instanceof u&&!_p(re)||($e==="noscript"||$e==="noembed"||$e==="noframes")&&Nr(/<\/no(script|embed|frames)/i,re.innerHTML)?(Ur(re),!0):(Xe&&re.nodeType===jd.text&&(_e=re.textContent,h0([Z,V,q],Vt=>{_e=$d(_e,Vt," ")}),re.textContent!==_e&&(zd(t.removed,{element:re.cloneNode()}),re.textContent=_e)),fn(H.afterSanitizeElements,re,null),!1)},Pl=function(re,_e,$e){if(Ee[_e]||wa&&(_e==="id"||_e==="name")&&($e in n||$e in Mu))return!1;if(!(De&&!Ee[_e]&&Nr(X,_e))){if(!(ve&&Nr($,_e))){if(!(Ae.attributeCheck instanceof Function&&Ae.attributeCheck(_e,re))){if(!U[_e]||Ee[_e]){if(!(Cp(re)&&(ge.tagNameCheck instanceof RegExp&&Nr(ge.tagNameCheck,re)||ge.tagNameCheck instanceof Function&&ge.tagNameCheck(re))&&(ge.attributeNameCheck instanceof RegExp&&Nr(ge.attributeNameCheck,_e)||ge.attributeNameCheck instanceof Function&&ge.attributeNameCheck(_e,re))||_e==="is"&&ge.allowCustomizedBuiltInElements&&(ge.tagNameCheck instanceof RegExp&&Nr(ge.tagNameCheck,$e)||ge.tagNameCheck instanceof Function&&ge.tagNameCheck($e))))return!1}else if(!En[_e]){if(!Nr(F,$d($e,J,""))){if(!((_e==="src"||_e==="xlink:href"||_e==="href")&&re!=="script"&&vce($e,"data:")===0&&ut[re])){if(!(Le&&!Nr(Q,$d($e,J,"")))){if($e)return!1}}}}}}}return!0},Cp=function(re){return re!=="annotation-xml"&&Lv(re,ie)},Ap=function(re){fn(H.beforeSanitizeAttributes,re,null);const{attributes:_e}=re;if(!_e||ka(re))return;const $e={attrName:"",attrValue:"",keepAttr:!0,allowedAttributes:U,forceKeepAttr:void 0};let Vt=_e.length;for(;Vt--;){const xn=_e[Vt],{name:Tt,namespaceURI:tr,value:Ta}=xn,jr=An(Tt),hi=Ta;let Gn=Tt==="value"?hi:xce(hi);if($e.attrName=jr,$e.attrValue=Gn,$e.keepAttr=!0,$e.forceKeepAttr=void 0,fn(H.uponSanitizeAttribute,re,$e),Gn=$e.attrValue,di&&(jr==="id"||jr==="name")&&(Ya(Tt,re),Gn=qe+Gn),gt&&Nr(/((--!?|])>)|<\/(style|script|title|xmp|textarea|noscript|iframe|noembed|noframes)/i,Gn)){Ya(Tt,re);continue}if(jr==="attributename"&&Lv(Gn,"href")){Ya(Tt,re);continue}if($e.forceKeepAttr)continue;if(!$e.keepAttr){Ya(Tt,re);continue}if(!rt&&Nr(/\/>/i,Gn)){Ya(Tt,re);continue}Xe&&h0([Z,V,q],ju=>{Gn=$d(Gn,ju," ")});const Uu=An(re.nodeName);if(!Pl(Uu,jr,Gn)){Ya(Tt,re);continue}if(I&&typeof b=="object"&&typeof b.getAttributeType=="function"&&!tr)switch(b.getAttributeType(Uu,jr)){case"TrustedHTML":{Gn=I.createHTML(Gn);break}case"TrustedScriptURL":{Gn=I.createScriptURL(Gn);break}}if(Gn!==hi)try{tr?re.setAttributeNS(tr,Tt,Gn):re.setAttribute(Tt,Gn),ka(re)?Ur(re):a7(t.removed)}catch{Ya(Tt,re)}}fn(H.afterSanitizeAttributes,re,null)},Rp=function Ke(re){let _e=null;const $e=Pu(re);for(fn(H.beforeSanitizeShadowDOM,re,null);_e=$e.nextNode();)fn(H.uponSanitizeShadowNode,_e,null),Wi(_e),Ap(_e),_e.content instanceof i&&Ke(_e.content);fn(H.afterSanitizeShadowDOM,re,null)};return t.sanitize=function(Ke){let re=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},_e=null,$e=null,Vt=null,xn=null;if(Ea=!Ke,Ea&&(Ke="<!-->"),typeof Ke!="string"&&!Ln(Ke))if(typeof Ke.toString=="function"){if(Ke=Ke.toString(),typeof Ke!="string")throw Pd("dirty is not a string, aborting")}else throw Pd("toString is not a function");if(!t.isSupported)return Ke;if(er||Bu(re),t.removed=[],typeof Ke=="string"&&(ur=!1),ur){if(Ke.nodeName){const Ta=An(Ke.nodeName);if(!Y[Ta]||fe[Ta])throw Pd("root node is forbidden and cannot be sanitized in-place")}}else if(Ke instanceof l)_e=$u("<!---->"),$e=_e.ownerDocument.importNode(Ke,!0),$e.nodeType===jd.element&&$e.nodeName==="BODY"||$e.nodeName==="HTML"?_e=$e:_e.appendChild($e);else{if(!Hn&&!Xe&&!Xt&&Ke.indexOf("<")===-1)return I&&Zn?I.createHTML(Ke):Ke;if(_e=$u(Ke),!_e)return Hn?null:Zn?L:""}_e&&Tr&&Ur(_e.firstChild);const Tt=Pu(ur?Ke:_e);for(;Vt=Tt.nextNode();)Wi(Vt),Ap(Vt),Vt.content instanceof i&&Rp(Vt.content);if(ur)return Ke;if(Hn){if(Cn)for(xn=P.call(_e.ownerDocument);_e.firstChild;)xn.appendChild(_e.firstChild);else xn=_e;return(U.shadowroot||U.shadowrootmode)&&(xn=B.call(r,xn,!0)),xn}let tr=Xt?_e.outerHTML:_e.innerHTML;return Xt&&Y["!doctype"]&&_e.ownerDocument&&_e.ownerDocument.doctype&&_e.ownerDocument.doctype.name&&Nr(o9,_e.ownerDocument.doctype.name)&&(tr="<!DOCTYPE "+_e.ownerDocument.doctype.name+`>
`+tr),Xe&&h0([Z,V,q],Ta=>{tr=$d(tr,Ta," ")}),I&&Zn?I.createHTML(tr):tr},t.setConfig=function(){let Ke=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{};Bu(Ke),er=!0},t.clearConfig=function(){qi=null,er=!1},t.isValidAttribute=function(Ke,re,_e){qi||Bu({});const $e=An(Ke),Vt=An(re);return Pl($e,Vt,_e)},t.addHook=function(Ke,re){typeof re=="function"&&zd(H[Ke],re)},t.removeHook=function(Ke,re){if(re!==void 0){const _e=bce(H[Ke],re);return _e===-1?void 0:yce(H[Ke],_e,1)[0]}return a7(H[Ke])},t.removeHooks=function(Ke){H[Ke]=[]},t.removeAllHooks=function(){H=u7()},t}var nu=s9(),l9=/^-{3}\s*[\n\r](.*?)[\n\r]-{3}\s*[\n\r]+/s,fh=/%{2}{\s*(?:(\w+)\s*:|(\w+))\s*(?:(\w+)|((?:(?!}%{2}).|\r?\n)*))?\s*(?:}%{2})?/gi,Mce=/\s*%%.*\n/gm,Hc,c9=(Hc=class extends Error{constructor(t){super(t),this.name="UnknownDiagramError"}},N(Hc,"UnknownDiagramError"),Hc),vl={},p_=N(function(e,t){e=e.replace(l9,"").replace(fh,"").replace(Mce,`
`);for(const[n,{detector:r}]of Object.entries(vl))if(r(e,t))return n;throw new c9(`No diagram type detected matching given configuration for text: ${e}`)},"detectType"),qx=N((...e)=>{for(const{id:t,detector:n,loader:r}of e)u9(t,n,r)},"registerLazyLoadedDiagrams"),u9=N((e,t,n)=>{vl[e]&&we.warn(`Detector with key ${e} already exists. Overwriting.`),vl[e]={detector:t,loader:n},we.debug(`Detector with key ${e} added${n?" with loader":""}`)},"addDetector"),Bce=N(e=>vl[e].loader,"getDiagramLoader"),Wx=N((e,t,{depth:n=2,clobber:r=!1}={})=>{const a={depth:n,clobber:r};return Array.isArray(t)&&!Array.isArray(e)?(t.forEach(i=>Wx(e,i,a)),e):Array.isArray(t)&&Array.isArray(e)?(t.forEach(i=>{e.includes(i)||e.push(i)}),e):e===void 0||n<=0?e!=null&&typeof e=="object"&&typeof t=="object"?Object.assign(e,t):t:(t!==void 0&&typeof e=="object"&&typeof t=="object"&&Object.keys(t).forEach(i=>{typeof t[i]=="object"&&t[i]!==null&&(e[i]===void 0||typeof e[i]=="object")?(e[i]===void 0&&(e[i]=Array.isArray(t[i])?[]:{}),e[i]=Wx(e[i],t[i],{depth:n-1,clobber:r})):(r||typeof e[i]!="object"&&typeof t[i]!="object")&&(e[i]=t[i])}),e)},"assignWithDepth"),Yn=Wx,Pg="#ffffff",Ug="#f2f2f2",Dr=N((e,t)=>t?le(e,{s:-40,l:10}):le(e,{s:-40,l:-10}),"mkBorder"),Gc,Fce=(Gc=class{constructor(){this.background="#f4f4f4",this.primaryColor="#fff4dd",this.noteBkgColor="#fff5ad",this.noteTextColor="#333",this.THEME_COLOR_LIMIT=12,this.fontFamily='"trebuchet ms", verdana, arial, sans-serif',this.fontSize="16px"}updateColors(){var n,r,a,i,o,l,u,d,h,f,m,b,y,v,w,S,k,R,I,L,A;if(this.primaryTextColor=this.primaryTextColor||(this.darkMode?"#eee":"#333"),this.secondaryColor=this.secondaryColor||le(this.primaryColor,{h:-120}),this.tertiaryColor=this.tertiaryColor||le(this.primaryColor,{h:180,l:5}),this.primaryBorderColor=this.primaryBorderColor||Dr(this.primaryColor,this.darkMode),this.secondaryBorderColor=this.secondaryBorderColor||Dr(this.secondaryColor,this.darkMode),this.tertiaryBorderColor=this.tertiaryBorderColor||Dr(this.tertiaryColor,this.darkMode),this.noteBorderColor=this.noteBorderColor||Dr(this.noteBkgColor,this.darkMode),this.noteBkgColor=this.noteBkgColor||"#fff5ad",this.noteTextColor=this.noteTextColor||"#333",this.secondaryTextColor=this.secondaryTextColor||Me(this.secondaryColor),this.tertiaryTextColor=this.tertiaryTextColor||Me(this.tertiaryColor),this.lineColor=this.lineColor||Me(this.background),this.arrowheadColor=this.arrowheadColor||Me(this.background),this.textColor=this.textColor||this.primaryTextColor,this.border2=this.border2||this.tertiaryBorderColor,this.nodeBkg=this.nodeBkg||this.primaryColor,this.mainBkg=this.mainBkg||this.primaryColor,this.nodeBorder=this.nodeBorder||this.primaryBorderColor,this.clusterBkg=this.clusterBkg||this.tertiaryColor,this.clusterBorder=this.clusterBorder||this.tertiaryBorderColor,this.defaultLinkColor=this.defaultLinkColor||this.lineColor,this.titleColor=this.titleColor||this.tertiaryTextColor,this.edgeLabelBackground=this.edgeLabelBackground||(this.darkMode?nt(this.secondaryColor,30):this.secondaryColor),this.nodeTextColor=this.nodeTextColor||this.primaryTextColor,this.actorBorder=this.actorBorder||this.primaryBorderColor,this.actorBkg=this.actorBkg||this.mainBkg,this.actorTextColor=this.actorTextColor||this.primaryTextColor,this.actorLineColor=this.actorLineColor||this.actorBorder,this.labelBoxBkgColor=this.labelBoxBkgColor||this.actorBkg,this.signalColor=this.signalColor||this.textColor,this.signalTextColor=this.signalTextColor||this.textColor,this.labelBoxBorderColor=this.labelBoxBorderColor||this.actorBorder,this.labelTextColor=this.labelTextColor||this.actorTextColor,this.loopTextColor=this.loopTextColor||this.actorTextColor,this.activationBorderColor=this.activationBorderColor||nt(this.secondaryColor,10),this.activationBkgColor=this.activationBkgColor||this.secondaryColor,this.sequenceNumberColor=this.sequenceNumberColor||Me(this.lineColor),this.sectionBkgColor=this.sectionBkgColor||this.tertiaryColor,this.altSectionBkgColor=this.altSectionBkgColor||"white",this.sectionBkgColor=this.sectionBkgColor||this.secondaryColor,this.sectionBkgColor2=this.sectionBkgColor2||this.primaryColor,this.excludeBkgColor=this.excludeBkgColor||"#eeeeee",this.taskBorderColor=this.taskBorderColor||this.primaryBorderColor,this.taskBkgColor=this.taskBkgColor||this.primaryColor,this.activeTaskBorderColor=this.activeTaskBorderColor||this.primaryColor,this.activeTaskBkgColor=this.activeTaskBkgColor||Ue(this.primaryColor,23),this.gridColor=this.gridColor||"lightgrey",this.doneTaskBkgColor=this.doneTaskBkgColor||"lightgrey",this.doneTaskBorderColor=this.doneTaskBorderColor||"grey",this.critBorderColor=this.critBorderColor||"#ff8888",this.critBkgColor=this.critBkgColor||"red",this.todayLineColor=this.todayLineColor||"red",this.vertLineColor=this.vertLineColor||"navy",this.taskTextColor=this.taskTextColor||this.textColor,this.taskTextOutsideColor=this.taskTextOutsideColor||this.textColor,this.taskTextLightColor=this.taskTextLightColor||this.textColor,this.taskTextColor=this.taskTextColor||this.primaryTextColor,this.taskTextDarkColor=this.taskTextDarkColor||this.textColor,this.taskTextClickableColor=this.taskTextClickableColor||"#003163",this.personBorder=this.personBorder||this.primaryBorderColor,this.personBkg=this.personBkg||this.mainBkg,this.darkMode?(this.rowOdd=this.rowOdd||nt(this.mainBkg,5)||"#ffffff",this.rowEven=this.rowEven||nt(this.mainBkg,10)):(this.rowOdd=this.rowOdd||Ue(this.mainBkg,75)||"#ffffff",this.rowEven=this.rowEven||Ue(this.mainBkg,5)),this.transitionColor=this.transitionColor||this.lineColor,this.transitionLabelColor=this.transitionLabelColor||this.textColor,this.stateLabelColor=this.stateLabelColor||this.stateBkg||this.primaryTextColor,this.stateBkg=this.stateBkg||this.mainBkg,this.labelBackgroundColor=this.labelBackgroundColor||this.stateBkg,this.compositeBackground=this.compositeBackground||this.background||this.tertiaryColor,this.altBackground=this.altBackground||this.tertiaryColor,this.compositeTitleBackground=this.compositeTitleBackground||this.mainBkg,this.compositeBorder=this.compositeBorder||this.nodeBorder,this.innerEndBackground=this.nodeBorder,this.errorBkgColor=this.errorBkgColor||this.tertiaryColor,this.errorTextColor=this.errorTextColor||this.tertiaryTextColor,this.transitionColor=this.transitionColor||this.lineColor,this.specialStateColor=this.lineColor,this.cScale0=this.cScale0||this.primaryColor,this.cScale1=this.cScale1||this.secondaryColor,this.cScale2=this.cScale2||this.tertiaryColor,this.cScale3=this.cScale3||le(this.primaryColor,{h:30}),this.cScale4=this.cScale4||le(this.primaryColor,{h:60}),this.cScale5=this.cScale5||le(this.primaryColor,{h:90}),this.cScale6=this.cScale6||le(this.primaryColor,{h:120}),this.cScale7=this.cScale7||le(this.primaryColor,{h:150}),this.cScale8=this.cScale8||le(this.primaryColor,{h:210,l:150}),this.cScale9=this.cScale9||le(this.primaryColor,{h:270}),this.cScale10=this.cScale10||le(this.primaryColor,{h:300}),this.cScale11=this.cScale11||le(this.primaryColor,{h:330}),this.darkMode)for(let M=0;M<this.THEME_COLOR_LIMIT;M++)this["cScale"+M]=nt(this["cScale"+M],75);else for(let M=0;M<this.THEME_COLOR_LIMIT;M++)this["cScale"+M]=nt(this["cScale"+M],25);for(let M=0;M<this.THEME_COLOR_LIMIT;M++)this["cScaleInv"+M]=this["cScaleInv"+M]||Me(this["cScale"+M]);for(let M=0;M<this.THEME_COLOR_LIMIT;M++)this.darkMode?this["cScalePeer"+M]=this["cScalePeer"+M]||Ue(this["cScale"+M],10):this["cScalePeer"+M]=this["cScalePeer"+M]||nt(this["cScale"+M],10);this.scaleLabelColor=this.scaleLabelColor||this.labelTextColor;for(let M=0;M<this.THEME_COLOR_LIMIT;M++)this["cScaleLabel"+M]=this["cScaleLabel"+M]||this.scaleLabelColor;const t=this.darkMode?-4:-1;for(let M=0;M<5;M++)this["surface"+M]=this["surface"+M]||le(this.mainBkg,{h:180,s:-15,l:t*(5+M*3)}),this["surfacePeer"+M]=this["surfacePeer"+M]||le(this.mainBkg,{h:180,s:-15,l:t*(8+M*3)});this.classText=this.classText||this.textColor,this.fillType0=this.fillType0||this.primaryColor,this.fillType1=this.fillType1||this.secondaryColor,this.fillType2=this.fillType2||le(this.primaryColor,{h:64}),this.fillType3=this.fillType3||le(this.secondaryColor,{h:64}),this.fillType4=this.fillType4||le(this.primaryColor,{h:-64}),this.fillType5=this.fillType5||le(this.secondaryColor,{h:-64}),this.fillType6=this.fillType6||le(this.primaryColor,{h:128}),this.fillType7=this.fillType7||le(this.secondaryColor,{h:128}),this.pie1=this.pie1||this.primaryColor,this.pie2=this.pie2||this.secondaryColor,this.pie3=this.pie3||this.tertiaryColor,this.pie4=this.pie4||le(this.primaryColor,{l:-10}),this.pie5=this.pie5||le(this.secondaryColor,{l:-10}),this.pie6=this.pie6||le(this.tertiaryColor,{l:-10}),this.pie7=this.pie7||le(this.primaryColor,{h:60,l:-10}),this.pie8=this.pie8||le(this.primaryColor,{h:-60,l:-10}),this.pie9=this.pie9||le(this.primaryColor,{h:120,l:0}),this.pie10=this.pie10||le(this.primaryColor,{h:60,l:-20}),this.pie11=this.pie11||le(this.primaryColor,{h:-60,l:-20}),this.pie12=this.pie12||le(this.primaryColor,{h:120,l:-10}),this.pieTitleTextSize=this.pieTitleTextSize||"25px",this.pieTitleTextColor=this.pieTitleTextColor||this.taskTextDarkColor,this.pieSectionTextSize=this.pieSectionTextSize||"17px",this.pieSectionTextColor=this.pieSectionTextColor||this.textColor,this.pieLegendTextSize=this.pieLegendTextSize||"17px",this.pieLegendTextColor=this.pieLegendTextColor||this.taskTextDarkColor,this.pieStrokeColor=this.pieStrokeColor||"black",this.pieStrokeWidth=this.pieStrokeWidth||"2px",this.pieOuterStrokeWidth=this.pieOuterStrokeWidth||"2px",this.pieOuterStrokeColor=this.pieOuterStrokeColor||"black",this.pieOpacity=this.pieOpacity||"0.7",this.venn1=this.venn1??le(this.primaryColor,{l:-30}),this.venn2=this.venn2??le(this.secondaryColor,{l:-30}),this.venn3=this.venn3??le(this.tertiaryColor,{l:-30}),this.venn4=this.venn4??le(this.primaryColor,{h:60,l:-30}),this.venn5=this.venn5??le(this.primaryColor,{h:-60,l:-30}),this.venn6=this.venn6??le(this.secondaryColor,{h:60,l:-30}),this.venn7=this.venn7??le(this.primaryColor,{h:120,l:-30}),this.venn8=this.venn8??le(this.secondaryColor,{h:120,l:-30}),this.vennTitleTextColor=this.vennTitleTextColor??this.titleColor,this.vennSetTextColor=this.vennSetTextColor??this.textColor,this.radar={axisColor:((n=this.radar)==null?void 0:n.axisColor)||this.lineColor,axisStrokeWidth:((r=this.radar)==null?void 0:r.axisStrokeWidth)||2,axisLabelFontSize:((a=this.radar)==null?void 0:a.axisLabelFontSize)||12,curveOpacity:((i=this.radar)==null?void 0:i.curveOpacity)||.5,curveStrokeWidth:((o=this.radar)==null?void 0:o.curveStrokeWidth)||2,graticuleColor:((l=this.radar)==null?void 0:l.graticuleColor)||"#DEDEDE",graticuleStrokeWidth:((u=this.radar)==null?void 0:u.graticuleStrokeWidth)||1,graticuleOpacity:((d=this.radar)==null?void 0:d.graticuleOpacity)||.3,legendBoxSize:((h=this.radar)==null?void 0:h.legendBoxSize)||12,legendFontSize:((f=this.radar)==null?void 0:f.legendFontSize)||12},this.archEdgeColor=this.archEdgeColor||"#777",this.archEdgeArrowColor=this.archEdgeArrowColor||"#777",this.archEdgeWidth=this.archEdgeWidth||"3",this.archGroupBorderColor=this.archGroupBorderColor||"#000",this.archGroupBorderWidth=this.archGroupBorderWidth||"2px",this.quadrant1Fill=this.quadrant1Fill||this.primaryColor,this.quadrant2Fill=this.quadrant2Fill||le(this.primaryColor,{r:5,g:5,b:5}),this.quadrant3Fill=this.quadrant3Fill||le(this.primaryColor,{r:10,g:10,b:10}),this.quadrant4Fill=this.quadrant4Fill||le(this.primaryColor,{r:15,g:15,b:15}),this.quadrant1TextFill=this.quadrant1TextFill||this.primaryTextColor,this.quadrant2TextFill=this.quadrant2TextFill||le(this.primaryTextColor,{r:-5,g:-5,b:-5}),this.quadrant3TextFill=this.quadrant3TextFill||le(this.primaryTextColor,{r:-10,g:-10,b:-10}),this.quadrant4TextFill=this.quadrant4TextFill||le(this.primaryTextColor,{r:-15,g:-15,b:-15}),this.quadrantPointFill=this.quadrantPointFill||dp(this.quadrant1Fill)?Ue(this.quadrant1Fill):nt(this.quadrant1Fill),this.quadrantPointTextFill=this.quadrantPointTextFill||this.primaryTextColor,this.quadrantXAxisTextFill=this.quadrantXAxisTextFill||this.primaryTextColor,this.quadrantYAxisTextFill=this.quadrantYAxisTextFill||this.primaryTextColor,this.quadrantInternalBorderStrokeFill=this.quadrantInternalBorderStrokeFill||this.primaryBorderColor,this.quadrantExternalBorderStrokeFill=this.quadrantExternalBorderStrokeFill||this.primaryBorderColor,this.quadrantTitleFill=this.quadrantTitleFill||this.primaryTextColor,this.xyChart={backgroundColor:((m=this.xyChart)==null?void 0:m.backgroundColor)||this.background,titleColor:((b=this.xyChart)==null?void 0:b.titleColor)||this.primaryTextColor,xAxisTitleColor:((y=this.xyChart)==null?void 0:y.xAxisTitleColor)||this.primaryTextColor,xAxisLabelColor:((v=this.xyChart)==null?void 0:v.xAxisLabelColor)||this.primaryTextColor,xAxisTickColor:((w=this.xyChart)==null?void 0:w.xAxisTickColor)||this.primaryTextColor,xAxisLineColor:((S=this.xyChart)==null?void 0:S.xAxisLineColor)||this.primaryTextColor,yAxisTitleColor:((k=this.xyChart)==null?void 0:k.yAxisTitleColor)||this.primaryTextColor,yAxisLabelColor:((R=this.xyChart)==null?void 0:R.yAxisLabelColor)||this.primaryTextColor,yAxisTickColor:((I=this.xyChart)==null?void 0:I.yAxisTickColor)||this.primaryTextColor,yAxisLineColor:((L=this.xyChart)==null?void 0:L.yAxisLineColor)||this.primaryTextColor,plotColorPalette:((A=this.xyChart)==null?void 0:A.plotColorPalette)||"#FFF4DD,#FFD8B1,#FFA07A,#ECEFF1,#D6DBDF,#C3E0A8,#FFB6A4,#FFD74D,#738FA7,#FFFFF0"},this.requirementBackground=this.requirementBackground||this.primaryColor,this.requirementBorderColor=this.requirementBorderColor||this.primaryBorderColor,this.requirementBorderSize=this.requirementBorderSize||"1",this.requirementTextColor=this.requirementTextColor||this.primaryTextColor,this.relationColor=this.relationColor||this.lineColor,this.relationLabelBackground=this.relationLabelBackground||(this.darkMode?nt(this.secondaryColor,30):this.secondaryColor),this.relationLabelColor=this.relationLabelColor||this.actorTextColor,this.git0=this.git0||this.primaryColor,this.git1=this.git1||this.secondaryColor,this.git2=this.git2||this.tertiaryColor,this.git3=this.git3||le(this.primaryColor,{h:-30}),this.git4=this.git4||le(this.primaryColor,{h:-60}),this.git5=this.git5||le(this.primaryColor,{h:-90}),this.git6=this.git6||le(this.primaryColor,{h:60}),this.git7=this.git7||le(this.primaryColor,{h:120}),this.darkMode?(this.git0=Ue(this.git0,25),this.git1=Ue(this.git1,25),this.git2=Ue(this.git2,25),this.git3=Ue(this.git3,25),this.git4=Ue(this.git4,25),this.git5=Ue(this.git5,25),this.git6=Ue(this.git6,25),this.git7=Ue(this.git7,25)):(this.git0=nt(this.git0,25),this.git1=nt(this.git1,25),this.git2=nt(this.git2,25),this.git3=nt(this.git3,25),this.git4=nt(this.git4,25),this.git5=nt(this.git5,25),this.git6=nt(this.git6,25),this.git7=nt(this.git7,25)),this.gitInv0=this.gitInv0||Me(this.git0),this.gitInv1=this.gitInv1||Me(this.git1),this.gitInv2=this.gitInv2||Me(this.git2),this.gitInv3=this.gitInv3||Me(this.git3),this.gitInv4=this.gitInv4||Me(this.git4),this.gitInv5=this.gitInv5||Me(this.git5),this.gitInv6=this.gitInv6||Me(this.git6),this.gitInv7=this.gitInv7||Me(this.git7),this.branchLabelColor=this.branchLabelColor||(this.darkMode?"black":this.labelTextColor),this.gitBranchLabel0=this.gitBranchLabel0||this.branchLabelColor,this.gitBranchLabel1=this.gitBranchLabel1||this.branchLabelColor,this.gitBranchLabel2=this.gitBranchLabel2||this.branchLabelColor,this.gitBranchLabel3=this.gitBranchLabel3||this.branchLabelColor,this.gitBranchLabel4=this.gitBranchLabel4||this.branchLabelColor,this.gitBranchLabel5=this.gitBranchLabel5||this.branchLabelColor,this.gitBranchLabel6=this.gitBranchLabel6||this.branchLabelColor,this.gitBranchLabel7=this.gitBranchLabel7||this.branchLabelColor,this.tagLabelColor=this.tagLabelColor||this.primaryTextColor,this.tagLabelBackground=this.tagLabelBackground||this.primaryColor,this.tagLabelBorder=this.tagBorder||this.primaryBorderColor,this.tagLabelFontSize=this.tagLabelFontSize||"10px",this.commitLabelColor=this.commitLabelColor||this.secondaryTextColor,this.commitLabelBackground=this.commitLabelBackground||this.secondaryColor,this.commitLabelFontSize=this.commitLabelFontSize||"10px",this.attributeBackgroundColorOdd=this.attributeBackgroundColorOdd||Pg,this.attributeBackgroundColorEven=this.attributeBackgroundColorEven||Ug}calculate(t){if(typeof t!="object"){this.updateColors();return}const n=Object.keys(t);n.forEach(r=>{this[r]=t[r]}),this.updateColors(),n.forEach(r=>{this[r]=t[r]})}},N(Gc,"Theme"),Gc),zce=N(e=>{const t=new Fce;return t.calculate(e),t},"getThemeVariables"),qc,$ce=(qc=class{constructor(){this.background="#333",this.primaryColor="#1f2020",this.secondaryColor=Ue(this.primaryColor,16),this.tertiaryColor=le(this.primaryColor,{h:-160}),this.primaryBorderColor=Me(this.background),this.secondaryBorderColor=Dr(this.secondaryColor,this.darkMode),this.tertiaryBorderColor=Dr(this.tertiaryColor,this.darkMode),this.primaryTextColor=Me(this.primaryColor),this.secondaryTextColor=Me(this.secondaryColor),this.tertiaryTextColor=Me(this.tertiaryColor),this.lineColor=Me(this.background),this.textColor=Me(this.background),this.mainBkg="#1f2020",this.secondBkg="calculated",this.mainContrastColor="lightgrey",this.darkTextColor=Ue(Me("#323D47"),10),this.lineColor="calculated",this.border1="#ccc",this.border2=ph(255,255,255,.25),this.arrowheadColor="calculated",this.fontFamily='"trebuchet ms", verdana, arial, sans-serif',this.fontSize="16px",this.labelBackground="#181818",this.textColor="#ccc",this.THEME_COLOR_LIMIT=12,this.nodeBkg="calculated",this.nodeBorder="calculated",this.clusterBkg="calculated",this.clusterBorder="calculated",this.defaultLinkColor="calculated",this.titleColor="#F9FFFE",this.edgeLabelBackground="calculated",this.actorBorder="calculated",this.actorBkg="calculated",this.actorTextColor="calculated",this.actorLineColor="calculated",this.signalColor="calculated",this.signalTextColor="calculated",this.labelBoxBkgColor="calculated",this.labelBoxBorderColor="calculated",this.labelTextColor="calculated",this.loopTextColor="calculated",this.noteBorderColor="calculated",this.noteBkgColor="#fff5ad",this.noteTextColor="calculated",this.activationBorderColor="calculated",this.activationBkgColor="calculated",this.sequenceNumberColor="black",this.sectionBkgColor=nt("#EAE8D9",30),this.altSectionBkgColor="calculated",this.sectionBkgColor2="#EAE8D9",this.excludeBkgColor=nt(this.sectionBkgColor,10),this.taskBorderColor=ph(255,255,255,70),this.taskBkgColor="calculated",this.taskTextColor="calculated",this.taskTextLightColor="calculated",this.taskTextOutsideColor="calculated",this.taskTextClickableColor="#003163",this.activeTaskBorderColor=ph(255,255,255,50),this.activeTaskBkgColor="#81B1DB",this.gridColor="calculated",this.doneTaskBkgColor="calculated",this.doneTaskBorderColor="grey",this.critBorderColor="#E83737",this.critBkgColor="#E83737",this.taskTextDarkColor="calculated",this.todayLineColor="#DB5757",this.vertLineColor="#00BFFF",this.personBorder=this.primaryBorderColor,this.personBkg=this.mainBkg,this.archEdgeColor="calculated",this.archEdgeArrowColor="calculated",this.archEdgeWidth="3",this.archGroupBorderColor=this.primaryBorderColor,this.archGroupBorderWidth="2px",this.rowOdd=this.rowOdd||Ue(this.mainBkg,5)||"#ffffff",this.rowEven=this.rowEven||nt(this.mainBkg,10),this.labelColor="calculated",this.errorBkgColor="#a44141",this.errorTextColor="#ddd"}updateColors(){var t,n,r,a,i,o,l,u,d,h,f,m,b,y,v,w,S,k,R,I,L;this.secondBkg=Ue(this.mainBkg,16),this.lineColor=this.mainContrastColor,this.arrowheadColor=this.mainContrastColor,this.nodeBkg=this.mainBkg,this.nodeBorder=this.border1,this.clusterBkg=this.secondBkg,this.clusterBorder=this.border2,this.defaultLinkColor=this.lineColor,this.edgeLabelBackground=Ue(this.labelBackground,25),this.actorBorder=this.border1,this.actorBkg=this.mainBkg,this.actorTextColor=this.mainContrastColor,this.actorLineColor=this.actorBorder,this.signalColor=this.mainContrastColor,this.signalTextColor=this.mainContrastColor,this.labelBoxBkgColor=this.actorBkg,this.labelBoxBorderColor=this.actorBorder,this.labelTextColor=this.mainContrastColor,this.loopTextColor=this.mainContrastColor,this.noteBorderColor=this.secondaryBorderColor,this.noteBkgColor=this.secondBkg,this.noteTextColor=this.secondaryTextColor,this.activationBorderColor=this.border1,this.activationBkgColor=this.secondBkg,this.altSectionBkgColor=this.background,this.taskBkgColor=Ue(this.mainBkg,23),this.taskTextColor=this.darkTextColor,this.taskTextLightColor=this.mainContrastColor,this.taskTextOutsideColor=this.taskTextLightColor,this.gridColor=this.mainContrastColor,this.doneTaskBkgColor=this.mainContrastColor,this.taskTextDarkColor=Me(this.doneTaskBkgColor),this.archEdgeColor=this.lineColor,this.archEdgeArrowColor=this.lineColor,this.transitionColor=this.transitionColor||this.lineColor,this.transitionLabelColor=this.transitionLabelColor||this.textColor,this.stateLabelColor=this.stateLabelColor||this.stateBkg||this.primaryTextColor,this.stateBkg=this.stateBkg||this.mainBkg,this.labelBackgroundColor=this.labelBackgroundColor||this.stateBkg,this.compositeBackground=this.compositeBackground||this.background||this.tertiaryColor,this.altBackground=this.altBackground||"#555",this.compositeTitleBackground=this.compositeTitleBackground||this.mainBkg,this.compositeBorder=this.compositeBorder||this.nodeBorder,this.innerEndBackground=this.primaryBorderColor,this.specialStateColor="#f4f4f4",this.errorBkgColor=this.errorBkgColor||this.tertiaryColor,this.errorTextColor=this.errorTextColor||this.tertiaryTextColor,this.fillType0=this.primaryColor,this.fillType1=this.secondaryColor,this.fillType2=le(this.primaryColor,{h:64}),this.fillType3=le(this.secondaryColor,{h:64}),this.fillType4=le(this.primaryColor,{h:-64}),this.fillType5=le(this.secondaryColor,{h:-64}),this.fillType6=le(this.primaryColor,{h:128}),this.fillType7=le(this.secondaryColor,{h:128}),this.cScale1=this.cScale1||"#0b0000",this.cScale2=this.cScale2||"#4d1037",this.cScale3=this.cScale3||"#3f5258",this.cScale4=this.cScale4||"#4f2f1b",this.cScale5=this.cScale5||"#6e0a0a",this.cScale6=this.cScale6||"#3b0048",this.cScale7=this.cScale7||"#995a01",this.cScale8=this.cScale8||"#154706",this.cScale9=this.cScale9||"#161722",this.cScale10=this.cScale10||"#00296f",this.cScale11=this.cScale11||"#01629c",this.cScale12=this.cScale12||"#010029",this.cScale0=this.cScale0||this.primaryColor,this.cScale1=this.cScale1||this.secondaryColor,this.cScale2=this.cScale2||this.tertiaryColor,this.cScale3=this.cScale3||le(this.primaryColor,{h:30}),this.cScale4=this.cScale4||le(this.primaryColor,{h:60}),this.cScale5=this.cScale5||le(this.primaryColor,{h:90}),this.cScale6=this.cScale6||le(this.primaryColor,{h:120}),this.cScale7=this.cScale7||le(this.primaryColor,{h:150}),this.cScale8=this.cScale8||le(this.primaryColor,{h:210}),this.cScale9=this.cScale9||le(this.primaryColor,{h:270}),this.cScale10=this.cScale10||le(this.primaryColor,{h:300}),this.cScale11=this.cScale11||le(this.primaryColor,{h:330});for(let A=0;A<this.THEME_COLOR_LIMIT;A++)this["cScaleInv"+A]=this["cScaleInv"+A]||Me(this["cScale"+A]);for(let A=0;A<this.THEME_COLOR_LIMIT;A++)this["cScalePeer"+A]=this["cScalePeer"+A]||Ue(this["cScale"+A],10);for(let A=0;A<5;A++)this["surface"+A]=this["surface"+A]||le(this.mainBkg,{h:30,s:-30,l:-(-10+A*4)}),this["surfacePeer"+A]=this["surfacePeer"+A]||le(this.mainBkg,{h:30,s:-30,l:-(-7+A*4)});this.scaleLabelColor=this.scaleLabelColor||(this.darkMode?"black":this.labelTextColor);for(let A=0;A<this.THEME_COLOR_LIMIT;A++)this["cScaleLabel"+A]=this["cScaleLabel"+A]||this.scaleLabelColor;for(let A=0;A<this.THEME_COLOR_LIMIT;A++)this["pie"+A]=this["cScale"+A];this.pieTitleTextSize=this.pieTitleTextSize||"25px",this.pieTitleTextColor=this.pieTitleTextColor||this.mainContrastColor,this.pieSectionTextSize=this.pieSectionTextSize||"17px",this.pieSectionTextColor=this.pieSectionTextColor||this.textColor,this.pieLegendTextSize=this.pieLegendTextSize||"17px",this.pieLegendTextColor=this.pieLegendTextColor||this.mainContrastColor,this.pieStrokeColor=this.pieStrokeColor||"black",this.pieStrokeWidth=this.pieStrokeWidth||"2px",this.pieOuterStrokeWidth=this.pieOuterStrokeWidth||"2px",this.pieOuterStrokeColor=this.pieOuterStrokeColor||"black",this.pieOpacity=this.pieOpacity||"0.7";for(let A=0;A<8;A++)this["venn"+(A+1)]=this["venn"+(A+1)]??Ue(this["cScale"+A],30);this.vennTitleTextColor=this.vennTitleTextColor??this.titleColor,this.vennSetTextColor=this.vennSetTextColor??this.textColor,this.quadrant1Fill=this.quadrant1Fill||this.primaryColor,this.quadrant2Fill=this.quadrant2Fill||le(this.primaryColor,{r:5,g:5,b:5}),this.quadrant3Fill=this.quadrant3Fill||le(this.primaryColor,{r:10,g:10,b:10}),this.quadrant4Fill=this.quadrant4Fill||le(this.primaryColor,{r:15,g:15,b:15}),this.quadrant1TextFill=this.quadrant1TextFill||this.primaryTextColor,this.quadrant2TextFill=this.quadrant2TextFill||le(this.primaryTextColor,{r:-5,g:-5,b:-5}),this.quadrant3TextFill=this.quadrant3TextFill||le(this.primaryTextColor,{r:-10,g:-10,b:-10}),this.quadrant4TextFill=this.quadrant4TextFill||le(this.primaryTextColor,{r:-15,g:-15,b:-15}),this.quadrantPointFill=this.quadrantPointFill||dp(this.quadrant1Fill)?Ue(this.quadrant1Fill):nt(this.quadrant1Fill),this.quadrantPointTextFill=this.quadrantPointTextFill||this.primaryTextColor,this.quadrantXAxisTextFill=this.quadrantXAxisTextFill||this.primaryTextColor,this.quadrantYAxisTextFill=this.quadrantYAxisTextFill||this.primaryTextColor,this.quadrantInternalBorderStrokeFill=this.quadrantInternalBorderStrokeFill||this.primaryBorderColor,this.quadrantExternalBorderStrokeFill=this.quadrantExternalBorderStrokeFill||this.primaryBorderColor,this.quadrantTitleFill=this.quadrantTitleFill||this.primaryTextColor,this.xyChart={backgroundColor:((t=this.xyChart)==null?void 0:t.backgroundColor)||this.background,titleColor:((n=this.xyChart)==null?void 0:n.titleColor)||this.primaryTextColor,xAxisTitleColor:((r=this.xyChart)==null?void 0:r.xAxisTitleColor)||this.primaryTextColor,xAxisLabelColor:((a=this.xyChart)==null?void 0:a.xAxisLabelColor)||this.primaryTextColor,xAxisTickColor:((i=this.xyChart)==null?void 0:i.xAxisTickColor)||this.primaryTextColor,xAxisLineColor:((o=this.xyChart)==null?void 0:o.xAxisLineColor)||this.primaryTextColor,yAxisTitleColor:((l=this.xyChart)==null?void 0:l.yAxisTitleColor)||this.primaryTextColor,yAxisLabelColor:((u=this.xyChart)==null?void 0:u.yAxisLabelColor)||this.primaryTextColor,yAxisTickColor:((d=this.xyChart)==null?void 0:d.yAxisTickColor)||this.primaryTextColor,yAxisLineColor:((h=this.xyChart)==null?void 0:h.yAxisLineColor)||this.primaryTextColor,plotColorPalette:((f=this.xyChart)==null?void 0:f.plotColorPalette)||"#3498db,#2ecc71,#e74c3c,#f1c40f,#bdc3c7,#ffffff,#34495e,#9b59b6,#1abc9c,#e67e22"},this.packet={startByteColor:this.primaryTextColor,endByteColor:this.primaryTextColor,labelColor:this.primaryTextColor,titleColor:this.primaryTextColor,blockStrokeColor:this.primaryTextColor,blockFillColor:this.background},this.radar={axisColor:((m=this.radar)==null?void 0:m.axisColor)||this.lineColor,axisStrokeWidth:((b=this.radar)==null?void 0:b.axisStrokeWidth)||2,axisLabelFontSize:((y=this.radar)==null?void 0:y.axisLabelFontSize)||12,curveOpacity:((v=this.radar)==null?void 0:v.curveOpacity)||.5,curveStrokeWidth:((w=this.radar)==null?void 0:w.curveStrokeWidth)||2,graticuleColor:((S=this.radar)==null?void 0:S.graticuleColor)||"#DEDEDE",graticuleStrokeWidth:((k=this.radar)==null?void 0:k.graticuleStrokeWidth)||1,graticuleOpacity:((R=this.radar)==null?void 0:R.graticuleOpacity)||.3,legendBoxSize:((I=this.radar)==null?void 0:I.legendBoxSize)||12,legendFontSize:((L=this.radar)==null?void 0:L.legendFontSize)||12},this.classText=this.primaryTextColor,this.requirementBackground=this.requirementBackground||this.primaryColor,this.requirementBorderColor=this.requirementBorderColor||this.primaryBorderColor,this.requirementBorderSize=this.requirementBorderSize||"1",this.requirementTextColor=this.requirementTextColor||this.primaryTextColor,this.relationColor=this.relationColor||this.lineColor,this.relationLabelBackground=this.relationLabelBackground||(this.darkMode?nt(this.secondaryColor,30):this.secondaryColor),this.relationLabelColor=this.relationLabelColor||this.actorTextColor,this.git0=Ue(this.secondaryColor,20),this.git1=Ue(this.pie2||this.secondaryColor,20),this.git2=Ue(this.pie3||this.tertiaryColor,20),this.git3=Ue(this.pie4||le(this.primaryColor,{h:-30}),20),this.git4=Ue(this.pie5||le(this.primaryColor,{h:-60}),20),this.git5=Ue(this.pie6||le(this.primaryColor,{h:-90}),10),this.git6=Ue(this.pie7||le(this.primaryColor,{h:60}),10),this.git7=Ue(this.pie8||le(this.primaryColor,{h:120}),20),this.gitInv0=this.gitInv0||Me(this.git0),this.gitInv1=this.gitInv1||Me(this.git1),this.gitInv2=this.gitInv2||Me(this.git2),this.gitInv3=this.gitInv3||Me(this.git3),this.gitInv4=this.gitInv4||Me(this.git4),this.gitInv5=this.gitInv5||Me(this.git5),this.gitInv6=this.gitInv6||Me(this.git6),this.gitInv7=this.gitInv7||Me(this.git7),this.gitBranchLabel0=this.gitBranchLabel0||Me(this.labelTextColor),this.gitBranchLabel1=this.gitBranchLabel1||this.labelTextColor,this.gitBranchLabel2=this.gitBranchLabel2||this.labelTextColor,this.gitBranchLabel3=this.gitBranchLabel3||Me(this.labelTextColor),this.gitBranchLabel4=this.gitBranchLabel4||this.labelTextColor,this.gitBranchLabel5=this.gitBranchLabel5||this.labelTextColor,this.gitBranchLabel6=this.gitBranchLabel6||this.labelTextColor,this.gitBranchLabel7=this.gitBranchLabel7||this.labelTextColor,this.tagLabelColor=this.tagLabelColor||this.primaryTextColor,this.tagLabelBackground=this.tagLabelBackground||this.primaryColor,this.tagLabelBorder=this.tagBorder||this.primaryBorderColor,this.tagLabelFontSize=this.tagLabelFontSize||"10px",this.commitLabelColor=this.commitLabelColor||this.secondaryTextColor,this.commitLabelBackground=this.commitLabelBackground||this.secondaryColor,this.commitLabelFontSize=this.commitLabelFontSize||"10px",this.attributeBackgroundColorOdd=this.attributeBackgroundColorOdd||Ue(this.background,12),this.attributeBackgroundColorEven=this.attributeBackgroundColorEven||Ue(this.background,2),this.nodeBorder=this.nodeBorder||"#999"}calculate(t){if(typeof t!="object"){this.updateColors();return}const n=Object.keys(t);n.forEach(r=>{this[r]=t[r]}),this.updateColors(),n.forEach(r=>{this[r]=t[r]})}},N(qc,"Theme"),qc),Pce=N(e=>{const t=new $ce;return t.calculate(e),t},"getThemeVariables"),Wc,Uce=(Wc=class{constructor(){this.background="#f4f4f4",this.primaryColor="#ECECFF",this.secondaryColor=le(this.primaryColor,{h:120}),this.secondaryColor="#ffffde",this.tertiaryColor=le(this.primaryColor,{h:-160}),this.primaryBorderColor=Dr(this.primaryColor,this.darkMode),this.secondaryBorderColor=Dr(this.secondaryColor,this.darkMode),this.tertiaryBorderColor=Dr(this.tertiaryColor,this.darkMode),this.primaryTextColor=Me(this.primaryColor),this.secondaryTextColor=Me(this.secondaryColor),this.tertiaryTextColor=Me(this.tertiaryColor),this.lineColor=Me(this.background),this.textColor=Me(this.background),this.background="white",this.mainBkg="#ECECFF",this.secondBkg="#ffffde",this.lineColor="#333333",this.border1="#9370DB",this.border2="#aaaa33",this.arrowheadColor="#333333",this.fontFamily='"trebuchet ms", verdana, arial, sans-serif',this.fontSize="16px",this.labelBackground="rgba(232,232,232, 0.8)",this.textColor="#333",this.THEME_COLOR_LIMIT=12,this.nodeBkg="calculated",this.nodeBorder="calculated",this.clusterBkg="calculated",this.clusterBorder="calculated",this.defaultLinkColor="calculated",this.titleColor="calculated",this.edgeLabelBackground="calculated",this.actorBorder="calculated",this.actorBkg="calculated",this.actorTextColor="black",this.actorLineColor="calculated",this.signalColor="calculated",this.signalTextColor="calculated",this.labelBoxBkgColor="calculated",this.labelBoxBorderColor="calculated",this.labelTextColor="calculated",this.loopTextColor="calculated",this.noteBorderColor="calculated",this.noteBkgColor="#fff5ad",this.noteTextColor="calculated",this.activationBorderColor="#666",this.activationBkgColor="#f4f4f4",this.sequenceNumberColor="white",this.sectionBkgColor="calculated",this.altSectionBkgColor="calculated",this.sectionBkgColor2="calculated",this.excludeBkgColor="#eeeeee",this.taskBorderColor="calculated",this.taskBkgColor="calculated",this.taskTextLightColor="calculated",this.taskTextColor=this.taskTextLightColor,this.taskTextDarkColor="calculated",this.taskTextOutsideColor=this.taskTextDarkColor,this.taskTextClickableColor="calculated",this.activeTaskBorderColor="calculated",this.activeTaskBkgColor="calculated",this.gridColor="calculated",this.doneTaskBkgColor="calculated",this.doneTaskBorderColor="calculated",this.critBorderColor="calculated",this.critBkgColor="calculated",this.todayLineColor="calculated",this.vertLineColor="calculated",this.sectionBkgColor=ph(102,102,255,.49),this.altSectionBkgColor="white",this.sectionBkgColor2="#fff400",this.taskBorderColor="#534fbc",this.taskBkgColor="#8a90dd",this.taskTextLightColor="white",this.taskTextColor="calculated",this.taskTextDarkColor="black",this.taskTextOutsideColor="calculated",this.taskTextClickableColor="#003163",this.activeTaskBorderColor="#534fbc",this.activeTaskBkgColor="#bfc7ff",this.gridColor="lightgrey",this.doneTaskBkgColor="lightgrey",this.doneTaskBorderColor="grey",this.critBorderColor="#ff8888",this.critBkgColor="red",this.todayLineColor="red",this.vertLineColor="navy",this.personBorder=this.primaryBorderColor,this.personBkg=this.mainBkg,this.archEdgeColor="calculated",this.archEdgeArrowColor="calculated",this.archEdgeWidth="3",this.archGroupBorderColor=this.primaryBorderColor,this.archGroupBorderWidth="2px",this.rowOdd="calculated",this.rowEven="calculated",this.labelColor="black",this.errorBkgColor="#552222",this.errorTextColor="#552222",this.updateColors()}updateColors(){var t,n,r,a,i,o,l,u,d,h,f,m,b,y,v,w,S,k,R,I,L;this.cScale0=this.cScale0||this.primaryColor,this.cScale1=this.cScale1||this.secondaryColor,this.cScale2=this.cScale2||this.tertiaryColor,this.cScale3=this.cScale3||le(this.primaryColor,{h:30}),this.cScale4=this.cScale4||le(this.primaryColor,{h:60}),this.cScale5=this.cScale5||le(this.primaryColor,{h:90}),this.cScale6=this.cScale6||le(this.primaryColor,{h:120}),this.cScale7=this.cScale7||le(this.primaryColor,{h:150}),this.cScale8=this.cScale8||le(this.primaryColor,{h:210}),this.cScale9=this.cScale9||le(this.primaryColor,{h:270}),this.cScale10=this.cScale10||le(this.primaryColor,{h:300}),this.cScale11=this.cScale11||le(this.primaryColor,{h:330}),this.cScalePeer1=this.cScalePeer1||nt(this.secondaryColor,45),this.cScalePeer2=this.cScalePeer2||nt(this.tertiaryColor,40);for(let A=0;A<this.THEME_COLOR_LIMIT;A++)this["cScale"+A]=nt(this["cScale"+A],10),this["cScalePeer"+A]=this["cScalePeer"+A]||nt(this["cScale"+A],25);for(let A=0;A<this.THEME_COLOR_LIMIT;A++)this["cScaleInv"+A]=this["cScaleInv"+A]||le(this["cScale"+A],{h:180});for(let A=0;A<5;A++)this["surface"+A]=this["surface"+A]||le(this.mainBkg,{h:30,l:-(5+A*5)}),this["surfacePeer"+A]=this["surfacePeer"+A]||le(this.mainBkg,{h:30,l:-(7+A*5)});if(this.scaleLabelColor=this.scaleLabelColor!=="calculated"&&this.scaleLabelColor?this.scaleLabelColor:this.labelTextColor,this.labelTextColor!=="calculated"){this.cScaleLabel0=this.cScaleLabel0||Me(this.labelTextColor),this.cScaleLabel3=this.cScaleLabel3||Me(this.labelTextColor);for(let A=0;A<this.THEME_COLOR_LIMIT;A++)this["cScaleLabel"+A]=this["cScaleLabel"+A]||this.labelTextColor}this.nodeBkg=this.mainBkg,this.nodeBorder=this.border1,this.clusterBkg=this.secondBkg,this.clusterBorder=this.border2,this.defaultLinkColor=this.lineColor,this.titleColor=this.textColor,this.edgeLabelBackground=this.labelBackground,this.actorBorder=Ue(this.border1,23),this.actorBkg=this.mainBkg,this.labelBoxBkgColor=this.actorBkg,this.signalColor=this.textColor,this.signalTextColor=this.textColor,this.labelBoxBorderColor=this.actorBorder,this.labelTextColor=this.actorTextColor,this.loopTextColor=this.actorTextColor,this.noteBorderColor=this.border2,this.noteTextColor=this.actorTextColor,this.actorLineColor=this.actorBorder,this.taskTextColor=this.taskTextLightColor,this.taskTextOutsideColor=this.taskTextDarkColor,this.archEdgeColor=this.lineColor,this.archEdgeArrowColor=this.lineColor,this.rowOdd=this.rowOdd||Ue(this.primaryColor,75)||"#ffffff",this.rowEven=this.rowEven||Ue(this.primaryColor,1),this.transitionColor=this.transitionColor||this.lineColor,this.transitionLabelColor=this.transitionLabelColor||this.textColor,this.stateLabelColor=this.stateLabelColor||this.stateBkg||this.primaryTextColor,this.stateBkg=this.stateBkg||this.mainBkg,this.labelBackgroundColor=this.labelBackgroundColor||this.stateBkg,this.compositeBackground=this.compositeBackground||this.background||this.tertiaryColor,this.altBackground=this.altBackground||"#f0f0f0",this.compositeTitleBackground=this.compositeTitleBackground||this.mainBkg,this.compositeBorder=this.compositeBorder||this.nodeBorder,this.innerEndBackground=this.nodeBorder,this.specialStateColor=this.lineColor,this.errorBkgColor=this.errorBkgColor||this.tertiaryColor,this.errorTextColor=this.errorTextColor||this.tertiaryTextColor,this.transitionColor=this.transitionColor||this.lineColor,this.classText=this.primaryTextColor,this.fillType0=this.primaryColor,this.fillType1=this.secondaryColor,this.fillType2=le(this.primaryColor,{h:64}),this.fillType3=le(this.secondaryColor,{h:64}),this.fillType4=le(this.primaryColor,{h:-64}),this.fillType5=le(this.secondaryColor,{h:-64}),this.fillType6=le(this.primaryColor,{h:128}),this.fillType7=le(this.secondaryColor,{h:128}),this.pie1=this.pie1||this.primaryColor,this.pie2=this.pie2||this.secondaryColor,this.pie3=this.pie3||le(this.tertiaryColor,{l:-40}),this.pie4=this.pie4||le(this.primaryColor,{l:-10}),this.pie5=this.pie5||le(this.secondaryColor,{l:-30}),this.pie6=this.pie6||le(this.tertiaryColor,{l:-20}),this.pie7=this.pie7||le(this.primaryColor,{h:60,l:-20}),this.pie8=this.pie8||le(this.primaryColor,{h:-60,l:-40}),this.pie9=this.pie9||le(this.primaryColor,{h:120,l:-40}),this.pie10=this.pie10||le(this.primaryColor,{h:60,l:-40}),this.pie11=this.pie11||le(this.primaryColor,{h:-90,l:-40}),this.pie12=this.pie12||le(this.primaryColor,{h:120,l:-30}),this.pieTitleTextSize=this.pieTitleTextSize||"25px",this.pieTitleTextColor=this.pieTitleTextColor||this.taskTextDarkColor,this.pieSectionTextSize=this.pieSectionTextSize||"17px",this.pieSectionTextColor=this.pieSectionTextColor||this.textColor,this.pieLegendTextSize=this.pieLegendTextSize||"17px",this.pieLegendTextColor=this.pieLegendTextColor||this.taskTextDarkColor,this.pieStrokeColor=this.pieStrokeColor||"black",this.pieStrokeWidth=this.pieStrokeWidth||"2px",this.pieOuterStrokeWidth=this.pieOuterStrokeWidth||"2px",this.pieOuterStrokeColor=this.pieOuterStrokeColor||"black",this.pieOpacity=this.pieOpacity||"0.7",this.venn1=this.venn1??le(this.primaryColor,{l:-30}),this.venn2=this.venn2??le(this.secondaryColor,{l:-30}),this.venn3=this.venn3??le(this.tertiaryColor,{l:-40}),this.venn4=this.venn4??le(this.primaryColor,{h:60,l:-30}),this.venn5=this.venn5??le(this.primaryColor,{h:-60,l:-30}),this.venn6=this.venn6??le(this.secondaryColor,{h:60,l:-30}),this.venn7=this.venn7??le(this.primaryColor,{h:120,l:-30}),this.venn8=this.venn8??le(this.secondaryColor,{h:120,l:-30}),this.vennTitleTextColor=this.vennTitleTextColor??this.titleColor,this.vennSetTextColor=this.vennSetTextColor??this.textColor,this.quadrant1Fill=this.quadrant1Fill||this.primaryColor,this.quadrant2Fill=this.quadrant2Fill||le(this.primaryColor,{r:5,g:5,b:5}),this.quadrant3Fill=this.quadrant3Fill||le(this.primaryColor,{r:10,g:10,b:10}),this.quadrant4Fill=this.quadrant4Fill||le(this.primaryColor,{r:15,g:15,b:15}),this.quadrant1TextFill=this.quadrant1TextFill||this.primaryTextColor,this.quadrant2TextFill=this.quadrant2TextFill||le(this.primaryTextColor,{r:-5,g:-5,b:-5}),this.quadrant3TextFill=this.quadrant3TextFill||le(this.primaryTextColor,{r:-10,g:-10,b:-10}),this.quadrant4TextFill=this.quadrant4TextFill||le(this.primaryTextColor,{r:-15,g:-15,b:-15}),this.quadrantPointFill=this.quadrantPointFill||dp(this.quadrant1Fill)?Ue(this.quadrant1Fill):nt(this.quadrant1Fill),this.quadrantPointTextFill=this.quadrantPointTextFill||this.primaryTextColor,this.quadrantXAxisTextFill=this.quadrantXAxisTextFill||this.primaryTextColor,this.quadrantYAxisTextFill=this.quadrantYAxisTextFill||this.primaryTextColor,this.quadrantInternalBorderStrokeFill=this.quadrantInternalBorderStrokeFill||this.primaryBorderColor,this.quadrantExternalBorderStrokeFill=this.quadrantExternalBorderStrokeFill||this.primaryBorderColor,this.quadrantTitleFill=this.quadrantTitleFill||this.primaryTextColor,this.radar={axisColor:((t=this.radar)==null?void 0:t.axisColor)||this.lineColor,axisStrokeWidth:((n=this.radar)==null?void 0:n.axisStrokeWidth)||2,axisLabelFontSize:((r=this.radar)==null?void 0:r.axisLabelFontSize)||12,curveOpacity:((a=this.radar)==null?void 0:a.curveOpacity)||.5,curveStrokeWidth:((i=this.radar)==null?void 0:i.curveStrokeWidth)||2,graticuleColor:((o=this.radar)==null?void 0:o.graticuleColor)||"#DEDEDE",graticuleStrokeWidth:((l=this.radar)==null?void 0:l.graticuleStrokeWidth)||1,graticuleOpacity:((u=this.radar)==null?void 0:u.graticuleOpacity)||.3,legendBoxSize:((d=this.radar)==null?void 0:d.legendBoxSize)||12,legendFontSize:((h=this.radar)==null?void 0:h.legendFontSize)||12},this.xyChart={backgroundColor:((f=this.xyChart)==null?void 0:f.backgroundColor)||this.background,titleColor:((m=this.xyChart)==null?void 0:m.titleColor)||this.primaryTextColor,xAxisTitleColor:((b=this.xyChart)==null?void 0:b.xAxisTitleColor)||this.primaryTextColor,xAxisLabelColor:((y=this.xyChart)==null?void 0:y.xAxisLabelColor)||this.primaryTextColor,xAxisTickColor:((v=this.xyChart)==null?void 0:v.xAxisTickColor)||this.primaryTextColor,xAxisLineColor:((w=this.xyChart)==null?void 0:w.xAxisLineColor)||this.primaryTextColor,yAxisTitleColor:((S=this.xyChart)==null?void 0:S.yAxisTitleColor)||this.primaryTextColor,yAxisLabelColor:((k=this.xyChart)==null?void 0:k.yAxisLabelColor)||this.primaryTextColor,yAxisTickColor:((R=this.xyChart)==null?void 0:R.yAxisTickColor)||this.primaryTextColor,yAxisLineColor:((I=this.xyChart)==null?void 0:I.yAxisLineColor)||this.primaryTextColor,plotColorPalette:((L=this.xyChart)==null?void 0:L.plotColorPalette)||"#ECECFF,#8493A6,#FFC3A0,#DCDDE1,#B8E994,#D1A36F,#C3CDE6,#FFB6C1,#496078,#F8F3E3"},this.requirementBackground=this.requirementBackground||this.primaryColor,this.requirementBorderColor=this.requirementBorderColor||this.primaryBorderColor,this.requirementBorderSize=this.requirementBorderSize||"1",this.requirementTextColor=this.requirementTextColor||this.primaryTextColor,this.relationColor=this.relationColor||this.lineColor,this.relationLabelBackground=this.relationLabelBackground||this.labelBackground,this.relationLabelColor=this.relationLabelColor||this.actorTextColor,this.git0=this.git0||this.primaryColor,this.git1=this.git1||this.secondaryColor,this.git2=this.git2||this.tertiaryColor,this.git3=this.git3||le(this.primaryColor,{h:-30}),this.git4=this.git4||le(this.primaryColor,{h:-60}),this.git5=this.git5||le(this.primaryColor,{h:-90}),this.git6=this.git6||le(this.primaryColor,{h:60}),this.git7=this.git7||le(this.primaryColor,{h:120}),this.darkMode?(this.git0=Ue(this.git0,25),this.git1=Ue(this.git1,25),this.git2=Ue(this.git2,25),this.git3=Ue(this.git3,25),this.git4=Ue(this.git4,25),this.git5=Ue(this.git5,25),this.git6=Ue(this.git6,25),this.git7=Ue(this.git7,25)):(this.git0=nt(this.git0,25),this.git1=nt(this.git1,25),this.git2=nt(this.git2,25),this.git3=nt(this.git3,25),this.git4=nt(this.git4,25),this.git5=nt(this.git5,25),this.git6=nt(this.git6,25),this.git7=nt(this.git7,25)),this.gitInv0=this.gitInv0||nt(Me(this.git0),25),this.gitInv1=this.gitInv1||Me(this.git1),this.gitInv2=this.gitInv2||Me(this.git2),this.gitInv3=this.gitInv3||Me(this.git3),this.gitInv4=this.gitInv4||Me(this.git4),this.gitInv5=this.gitInv5||Me(this.git5),this.gitInv6=this.gitInv6||Me(this.git6),this.gitInv7=this.gitInv7||Me(this.git7),this.gitBranchLabel0=this.gitBranchLabel0||Me(this.labelTextColor),this.gitBranchLabel1=this.gitBranchLabel1||this.labelTextColor,this.gitBranchLabel2=this.gitBranchLabel2||this.labelTextColor,this.gitBranchLabel3=this.gitBranchLabel3||Me(this.labelTextColor),this.gitBranchLabel4=this.gitBranchLabel4||this.labelTextColor,this.gitBranchLabel5=this.gitBranchLabel5||this.labelTextColor,this.gitBranchLabel6=this.gitBranchLabel6||this.labelTextColor,this.gitBranchLabel7=this.gitBranchLabel7||this.labelTextColor,this.tagLabelColor=this.tagLabelColor||this.primaryTextColor,this.tagLabelBackground=this.tagLabelBackground||this.primaryColor,this.tagLabelBorder=this.tagBorder||this.primaryBorderColor,this.tagLabelFontSize=this.tagLabelFontSize||"10px",this.commitLabelColor=this.commitLabelColor||this.secondaryTextColor,this.commitLabelBackground=this.commitLabelBackground||this.secondaryColor,this.commitLabelFontSize=this.commitLabelFontSize||"10px",this.attributeBackgroundColorOdd=this.attributeBackgroundColorOdd||Pg,this.attributeBackgroundColorEven=this.attributeBackgroundColorEven||Ug}calculate(t){if(Object.keys(this).forEach(r=>{this[r]==="calculated"&&(this[r]=void 0)}),typeof t!="object"){this.updateColors();return}const n=Object.keys(t);n.forEach(r=>{this[r]=t[r]}),this.updateColors(),n.forEach(r=>{this[r]=t[r]})}},N(Wc,"Theme"),Wc),jce=N(e=>{const t=new Uce;return t.calculate(e),t},"getThemeVariables"),Vc,Hce=(Vc=class{constructor(){this.background="#f4f4f4",this.primaryColor="#cde498",this.secondaryColor="#cdffb2",this.background="white",this.mainBkg="#cde498",this.secondBkg="#cdffb2",this.lineColor="green",this.border1="#13540c",this.border2="#6eaa49",this.arrowheadColor="green",this.fontFamily='"trebuchet ms", verdana, arial, sans-serif',this.fontSize="16px",this.tertiaryColor=Ue("#cde498",10),this.primaryBorderColor=Dr(this.primaryColor,this.darkMode),this.secondaryBorderColor=Dr(this.secondaryColor,this.darkMode),this.tertiaryBorderColor=Dr(this.tertiaryColor,this.darkMode),this.primaryTextColor=Me(this.primaryColor),this.secondaryTextColor=Me(this.secondaryColor),this.tertiaryTextColor=Me(this.primaryColor),this.lineColor=Me(this.background),this.textColor=Me(this.background),this.THEME_COLOR_LIMIT=12,this.nodeBkg="calculated",this.nodeBorder="calculated",this.clusterBkg="calculated",this.clusterBorder="calculated",this.defaultLinkColor="calculated",this.titleColor="#333",this.edgeLabelBackground="#e8e8e8",this.actorBorder="calculated",this.actorBkg="calculated",this.actorTextColor="black",this.actorLineColor="calculated",this.signalColor="#333",this.signalTextColor="#333",this.labelBoxBkgColor="calculated",this.labelBoxBorderColor="#326932",this.labelTextColor="calculated",this.loopTextColor="calculated",this.noteBorderColor="calculated",this.noteBkgColor="#fff5ad",this.noteTextColor="calculated",this.activationBorderColor="#666",this.activationBkgColor="#f4f4f4",this.sequenceNumberColor="white",this.sectionBkgColor="#6eaa49",this.altSectionBkgColor="white",this.sectionBkgColor2="#6eaa49",this.excludeBkgColor="#eeeeee",this.taskBorderColor="calculated",this.taskBkgColor="#487e3a",this.taskTextLightColor="white",this.taskTextColor="calculated",this.taskTextDarkColor="black",this.taskTextOutsideColor="calculated",this.taskTextClickableColor="#003163",this.activeTaskBorderColor="calculated",this.activeTaskBkgColor="calculated",this.gridColor="lightgrey",this.doneTaskBkgColor="lightgrey",this.doneTaskBorderColor="grey",this.critBorderColor="#ff8888",this.critBkgColor="red",this.todayLineColor="red",this.vertLineColor="#00BFFF",this.personBorder=this.primaryBorderColor,this.personBkg=this.mainBkg,this.archEdgeColor="calculated",this.archEdgeArrowColor="calculated",this.archEdgeWidth="3",this.archGroupBorderColor=this.primaryBorderColor,this.archGroupBorderWidth="2px",this.labelColor="black",this.errorBkgColor="#552222",this.errorTextColor="#552222"}updateColors(){var t,n,r,a,i,o,l,u,d,h,f,m,b,y,v,w,S,k,R,I,L;this.actorBorder=nt(this.mainBkg,20),this.actorBkg=this.mainBkg,this.labelBoxBkgColor=this.actorBkg,this.labelTextColor=this.actorTextColor,this.loopTextColor=this.actorTextColor,this.noteBorderColor=this.border2,this.noteTextColor=this.actorTextColor,this.actorLineColor=this.actorBorder,this.cScale0=this.cScale0||this.primaryColor,this.cScale1=this.cScale1||this.secondaryColor,this.cScale2=this.cScale2||this.tertiaryColor,this.cScale3=this.cScale3||le(this.primaryColor,{h:30}),this.cScale4=this.cScale4||le(this.primaryColor,{h:60}),this.cScale5=this.cScale5||le(this.primaryColor,{h:90}),this.cScale6=this.cScale6||le(this.primaryColor,{h:120}),this.cScale7=this.cScale7||le(this.primaryColor,{h:150}),this.cScale8=this.cScale8||le(this.primaryColor,{h:210}),this.cScale9=this.cScale9||le(this.primaryColor,{h:270}),this.cScale10=this.cScale10||le(this.primaryColor,{h:300}),this.cScale11=this.cScale11||le(this.primaryColor,{h:330}),this.cScalePeer1=this.cScalePeer1||nt(this.secondaryColor,45),this.cScalePeer2=this.cScalePeer2||nt(this.tertiaryColor,40);for(let A=0;A<this.THEME_COLOR_LIMIT;A++)this["cScale"+A]=nt(this["cScale"+A],10),this["cScalePeer"+A]=this["cScalePeer"+A]||nt(this["cScale"+A],25);for(let A=0;A<this.THEME_COLOR_LIMIT;A++)this["cScaleInv"+A]=this["cScaleInv"+A]||le(this["cScale"+A],{h:180});this.scaleLabelColor=this.scaleLabelColor!=="calculated"&&this.scaleLabelColor?this.scaleLabelColor:this.labelTextColor;for(let A=0;A<this.THEME_COLOR_LIMIT;A++)this["cScaleLabel"+A]=this["cScaleLabel"+A]||this.scaleLabelColor;for(let A=0;A<5;A++)this["surface"+A]=this["surface"+A]||le(this.mainBkg,{h:30,s:-30,l:-(5+A*5)}),this["surfacePeer"+A]=this["surfacePeer"+A]||le(this.mainBkg,{h:30,s:-30,l:-(8+A*5)});this.nodeBkg=this.mainBkg,this.nodeBorder=this.border1,this.clusterBkg=this.secondBkg,this.clusterBorder=this.border2,this.defaultLinkColor=this.lineColor,this.taskBorderColor=this.border1,this.taskTextColor=this.taskTextLightColor,this.taskTextOutsideColor=this.taskTextDarkColor,this.activeTaskBorderColor=this.taskBorderColor,this.activeTaskBkgColor=this.mainBkg,this.archEdgeColor=this.lineColor,this.archEdgeArrowColor=this.lineColor,this.rowOdd=this.rowOdd||Ue(this.mainBkg,75)||"#ffffff",this.rowEven=this.rowEven||Ue(this.mainBkg,20),this.transitionColor=this.transitionColor||this.lineColor,this.transitionLabelColor=this.transitionLabelColor||this.textColor,this.stateLabelColor=this.stateLabelColor||this.stateBkg||this.primaryTextColor,this.stateBkg=this.stateBkg||this.mainBkg,this.labelBackgroundColor=this.labelBackgroundColor||this.stateBkg,this.compositeBackground=this.compositeBackground||this.background||this.tertiaryColor,this.altBackground=this.altBackground||"#f0f0f0",this.compositeTitleBackground=this.compositeTitleBackground||this.mainBkg,this.compositeBorder=this.compositeBorder||this.nodeBorder,this.innerEndBackground=this.primaryBorderColor,this.specialStateColor=this.lineColor,this.errorBkgColor=this.errorBkgColor||this.tertiaryColor,this.errorTextColor=this.errorTextColor||this.tertiaryTextColor,this.transitionColor=this.transitionColor||this.lineColor,this.classText=this.primaryTextColor,this.fillType0=this.primaryColor,this.fillType1=this.secondaryColor,this.fillType2=le(this.primaryColor,{h:64}),this.fillType3=le(this.secondaryColor,{h:64}),this.fillType4=le(this.primaryColor,{h:-64}),this.fillType5=le(this.secondaryColor,{h:-64}),this.fillType6=le(this.primaryColor,{h:128}),this.fillType7=le(this.secondaryColor,{h:128}),this.pie1=this.pie1||this.primaryColor,this.pie2=this.pie2||this.secondaryColor,this.pie3=this.pie3||this.tertiaryColor,this.pie4=this.pie4||le(this.primaryColor,{l:-30}),this.pie5=this.pie5||le(this.secondaryColor,{l:-30}),this.pie6=this.pie6||le(this.tertiaryColor,{h:40,l:-40}),this.pie7=this.pie7||le(this.primaryColor,{h:60,l:-10}),this.pie8=this.pie8||le(this.primaryColor,{h:-60,l:-10}),this.pie9=this.pie9||le(this.primaryColor,{h:120,l:0}),this.pie10=this.pie10||le(this.primaryColor,{h:60,l:-50}),this.pie11=this.pie11||le(this.primaryColor,{h:-60,l:-50}),this.pie12=this.pie12||le(this.primaryColor,{h:120,l:-50}),this.pieTitleTextSize=this.pieTitleTextSize||"25px",this.pieTitleTextColor=this.pieTitleTextColor||this.taskTextDarkColor,this.pieSectionTextSize=this.pieSectionTextSize||"17px",this.pieSectionTextColor=this.pieSectionTextColor||this.textColor,this.pieLegendTextSize=this.pieLegendTextSize||"17px",this.pieLegendTextColor=this.pieLegendTextColor||this.taskTextDarkColor,this.pieStrokeColor=this.pieStrokeColor||"black",this.pieStrokeWidth=this.pieStrokeWidth||"2px",this.pieOuterStrokeWidth=this.pieOuterStrokeWidth||"2px",this.pieOuterStrokeColor=this.pieOuterStrokeColor||"black",this.pieOpacity=this.pieOpacity||"0.7",this.venn1=this.venn1??le(this.primaryColor,{l:-30}),this.venn2=this.venn2??le(this.secondaryColor,{l:-30}),this.venn3=this.venn3??le(this.tertiaryColor,{l:-30}),this.venn4=this.venn4??le(this.primaryColor,{h:60,l:-30}),this.venn5=this.venn5??le(this.primaryColor,{h:-60,l:-30}),this.venn6=this.venn6??le(this.secondaryColor,{h:60,l:-30}),this.venn7=this.venn7??le(this.primaryColor,{h:120,l:-30}),this.venn8=this.venn8??le(this.secondaryColor,{h:120,l:-30}),this.vennTitleTextColor=this.vennTitleTextColor??this.titleColor,this.vennSetTextColor=this.vennSetTextColor??this.textColor,this.quadrant1Fill=this.quadrant1Fill||this.primaryColor,this.quadrant2Fill=this.quadrant2Fill||le(this.primaryColor,{r:5,g:5,b:5}),this.quadrant3Fill=this.quadrant3Fill||le(this.primaryColor,{r:10,g:10,b:10}),this.quadrant4Fill=this.quadrant4Fill||le(this.primaryColor,{r:15,g:15,b:15}),this.quadrant1TextFill=this.quadrant1TextFill||this.primaryTextColor,this.quadrant2TextFill=this.quadrant2TextFill||le(this.primaryTextColor,{r:-5,g:-5,b:-5}),this.quadrant3TextFill=this.quadrant3TextFill||le(this.primaryTextColor,{r:-10,g:-10,b:-10}),this.quadrant4TextFill=this.quadrant4TextFill||le(this.primaryTextColor,{r:-15,g:-15,b:-15}),this.quadrantPointFill=this.quadrantPointFill||dp(this.quadrant1Fill)?Ue(this.quadrant1Fill):nt(this.quadrant1Fill),this.quadrantPointTextFill=this.quadrantPointTextFill||this.primaryTextColor,this.quadrantXAxisTextFill=this.quadrantXAxisTextFill||this.primaryTextColor,this.quadrantYAxisTextFill=this.quadrantYAxisTextFill||this.primaryTextColor,this.quadrantInternalBorderStrokeFill=this.quadrantInternalBorderStrokeFill||this.primaryBorderColor,this.quadrantExternalBorderStrokeFill=this.quadrantExternalBorderStrokeFill||this.primaryBorderColor,this.quadrantTitleFill=this.quadrantTitleFill||this.primaryTextColor,this.packet={startByteColor:this.primaryTextColor,endByteColor:this.primaryTextColor,labelColor:this.primaryTextColor,titleColor:this.primaryTextColor,blockStrokeColor:this.primaryTextColor,blockFillColor:this.mainBkg},this.radar={axisColor:((t=this.radar)==null?void 0:t.axisColor)||this.lineColor,axisStrokeWidth:((n=this.radar)==null?void 0:n.axisStrokeWidth)||2,axisLabelFontSize:((r=this.radar)==null?void 0:r.axisLabelFontSize)||12,curveOpacity:((a=this.radar)==null?void 0:a.curveOpacity)||.5,curveStrokeWidth:((i=this.radar)==null?void 0:i.curveStrokeWidth)||2,graticuleColor:((o=this.radar)==null?void 0:o.graticuleColor)||"#DEDEDE",graticuleStrokeWidth:((l=this.radar)==null?void 0:l.graticuleStrokeWidth)||1,graticuleOpacity:((u=this.radar)==null?void 0:u.graticuleOpacity)||.3,legendBoxSize:((d=this.radar)==null?void 0:d.legendBoxSize)||12,legendFontSize:((h=this.radar)==null?void 0:h.legendFontSize)||12},this.xyChart={backgroundColor:((f=this.xyChart)==null?void 0:f.backgroundColor)||this.background,titleColor:((m=this.xyChart)==null?void 0:m.titleColor)||this.primaryTextColor,xAxisTitleColor:((b=this.xyChart)==null?void 0:b.xAxisTitleColor)||this.primaryTextColor,xAxisLabelColor:((y=this.xyChart)==null?void 0:y.xAxisLabelColor)||this.primaryTextColor,xAxisTickColor:((v=this.xyChart)==null?void 0:v.xAxisTickColor)||this.primaryTextColor,xAxisLineColor:((w=this.xyChart)==null?void 0:w.xAxisLineColor)||this.primaryTextColor,yAxisTitleColor:((S=this.xyChart)==null?void 0:S.yAxisTitleColor)||this.primaryTextColor,yAxisLabelColor:((k=this.xyChart)==null?void 0:k.yAxisLabelColor)||this.primaryTextColor,yAxisTickColor:((R=this.xyChart)==null?void 0:R.yAxisTickColor)||this.primaryTextColor,yAxisLineColor:((I=this.xyChart)==null?void 0:I.yAxisLineColor)||this.primaryTextColor,plotColorPalette:((L=this.xyChart)==null?void 0:L.plotColorPalette)||"#CDE498,#FF6B6B,#A0D2DB,#D7BDE2,#F0F0F0,#FFC3A0,#7FD8BE,#FF9A8B,#FAF3E0,#FFF176"},this.requirementBackground=this.requirementBackground||this.primaryColor,this.requirementBorderColor=this.requirementBorderColor||this.primaryBorderColor,this.requirementBorderSize=this.requirementBorderSize||"1",this.requirementTextColor=this.requirementTextColor||this.primaryTextColor,this.relationColor=this.relationColor||this.lineColor,this.relationLabelBackground=this.relationLabelBackground||this.edgeLabelBackground,this.relationLabelColor=this.relationLabelColor||this.actorTextColor,this.git0=this.git0||this.primaryColor,this.git1=this.git1||this.secondaryColor,this.git2=this.git2||this.tertiaryColor,this.git3=this.git3||le(this.primaryColor,{h:-30}),this.git4=this.git4||le(this.primaryColor,{h:-60}),this.git5=this.git5||le(this.primaryColor,{h:-90}),this.git6=this.git6||le(this.primaryColor,{h:60}),this.git7=this.git7||le(this.primaryColor,{h:120}),this.darkMode?(this.git0=Ue(this.git0,25),this.git1=Ue(this.git1,25),this.git2=Ue(this.git2,25),this.git3=Ue(this.git3,25),this.git4=Ue(this.git4,25),this.git5=Ue(this.git5,25),this.git6=Ue(this.git6,25),this.git7=Ue(this.git7,25)):(this.git0=nt(this.git0,25),this.git1=nt(this.git1,25),this.git2=nt(this.git2,25),this.git3=nt(this.git3,25),this.git4=nt(this.git4,25),this.git5=nt(this.git5,25),this.git6=nt(this.git6,25),this.git7=nt(this.git7,25)),this.gitInv0=this.gitInv0||Me(this.git0),this.gitInv1=this.gitInv1||Me(this.git1),this.gitInv2=this.gitInv2||Me(this.git2),this.gitInv3=this.gitInv3||Me(this.git3),this.gitInv4=this.gitInv4||Me(this.git4),this.gitInv5=this.gitInv5||Me(this.git5),this.gitInv6=this.gitInv6||Me(this.git6),this.gitInv7=this.gitInv7||Me(this.git7),this.gitBranchLabel0=this.gitBranchLabel0||Me(this.labelTextColor),this.gitBranchLabel1=this.gitBranchLabel1||this.labelTextColor,this.gitBranchLabel2=this.gitBranchLabel2||this.labelTextColor,this.gitBranchLabel3=this.gitBranchLabel3||Me(this.labelTextColor),this.gitBranchLabel4=this.gitBranchLabel4||this.labelTextColor,this.gitBranchLabel5=this.gitBranchLabel5||this.labelTextColor,this.gitBranchLabel6=this.gitBranchLabel6||this.labelTextColor,this.gitBranchLabel7=this.gitBranchLabel7||this.labelTextColor,this.tagLabelColor=this.tagLabelColor||this.primaryTextColor,this.tagLabelBackground=this.tagLabelBackground||this.primaryColor,this.tagLabelBorder=this.tagBorder||this.primaryBorderColor,this.tagLabelFontSize=this.tagLabelFontSize||"10px",this.commitLabelColor=this.commitLabelColor||this.secondaryTextColor,this.commitLabelBackground=this.commitLabelBackground||this.secondaryColor,this.commitLabelFontSize=this.commitLabelFontSize||"10px",this.attributeBackgroundColorOdd=this.attributeBackgroundColorOdd||Pg,this.attributeBackgroundColorEven=this.attributeBackgroundColorEven||Ug}calculate(t){if(typeof t!="object"){this.updateColors();return}const n=Object.keys(t);n.forEach(r=>{this[r]=t[r]}),this.updateColors(),n.forEach(r=>{this[r]=t[r]})}},N(Vc,"Theme"),Vc),Gce=N(e=>{const t=new Hce;return t.calculate(e),t},"getThemeVariables"),Yc,qce=(Yc=class{constructor(){this.primaryColor="#eee",this.contrast="#707070",this.secondaryColor=Ue(this.contrast,55),this.background="#ffffff",this.tertiaryColor=le(this.primaryColor,{h:-160}),this.primaryBorderColor=Dr(this.primaryColor,this.darkMode),this.secondaryBorderColor=Dr(this.secondaryColor,this.darkMode),this.tertiaryBorderColor=Dr(this.tertiaryColor,this.darkMode),this.primaryTextColor=Me(this.primaryColor),this.secondaryTextColor=Me(this.secondaryColor),this.tertiaryTextColor=Me(this.tertiaryColor),this.lineColor=Me(this.background),this.textColor=Me(this.background),this.mainBkg="#eee",this.secondBkg="calculated",this.lineColor="#666",this.border1="#999",this.border2="calculated",this.note="#ffa",this.text="#333",this.critical="#d42",this.done="#bbb",this.arrowheadColor="#333333",this.fontFamily='"trebuchet ms", verdana, arial, sans-serif',this.fontSize="16px",this.THEME_COLOR_LIMIT=12,this.nodeBkg="calculated",this.nodeBorder="calculated",this.clusterBkg="calculated",this.clusterBorder="calculated",this.defaultLinkColor="calculated",this.titleColor="calculated",this.edgeLabelBackground="white",this.actorBorder="calculated",this.actorBkg="calculated",this.actorTextColor="calculated",this.actorLineColor=this.actorBorder,this.signalColor="calculated",this.signalTextColor="calculated",this.labelBoxBkgColor="calculated",this.labelBoxBorderColor="calculated",this.labelTextColor="calculated",this.loopTextColor="calculated",this.noteBorderColor="calculated",this.noteBkgColor="calculated",this.noteTextColor="calculated",this.activationBorderColor="#666",this.activationBkgColor="#f4f4f4",this.sequenceNumberColor="white",this.sectionBkgColor="calculated",this.altSectionBkgColor="white",this.sectionBkgColor2="calculated",this.excludeBkgColor="#eeeeee",this.taskBorderColor="calculated",this.taskBkgColor="calculated",this.taskTextLightColor="white",this.taskTextColor="calculated",this.taskTextDarkColor="calculated",this.taskTextOutsideColor="calculated",this.taskTextClickableColor="#003163",this.activeTaskBorderColor="calculated",this.activeTaskBkgColor="calculated",this.gridColor="calculated",this.doneTaskBkgColor="calculated",this.doneTaskBorderColor="calculated",this.critBkgColor="calculated",this.critBorderColor="calculated",this.todayLineColor="calculated",this.vertLineColor="calculated",this.personBorder=this.primaryBorderColor,this.personBkg=this.mainBkg,this.archEdgeColor="calculated",this.archEdgeArrowColor="calculated",this.archEdgeWidth="3",this.archGroupBorderColor=this.primaryBorderColor,this.archGroupBorderWidth="2px",this.rowOdd=this.rowOdd||Ue(this.mainBkg,75)||"#ffffff",this.rowEven=this.rowEven||"#f4f4f4",this.labelColor="black",this.errorBkgColor="#552222",this.errorTextColor="#552222"}updateColors(){var t,n,r,a,i,o,l,u,d,h,f,m,b,y,v,w,S,k,R,I,L;this.secondBkg=Ue(this.contrast,55),this.border2=this.contrast,this.actorBorder=Ue(this.border1,23),this.actorBkg=this.mainBkg,this.actorTextColor=this.text,this.actorLineColor=this.actorBorder,this.signalColor=this.text,this.signalTextColor=this.text,this.labelBoxBkgColor=this.actorBkg,this.labelBoxBorderColor=this.actorBorder,this.labelTextColor=this.text,this.loopTextColor=this.text,this.noteBorderColor="#999",this.noteBkgColor="#666",this.noteTextColor="#fff",this.cScale0=this.cScale0||"#555",this.cScale1=this.cScale1||"#F4F4F4",this.cScale2=this.cScale2||"#555",this.cScale3=this.cScale3||"#BBB",this.cScale4=this.cScale4||"#777",this.cScale5=this.cScale5||"#999",this.cScale6=this.cScale6||"#DDD",this.cScale7=this.cScale7||"#FFF",this.cScale8=this.cScale8||"#DDD",this.cScale9=this.cScale9||"#BBB",this.cScale10=this.cScale10||"#999",this.cScale11=this.cScale11||"#777";for(let A=0;A<this.THEME_COLOR_LIMIT;A++)this["cScaleInv"+A]=this["cScaleInv"+A]||Me(this["cScale"+A]);for(let A=0;A<this.THEME_COLOR_LIMIT;A++)this.darkMode?this["cScalePeer"+A]=this["cScalePeer"+A]||Ue(this["cScale"+A],10):this["cScalePeer"+A]=this["cScalePeer"+A]||nt(this["cScale"+A],10);this.scaleLabelColor=this.scaleLabelColor||(this.darkMode?"black":this.labelTextColor),this.cScaleLabel0=this.cScaleLabel0||this.cScale1,this.cScaleLabel2=this.cScaleLabel2||this.cScale1;for(let A=0;A<this.THEME_COLOR_LIMIT;A++)this["cScaleLabel"+A]=this["cScaleLabel"+A]||this.scaleLabelColor;for(let A=0;A<5;A++)this["surface"+A]=this["surface"+A]||le(this.mainBkg,{l:-(5+A*5)}),this["surfacePeer"+A]=this["surfacePeer"+A]||le(this.mainBkg,{l:-(8+A*5)});this.nodeBkg=this.mainBkg,this.nodeBorder=this.border1,this.clusterBkg=this.secondBkg,this.clusterBorder=this.border2,this.defaultLinkColor=this.lineColor,this.titleColor=this.text,this.sectionBkgColor=Ue(this.contrast,30),this.sectionBkgColor2=Ue(this.contrast,30),this.taskBorderColor=nt(this.contrast,10),this.taskBkgColor=this.contrast,this.taskTextColor=this.taskTextLightColor,this.taskTextDarkColor=this.text,this.taskTextOutsideColor=this.taskTextDarkColor,this.activeTaskBorderColor=this.taskBorderColor,this.activeTaskBkgColor=this.mainBkg,this.gridColor=Ue(this.border1,30),this.doneTaskBkgColor=this.done,this.doneTaskBorderColor=this.lineColor,this.critBkgColor=this.critical,this.critBorderColor=nt(this.critBkgColor,10),this.todayLineColor=this.critBkgColor,this.vertLineColor=this.critBkgColor,this.archEdgeColor=this.lineColor,this.archEdgeArrowColor=this.lineColor,this.transitionColor=this.transitionColor||"#000",this.transitionLabelColor=this.transitionLabelColor||this.textColor,this.stateLabelColor=this.stateLabelColor||this.stateBkg||this.primaryTextColor,this.stateBkg=this.stateBkg||this.mainBkg,this.labelBackgroundColor=this.labelBackgroundColor||this.stateBkg,this.compositeBackground=this.compositeBackground||this.background||this.tertiaryColor,this.altBackground=this.altBackground||"#f4f4f4",this.compositeTitleBackground=this.compositeTitleBackground||this.mainBkg,this.stateBorder=this.stateBorder||"#000",this.innerEndBackground=this.primaryBorderColor,this.specialStateColor="#222",this.errorBkgColor=this.errorBkgColor||this.tertiaryColor,this.errorTextColor=this.errorTextColor||this.tertiaryTextColor,this.classText=this.primaryTextColor,this.fillType0=this.primaryColor,this.fillType1=this.secondaryColor,this.fillType2=le(this.primaryColor,{h:64}),this.fillType3=le(this.secondaryColor,{h:64}),this.fillType4=le(this.primaryColor,{h:-64}),this.fillType5=le(this.secondaryColor,{h:-64}),this.fillType6=le(this.primaryColor,{h:128}),this.fillType7=le(this.secondaryColor,{h:128});for(let A=0;A<this.THEME_COLOR_LIMIT;A++)this["pie"+A]=this["cScale"+A];this.pie12=this.pie0,this.pieTitleTextSize=this.pieTitleTextSize||"25px",this.pieTitleTextColor=this.pieTitleTextColor||this.taskTextDarkColor,this.pieSectionTextSize=this.pieSectionTextSize||"17px",this.pieSectionTextColor=this.pieSectionTextColor||this.textColor,this.pieLegendTextSize=this.pieLegendTextSize||"17px",this.pieLegendTextColor=this.pieLegendTextColor||this.taskTextDarkColor,this.pieStrokeColor=this.pieStrokeColor||"black",this.pieStrokeWidth=this.pieStrokeWidth||"2px",this.pieOuterStrokeWidth=this.pieOuterStrokeWidth||"2px",this.pieOuterStrokeColor=this.pieOuterStrokeColor||"black",this.pieOpacity=this.pieOpacity||"0.7";for(let A=0;A<8;A++)this["venn"+(A+1)]=this["venn"+(A+1)]??this["cScale"+A];this.vennTitleTextColor=this.vennTitleTextColor??this.titleColor,this.vennSetTextColor=this.vennSetTextColor??this.textColor,this.quadrant1Fill=this.quadrant1Fill||this.primaryColor,this.quadrant2Fill=this.quadrant2Fill||le(this.primaryColor,{r:5,g:5,b:5}),this.quadrant3Fill=this.quadrant3Fill||le(this.primaryColor,{r:10,g:10,b:10}),this.quadrant4Fill=this.quadrant4Fill||le(this.primaryColor,{r:15,g:15,b:15}),this.quadrant1TextFill=this.quadrant1TextFill||this.primaryTextColor,this.quadrant2TextFill=this.quadrant2TextFill||le(this.primaryTextColor,{r:-5,g:-5,b:-5}),this.quadrant3TextFill=this.quadrant3TextFill||le(this.primaryTextColor,{r:-10,g:-10,b:-10}),this.quadrant4TextFill=this.quadrant4TextFill||le(this.primaryTextColor,{r:-15,g:-15,b:-15}),this.quadrantPointFill=this.quadrantPointFill||dp(this.quadrant1Fill)?Ue(this.quadrant1Fill):nt(this.quadrant1Fill),this.quadrantPointTextFill=this.quadrantPointTextFill||this.primaryTextColor,this.quadrantXAxisTextFill=this.quadrantXAxisTextFill||this.primaryTextColor,this.quadrantYAxisTextFill=this.quadrantYAxisTextFill||this.primaryTextColor,this.quadrantInternalBorderStrokeFill=this.quadrantInternalBorderStrokeFill||this.primaryBorderColor,this.quadrantExternalBorderStrokeFill=this.quadrantExternalBorderStrokeFill||this.primaryBorderColor,this.quadrantTitleFill=this.quadrantTitleFill||this.primaryTextColor,this.xyChart={backgroundColor:((t=this.xyChart)==null?void 0:t.backgroundColor)||this.background,titleColor:((n=this.xyChart)==null?void 0:n.titleColor)||this.primaryTextColor,xAxisTitleColor:((r=this.xyChart)==null?void 0:r.xAxisTitleColor)||this.primaryTextColor,xAxisLabelColor:((a=this.xyChart)==null?void 0:a.xAxisLabelColor)||this.primaryTextColor,xAxisTickColor:((i=this.xyChart)==null?void 0:i.xAxisTickColor)||this.primaryTextColor,xAxisLineColor:((o=this.xyChart)==null?void 0:o.xAxisLineColor)||this.primaryTextColor,yAxisTitleColor:((l=this.xyChart)==null?void 0:l.yAxisTitleColor)||this.primaryTextColor,yAxisLabelColor:((u=this.xyChart)==null?void 0:u.yAxisLabelColor)||this.primaryTextColor,yAxisTickColor:((d=this.xyChart)==null?void 0:d.yAxisTickColor)||this.primaryTextColor,yAxisLineColor:((h=this.xyChart)==null?void 0:h.yAxisLineColor)||this.primaryTextColor,plotColorPalette:((f=this.xyChart)==null?void 0:f.plotColorPalette)||"#EEE,#6BB8E4,#8ACB88,#C7ACD6,#E8DCC2,#FFB2A8,#FFF380,#7E8D91,#FFD8B1,#FAF3E0"},this.radar={axisColor:((m=this.radar)==null?void 0:m.axisColor)||this.lineColor,axisStrokeWidth:((b=this.radar)==null?void 0:b.axisStrokeWidth)||2,axisLabelFontSize:((y=this.radar)==null?void 0:y.axisLabelFontSize)||12,curveOpacity:((v=this.radar)==null?void 0:v.curveOpacity)||.5,curveStrokeWidth:((w=this.radar)==null?void 0:w.curveStrokeWidth)||2,graticuleColor:((S=this.radar)==null?void 0:S.graticuleColor)||"#DEDEDE",graticuleStrokeWidth:((k=this.radar)==null?void 0:k.graticuleStrokeWidth)||1,graticuleOpacity:((R=this.radar)==null?void 0:R.graticuleOpacity)||.3,legendBoxSize:((I=this.radar)==null?void 0:I.legendBoxSize)||12,legendFontSize:((L=this.radar)==null?void 0:L.legendFontSize)||12},this.requirementBackground=this.requirementBackground||this.primaryColor,this.requirementBorderColor=this.requirementBorderColor||this.primaryBorderColor,this.requirementBorderSize=this.requirementBorderSize||"1",this.requirementTextColor=this.requirementTextColor||this.primaryTextColor,this.relationColor=this.relationColor||this.lineColor,this.relationLabelBackground=this.relationLabelBackground||this.edgeLabelBackground,this.relationLabelColor=this.relationLabelColor||this.actorTextColor,this.git0=nt(this.pie1,25)||this.primaryColor,this.git1=this.pie2||this.secondaryColor,this.git2=this.pie3||this.tertiaryColor,this.git3=this.pie4||le(this.primaryColor,{h:-30}),this.git4=this.pie5||le(this.primaryColor,{h:-60}),this.git5=this.pie6||le(this.primaryColor,{h:-90}),this.git6=this.pie7||le(this.primaryColor,{h:60}),this.git7=this.pie8||le(this.primaryColor,{h:120}),this.gitInv0=this.gitInv0||Me(this.git0),this.gitInv1=this.gitInv1||Me(this.git1),this.gitInv2=this.gitInv2||Me(this.git2),this.gitInv3=this.gitInv3||Me(this.git3),this.gitInv4=this.gitInv4||Me(this.git4),this.gitInv5=this.gitInv5||Me(this.git5),this.gitInv6=this.gitInv6||Me(this.git6),this.gitInv7=this.gitInv7||Me(this.git7),this.branchLabelColor=this.branchLabelColor||this.labelTextColor,this.gitBranchLabel0=this.branchLabelColor,this.gitBranchLabel1="white",this.gitBranchLabel2=this.branchLabelColor,this.gitBranchLabel3="white",this.gitBranchLabel4=this.branchLabelColor,this.gitBranchLabel5=this.branchLabelColor,this.gitBranchLabel6=this.branchLabelColor,this.gitBranchLabel7=this.branchLabelColor,this.tagLabelColor=this.tagLabelColor||this.primaryTextColor,this.tagLabelBackground=this.tagLabelBackground||this.primaryColor,this.tagLabelBorder=this.tagBorder||this.primaryBorderColor,this.tagLabelFontSize=this.tagLabelFontSize||"10px",this.commitLabelColor=this.commitLabelColor||this.secondaryTextColor,this.commitLabelBackground=this.commitLabelBackground||this.secondaryColor,this.commitLabelFontSize=this.commitLabelFontSize||"10px",this.attributeBackgroundColorOdd=this.attributeBackgroundColorOdd||Pg,this.attributeBackgroundColorEven=this.attributeBackgroundColorEven||Ug}calculate(t){if(typeof t!="object"){this.updateColors();return}const n=Object.keys(t);n.forEach(r=>{this[r]=t[r]}),this.updateColors(),n.forEach(r=>{this[r]=t[r]})}},N(Yc,"Theme"),Yc),Wce=N(e=>{const t=new qce;return t.calculate(e),t},"getThemeVariables"),xo={base:{getThemeVariables:zce},dark:{getThemeVariables:Pce},default:{getThemeVariables:jce},forest:{getThemeVariables:Gce},neutral:{getThemeVariables:Wce}},Fa={flowchart:{useMaxWidth:!0,titleTopMargin:25,subGraphTitleMargin:{top:0,bottom:0},diagramPadding:8,htmlLabels:null,nodeSpacing:50,rankSpacing:50,curve:"basis",padding:15,defaultRenderer:"dagre-wrapper",wrappingWidth:200,inheritDir:!1},sequence:{useMaxWidth:!0,hideUnusedParticipants:!1,activationWidth:10,diagramMarginX:50,diagramMarginY:10,actorMargin:50,width:150,height:65,boxMargin:10,boxTextMargin:5,noteMargin:10,messageMargin:35,messageAlign:"center",mirrorActors:!0,forceMenus:!1,bottomMarginAdj:1,rightAngles:!1,showSequenceNumbers:!1,actorFontSize:14,actorFontFamily:'"Open Sans", sans-serif',actorFontWeight:400,noteFontSize:14,noteFontFamily:'"trebuchet ms", verdana, arial, sans-serif',noteFontWeight:400,noteAlign:"center",messageFontSize:16,messageFontFamily:'"trebuchet ms", verdana, arial, sans-serif',messageFontWeight:400,wrap:!1,wrapPadding:10,labelBoxWidth:50,labelBoxHeight:20},gantt:{useMaxWidth:!0,titleTopMargin:25,barHeight:20,barGap:4,topPadding:50,rightPadding:75,leftPadding:75,gridLineStartPadding:35,fontSize:11,sectionFontSize:11,numberSectionStyles:4,axisFormat:"%Y-%m-%d",topAxis:!1,displayMode:"",weekday:"sunday"},journey:{useMaxWidth:!0,diagramMarginX:50,diagramMarginY:10,leftMargin:150,maxLabelWidth:360,width:150,height:50,boxMargin:10,boxTextMargin:5,noteMargin:10,messageMargin:35,messageAlign:"center",bottomMarginAdj:1,rightAngles:!1,taskFontSize:14,taskFontFamily:'"Open Sans", sans-serif',taskMargin:50,activationWidth:10,textPlacement:"fo",actorColours:["#8FBC8F","#7CFC00","#00FFFF","#20B2AA","#B0E0E6","#FFFFE0"],sectionFills:["#191970","#8B008B","#4B0082","#2F4F4F","#800000","#8B4513","#00008B"],sectionColours:["#fff"],titleColor:"",titleFontFamily:'"trebuchet ms", verdana, arial, sans-serif',titleFontSize:"4ex"},class:{useMaxWidth:!0,titleTopMargin:25,arrowMarkerAbsolute:!1,dividerMargin:10,padding:5,textHeight:10,defaultRenderer:"dagre-wrapper",htmlLabels:!1,hideEmptyMembersBox:!1},state:{useMaxWidth:!0,titleTopMargin:25,dividerMargin:10,sizeUnit:5,padding:8,textHeight:10,titleShift:-15,noteMargin:10,forkWidth:70,forkHeight:7,miniPadding:2,fontSizeFactor:5.02,fontSize:24,labelHeight:16,edgeLengthFactor:"20",compositTitleSize:35,radius:5,defaultRenderer:"dagre-wrapper"},er:{useMaxWidth:!0,titleTopMargin:25,diagramPadding:20,layoutDirection:"TB",minEntityWidth:100,minEntityHeight:75,entityPadding:15,nodeSpacing:140,rankSpacing:80,stroke:"gray",fill:"honeydew",fontSize:12},pie:{useMaxWidth:!0,textPosition:.75},quadrantChart:{useMaxWidth:!0,chartWidth:500,chartHeight:500,titleFontSize:20,titlePadding:10,quadrantPadding:5,xAxisLabelPadding:5,yAxisLabelPadding:5,xAxisLabelFontSize:16,yAxisLabelFontSize:16,quadrantLabelFontSize:16,quadrantTextTopPadding:5,pointTextPadding:5,pointLabelFontSize:12,pointRadius:5,xAxisPosition:"top",yAxisPosition:"left",quadrantInternalBorderStrokeWidth:1,quadrantExternalBorderStrokeWidth:2},xyChart:{useMaxWidth:!0,width:700,height:500,titleFontSize:20,titlePadding:10,showDataLabel:!1,showTitle:!0,xAxis:{$ref:"#/$defs/XYChartAxisConfig",showLabel:!0,labelFontSize:14,labelPadding:5,showTitle:!0,titleFontSize:16,titlePadding:5,showTick:!0,tickLength:5,tickWidth:2,showAxisLine:!0,axisLineWidth:2},yAxis:{$ref:"#/$defs/XYChartAxisConfig",showLabel:!0,labelFontSize:14,labelPadding:5,showTitle:!0,titleFontSize:16,titlePadding:5,showTick:!0,tickLength:5,tickWidth:2,showAxisLine:!0,axisLineWidth:2},chartOrientation:"vertical",plotReservedSpacePercent:50},requirement:{useMaxWidth:!0,rect_fill:"#f9f9f9",text_color:"#333",rect_border_size:"0.5px",rect_border_color:"#bbb",rect_min_width:200,rect_min_height:200,fontSize:14,rect_padding:10,line_height:20},mindmap:{useMaxWidth:!0,padding:10,maxNodeWidth:200,layoutAlgorithm:"cose-bilkent"},ishikawa:{useMaxWidth:!0,diagramPadding:20},kanban:{useMaxWidth:!0,padding:8,sectionWidth:200,ticketBaseUrl:""},timeline:{useMaxWidth:!0,diagramMarginX:50,diagramMarginY:10,leftMargin:150,width:150,height:50,boxMargin:10,boxTextMargin:5,noteMargin:10,messageMargin:35,messageAlign:"center",bottomMarginAdj:1,rightAngles:!1,taskFontSize:14,taskFontFamily:'"Open Sans", sans-serif',taskMargin:50,activationWidth:10,textPlacement:"fo",actorColours:["#8FBC8F","#7CFC00","#00FFFF","#20B2AA","#B0E0E6","#FFFFE0"],sectionFills:["#191970","#8B008B","#4B0082","#2F4F4F","#800000","#8B4513","#00008B"],sectionColours:["#fff"],disableMulticolor:!1},gitGraph:{useMaxWidth:!0,titleTopMargin:25,diagramPadding:8,nodeLabel:{width:75,height:100,x:-25,y:0},mainBranchName:"main",mainBranchOrder:0,showCommitLabel:!0,showBranches:!0,rotateCommitLabel:!0,parallelCommits:!1,arrowMarkerAbsolute:!1},c4:{useMaxWidth:!0,diagramMarginX:50,diagramMarginY:10,c4ShapeMargin:50,c4ShapePadding:20,width:216,height:60,boxMargin:10,c4ShapeInRow:4,nextLinePaddingX:0,c4BoundaryInRow:2,personFontSize:14,personFontFamily:'"Open Sans", sans-serif',personFontWeight:"normal",external_personFontSize:14,external_personFontFamily:'"Open Sans", sans-serif',external_personFontWeight:"normal",systemFontSize:14,systemFontFamily:'"Open Sans", sans-serif',systemFontWeight:"normal",external_systemFontSize:14,external_systemFontFamily:'"Open Sans", sans-serif',external_systemFontWeight:"normal",system_dbFontSize:14,system_dbFontFamily:'"Open Sans", sans-serif',system_dbFontWeight:"normal",external_system_dbFontSize:14,external_system_dbFontFamily:'"Open Sans", sans-serif',external_system_dbFontWeight:"normal",system_queueFontSize:14,system_queueFontFamily:'"Open Sans", sans-serif',system_queueFontWeight:"normal",external_system_queueFontSize:14,external_system_queueFontFamily:'"Open Sans", sans-serif',external_system_queueFontWeight:"normal",boundaryFontSize:14,boundaryFontFamily:'"Open Sans", sans-serif',boundaryFontWeight:"normal",messageFontSize:12,messageFontFamily:'"Open Sans", sans-serif',messageFontWeight:"normal",containerFontSize:14,containerFontFamily:'"Open Sans", sans-serif',containerFontWeight:"normal",external_containerFontSize:14,external_containerFontFamily:'"Open Sans", sans-serif',external_containerFontWeight:"normal",container_dbFontSize:14,container_dbFontFamily:'"Open Sans", sans-serif',container_dbFontWeight:"normal",external_container_dbFontSize:14,external_container_dbFontFamily:'"Open Sans", sans-serif',external_container_dbFontWeight:"normal",container_queueFontSize:14,container_queueFontFamily:'"Open Sans", sans-serif',container_queueFontWeight:"normal",external_container_queueFontSize:14,external_container_queueFontFamily:'"Open Sans", sans-serif',external_container_queueFontWeight:"normal",componentFontSize:14,componentFontFamily:'"Open Sans", sans-serif',componentFontWeight:"normal",external_componentFontSize:14,external_componentFontFamily:'"Open Sans", sans-serif',external_componentFontWeight:"normal",component_dbFontSize:14,component_dbFontFamily:'"Open Sans", sans-serif',component_dbFontWeight:"normal",external_component_dbFontSize:14,external_component_dbFontFamily:'"Open Sans", sans-serif',external_component_dbFontWeight:"normal",component_queueFontSize:14,component_queueFontFamily:'"Open Sans", sans-serif',component_queueFontWeight:"normal",external_component_queueFontSize:14,external_component_queueFontFamily:'"Open Sans", sans-serif',external_component_queueFontWeight:"normal",wrap:!0,wrapPadding:10,person_bg_color:"#08427B",person_border_color:"#073B6F",external_person_bg_color:"#686868",external_person_border_color:"#8A8A8A",system_bg_color:"#1168BD",system_border_color:"#3C7FC0",system_db_bg_color:"#1168BD",system_db_border_color:"#3C7FC0",system_queue_bg_color:"#1168BD",system_queue_border_color:"#3C7FC0",external_system_bg_color:"#999999",external_system_border_color:"#8A8A8A",external_system_db_bg_color:"#999999",external_system_db_border_color:"#8A8A8A",external_system_queue_bg_color:"#999999",external_system_queue_border_color:"#8A8A8A",container_bg_color:"#438DD5",container_border_color:"#3C7FC0",container_db_bg_color:"#438DD5",container_db_border_color:"#3C7FC0",container_queue_bg_color:"#438DD5",container_queue_border_color:"#3C7FC0",external_container_bg_color:"#B3B3B3",external_container_border_color:"#A6A6A6",external_container_db_bg_color:"#B3B3B3",external_container_db_border_color:"#A6A6A6",external_container_queue_bg_color:"#B3B3B3",external_container_queue_border_color:"#A6A6A6",component_bg_color:"#85BBF0",component_border_color:"#78A8D8",component_db_bg_color:"#85BBF0",component_db_border_color:"#78A8D8",component_queue_bg_color:"#85BBF0",component_queue_border_color:"#78A8D8",external_component_bg_color:"#CCCCCC",external_component_border_color:"#BFBFBF",external_component_db_bg_color:"#CCCCCC",external_component_db_border_color:"#BFBFBF",external_component_queue_bg_color:"#CCCCCC",external_component_queue_border_color:"#BFBFBF"},sankey:{useMaxWidth:!0,width:600,height:400,linkColor:"gradient",nodeAlignment:"justify",showValues:!0,prefix:"",suffix:""},block:{useMaxWidth:!0,padding:8},packet:{useMaxWidth:!0,rowHeight:32,bitWidth:32,bitsPerRow:32,showBits:!0,paddingX:5,paddingY:5},architecture:{useMaxWidth:!0,padding:40,iconSize:80,fontSize:16},radar:{useMaxWidth:!0,width:600,height:600,marginTop:50,marginRight:50,marginBottom:50,marginLeft:50,axisScaleFactor:1,axisLabelFactor:1.05,curveTension:.17},venn:{useMaxWidth:!0,width:800,height:450,padding:8,useDebugLayout:!1},theme:"default",look:"classic",handDrawnSeed:0,layout:"dagre",maxTextSize:5e4,maxEdges:500,darkMode:!1,fontFamily:'"trebuchet ms", verdana, arial, sans-serif;',logLevel:5,securityLevel:"strict",startOnLoad:!0,arrowMarkerAbsolute:!1,secure:["secure","securityLevel","startOnLoad","maxTextSize","suppressErrorRendering","maxEdges"],legacyMathML:!1,forceLegacyMathML:!1,deterministicIds:!1,fontSize:16,markdownAutoWrap:!0,suppressErrorRendering:!1},d9={...Fa,deterministicIDSeed:void 0,elk:{mergeEdges:!1,nodePlacementStrategy:"BRANDES_KOEPF",forceNodeModelOrder:!1,considerModelOrder:"NODES_AND_EDGES"},themeCSS:void 0,themeVariables:xo.default.getThemeVariables(),sequence:{...Fa.sequence,messageFont:N(function(){return{fontFamily:this.messageFontFamily,fontSize:this.messageFontSize,fontWeight:this.messageFontWeight}},"messageFont"),noteFont:N(function(){return{fontFamily:this.noteFontFamily,fontSize:this.noteFontSize,fontWeight:this.noteFontWeight}},"noteFont"),actorFont:N(function(){return{fontFamily:this.actorFontFamily,fontSize:this.actorFontSize,fontWeight:this.actorFontWeight}},"actorFont")},class:{hideEmptyMembersBox:!1},gantt:{...Fa.gantt,tickInterval:void 0,useWidth:void 0},c4:{...Fa.c4,useWidth:void 0,personFont:N(function(){return{fontFamily:this.personFontFamily,fontSize:this.personFontSize,fontWeight:this.personFontWeight}},"personFont"),flowchart:{...Fa.flowchart,inheritDir:!1},external_personFont:N(function(){return{fontFamily:this.external_personFontFamily,fontSize:this.external_personFontSize,fontWeight:this.external_personFontWeight}},"external_personFont"),systemFont:N(function(){return{fontFamily:this.systemFontFamily,fontSize:this.systemFontSize,fontWeight:this.systemFontWeight}},"systemFont"),external_systemFont:N(function(){return{fontFamily:this.external_systemFontFamily,fontSize:this.external_systemFontSize,fontWeight:this.external_systemFontWeight}},"external_systemFont"),system_dbFont:N(function(){return{fontFamily:this.system_dbFontFamily,fontSize:this.system_dbFontSize,fontWeight:this.system_dbFontWeight}},"system_dbFont"),external_system_dbFont:N(function(){return{fontFamily:this.external_system_dbFontFamily,fontSize:this.external_system_dbFontSize,fontWeight:this.external_system_dbFontWeight}},"external_system_dbFont"),system_queueFont:N(function(){return{fontFamily:this.system_queueFontFamily,fontSize:this.system_queueFontSize,fontWeight:this.system_queueFontWeight}},"system_queueFont"),external_system_queueFont:N(function(){return{fontFamily:this.external_system_queueFontFamily,fontSize:this.external_system_queueFontSize,fontWeight:this.external_system_queueFontWeight}},"external_system_queueFont"),containerFont:N(function(){return{fontFamily:this.containerFontFamily,fontSize:this.containerFontSize,fontWeight:this.containerFontWeight}},"containerFont"),external_containerFont:N(function(){return{fontFamily:this.external_containerFontFamily,fontSize:this.external_containerFontSize,fontWeight:this.external_containerFontWeight}},"external_containerFont"),container_dbFont:N(function(){return{fontFamily:this.container_dbFontFamily,fontSize:this.container_dbFontSize,fontWeight:this.container_dbFontWeight}},"container_dbFont"),external_container_dbFont:N(function(){return{fontFamily:this.external_container_dbFontFamily,fontSize:this.external_container_dbFontSize,fontWeight:this.external_container_dbFontWeight}},"external_container_dbFont"),container_queueFont:N(function(){return{fontFamily:this.container_queueFontFamily,fontSize:this.container_queueFontSize,fontWeight:this.container_queueFontWeight}},"container_queueFont"),external_container_queueFont:N(function(){return{fontFamily:this.external_container_queueFontFamily,fontSize:this.external_container_queueFontSize,fontWeight:this.external_container_queueFontWeight}},"external_container_queueFont"),componentFont:N(function(){return{fontFamily:this.componentFontFamily,fontSize:this.componentFontSize,fontWeight:this.componentFontWeight}},"componentFont"),external_componentFont:N(function(){return{fontFamily:this.external_componentFontFamily,fontSize:this.external_componentFontSize,fontWeight:this.external_componentFontWeight}},"external_componentFont"),component_dbFont:N(function(){return{fontFamily:this.component_dbFontFamily,fontSize:this.component_dbFontSize,fontWeight:this.component_dbFontWeight}},"component_dbFont"),external_component_dbFont:N(function(){return{fontFamily:this.external_component_dbFontFamily,fontSize:this.external_component_dbFontSize,fontWeight:this.external_component_dbFontWeight}},"external_component_dbFont"),component_queueFont:N(function(){return{fontFamily:this.component_queueFontFamily,fontSize:this.component_queueFontSize,fontWeight:this.component_queueFontWeight}},"component_queueFont"),external_component_queueFont:N(function(){return{fontFamily:this.external_component_queueFontFamily,fontSize:this.external_component_queueFontSize,fontWeight:this.external_component_queueFontWeight}},"external_component_queueFont"),boundaryFont:N(function(){return{fontFamily:this.boundaryFontFamily,fontSize:this.boundaryFontSize,fontWeight:this.boundaryFontWeight}},"boundaryFont"),messageFont:N(function(){return{fontFamily:this.messageFontFamily,fontSize:this.messageFontSize,fontWeight:this.messageFontWeight}},"messageFont")},pie:{...Fa.pie,useWidth:984},xyChart:{...Fa.xyChart,useWidth:void 0},requirement:{...Fa.requirement,useWidth:void 0},packet:{...Fa.packet},radar:{...Fa.radar},ishikawa:{...Fa.ishikawa},treemap:{useMaxWidth:!0,padding:10,diagramPadding:8,showValues:!0,nodeWidth:100,nodeHeight:40,borderWidth:1,valueFontSize:12,labelFontSize:14,valueFormat:","},venn:{...Fa.venn}},h9=N((e,t="")=>Object.keys(e).reduce((n,r)=>Array.isArray(e[r])?n:typeof e[r]=="object"&&e[r]!==null?[...n,t+r,...h9(e[r],"")]:[...n,t+r],[]),"keyify"),Vce=new Set(h9(d9,"")),p9=d9,mm=N(e=>{if(we.debug("sanitizeDirective called with",e),!(typeof e!="object"||e==null)){if(Array.isArray(e)){e.forEach(t=>mm(t));return}for(const t of Object.keys(e)){if(we.debug("Checking key",t),t.startsWith("__")||t.includes("proto")||t.includes("constr")||!Vce.has(t)||e[t]==null){we.debug("sanitize deleting key: ",t),delete e[t];continue}if(typeof e[t]=="object"){we.debug("sanitizing object",t),mm(e[t]);continue}const n=["themeCSS","fontFamily","altFontFamily"];for(const r of n)t.includes(r)&&(we.debug("sanitizing css option",t),e[t]=Yce(e[t]))}if(e.themeVariables)for(const t of Object.keys(e.themeVariables)){const n=e.themeVariables[t];n!=null&&n.match&&!n.match(/^[\d "#%(),.;A-Za-z]+$/)&&(e.themeVariables[t]="")}we.debug("After sanitization",e)}},"sanitizeDirective"),Yce=N(e=>{let t=0,n=0;for(const r of e){if(t<n)return"{ /* ERROR: Unbalanced CSS */ }";r==="{"?t++:r==="}"&&n++}return t!==n?"{ /* ERROR: Unbalanced CSS */ }":e},"sanitizeCss"),ru=Object.freeze(p9),Ds=N(e=>!(e===!1||["false","null","0"].includes(String(e).trim().toLowerCase())),"evaluate"),Qr=Yn({},ru),gm,xl=[],mh=Yn({},ru),jg=N((e,t)=>{let n=Yn({},e),r={};for(const a of t)g9(a),r=Yn(r,a);if(n=Yn(n,r),r.theme&&r.theme in xo){const a=Yn({},gm),i=Yn(a.themeVariables||{},r.themeVariables);n.theme&&n.theme in xo&&(n.themeVariables=xo[n.theme].getThemeVariables(i))}return mh=n,y9(mh),mh},"updateCurrentConfig"),Xce=N(e=>(Qr=Yn({},ru),Qr=Yn(Qr,e),e.theme&&xo[e.theme]&&(Qr.themeVariables=xo[e.theme].getThemeVariables(e.themeVariables)),jg(Qr,xl),Qr),"setSiteConfig"),Kce=N(e=>{gm=Yn({},e)},"saveConfigFromInitialize"),Zce=N(e=>(Qr=Yn(Qr,e),jg(Qr,xl),Qr),"updateSiteConfig"),f9=N(()=>Yn({},Qr),"getSiteConfig"),m9=N(e=>(y9(e),Yn(mh,e),br()),"setConfig"),br=N(()=>Yn({},mh),"getConfig"),g9=N(e=>{e&&(["secure",...Qr.secure??[]].forEach(t=>{Object.hasOwn(e,t)&&(we.debug(`Denied attempt to modify a secure key ${t}`,e[t]),delete e[t])}),Object.keys(e).forEach(t=>{t.startsWith("__")&&delete e[t]}),Object.keys(e).forEach(t=>{typeof e[t]=="string"&&(e[t].includes("<")||e[t].includes(">")||e[t].includes("url(data:"))&&delete e[t],typeof e[t]=="object"&&g9(e[t])}))},"sanitize"),Qce=N(e=>{var t;mm(e),e.fontFamily&&!((t=e.themeVariables)!=null&&t.fontFamily)&&(e.themeVariables={...e.themeVariables,fontFamily:e.fontFamily}),xl.push(e),jg(Qr,xl)},"addDirective"),bm=N((e=Qr)=>{xl=[],jg(e,xl)},"reset"),Jce={LAZY_LOAD_DEPRECATED:"The configuration options lazyLoadedDiagrams and loadExternalDiagramsAtStartup are deprecated. Please use registerExternalDiagrams instead.",FLOWCHART_HTML_LABELS_DEPRECATED:"flowchart.htmlLabels is deprecated. Please use global htmlLabels instead."},d7={},b9=N(e=>{d7[e]||(we.warn(Jce[e]),d7[e]=!0)},"issueWarning"),y9=N(e=>{e&&(e.lazyLoadedDiagrams||e.loadExternalDiagramsAtStartup)&&b9("LAZY_LOAD_DEPRECATED")},"checkConfig"),cEe=N(()=>{let e={};gm&&(e=Yn(e,gm));for(const t of xl)e=Yn(e,t);return e},"getUserDefinedConfig"),xr=N(e=>{var t,n;return((t=e.flowchart)==null?void 0:t.htmlLabels)!=null&&b9("FLOWCHART_HTML_LABELS_DEPRECATED"),Ds(e.htmlLabels??((n=e.flowchart)==null?void 0:n.htmlLabels)??!0)},"getEffectiveHtmlLabels"),hp=/<br\s*\/?>/gi,eue=N(e=>e?S9(e).replace(/\\n/g,"#br#").split("#br#"):[""],"getRows"),tue=(()=>{let e=!1;return()=>{e||(v9(),e=!0)}})();function v9(){const e="data-temp-href-target";nu.addHook("beforeSanitizeAttributes",t=>{t.tagName==="A"&&t.hasAttribute("target")&&t.setAttribute(e,t.getAttribute("target")??"")}),nu.addHook("afterSanitizeAttributes",t=>{t.tagName==="A"&&t.hasAttribute(e)&&(t.setAttribute("target",t.getAttribute(e)??""),t.removeAttribute(e),t.getAttribute("target")==="_blank"&&t.setAttribute("rel","noopener"))})}N(v9,"setupDompurifyHooks");var x9=N(e=>(tue(),nu.sanitize(e)),"removeScript"),h7=N((e,t)=>{if(xr(t)){const n=t.securityLevel;n==="antiscript"||n==="strict"||n==="sandbox"?e=x9(e):n!=="loose"&&(e=S9(e),e=e.replace(/</g,"&lt;").replace(/>/g,"&gt;"),e=e.replace(/=/g,"&equals;"),e=iue(e))}return e},"sanitizeMore"),li=N((e,t)=>e&&(t.dompurifyConfig?e=nu.sanitize(h7(e,t),t.dompurifyConfig).toString():e=nu.sanitize(h7(e,t),{FORBID_TAGS:["style"]}).toString(),e),"sanitizeText"),nue=N((e,t)=>typeof e=="string"?li(e,t):e.flat().map(n=>li(n,t)),"sanitizeTextOrArray"),rue=N(e=>hp.test(e),"hasBreaks"),aue=N(e=>e.split(hp),"splitBreaks"),iue=N(e=>e.replace(/#br#/g,"<br/>"),"placeholderToBreak"),S9=N(e=>e.replace(hp,"#br#"),"breakToPlaceholder"),oue=N(e=>{let t="";return e&&(t=window.location.protocol+"//"+window.location.host+window.location.pathname+window.location.search,t=CSS.escape(t)),t},"getUrl"),sue=N(function(...e){const t=e.filter(n=>!isNaN(n));return Math.max(...t)},"getMax"),lue=N(function(...e){const t=e.filter(n=>!isNaN(n));return Math.min(...t)},"getMin"),p7=N(function(e){const t=e.split(/(,)/),n=[];for(let r=0;r<t.length;r++){let a=t[r];if(a===","&&r>0&&r+1<t.length){const i=t[r-1],o=t[r+1];cue(i,o)&&(a=i+","+o,r++,n.pop())}n.push(uue(a))}return n.join("")},"parseGenericTypes"),Vx=N((e,t)=>Math.max(0,e.split(t).length-1),"countOccurrence"),cue=N((e,t)=>{const n=Vx(e,"~"),r=Vx(t,"~");return n===1&&r===1},"shouldCombineSets"),uue=N(e=>{const t=Vx(e,"~");let n=!1;if(t<=1)return e;t%2!==0&&e.startsWith("~")&&(e=e.substring(1),n=!0);const r=[...e];let a=r.indexOf("~"),i=r.lastIndexOf("~");for(;a!==-1&&i!==-1&&a!==i;)r[a]="<",r[i]=">",a=r.indexOf("~"),i=r.lastIndexOf("~");return n&&r.unshift("~"),r.join("")},"processSet"),f7=N(()=>window.MathMLElement!==void 0,"isMathMLSupported"),Yx=/\$\$(.*)\$\$/g,Oh=N(e=>{var t;return(((t=e.match(Yx))==null?void 0:t.length)??0)>0},"hasKatex"),uEe=N(async(e,t)=>{const n=document.createElement("div");n.innerHTML=await w9(e,t),n.id="katex-temp",n.style.visibility="hidden",n.style.position="absolute",n.style.top="0";const r=document.querySelector("body");r==null||r.insertAdjacentElement("beforeend",n);const a={width:n.clientWidth,height:n.clientHeight};return n.remove(),a},"calculateMathMLDimensions"),due=N(async(e,t)=>{if(!Oh(e))return e;if(!(f7()||t.legacyMathML||t.forceLegacyMathML))return e.replace(Yx,"MathML is unsupported in this environment.");{const{default:n}=await Ut(async()=>{const{default:a}=await Promise.resolve().then(()=>Pie);return{default:a}},[]),r=t.forceLegacyMathML||!f7()&&t.legacyMathML?"htmlAndMathml":"mathml";return e.split(hp).map(a=>Oh(a)?`<div style="display: flex; align-items: center; justify-content: center; white-space: nowrap;">${a}</div>`:`<div>${a}</div>`).join("").replace(Yx,(a,i)=>n.renderToString(i,{throwOnError:!0,displayMode:!0,output:r}).replace(/\n/g," ").replace(/<annotation.*<\/annotation>/g,""))}},"renderKatexUnsanitized"),w9=N(async(e,t)=>li(await due(e,t),t),"renderKatexSanitized"),pp={getRows:eue,sanitizeText:li,sanitizeTextOrArray:nue,hasBreaks:rue,splitBreaks:aue,lineBreakRegex:hp,removeScript:x9,getUrl:oue,evaluate:Ds,getMax:sue,getMin:lue},hue=N(function(e,t){for(let n of t)e.attr(n[0],n[1])},"d3Attrs"),pue=N(function(e,t,n){let r=new Map;return n?(r.set("width","100%"),r.set("style",`max-width: ${t}px;`)):(r.set("height",e),r.set("width",t)),r},"calculateSvgSizeAttrs"),E9=N(function(e,t,n,r){const a=pue(t,n,r);hue(e,a)},"configureSvgSize"),fue=N(function(e,t,n,r){const a=t.node().getBBox(),i=a.width,o=a.height;we.info(`SVG bounds: ${i}x${o}`,a);let l=0,u=0;we.info(`Graph bounds: ${l}x${u}`,e),l=i+n*2,u=o+n*2,we.info(`Calculated bounds: ${l}x${u}`),E9(t,u,l,r);const d=`${a.x-n} ${a.y-n} ${a.width+2*n} ${a.height+2*n}`;t.attr("viewBox",d)},"setupGraphViewbox"),$0={},mue=N((e,t,n)=>{let r="";return e in $0&&$0[e]?r=$0[e](n):we.warn(`No theme found for ${e}`),` & {
    font-family: ${n.fontFamily};
    font-size: ${n.fontSize};
    fill: ${n.textColor}
  }
  @keyframes edge-animation-frame {
    from {
      stroke-dashoffset: 0;
    }
  }
  @keyframes dash {
    to {
      stroke-dashoffset: 0;
    }
  }
  & .edge-animation-slow {
    stroke-dasharray: 9,5 !important;
    stroke-dashoffset: 900;
    animation: dash 50s linear infinite;
    stroke-linecap: round;
  }
  & .edge-animation-fast {
    stroke-dasharray: 9,5 !important;
    stroke-dashoffset: 900;
    animation: dash 20s linear infinite;
    stroke-linecap: round;
  }
  /* Classes common for multiple diagrams */

  & .error-icon {
    fill: ${n.errorBkgColor};
  }
  & .error-text {
    fill: ${n.errorTextColor};
    stroke: ${n.errorTextColor};
  }

  & .edge-thickness-normal {
    stroke-width: 1px;
  }
  & .edge-thickness-thick {
    stroke-width: 3.5px
  }
  & .edge-pattern-solid {
    stroke-dasharray: 0;
  }
  & .edge-thickness-invisible {
    stroke-width: 0;
    fill: none;
  }
  & .edge-pattern-dashed{
    stroke-dasharray: 3;
  }
  .edge-pattern-dotted {
    stroke-dasharray: 2;
  }

  & .marker {
    fill: ${n.lineColor};
    stroke: ${n.lineColor};
  }
  & .marker.cross {
    stroke: ${n.lineColor};
  }

  & svg {
    font-family: ${n.fontFamily};
    font-size: ${n.fontSize};
  }
   & p {
    margin: 0
   }

  ${r}

  ${t}
`},"getStyles"),gue=N((e,t)=>{t!==void 0&&($0[e]=t)},"addStylesForDiagram"),bue=mue,k9={};oce(k9,{clear:()=>yue,getAccDescription:()=>wue,getAccTitle:()=>xue,getDiagramTitle:()=>kue,setAccDescription:()=>Sue,setAccTitle:()=>vue,setDiagramTitle:()=>Eue});var f_="",m_="",g_="",b_=N(e=>li(e,br()),"sanitizeText"),yue=N(()=>{f_="",g_="",m_=""},"clear"),vue=N(e=>{f_=b_(e).replace(/^\s+/g,"")},"setAccTitle"),xue=N(()=>f_,"getAccTitle"),Sue=N(e=>{g_=b_(e).replace(/\n\s+/g,`
`)},"setAccDescription"),wue=N(()=>g_,"getAccDescription"),Eue=N(e=>{m_=b_(e)},"setDiagramTitle"),kue=N(()=>m_,"getDiagramTitle"),m7=we,Tue=h_,qt=br,dEe=m9,hEe=ru,y_=N(e=>li(e,qt()),"sanitizeText"),_ue=fue,Cue=N(()=>k9,"getCommonDb"),ym={},vm=N((e,t,n)=>{var r;ym[e]&&m7.warn(`Diagram with id ${e} already registered. Overwriting.`),ym[e]=t,n&&u9(e,n),gue(e,t.styles),(r=t.injectUtils)==null||r.call(t,m7,Tue,qt,y_,_ue,Cue(),()=>{})},"registerDiagram"),Xx=N(e=>{if(e in ym)return ym[e];throw new Aue(e)},"getDiagram"),Xc,Aue=(Xc=class extends Error{constructor(t){super(`Diagram ${t} not found.`)}},N(Xc,"DiagramNotFoundError"),Xc),Rue={value:()=>{}};function T9(){for(var e=0,t=arguments.length,n={},r;e<t;++e){if(!(r=arguments[e]+"")||r in n||/[\s.]/.test(r))throw new Error("illegal type: "+r);n[r]=[]}return new P0(n)}function P0(e){this._=e}function Nue(e,t){return e.trim().split(/^|\s+/).map(function(n){var r="",a=n.indexOf(".");if(a>=0&&(r=n.slice(a+1),n=n.slice(0,a)),n&&!t.hasOwnProperty(n))throw new Error("unknown type: "+n);return{type:n,name:r}})}P0.prototype=T9.prototype={constructor:P0,on:function(e,t){var n=this._,r=Nue(e+"",n),a,i=-1,o=r.length;if(arguments.length<2){for(;++i<o;)if((a=(e=r[i]).type)&&(a=Oue(n[a],e.name)))return a;return}if(t!=null&&typeof t!="function")throw new Error("invalid callback: "+t);for(;++i<o;)if(a=(e=r[i]).type)n[a]=g7(n[a],e.name,t);else if(t==null)for(a in n)n[a]=g7(n[a],e.name,null);return this},copy:function(){var e={},t=this._;for(var n in t)e[n]=t[n].slice();return new P0(e)},call:function(e,t){if((a=arguments.length-2)>0)for(var n=new Array(a),r=0,a,i;r<a;++r)n[r]=arguments[r+2];if(!this._.hasOwnProperty(e))throw new Error("unknown type: "+e);for(i=this._[e],r=0,a=i.length;r<a;++r)i[r].value.apply(t,n)},apply:function(e,t,n){if(!this._.hasOwnProperty(e))throw new Error("unknown type: "+e);for(var r=this._[e],a=0,i=r.length;a<i;++a)r[a].value.apply(t,n)}};function Oue(e,t){for(var n=0,r=e.length,a;n<r;++n)if((a=e[n]).name===t)return a.value}function g7(e,t,n){for(var r=0,a=e.length;r<a;++r)if(e[r].name===t){e[r]=Rue,e=e.slice(0,r).concat(e.slice(r+1));break}return n!=null&&e.push({name:t,value:n}),e}var Kx="http://www.w3.org/1999/xhtml";const b7={svg:"http://www.w3.org/2000/svg",xhtml:Kx,xlink:"http://www.w3.org/1999/xlink",xml:"http://www.w3.org/XML/1998/namespace",xmlns:"http://www.w3.org/2000/xmlns/"};function Hg(e){var t=e+="",n=t.indexOf(":");return n>=0&&(t=e.slice(0,n))!=="xmlns"&&(e=e.slice(n+1)),b7.hasOwnProperty(t)?{space:b7[t],local:e}:e}function Iue(e){return function(){var t=this.ownerDocument,n=this.namespaceURI;return n===Kx&&t.documentElement.namespaceURI===Kx?t.createElement(e):t.createElementNS(n,e)}}function Lue(e){return function(){return this.ownerDocument.createElementNS(e.space,e.local)}}function _9(e){var t=Hg(e);return(t.local?Lue:Iue)(t)}function Due(){}function v_(e){return e==null?Due:function(){return this.querySelector(e)}}function Mue(e){typeof e!="function"&&(e=v_(e));for(var t=this._groups,n=t.length,r=new Array(n),a=0;a<n;++a)for(var i=t[a],o=i.length,l=r[a]=new Array(o),u,d,h=0;h<o;++h)(u=i[h])&&(d=e.call(u,u.__data__,h,i))&&("__data__"in u&&(d.__data__=u.__data__),l[h]=d);return new ya(r,this._parents)}function Bue(e){return e==null?[]:Array.isArray(e)?e:Array.from(e)}function Fue(){return[]}function C9(e){return e==null?Fue:function(){return this.querySelectorAll(e)}}function zue(e){return function(){return Bue(e.apply(this,arguments))}}function $ue(e){typeof e=="function"?e=zue(e):e=C9(e);for(var t=this._groups,n=t.length,r=[],a=[],i=0;i<n;++i)for(var o=t[i],l=o.length,u,d=0;d<l;++d)(u=o[d])&&(r.push(e.call(u,u.__data__,d,o)),a.push(u));return new ya(r,a)}function A9(e){return function(){return this.matches(e)}}function R9(e){return function(t){return t.matches(e)}}var Pue=Array.prototype.find;function Uue(e){return function(){return Pue.call(this.children,e)}}function jue(){return this.firstElementChild}function Hue(e){return this.select(e==null?jue:Uue(typeof e=="function"?e:R9(e)))}var Gue=Array.prototype.filter;function que(){return Array.from(this.children)}function Wue(e){return function(){return Gue.call(this.children,e)}}function Vue(e){return this.selectAll(e==null?que:Wue(typeof e=="function"?e:R9(e)))}function Yue(e){typeof e!="function"&&(e=A9(e));for(var t=this._groups,n=t.length,r=new Array(n),a=0;a<n;++a)for(var i=t[a],o=i.length,l=r[a]=[],u,d=0;d<o;++d)(u=i[d])&&e.call(u,u.__data__,d,i)&&l.push(u);return new ya(r,this._parents)}function N9(e){return new Array(e.length)}function Xue(){return new ya(this._enter||this._groups.map(N9),this._parents)}function xm(e,t){this.ownerDocument=e.ownerDocument,this.namespaceURI=e.namespaceURI,this._next=null,this._parent=e,this.__data__=t}xm.prototype={constructor:xm,appendChild:function(e){return this._parent.insertBefore(e,this._next)},insertBefore:function(e,t){return this._parent.insertBefore(e,t)},querySelector:function(e){return this._parent.querySelector(e)},querySelectorAll:function(e){return this._parent.querySelectorAll(e)}};function Kue(e){return function(){return e}}function Zue(e,t,n,r,a,i){for(var o=0,l,u=t.length,d=i.length;o<d;++o)(l=t[o])?(l.__data__=i[o],r[o]=l):n[o]=new xm(e,i[o]);for(;o<u;++o)(l=t[o])&&(a[o]=l)}function Que(e,t,n,r,a,i,o){var l,u,d=new Map,h=t.length,f=i.length,m=new Array(h),b;for(l=0;l<h;++l)(u=t[l])&&(m[l]=b=o.call(u,u.__data__,l,t)+"",d.has(b)?a[l]=u:d.set(b,u));for(l=0;l<f;++l)b=o.call(e,i[l],l,i)+"",(u=d.get(b))?(r[l]=u,u.__data__=i[l],d.delete(b)):n[l]=new xm(e,i[l]);for(l=0;l<h;++l)(u=t[l])&&d.get(m[l])===u&&(a[l]=u)}function Jue(e){return e.__data__}function ede(e,t){if(!arguments.length)return Array.from(this,Jue);var n=t?Que:Zue,r=this._parents,a=this._groups;typeof e!="function"&&(e=Kue(e));for(var i=a.length,o=new Array(i),l=new Array(i),u=new Array(i),d=0;d<i;++d){var h=r[d],f=a[d],m=f.length,b=tde(e.call(h,h&&h.__data__,d,r)),y=b.length,v=l[d]=new Array(y),w=o[d]=new Array(y),S=u[d]=new Array(m);n(h,f,v,w,S,b,t);for(var k=0,R=0,I,L;k<y;++k)if(I=v[k]){for(k>=R&&(R=k+1);!(L=w[R])&&++R<y;);I._next=L||null}}return o=new ya(o,r),o._enter=l,o._exit=u,o}function tde(e){return typeof e=="object"&&"length"in e?e:Array.from(e)}function nde(){return new ya(this._exit||this._groups.map(N9),this._parents)}function rde(e,t,n){var r=this.enter(),a=this,i=this.exit();return typeof e=="function"?(r=e(r),r&&(r=r.selection())):r=r.append(e+""),t!=null&&(a=t(a),a&&(a=a.selection())),n==null?i.remove():n(i),r&&a?r.merge(a).order():a}function ade(e){for(var t=e.selection?e.selection():e,n=this._groups,r=t._groups,a=n.length,i=r.length,o=Math.min(a,i),l=new Array(a),u=0;u<o;++u)for(var d=n[u],h=r[u],f=d.length,m=l[u]=new Array(f),b,y=0;y<f;++y)(b=d[y]||h[y])&&(m[y]=b);for(;u<a;++u)l[u]=n[u];return new ya(l,this._parents)}function ide(){for(var e=this._groups,t=-1,n=e.length;++t<n;)for(var r=e[t],a=r.length-1,i=r[a],o;--a>=0;)(o=r[a])&&(i&&o.compareDocumentPosition(i)^4&&i.parentNode.insertBefore(o,i),i=o);return this}function ode(e){e||(e=sde);function t(f,m){return f&&m?e(f.__data__,m.__data__):!f-!m}for(var n=this._groups,r=n.length,a=new Array(r),i=0;i<r;++i){for(var o=n[i],l=o.length,u=a[i]=new Array(l),d,h=0;h<l;++h)(d=o[h])&&(u[h]=d);u.sort(t)}return new ya(a,this._parents).order()}function sde(e,t){return e<t?-1:e>t?1:e>=t?0:NaN}function lde(){var e=arguments[0];return arguments[0]=this,e.apply(null,arguments),this}function cde(){return Array.from(this)}function ude(){for(var e=this._groups,t=0,n=e.length;t<n;++t)for(var r=e[t],a=0,i=r.length;a<i;++a){var o=r[a];if(o)return o}return null}function dde(){let e=0;for(const t of this)++e;return e}function hde(){return!this.node()}function pde(e){for(var t=this._groups,n=0,r=t.length;n<r;++n)for(var a=t[n],i=0,o=a.length,l;i<o;++i)(l=a[i])&&e.call(l,l.__data__,i,a);return this}function fde(e){return function(){this.removeAttribute(e)}}function mde(e){return function(){this.removeAttributeNS(e.space,e.local)}}function gde(e,t){return function(){this.setAttribute(e,t)}}function bde(e,t){return function(){this.setAttributeNS(e.space,e.local,t)}}function yde(e,t){return function(){var n=t.apply(this,arguments);n==null?this.removeAttribute(e):this.setAttribute(e,n)}}function vde(e,t){return function(){var n=t.apply(this,arguments);n==null?this.removeAttributeNS(e.space,e.local):this.setAttributeNS(e.space,e.local,n)}}function xde(e,t){var n=Hg(e);if(arguments.length<2){var r=this.node();return n.local?r.getAttributeNS(n.space,n.local):r.getAttribute(n)}return this.each((t==null?n.local?mde:fde:typeof t=="function"?n.local?vde:yde:n.local?bde:gde)(n,t))}function O9(e){return e.ownerDocument&&e.ownerDocument.defaultView||e.document&&e||e.defaultView}function Sde(e){return function(){this.style.removeProperty(e)}}function wde(e,t,n){return function(){this.style.setProperty(e,t,n)}}function Ede(e,t,n){return function(){var r=t.apply(this,arguments);r==null?this.style.removeProperty(e):this.style.setProperty(e,r,n)}}function kde(e,t,n){return arguments.length>1?this.each((t==null?Sde:typeof t=="function"?Ede:wde)(e,t,n??"")):au(this.node(),e)}function au(e,t){return e.style.getPropertyValue(t)||O9(e).getComputedStyle(e,null).getPropertyValue(t)}function Tde(e){return function(){delete this[e]}}function _de(e,t){return function(){this[e]=t}}function Cde(e,t){return function(){var n=t.apply(this,arguments);n==null?delete this[e]:this[e]=n}}function Ade(e,t){return arguments.length>1?this.each((t==null?Tde:typeof t=="function"?Cde:_de)(e,t)):this.node()[e]}function I9(e){return e.trim().split(/^|\s+/)}function x_(e){return e.classList||new L9(e)}function L9(e){this._node=e,this._names=I9(e.getAttribute("class")||"")}L9.prototype={add:function(e){var t=this._names.indexOf(e);t<0&&(this._names.push(e),this._node.setAttribute("class",this._names.join(" ")))},remove:function(e){var t=this._names.indexOf(e);t>=0&&(this._names.splice(t,1),this._node.setAttribute("class",this._names.join(" ")))},contains:function(e){return this._names.indexOf(e)>=0}};function D9(e,t){for(var n=x_(e),r=-1,a=t.length;++r<a;)n.add(t[r])}function M9(e,t){for(var n=x_(e),r=-1,a=t.length;++r<a;)n.remove(t[r])}function Rde(e){return function(){D9(this,e)}}function Nde(e){return function(){M9(this,e)}}function Ode(e,t){return function(){(t.apply(this,arguments)?D9:M9)(this,e)}}function Ide(e,t){var n=I9(e+"");if(arguments.length<2){for(var r=x_(this.node()),a=-1,i=n.length;++a<i;)if(!r.contains(n[a]))return!1;return!0}return this.each((typeof t=="function"?Ode:t?Rde:Nde)(n,t))}function Lde(){this.textContent=""}function Dde(e){return function(){this.textContent=e}}function Mde(e){return function(){var t=e.apply(this,arguments);this.textContent=t??""}}function Bde(e){return arguments.length?this.each(e==null?Lde:(typeof e=="function"?Mde:Dde)(e)):this.node().textContent}function Fde(){this.innerHTML=""}function zde(e){return function(){this.innerHTML=e}}function $de(e){return function(){var t=e.apply(this,arguments);this.innerHTML=t??""}}function Pde(e){return arguments.length?this.each(e==null?Fde:(typeof e=="function"?$de:zde)(e)):this.node().innerHTML}function Ude(){this.nextSibling&&this.parentNode.appendChild(this)}function jde(){return this.each(Ude)}function Hde(){this.previousSibling&&this.parentNode.insertBefore(this,this.parentNode.firstChild)}function Gde(){return this.each(Hde)}function qde(e){var t=typeof e=="function"?e:_9(e);return this.select(function(){return this.appendChild(t.apply(this,arguments))})}function Wde(){return null}function Vde(e,t){var n=typeof e=="function"?e:_9(e),r=t==null?Wde:typeof t=="function"?t:v_(t);return this.select(function(){return this.insertBefore(n.apply(this,arguments),r.apply(this,arguments)||null)})}function Yde(){var e=this.parentNode;e&&e.removeChild(this)}function Xde(){return this.each(Yde)}function Kde(){var e=this.cloneNode(!1),t=this.parentNode;return t?t.insertBefore(e,this.nextSibling):e}function Zde(){var e=this.cloneNode(!0),t=this.parentNode;return t?t.insertBefore(e,this.nextSibling):e}function Qde(e){return this.select(e?Zde:Kde)}function Jde(e){return arguments.length?this.property("__data__",e):this.node().__data__}function ehe(e){return function(t){e.call(this,t,this.__data__)}}function the(e){return e.trim().split(/^|\s+/).map(function(t){var n="",r=t.indexOf(".");return r>=0&&(n=t.slice(r+1),t=t.slice(0,r)),{type:t,name:n}})}function nhe(e){return function(){var t=this.__on;if(t){for(var n=0,r=-1,a=t.length,i;n<a;++n)i=t[n],(!e.type||i.type===e.type)&&i.name===e.name?this.removeEventListener(i.type,i.listener,i.options):t[++r]=i;++r?t.length=r:delete this.__on}}}function rhe(e,t,n){return function(){var r=this.__on,a,i=ehe(t);if(r){for(var o=0,l=r.length;o<l;++o)if((a=r[o]).type===e.type&&a.name===e.name){this.removeEventListener(a.type,a.listener,a.options),this.addEventListener(a.type,a.listener=i,a.options=n),a.value=t;return}}this.addEventListener(e.type,i,n),a={type:e.type,name:e.name,value:t,listener:i,options:n},r?r.push(a):this.__on=[a]}}function ahe(e,t,n){var r=the(e+""),a,i=r.length,o;if(arguments.length<2){var l=this.node().__on;if(l){for(var u=0,d=l.length,h;u<d;++u)for(a=0,h=l[u];a<i;++a)if((o=r[a]).type===h.type&&o.name===h.name)return h.value}return}for(l=t?rhe:nhe,a=0;a<i;++a)this.each(l(r[a],t,n));return this}function B9(e,t,n){var r=O9(e),a=r.CustomEvent;typeof a=="function"?a=new a(t,n):(a=r.document.createEvent("Event"),n?(a.initEvent(t,n.bubbles,n.cancelable),a.detail=n.detail):a.initEvent(t,!1,!1)),e.dispatchEvent(a)}function ihe(e,t){return function(){return B9(this,e,t)}}function ohe(e,t){return function(){return B9(this,e,t.apply(this,arguments))}}function she(e,t){return this.each((typeof t=="function"?ohe:ihe)(e,t))}function*lhe(){for(var e=this._groups,t=0,n=e.length;t<n;++t)for(var r=e[t],a=0,i=r.length,o;a<i;++a)(o=r[a])&&(yield o)}var F9=[null];function ya(e,t){this._groups=e,this._parents=t}function fp(){return new ya([[document.documentElement]],F9)}function che(){return this}ya.prototype=fp.prototype={constructor:ya,select:Mue,selectAll:$ue,selectChild:Hue,selectChildren:Vue,filter:Yue,data:ede,enter:Xue,exit:nde,join:rde,merge:ade,selection:che,order:ide,sort:ode,call:lde,nodes:cde,node:ude,size:dde,empty:hde,each:pde,attr:xde,style:kde,property:Ade,classed:Ide,text:Bde,html:Pde,raise:jde,lower:Gde,append:qde,insert:Vde,remove:Xde,clone:Qde,datum:Jde,on:ahe,dispatch:she,[Symbol.iterator]:lhe};function Et(e){return typeof e=="string"?new ya([[document.querySelector(e)]],[document.documentElement]):new ya([[e]],F9)}function S_(e,t,n){e.prototype=t.prototype=n,n.constructor=e}function z9(e,t){var n=Object.create(e.prototype);for(var r in t)n[r]=t[r];return n}function mp(){}var Ih=.7,Sm=1/Ih,Pc="\\s*([+-]?\\d+)\\s*",Lh="\\s*([+-]?(?:\\d*\\.)?\\d+(?:[eE][+-]?\\d+)?)\\s*",Ai="\\s*([+-]?(?:\\d*\\.)?\\d+(?:[eE][+-]?\\d+)?)%\\s*",uhe=/^#([0-9a-f]{3,8})$/,dhe=new RegExp(`^rgb\\(${Pc},${Pc},${Pc}\\)$`),hhe=new RegExp(`^rgb\\(${Ai},${Ai},${Ai}\\)$`),phe=new RegExp(`^rgba\\(${Pc},${Pc},${Pc},${Lh}\\)$`),fhe=new RegExp(`^rgba\\(${Ai},${Ai},${Ai},${Lh}\\)$`),mhe=new RegExp(`^hsl\\(${Lh},${Ai},${Ai}\\)$`),ghe=new RegExp(`^hsla\\(${Lh},${Ai},${Ai},${Lh}\\)$`),y7={aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074};S_(mp,Dh,{copy(e){return Object.assign(new this.constructor,this,e)},displayable(){return this.rgb().displayable()},hex:v7,formatHex:v7,formatHex8:bhe,formatHsl:yhe,formatRgb:x7,toString:x7});function v7(){return this.rgb().formatHex()}function bhe(){return this.rgb().formatHex8()}function yhe(){return $9(this).formatHsl()}function x7(){return this.rgb().formatRgb()}function Dh(e){var t,n;return e=(e+"").trim().toLowerCase(),(t=uhe.exec(e))?(n=t[1].length,t=parseInt(t[1],16),n===6?S7(t):n===3?new ea(t>>8&15|t>>4&240,t>>4&15|t&240,(t&15)<<4|t&15,1):n===8?f0(t>>24&255,t>>16&255,t>>8&255,(t&255)/255):n===4?f0(t>>12&15|t>>8&240,t>>8&15|t>>4&240,t>>4&15|t&240,((t&15)<<4|t&15)/255):null):(t=dhe.exec(e))?new ea(t[1],t[2],t[3],1):(t=hhe.exec(e))?new ea(t[1]*255/100,t[2]*255/100,t[3]*255/100,1):(t=phe.exec(e))?f0(t[1],t[2],t[3],t[4]):(t=fhe.exec(e))?f0(t[1]*255/100,t[2]*255/100,t[3]*255/100,t[4]):(t=mhe.exec(e))?k7(t[1],t[2]/100,t[3]/100,1):(t=ghe.exec(e))?k7(t[1],t[2]/100,t[3]/100,t[4]):y7.hasOwnProperty(e)?S7(y7[e]):e==="transparent"?new ea(NaN,NaN,NaN,0):null}function S7(e){return new ea(e>>16&255,e>>8&255,e&255,1)}function f0(e,t,n,r){return r<=0&&(e=t=n=NaN),new ea(e,t,n,r)}function vhe(e){return e instanceof mp||(e=Dh(e)),e?(e=e.rgb(),new ea(e.r,e.g,e.b,e.opacity)):new ea}function Zx(e,t,n,r){return arguments.length===1?vhe(e):new ea(e,t,n,r??1)}function ea(e,t,n,r){this.r=+e,this.g=+t,this.b=+n,this.opacity=+r}S_(ea,Zx,z9(mp,{brighter(e){return e=e==null?Sm:Math.pow(Sm,e),new ea(this.r*e,this.g*e,this.b*e,this.opacity)},darker(e){return e=e==null?Ih:Math.pow(Ih,e),new ea(this.r*e,this.g*e,this.b*e,this.opacity)},rgb(){return this},clamp(){return new ea(fl(this.r),fl(this.g),fl(this.b),wm(this.opacity))},displayable(){return-.5<=this.r&&this.r<255.5&&-.5<=this.g&&this.g<255.5&&-.5<=this.b&&this.b<255.5&&0<=this.opacity&&this.opacity<=1},hex:w7,formatHex:w7,formatHex8:xhe,formatRgb:E7,toString:E7}));function w7(){return`#${dl(this.r)}${dl(this.g)}${dl(this.b)}`}function xhe(){return`#${dl(this.r)}${dl(this.g)}${dl(this.b)}${dl((isNaN(this.opacity)?1:this.opacity)*255)}`}function E7(){const e=wm(this.opacity);return`${e===1?"rgb(":"rgba("}${fl(this.r)}, ${fl(this.g)}, ${fl(this.b)}${e===1?")":`, ${e})`}`}function wm(e){return isNaN(e)?1:Math.max(0,Math.min(1,e))}function fl(e){return Math.max(0,Math.min(255,Math.round(e)||0))}function dl(e){return e=fl(e),(e<16?"0":"")+e.toString(16)}function k7(e,t,n,r){return r<=0?e=t=n=NaN:n<=0||n>=1?e=t=NaN:t<=0&&(e=NaN),new ei(e,t,n,r)}function $9(e){if(e instanceof ei)return new ei(e.h,e.s,e.l,e.opacity);if(e instanceof mp||(e=Dh(e)),!e)return new ei;if(e instanceof ei)return e;e=e.rgb();var t=e.r/255,n=e.g/255,r=e.b/255,a=Math.min(t,n,r),i=Math.max(t,n,r),o=NaN,l=i-a,u=(i+a)/2;return l?(t===i?o=(n-r)/l+(n<r)*6:n===i?o=(r-t)/l+2:o=(t-n)/l+4,l/=u<.5?i+a:2-i-a,o*=60):l=u>0&&u<1?0:o,new ei(o,l,u,e.opacity)}function She(e,t,n,r){return arguments.length===1?$9(e):new ei(e,t,n,r??1)}function ei(e,t,n,r){this.h=+e,this.s=+t,this.l=+n,this.opacity=+r}S_(ei,She,z9(mp,{brighter(e){return e=e==null?Sm:Math.pow(Sm,e),new ei(this.h,this.s,this.l*e,this.opacity)},darker(e){return e=e==null?Ih:Math.pow(Ih,e),new ei(this.h,this.s,this.l*e,this.opacity)},rgb(){var e=this.h%360+(this.h<0)*360,t=isNaN(e)||isNaN(this.s)?0:this.s,n=this.l,r=n+(n<.5?n:1-n)*t,a=2*n-r;return new ea(zv(e>=240?e-240:e+120,a,r),zv(e,a,r),zv(e<120?e+240:e-120,a,r),this.opacity)},clamp(){return new ei(T7(this.h),m0(this.s),m0(this.l),wm(this.opacity))},displayable(){return(0<=this.s&&this.s<=1||isNaN(this.s))&&0<=this.l&&this.l<=1&&0<=this.opacity&&this.opacity<=1},formatHsl(){const e=wm(this.opacity);return`${e===1?"hsl(":"hsla("}${T7(this.h)}, ${m0(this.s)*100}%, ${m0(this.l)*100}%${e===1?")":`, ${e})`}`}}));function T7(e){return e=(e||0)%360,e<0?e+360:e}function m0(e){return Math.max(0,Math.min(1,e||0))}function zv(e,t,n){return(e<60?t+(n-t)*e/60:e<180?n:e<240?t+(n-t)*(240-e)/60:t)*255}const w_=e=>()=>e;function P9(e,t){return function(n){return e+n*t}}function whe(e,t,n){return e=Math.pow(e,n),t=Math.pow(t,n)-e,n=1/n,function(r){return Math.pow(e+r*t,n)}}function pEe(e,t){var n=t-e;return n?P9(e,n>180||n<-180?n-360*Math.round(n/360):n):w_(isNaN(e)?t:e)}function Ehe(e){return(e=+e)==1?U9:function(t,n){return n-t?whe(t,n,e):w_(isNaN(t)?n:t)}}function U9(e,t){var n=t-e;return n?P9(e,n):w_(isNaN(e)?t:e)}const _7=(function e(t){var n=Ehe(t);function r(a,i){var o=n((a=Zx(a)).r,(i=Zx(i)).r),l=n(a.g,i.g),u=n(a.b,i.b),d=U9(a.opacity,i.opacity);return function(h){return a.r=o(h),a.g=l(h),a.b=u(h),a.opacity=d(h),a+""}}return r.gamma=e,r})(1);function fs(e,t){return e=+e,t=+t,function(n){return e*(1-n)+t*n}}var Qx=/[-+]?(?:\d+\.?\d*|\.?\d+)(?:[eE][-+]?\d+)?/g,$v=new RegExp(Qx.source,"g");function khe(e){return function(){return e}}function The(e){return function(t){return e(t)+""}}function _he(e,t){var n=Qx.lastIndex=$v.lastIndex=0,r,a,i,o=-1,l=[],u=[];for(e=e+"",t=t+"";(r=Qx.exec(e))&&(a=$v.exec(t));)(i=a.index)>n&&(i=t.slice(n,i),l[o]?l[o]+=i:l[++o]=i),(r=r[0])===(a=a[0])?l[o]?l[o]+=a:l[++o]=a:(l[++o]=null,u.push({i:o,x:fs(r,a)})),n=$v.lastIndex;return n<t.length&&(i=t.slice(n),l[o]?l[o]+=i:l[++o]=i),l.length<2?u[0]?The(u[0].x):khe(t):(t=u.length,function(d){for(var h=0,f;h<t;++h)l[(f=u[h]).i]=f.x(d);return l.join("")})}var C7=180/Math.PI,Jx={translateX:0,translateY:0,rotate:0,skewX:0,scaleX:1,scaleY:1};function j9(e,t,n,r,a,i){var o,l,u;return(o=Math.sqrt(e*e+t*t))&&(e/=o,t/=o),(u=e*n+t*r)&&(n-=e*u,r-=t*u),(l=Math.sqrt(n*n+r*r))&&(n/=l,r/=l,u/=l),e*r<t*n&&(e=-e,t=-t,u=-u,o=-o),{translateX:a,translateY:i,rotate:Math.atan2(t,e)*C7,skewX:Math.atan(u)*C7,scaleX:o,scaleY:l}}var g0;function Che(e){const t=new(typeof DOMMatrix=="function"?DOMMatrix:WebKitCSSMatrix)(e+"");return t.isIdentity?Jx:j9(t.a,t.b,t.c,t.d,t.e,t.f)}function Ahe(e){return e==null||(g0||(g0=document.createElementNS("http://www.w3.org/2000/svg","g")),g0.setAttribute("transform",e),!(e=g0.transform.baseVal.consolidate()))?Jx:(e=e.matrix,j9(e.a,e.b,e.c,e.d,e.e,e.f))}function H9(e,t,n,r){function a(d){return d.length?d.pop()+" ":""}function i(d,h,f,m,b,y){if(d!==f||h!==m){var v=b.push("translate(",null,t,null,n);y.push({i:v-4,x:fs(d,f)},{i:v-2,x:fs(h,m)})}else(f||m)&&b.push("translate("+f+t+m+n)}function o(d,h,f,m){d!==h?(d-h>180?h+=360:h-d>180&&(d+=360),m.push({i:f.push(a(f)+"rotate(",null,r)-2,x:fs(d,h)})):h&&f.push(a(f)+"rotate("+h+r)}function l(d,h,f,m){d!==h?m.push({i:f.push(a(f)+"skewX(",null,r)-2,x:fs(d,h)}):h&&f.push(a(f)+"skewX("+h+r)}function u(d,h,f,m,b,y){if(d!==f||h!==m){var v=b.push(a(b)+"scale(",null,",",null,")");y.push({i:v-4,x:fs(d,f)},{i:v-2,x:fs(h,m)})}else(f!==1||m!==1)&&b.push(a(b)+"scale("+f+","+m+")")}return function(d,h){var f=[],m=[];return d=e(d),h=e(h),i(d.translateX,d.translateY,h.translateX,h.translateY,f,m),o(d.rotate,h.rotate,f,m),l(d.skewX,h.skewX,f,m),u(d.scaleX,d.scaleY,h.scaleX,h.scaleY,f,m),d=h=null,function(b){for(var y=-1,v=m.length,w;++y<v;)f[(w=m[y]).i]=w.x(b);return f.join("")}}}var Rhe=H9(Che,"px, ","px)","deg)"),Nhe=H9(Ahe,", ",")",")"),iu=0,eh=0,Hd=0,G9=1e3,Em,th,km=0,Sl=0,Gg=0,Mh=typeof performance=="object"&&performance.now?performance:Date,q9=typeof window=="object"&&window.requestAnimationFrame?window.requestAnimationFrame.bind(window):function(e){setTimeout(e,17)};function E_(){return Sl||(q9(Ohe),Sl=Mh.now()+Gg)}function Ohe(){Sl=0}function Tm(){this._call=this._time=this._next=null}Tm.prototype=W9.prototype={constructor:Tm,restart:function(e,t,n){if(typeof e!="function")throw new TypeError("callback is not a function");n=(n==null?E_():+n)+(t==null?0:+t),!this._next&&th!==this&&(th?th._next=this:Em=this,th=this),this._call=e,this._time=n,e2()},stop:function(){this._call&&(this._call=null,this._time=1/0,e2())}};function W9(e,t,n){var r=new Tm;return r.restart(e,t,n),r}function Ihe(){E_(),++iu;for(var e=Em,t;e;)(t=Sl-e._time)>=0&&e._call.call(void 0,t),e=e._next;--iu}function A7(){Sl=(km=Mh.now())+Gg,iu=eh=0;try{Ihe()}finally{iu=0,Dhe(),Sl=0}}function Lhe(){var e=Mh.now(),t=e-km;t>G9&&(Gg-=t,km=e)}function Dhe(){for(var e,t=Em,n,r=1/0;t;)t._call?(r>t._time&&(r=t._time),e=t,t=t._next):(n=t._next,t._next=null,t=e?e._next=n:Em=n);th=e,e2(r)}function e2(e){if(!iu){eh&&(eh=clearTimeout(eh));var t=e-Sl;t>24?(e<1/0&&(eh=setTimeout(A7,e-Mh.now()-Gg)),Hd&&(Hd=clearInterval(Hd))):(Hd||(km=Mh.now(),Hd=setInterval(Lhe,G9)),iu=1,q9(A7))}}function R7(e,t,n){var r=new Tm;return t=t==null?0:+t,r.restart(a=>{r.stop(),e(a+t)},t,n),r}var Mhe=T9("start","end","cancel","interrupt"),Bhe=[],V9=0,N7=1,t2=2,U0=3,O7=4,n2=5,j0=6;function qg(e,t,n,r,a,i){var o=e.__transition;if(!o)e.__transition={};else if(n in o)return;Fhe(e,n,{name:t,index:r,group:a,on:Mhe,tween:Bhe,time:i.time,delay:i.delay,duration:i.duration,ease:i.ease,timer:null,state:V9})}function k_(e,t){var n=ci(e,t);if(n.state>V9)throw new Error("too late; already scheduled");return n}function Pi(e,t){var n=ci(e,t);if(n.state>U0)throw new Error("too late; already running");return n}function ci(e,t){var n=e.__transition;if(!n||!(n=n[t]))throw new Error("transition not found");return n}function Fhe(e,t,n){var r=e.__transition,a;r[t]=n,n.timer=W9(i,0,n.time);function i(d){n.state=N7,n.timer.restart(o,n.delay,n.time),n.delay<=d&&o(d-n.delay)}function o(d){var h,f,m,b;if(n.state!==N7)return u();for(h in r)if(b=r[h],b.name===n.name){if(b.state===U0)return R7(o);b.state===O7?(b.state=j0,b.timer.stop(),b.on.call("interrupt",e,e.__data__,b.index,b.group),delete r[h]):+h<t&&(b.state=j0,b.timer.stop(),b.on.call("cancel",e,e.__data__,b.index,b.group),delete r[h])}if(R7(function(){n.state===U0&&(n.state=O7,n.timer.restart(l,n.delay,n.time),l(d))}),n.state=t2,n.on.call("start",e,e.__data__,n.index,n.group),n.state===t2){for(n.state=U0,a=new Array(m=n.tween.length),h=0,f=-1;h<m;++h)(b=n.tween[h].value.call(e,e.__data__,n.index,n.group))&&(a[++f]=b);a.length=f+1}}function l(d){for(var h=d<n.duration?n.ease.call(null,d/n.duration):(n.timer.restart(u),n.state=n2,1),f=-1,m=a.length;++f<m;)a[f].call(e,h);n.state===n2&&(n.on.call("end",e,e.__data__,n.index,n.group),u())}function u(){n.state=j0,n.timer.stop(),delete r[t];for(var d in r)return;delete e.__transition}}function zhe(e,t){var n=e.__transition,r,a,i=!0,o;if(n){t=t==null?null:t+"";for(o in n){if((r=n[o]).name!==t){i=!1;continue}a=r.state>t2&&r.state<n2,r.state=j0,r.timer.stop(),r.on.call(a?"interrupt":"cancel",e,e.__data__,r.index,r.group),delete n[o]}i&&delete e.__transition}}function $he(e){return this.each(function(){zhe(this,e)})}function Phe(e,t){var n,r;return function(){var a=Pi(this,e),i=a.tween;if(i!==n){r=n=i;for(var o=0,l=r.length;o<l;++o)if(r[o].name===t){r=r.slice(),r.splice(o,1);break}}a.tween=r}}function Uhe(e,t,n){var r,a;if(typeof n!="function")throw new Error;return function(){var i=Pi(this,e),o=i.tween;if(o!==r){a=(r=o).slice();for(var l={name:t,value:n},u=0,d=a.length;u<d;++u)if(a[u].name===t){a[u]=l;break}u===d&&a.push(l)}i.tween=a}}function jhe(e,t){var n=this._id;if(e+="",arguments.length<2){for(var r=ci(this.node(),n).tween,a=0,i=r.length,o;a<i;++a)if((o=r[a]).name===e)return o.value;return null}return this.each((t==null?Phe:Uhe)(n,e,t))}function T_(e,t,n){var r=e._id;return e.each(function(){var a=Pi(this,r);(a.value||(a.value={}))[t]=n.apply(this,arguments)}),function(a){return ci(a,r).value[t]}}function Y9(e,t){var n;return(typeof t=="number"?fs:t instanceof Dh?_7:(n=Dh(t))?(t=n,_7):_he)(e,t)}function Hhe(e){return function(){this.removeAttribute(e)}}function Ghe(e){return function(){this.removeAttributeNS(e.space,e.local)}}function qhe(e,t,n){var r,a=n+"",i;return function(){var o=this.getAttribute(e);return o===a?null:o===r?i:i=t(r=o,n)}}function Whe(e,t,n){var r,a=n+"",i;return function(){var o=this.getAttributeNS(e.space,e.local);return o===a?null:o===r?i:i=t(r=o,n)}}function Vhe(e,t,n){var r,a,i;return function(){var o,l=n(this),u;return l==null?void this.removeAttribute(e):(o=this.getAttribute(e),u=l+"",o===u?null:o===r&&u===a?i:(a=u,i=t(r=o,l)))}}function Yhe(e,t,n){var r,a,i;return function(){var o,l=n(this),u;return l==null?void this.removeAttributeNS(e.space,e.local):(o=this.getAttributeNS(e.space,e.local),u=l+"",o===u?null:o===r&&u===a?i:(a=u,i=t(r=o,l)))}}function Xhe(e,t){var n=Hg(e),r=n==="transform"?Nhe:Y9;return this.attrTween(e,typeof t=="function"?(n.local?Yhe:Vhe)(n,r,T_(this,"attr."+e,t)):t==null?(n.local?Ghe:Hhe)(n):(n.local?Whe:qhe)(n,r,t))}function Khe(e,t){return function(n){this.setAttribute(e,t.call(this,n))}}function Zhe(e,t){return function(n){this.setAttributeNS(e.space,e.local,t.call(this,n))}}function Qhe(e,t){var n,r;function a(){var i=t.apply(this,arguments);return i!==r&&(n=(r=i)&&Zhe(e,i)),n}return a._value=t,a}function Jhe(e,t){var n,r;function a(){var i=t.apply(this,arguments);return i!==r&&(n=(r=i)&&Khe(e,i)),n}return a._value=t,a}function epe(e,t){var n="attr."+e;if(arguments.length<2)return(n=this.tween(n))&&n._value;if(t==null)return this.tween(n,null);if(typeof t!="function")throw new Error;var r=Hg(e);return this.tween(n,(r.local?Qhe:Jhe)(r,t))}function tpe(e,t){return function(){k_(this,e).delay=+t.apply(this,arguments)}}function npe(e,t){return t=+t,function(){k_(this,e).delay=t}}function rpe(e){var t=this._id;return arguments.length?this.each((typeof e=="function"?tpe:npe)(t,e)):ci(this.node(),t).delay}function ape(e,t){return function(){Pi(this,e).duration=+t.apply(this,arguments)}}function ipe(e,t){return t=+t,function(){Pi(this,e).duration=t}}function ope(e){var t=this._id;return arguments.length?this.each((typeof e=="function"?ape:ipe)(t,e)):ci(this.node(),t).duration}function spe(e,t){if(typeof t!="function")throw new Error;return function(){Pi(this,e).ease=t}}function lpe(e){var t=this._id;return arguments.length?this.each(spe(t,e)):ci(this.node(),t).ease}function cpe(e,t){return function(){var n=t.apply(this,arguments);if(typeof n!="function")throw new Error;Pi(this,e).ease=n}}function upe(e){if(typeof e!="function")throw new Error;return this.each(cpe(this._id,e))}function dpe(e){typeof e!="function"&&(e=A9(e));for(var t=this._groups,n=t.length,r=new Array(n),a=0;a<n;++a)for(var i=t[a],o=i.length,l=r[a]=[],u,d=0;d<o;++d)(u=i[d])&&e.call(u,u.__data__,d,i)&&l.push(u);return new _o(r,this._parents,this._name,this._id)}function hpe(e){if(e._id!==this._id)throw new Error;for(var t=this._groups,n=e._groups,r=t.length,a=n.length,i=Math.min(r,a),o=new Array(r),l=0;l<i;++l)for(var u=t[l],d=n[l],h=u.length,f=o[l]=new Array(h),m,b=0;b<h;++b)(m=u[b]||d[b])&&(f[b]=m);for(;l<r;++l)o[l]=t[l];return new _o(o,this._parents,this._name,this._id)}function ppe(e){return(e+"").trim().split(/^|\s+/).every(function(t){var n=t.indexOf(".");return n>=0&&(t=t.slice(0,n)),!t||t==="start"})}function fpe(e,t,n){var r,a,i=ppe(t)?k_:Pi;return function(){var o=i(this,e),l=o.on;l!==r&&(a=(r=l).copy()).on(t,n),o.on=a}}function mpe(e,t){var n=this._id;return arguments.length<2?ci(this.node(),n).on.on(e):this.each(fpe(n,e,t))}function gpe(e){return function(){var t=this.parentNode;for(var n in this.__transition)if(+n!==e)return;t&&t.removeChild(this)}}function bpe(){return this.on("end.remove",gpe(this._id))}function ype(e){var t=this._name,n=this._id;typeof e!="function"&&(e=v_(e));for(var r=this._groups,a=r.length,i=new Array(a),o=0;o<a;++o)for(var l=r[o],u=l.length,d=i[o]=new Array(u),h,f,m=0;m<u;++m)(h=l[m])&&(f=e.call(h,h.__data__,m,l))&&("__data__"in h&&(f.__data__=h.__data__),d[m]=f,qg(d[m],t,n,m,d,ci(h,n)));return new _o(i,this._parents,t,n)}function vpe(e){var t=this._name,n=this._id;typeof e!="function"&&(e=C9(e));for(var r=this._groups,a=r.length,i=[],o=[],l=0;l<a;++l)for(var u=r[l],d=u.length,h,f=0;f<d;++f)if(h=u[f]){for(var m=e.call(h,h.__data__,f,u),b,y=ci(h,n),v=0,w=m.length;v<w;++v)(b=m[v])&&qg(b,t,n,v,m,y);i.push(m),o.push(h)}return new _o(i,o,t,n)}var xpe=fp.prototype.constructor;function Spe(){return new xpe(this._groups,this._parents)}function wpe(e,t){var n,r,a;return function(){var i=au(this,e),o=(this.style.removeProperty(e),au(this,e));return i===o?null:i===n&&o===r?a:a=t(n=i,r=o)}}function X9(e){return function(){this.style.removeProperty(e)}}function Epe(e,t,n){var r,a=n+"",i;return function(){var o=au(this,e);return o===a?null:o===r?i:i=t(r=o,n)}}function kpe(e,t,n){var r,a,i;return function(){var o=au(this,e),l=n(this),u=l+"";return l==null&&(u=l=(this.style.removeProperty(e),au(this,e))),o===u?null:o===r&&u===a?i:(a=u,i=t(r=o,l))}}function Tpe(e,t){var n,r,a,i="style."+t,o="end."+i,l;return function(){var u=Pi(this,e),d=u.on,h=u.value[i]==null?l||(l=X9(t)):void 0;(d!==n||a!==h)&&(r=(n=d).copy()).on(o,a=h),u.on=r}}function _pe(e,t,n){var r=(e+="")=="transform"?Rhe:Y9;return t==null?this.styleTween(e,wpe(e,r)).on("end.style."+e,X9(e)):typeof t=="function"?this.styleTween(e,kpe(e,r,T_(this,"style."+e,t))).each(Tpe(this._id,e)):this.styleTween(e,Epe(e,r,t),n).on("end.style."+e,null)}function Cpe(e,t,n){return function(r){this.style.setProperty(e,t.call(this,r),n)}}function Ape(e,t,n){var r,a;function i(){var o=t.apply(this,arguments);return o!==a&&(r=(a=o)&&Cpe(e,o,n)),r}return i._value=t,i}function Rpe(e,t,n){var r="style."+(e+="");if(arguments.length<2)return(r=this.tween(r))&&r._value;if(t==null)return this.tween(r,null);if(typeof t!="function")throw new Error;return this.tween(r,Ape(e,t,n??""))}function Npe(e){return function(){this.textContent=e}}function Ope(e){return function(){var t=e(this);this.textContent=t??""}}function Ipe(e){return this.tween("text",typeof e=="function"?Ope(T_(this,"text",e)):Npe(e==null?"":e+""))}function Lpe(e){return function(t){this.textContent=e.call(this,t)}}function Dpe(e){var t,n;function r(){var a=e.apply(this,arguments);return a!==n&&(t=(n=a)&&Lpe(a)),t}return r._value=e,r}function Mpe(e){var t="text";if(arguments.length<1)return(t=this.tween(t))&&t._value;if(e==null)return this.tween(t,null);if(typeof e!="function")throw new Error;return this.tween(t,Dpe(e))}function Bpe(){for(var e=this._name,t=this._id,n=K9(),r=this._groups,a=r.length,i=0;i<a;++i)for(var o=r[i],l=o.length,u,d=0;d<l;++d)if(u=o[d]){var h=ci(u,t);qg(u,e,n,d,o,{time:h.time+h.delay+h.duration,delay:0,duration:h.duration,ease:h.ease})}return new _o(r,this._parents,e,n)}function Fpe(){var e,t,n=this,r=n._id,a=n.size();return new Promise(function(i,o){var l={value:o},u={value:function(){--a===0&&i()}};n.each(function(){var d=Pi(this,r),h=d.on;h!==e&&(t=(e=h).copy(),t._.cancel.push(l),t._.interrupt.push(l),t._.end.push(u)),d.on=t}),a===0&&i()})}var zpe=0;function _o(e,t,n,r){this._groups=e,this._parents=t,this._name=n,this._id=r}function K9(){return++zpe}var mo=fp.prototype;_o.prototype={constructor:_o,select:ype,selectAll:vpe,selectChild:mo.selectChild,selectChildren:mo.selectChildren,filter:dpe,merge:hpe,selection:Spe,transition:Bpe,call:mo.call,nodes:mo.nodes,node:mo.node,size:mo.size,empty:mo.empty,each:mo.each,on:mpe,attr:Xhe,attrTween:epe,style:_pe,styleTween:Rpe,text:Ipe,textTween:Mpe,remove:bpe,tween:jhe,delay:rpe,duration:ope,ease:lpe,easeVarying:upe,end:Fpe,[Symbol.iterator]:mo[Symbol.iterator]};function $pe(e){return((e*=2)<=1?e*e*e:(e-=2)*e*e+2)/2}var Ppe={time:null,delay:0,duration:250,ease:$pe};function Upe(e,t){for(var n;!(n=e.__transition)||!(n=n[t]);)if(!(e=e.parentNode))throw new Error(`transition ${t} not found`);return n}function jpe(e){var t,n;e instanceof _o?(t=e._id,e=e._name):(t=K9(),(n=Ppe).time=E_(),e=e==null?null:e+"");for(var r=this._groups,a=r.length,i=0;i<a;++i)for(var o=r[i],l=o.length,u,d=0;d<l;++d)(u=o[d])&&qg(u,e,t,d,o,n||Upe(u,t));return new _o(r,this._parents,e,t)}fp.prototype.interrupt=$he;fp.prototype.transition=jpe;const r2=Math.PI,a2=2*r2,ol=1e-6,Hpe=a2-ol;function Z9(e){this._+=e[0];for(let t=1,n=e.length;t<n;++t)this._+=arguments[t]+e[t]}function Gpe(e){let t=Math.floor(e);if(!(t>=0))throw new Error(`invalid digits: ${e}`);if(t>15)return Z9;const n=10**t;return function(r){this._+=r[0];for(let a=1,i=r.length;a<i;++a)this._+=Math.round(arguments[a]*n)/n+r[a]}}class qpe{constructor(t){this._x0=this._y0=this._x1=this._y1=null,this._="",this._append=t==null?Z9:Gpe(t)}moveTo(t,n){this._append`M${this._x0=this._x1=+t},${this._y0=this._y1=+n}`}closePath(){this._x1!==null&&(this._x1=this._x0,this._y1=this._y0,this._append`Z`)}lineTo(t,n){this._append`L${this._x1=+t},${this._y1=+n}`}quadraticCurveTo(t,n,r,a){this._append`Q${+t},${+n},${this._x1=+r},${this._y1=+a}`}bezierCurveTo(t,n,r,a,i,o){this._append`C${+t},${+n},${+r},${+a},${this._x1=+i},${this._y1=+o}`}arcTo(t,n,r,a,i){if(t=+t,n=+n,r=+r,a=+a,i=+i,i<0)throw new Error(`negative radius: ${i}`);let o=this._x1,l=this._y1,u=r-t,d=a-n,h=o-t,f=l-n,m=h*h+f*f;if(this._x1===null)this._append`M${this._x1=t},${this._y1=n}`;else if(m>ol)if(!(Math.abs(f*u-d*h)>ol)||!i)this._append`L${this._x1=t},${this._y1=n}`;else{let b=r-o,y=a-l,v=u*u+d*d,w=b*b+y*y,S=Math.sqrt(v),k=Math.sqrt(m),R=i*Math.tan((r2-Math.acos((v+m-w)/(2*S*k)))/2),I=R/k,L=R/S;Math.abs(I-1)>ol&&this._append`L${t+I*h},${n+I*f}`,this._append`A${i},${i},0,0,${+(f*b>h*y)},${this._x1=t+L*u},${this._y1=n+L*d}`}}arc(t,n,r,a,i,o){if(t=+t,n=+n,r=+r,o=!!o,r<0)throw new Error(`negative radius: ${r}`);let l=r*Math.cos(a),u=r*Math.sin(a),d=t+l,h=n+u,f=1^o,m=o?a-i:i-a;this._x1===null?this._append`M${d},${h}`:(Math.abs(this._x1-d)>ol||Math.abs(this._y1-h)>ol)&&this._append`L${d},${h}`,r&&(m<0&&(m=m%a2+a2),m>Hpe?this._append`A${r},${r},0,1,${f},${t-l},${n-u}A${r},${r},0,1,${f},${this._x1=d},${this._y1=h}`:m>ol&&this._append`A${r},${r},0,${+(m>=r2)},${f},${this._x1=t+r*Math.cos(i)},${this._y1=n+r*Math.sin(i)}`)}rect(t,n,r,a){this._append`M${this._x0=this._x1=+t},${this._y0=this._y1=+n}h${r=+r}v${+a}h${-r}Z`}toString(){return this._}}function _c(e){return function(){return e}}const fEe=Math.abs,mEe=Math.atan2,gEe=Math.cos,bEe=Math.max,yEe=Math.min,vEe=Math.sin,xEe=Math.sqrt,I7=1e-12,__=Math.PI,L7=__/2,SEe=2*__;function wEe(e){return e>1?0:e<-1?__:Math.acos(e)}function EEe(e){return e>=1?L7:e<=-1?-L7:Math.asin(e)}function Wpe(e){let t=3;return e.digits=function(n){if(!arguments.length)return t;if(n==null)t=null;else{const r=Math.floor(n);if(!(r>=0))throw new RangeError(`invalid digits: ${n}`);t=r}return e},()=>new qpe(t)}function Vpe(e){return typeof e=="object"&&"length"in e?e:Array.from(e)}function Q9(e){this._context=e}Q9.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._point=0},lineEnd:function(){(this._line||this._line!==0&&this._point===1)&&this._context.closePath(),this._line=1-this._line},point:function(e,t){switch(e=+e,t=+t,this._point){case 0:this._point=1,this._line?this._context.lineTo(e,t):this._context.moveTo(e,t);break;case 1:this._point=2;default:this._context.lineTo(e,t);break}}};function gh(e){return new Q9(e)}function Ype(e){return e[0]}function Xpe(e){return e[1]}function Kpe(e,t){var n=_c(!0),r=null,a=gh,i=null,o=Wpe(l);e=typeof e=="function"?e:e===void 0?Ype:_c(e),t=typeof t=="function"?t:t===void 0?Xpe:_c(t);function l(u){var d,h=(u=Vpe(u)).length,f,m=!1,b;for(r==null&&(i=a(b=o())),d=0;d<=h;++d)!(d<h&&n(f=u[d],d,u))===m&&((m=!m)?i.lineStart():i.lineEnd()),m&&i.point(+e(f,d,u),+t(f,d,u));if(b)return i=null,b+""||null}return l.x=function(u){return arguments.length?(e=typeof u=="function"?u:_c(+u),l):e},l.y=function(u){return arguments.length?(t=typeof u=="function"?u:_c(+u),l):t},l.defined=function(u){return arguments.length?(n=typeof u=="function"?u:_c(!!u),l):n},l.curve=function(u){return arguments.length?(a=u,r!=null&&(i=a(r)),l):a},l.context=function(u){return arguments.length?(u==null?r=i=null:i=a(r=u),l):r},l}class J9{constructor(t,n){this._context=t,this._x=n}areaStart(){this._line=0}areaEnd(){this._line=NaN}lineStart(){this._point=0}lineEnd(){(this._line||this._line!==0&&this._point===1)&&this._context.closePath(),this._line=1-this._line}point(t,n){switch(t=+t,n=+n,this._point){case 0:{this._point=1,this._line?this._context.lineTo(t,n):this._context.moveTo(t,n);break}case 1:this._point=2;default:{this._x?this._context.bezierCurveTo(this._x0=(this._x0+t)/2,this._y0,this._x0,n,t,n):this._context.bezierCurveTo(this._x0,this._y0=(this._y0+n)/2,t,this._y0,t,n);break}}this._x0=t,this._y0=n}}function eB(e){return new J9(e,!0)}function tB(e){return new J9(e,!1)}function _s(){}function _m(e,t,n){e._context.bezierCurveTo((2*e._x0+e._x1)/3,(2*e._y0+e._y1)/3,(e._x0+2*e._x1)/3,(e._y0+2*e._y1)/3,(e._x0+4*e._x1+t)/6,(e._y0+4*e._y1+n)/6)}function Wg(e){this._context=e}Wg.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){switch(this._point){case 3:_m(this,this._x1,this._y1);case 2:this._context.lineTo(this._x1,this._y1);break}(this._line||this._line!==0&&this._point===1)&&this._context.closePath(),this._line=1-this._line},point:function(e,t){switch(e=+e,t=+t,this._point){case 0:this._point=1,this._line?this._context.lineTo(e,t):this._context.moveTo(e,t);break;case 1:this._point=2;break;case 2:this._point=3,this._context.lineTo((5*this._x0+this._x1)/6,(5*this._y0+this._y1)/6);default:_m(this,e,t);break}this._x0=this._x1,this._x1=e,this._y0=this._y1,this._y1=t}};function i2(e){return new Wg(e)}function nB(e){this._context=e}nB.prototype={areaStart:_s,areaEnd:_s,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._y0=this._y1=this._y2=this._y3=this._y4=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:{this._context.moveTo(this._x2,this._y2),this._context.closePath();break}case 2:{this._context.moveTo((this._x2+2*this._x3)/3,(this._y2+2*this._y3)/3),this._context.lineTo((this._x3+2*this._x2)/3,(this._y3+2*this._y2)/3),this._context.closePath();break}case 3:{this.point(this._x2,this._y2),this.point(this._x3,this._y3),this.point(this._x4,this._y4);break}}},point:function(e,t){switch(e=+e,t=+t,this._point){case 0:this._point=1,this._x2=e,this._y2=t;break;case 1:this._point=2,this._x3=e,this._y3=t;break;case 2:this._point=3,this._x4=e,this._y4=t,this._context.moveTo((this._x0+4*this._x1+e)/6,(this._y0+4*this._y1+t)/6);break;default:_m(this,e,t);break}this._x0=this._x1,this._x1=e,this._y0=this._y1,this._y1=t}};function Zpe(e){return new nB(e)}function rB(e){this._context=e}rB.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){(this._line||this._line!==0&&this._point===3)&&this._context.closePath(),this._line=1-this._line},point:function(e,t){switch(e=+e,t=+t,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3;var n=(this._x0+4*this._x1+e)/6,r=(this._y0+4*this._y1+t)/6;this._line?this._context.lineTo(n,r):this._context.moveTo(n,r);break;case 3:this._point=4;default:_m(this,e,t);break}this._x0=this._x1,this._x1=e,this._y0=this._y1,this._y1=t}};function Qpe(e){return new rB(e)}function aB(e,t){this._basis=new Wg(e),this._beta=t}aB.prototype={lineStart:function(){this._x=[],this._y=[],this._basis.lineStart()},lineEnd:function(){var e=this._x,t=this._y,n=e.length-1;if(n>0)for(var r=e[0],a=t[0],i=e[n]-r,o=t[n]-a,l=-1,u;++l<=n;)u=l/n,this._basis.point(this._beta*e[l]+(1-this._beta)*(r+u*i),this._beta*t[l]+(1-this._beta)*(a+u*o));this._x=this._y=null,this._basis.lineEnd()},point:function(e,t){this._x.push(+e),this._y.push(+t)}};const Jpe=(function e(t){function n(r){return t===1?new Wg(r):new aB(r,t)}return n.beta=function(r){return e(+r)},n})(.85);function Cm(e,t,n){e._context.bezierCurveTo(e._x1+e._k*(e._x2-e._x0),e._y1+e._k*(e._y2-e._y0),e._x2+e._k*(e._x1-t),e._y2+e._k*(e._y1-n),e._x2,e._y2)}function C_(e,t){this._context=e,this._k=(1-t)/6}C_.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:Cm(this,this._x1,this._y1);break}(this._line||this._line!==0&&this._point===1)&&this._context.closePath(),this._line=1-this._line},point:function(e,t){switch(e=+e,t=+t,this._point){case 0:this._point=1,this._line?this._context.lineTo(e,t):this._context.moveTo(e,t);break;case 1:this._point=2,this._x1=e,this._y1=t;break;case 2:this._point=3;default:Cm(this,e,t);break}this._x0=this._x1,this._x1=this._x2,this._x2=e,this._y0=this._y1,this._y1=this._y2,this._y2=t}};const iB=(function e(t){function n(r){return new C_(r,t)}return n.tension=function(r){return e(+r)},n})(0);function A_(e,t){this._context=e,this._k=(1-t)/6}A_.prototype={areaStart:_s,areaEnd:_s,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:{this._context.moveTo(this._x3,this._y3),this._context.closePath();break}case 2:{this._context.lineTo(this._x3,this._y3),this._context.closePath();break}case 3:{this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5);break}}},point:function(e,t){switch(e=+e,t=+t,this._point){case 0:this._point=1,this._x3=e,this._y3=t;break;case 1:this._point=2,this._context.moveTo(this._x4=e,this._y4=t);break;case 2:this._point=3,this._x5=e,this._y5=t;break;default:Cm(this,e,t);break}this._x0=this._x1,this._x1=this._x2,this._x2=e,this._y0=this._y1,this._y1=this._y2,this._y2=t}};const efe=(function e(t){function n(r){return new A_(r,t)}return n.tension=function(r){return e(+r)},n})(0);function R_(e,t){this._context=e,this._k=(1-t)/6}R_.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){(this._line||this._line!==0&&this._point===3)&&this._context.closePath(),this._line=1-this._line},point:function(e,t){switch(e=+e,t=+t,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:Cm(this,e,t);break}this._x0=this._x1,this._x1=this._x2,this._x2=e,this._y0=this._y1,this._y1=this._y2,this._y2=t}};const tfe=(function e(t){function n(r){return new R_(r,t)}return n.tension=function(r){return e(+r)},n})(0);function N_(e,t,n){var r=e._x1,a=e._y1,i=e._x2,o=e._y2;if(e._l01_a>I7){var l=2*e._l01_2a+3*e._l01_a*e._l12_a+e._l12_2a,u=3*e._l01_a*(e._l01_a+e._l12_a);r=(r*l-e._x0*e._l12_2a+e._x2*e._l01_2a)/u,a=(a*l-e._y0*e._l12_2a+e._y2*e._l01_2a)/u}if(e._l23_a>I7){var d=2*e._l23_2a+3*e._l23_a*e._l12_a+e._l12_2a,h=3*e._l23_a*(e._l23_a+e._l12_a);i=(i*d+e._x1*e._l23_2a-t*e._l12_2a)/h,o=(o*d+e._y1*e._l23_2a-n*e._l12_2a)/h}e._context.bezierCurveTo(r,a,i,o,e._x2,e._y2)}function oB(e,t){this._context=e,this._alpha=t}oB.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:this.point(this._x2,this._y2);break}(this._line||this._line!==0&&this._point===1)&&this._context.closePath(),this._line=1-this._line},point:function(e,t){if(e=+e,t=+t,this._point){var n=this._x2-e,r=this._y2-t;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(n*n+r*r,this._alpha))}switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(e,t):this._context.moveTo(e,t);break;case 1:this._point=2;break;case 2:this._point=3;default:N_(this,e,t);break}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=e,this._y0=this._y1,this._y1=this._y2,this._y2=t}};const sB=(function e(t){function n(r){return t?new oB(r,t):new C_(r,0)}return n.alpha=function(r){return e(+r)},n})(.5);function lB(e,t){this._context=e,this._alpha=t}lB.prototype={areaStart:_s,areaEnd:_s,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 1:{this._context.moveTo(this._x3,this._y3),this._context.closePath();break}case 2:{this._context.lineTo(this._x3,this._y3),this._context.closePath();break}case 3:{this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5);break}}},point:function(e,t){if(e=+e,t=+t,this._point){var n=this._x2-e,r=this._y2-t;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(n*n+r*r,this._alpha))}switch(this._point){case 0:this._point=1,this._x3=e,this._y3=t;break;case 1:this._point=2,this._context.moveTo(this._x4=e,this._y4=t);break;case 2:this._point=3,this._x5=e,this._y5=t;break;default:N_(this,e,t);break}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=e,this._y0=this._y1,this._y1=this._y2,this._y2=t}};const nfe=(function e(t){function n(r){return t?new lB(r,t):new A_(r,0)}return n.alpha=function(r){return e(+r)},n})(.5);function cB(e,t){this._context=e,this._alpha=t}cB.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){(this._line||this._line!==0&&this._point===3)&&this._context.closePath(),this._line=1-this._line},point:function(e,t){if(e=+e,t=+t,this._point){var n=this._x2-e,r=this._y2-t;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(n*n+r*r,this._alpha))}switch(this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:N_(this,e,t);break}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=e,this._y0=this._y1,this._y1=this._y2,this._y2=t}};const rfe=(function e(t){function n(r){return t?new cB(r,t):new R_(r,0)}return n.alpha=function(r){return e(+r)},n})(.5);function uB(e){this._context=e}uB.prototype={areaStart:_s,areaEnd:_s,lineStart:function(){this._point=0},lineEnd:function(){this._point&&this._context.closePath()},point:function(e,t){e=+e,t=+t,this._point?this._context.lineTo(e,t):(this._point=1,this._context.moveTo(e,t))}};function afe(e){return new uB(e)}function D7(e){return e<0?-1:1}function M7(e,t,n){var r=e._x1-e._x0,a=t-e._x1,i=(e._y1-e._y0)/(r||a<0&&-0),o=(n-e._y1)/(a||r<0&&-0),l=(i*a+o*r)/(r+a);return(D7(i)+D7(o))*Math.min(Math.abs(i),Math.abs(o),.5*Math.abs(l))||0}function B7(e,t){var n=e._x1-e._x0;return n?(3*(e._y1-e._y0)/n-t)/2:t}function Pv(e,t,n){var r=e._x0,a=e._y0,i=e._x1,o=e._y1,l=(i-r)/3;e._context.bezierCurveTo(r+l,a+l*t,i-l,o-l*n,i,o)}function Am(e){this._context=e}Am.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=this._t0=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x1,this._y1);break;case 3:Pv(this,this._t0,B7(this,this._t0));break}(this._line||this._line!==0&&this._point===1)&&this._context.closePath(),this._line=1-this._line},point:function(e,t){var n=NaN;if(e=+e,t=+t,!(e===this._x1&&t===this._y1)){switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(e,t):this._context.moveTo(e,t);break;case 1:this._point=2;break;case 2:this._point=3,Pv(this,B7(this,n=M7(this,e,t)),n);break;default:Pv(this,this._t0,n=M7(this,e,t));break}this._x0=this._x1,this._x1=e,this._y0=this._y1,this._y1=t,this._t0=n}}};function dB(e){this._context=new hB(e)}(dB.prototype=Object.create(Am.prototype)).point=function(e,t){Am.prototype.point.call(this,t,e)};function hB(e){this._context=e}hB.prototype={moveTo:function(e,t){this._context.moveTo(t,e)},closePath:function(){this._context.closePath()},lineTo:function(e,t){this._context.lineTo(t,e)},bezierCurveTo:function(e,t,n,r,a,i){this._context.bezierCurveTo(t,e,r,n,i,a)}};function pB(e){return new Am(e)}function fB(e){return new dB(e)}function mB(e){this._context=e}mB.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=[],this._y=[]},lineEnd:function(){var e=this._x,t=this._y,n=e.length;if(n)if(this._line?this._context.lineTo(e[0],t[0]):this._context.moveTo(e[0],t[0]),n===2)this._context.lineTo(e[1],t[1]);else for(var r=F7(e),a=F7(t),i=0,o=1;o<n;++i,++o)this._context.bezierCurveTo(r[0][i],a[0][i],r[1][i],a[1][i],e[o],t[o]);(this._line||this._line!==0&&n===1)&&this._context.closePath(),this._line=1-this._line,this._x=this._y=null},point:function(e,t){this._x.push(+e),this._y.push(+t)}};function F7(e){var t,n=e.length-1,r,a=new Array(n),i=new Array(n),o=new Array(n);for(a[0]=0,i[0]=2,o[0]=e[0]+2*e[1],t=1;t<n-1;++t)a[t]=1,i[t]=4,o[t]=4*e[t]+2*e[t+1];for(a[n-1]=2,i[n-1]=7,o[n-1]=8*e[n-1]+e[n],t=1;t<n;++t)r=a[t]/i[t-1],i[t]-=r,o[t]-=r*o[t-1];for(a[n-1]=o[n-1]/i[n-1],t=n-2;t>=0;--t)a[t]=(o[t]-a[t+1])/i[t];for(i[n-1]=(e[n]+a[n-1])/2,t=0;t<n-1;++t)i[t]=2*e[t+1]-a[t+1];return[a,i]}function gB(e){return new mB(e)}function Vg(e,t){this._context=e,this._t=t}Vg.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=this._y=NaN,this._point=0},lineEnd:function(){0<this._t&&this._t<1&&this._point===2&&this._context.lineTo(this._x,this._y),(this._line||this._line!==0&&this._point===1)&&this._context.closePath(),this._line>=0&&(this._t=1-this._t,this._line=1-this._line)},point:function(e,t){switch(e=+e,t=+t,this._point){case 0:this._point=1,this._line?this._context.lineTo(e,t):this._context.moveTo(e,t);break;case 1:this._point=2;default:{if(this._t<=0)this._context.lineTo(this._x,t),this._context.lineTo(e,t);else{var n=this._x*(1-this._t)+e*this._t;this._context.lineTo(n,this._y),this._context.lineTo(n,t)}break}}this._x=e,this._y=t}};function bB(e){return new Vg(e,.5)}function yB(e){return new Vg(e,0)}function vB(e){return new Vg(e,1)}function nh(e,t,n){this.k=e,this.x=t,this.y=n}nh.prototype={constructor:nh,scale:function(e){return e===1?this:new nh(this.k*e,this.x,this.y)},translate:function(e,t){return e===0&t===0?this:new nh(this.k,this.x+this.k*e,this.y+this.k*t)},apply:function(e){return[e[0]*this.k+this.x,e[1]*this.k+this.y]},applyX:function(e){return e*this.k+this.x},applyY:function(e){return e*this.k+this.y},invert:function(e){return[(e[0]-this.x)/this.k,(e[1]-this.y)/this.k]},invertX:function(e){return(e-this.x)/this.k},invertY:function(e){return(e-this.y)/this.k},rescaleX:function(e){return e.copy().domain(e.range().map(this.invertX,this).map(e.invert,e))},rescaleY:function(e){return e.copy().domain(e.range().map(this.invertY,this).map(e.invert,e))},toString:function(){return"translate("+this.x+","+this.y+") scale("+this.k+")"}};nh.prototype;var ife=N(e=>{var a;const{securityLevel:t}=qt();let n=Et("body");if(t==="sandbox"){const o=((a=Et(`#i${e}`).node())==null?void 0:a.contentDocument)??document;n=Et(o.body)}return n.select(`#${e}`)},"selectSvgElement");function O_(e){return typeof e>"u"||e===null}N(O_,"isNothing");function xB(e){return typeof e=="object"&&e!==null}N(xB,"isObject");function SB(e){return Array.isArray(e)?e:O_(e)?[]:[e]}N(SB,"toArray");function wB(e,t){var n,r,a,i;if(t)for(i=Object.keys(t),n=0,r=i.length;n<r;n+=1)a=i[n],e[a]=t[a];return e}N(wB,"extend");function EB(e,t){var n="",r;for(r=0;r<t;r+=1)n+=e;return n}N(EB,"repeat");function kB(e){return e===0&&Number.NEGATIVE_INFINITY===1/e}N(kB,"isNegativeZero");var ofe=O_,sfe=xB,lfe=SB,cfe=EB,ufe=kB,dfe=wB,Xn={isNothing:ofe,isObject:sfe,toArray:lfe,repeat:cfe,isNegativeZero:ufe,extend:dfe};function I_(e,t){var n="",r=e.reason||"(unknown reason)";return e.mark?(e.mark.name&&(n+='in "'+e.mark.name+'" '),n+="("+(e.mark.line+1)+":"+(e.mark.column+1)+")",!t&&e.mark.snippet&&(n+=`

`+e.mark.snippet),r+" "+n):r}N(I_,"formatError");function ou(e,t){Error.call(this),this.name="YAMLException",this.reason=e,this.mark=t,this.message=I_(this,!1),Error.captureStackTrace?Error.captureStackTrace(this,this.constructor):this.stack=new Error().stack||""}N(ou,"YAMLException$1");ou.prototype=Object.create(Error.prototype);ou.prototype.constructor=ou;ou.prototype.toString=N(function(t){return this.name+": "+I_(this,t)},"toString");var Jr=ou;function H0(e,t,n,r,a){var i="",o="",l=Math.floor(a/2)-1;return r-t>l&&(i=" ... ",t=r-l+i.length),n-r>l&&(o=" ...",n=r+l-o.length),{str:i+e.slice(t,n).replace(/\t/g,"→")+o,pos:r-t+i.length}}N(H0,"getLine");function G0(e,t){return Xn.repeat(" ",t-e.length)+e}N(G0,"padStart");function TB(e,t){if(t=Object.create(t||null),!e.buffer)return null;t.maxLength||(t.maxLength=79),typeof t.indent!="number"&&(t.indent=1),typeof t.linesBefore!="number"&&(t.linesBefore=3),typeof t.linesAfter!="number"&&(t.linesAfter=2);for(var n=/\r?\n|\r|\0/g,r=[0],a=[],i,o=-1;i=n.exec(e.buffer);)a.push(i.index),r.push(i.index+i[0].length),e.position<=i.index&&o<0&&(o=r.length-2);o<0&&(o=r.length-1);var l="",u,d,h=Math.min(e.line+t.linesAfter,a.length).toString().length,f=t.maxLength-(t.indent+h+3);for(u=1;u<=t.linesBefore&&!(o-u<0);u++)d=H0(e.buffer,r[o-u],a[o-u],e.position-(r[o]-r[o-u]),f),l=Xn.repeat(" ",t.indent)+G0((e.line-u+1).toString(),h)+" | "+d.str+`
`+l;for(d=H0(e.buffer,r[o],a[o],e.position,f),l+=Xn.repeat(" ",t.indent)+G0((e.line+1).toString(),h)+" | "+d.str+`
`,l+=Xn.repeat("-",t.indent+h+3+d.pos)+`^
`,u=1;u<=t.linesAfter&&!(o+u>=a.length);u++)d=H0(e.buffer,r[o+u],a[o+u],e.position-(r[o]-r[o+u]),f),l+=Xn.repeat(" ",t.indent)+G0((e.line+u+1).toString(),h)+" | "+d.str+`
`;return l.replace(/\n$/,"")}N(TB,"makeSnippet");var hfe=TB,pfe=["kind","multi","resolve","construct","instanceOf","predicate","represent","representName","defaultStyle","styleAliases"],ffe=["scalar","sequence","mapping"];function _B(e){var t={};return e!==null&&Object.keys(e).forEach(function(n){e[n].forEach(function(r){t[String(r)]=n})}),t}N(_B,"compileStyleAliases");function CB(e,t){if(t=t||{},Object.keys(t).forEach(function(n){if(pfe.indexOf(n)===-1)throw new Jr('Unknown option "'+n+'" is met in definition of "'+e+'" YAML type.')}),this.options=t,this.tag=e,this.kind=t.kind||null,this.resolve=t.resolve||function(){return!0},this.construct=t.construct||function(n){return n},this.instanceOf=t.instanceOf||null,this.predicate=t.predicate||null,this.represent=t.represent||null,this.representName=t.representName||null,this.defaultStyle=t.defaultStyle||null,this.multi=t.multi||!1,this.styleAliases=_B(t.styleAliases||null),ffe.indexOf(this.kind)===-1)throw new Jr('Unknown kind "'+this.kind+'" is specified for "'+e+'" YAML type.')}N(CB,"Type$1");var yr=CB;function o2(e,t){var n=[];return e[t].forEach(function(r){var a=n.length;n.forEach(function(i,o){i.tag===r.tag&&i.kind===r.kind&&i.multi===r.multi&&(a=o)}),n[a]=r}),n}N(o2,"compileList");function AB(){var e={scalar:{},sequence:{},mapping:{},fallback:{},multi:{scalar:[],sequence:[],mapping:[],fallback:[]}},t,n;function r(a){a.multi?(e.multi[a.kind].push(a),e.multi.fallback.push(a)):e[a.kind][a.tag]=e.fallback[a.tag]=a}for(N(r,"collectType"),t=0,n=arguments.length;t<n;t+=1)arguments[t].forEach(r);return e}N(AB,"compileMap");function Rm(e){return this.extend(e)}N(Rm,"Schema$1");Rm.prototype.extend=N(function(t){var n=[],r=[];if(t instanceof yr)r.push(t);else if(Array.isArray(t))r=r.concat(t);else if(t&&(Array.isArray(t.implicit)||Array.isArray(t.explicit)))t.implicit&&(n=n.concat(t.implicit)),t.explicit&&(r=r.concat(t.explicit));else throw new Jr("Schema.extend argument should be a Type, [ Type ], or a schema definition ({ implicit: [...], explicit: [...] })");n.forEach(function(i){if(!(i instanceof yr))throw new Jr("Specified list of YAML types (or a single Type object) contains a non-Type object.");if(i.loadKind&&i.loadKind!=="scalar")throw new Jr("There is a non-scalar type in the implicit list of a schema. Implicit resolving of such types is not supported.");if(i.multi)throw new Jr("There is a multi type in the implicit list of a schema. Multi tags can only be listed as explicit.")}),r.forEach(function(i){if(!(i instanceof yr))throw new Jr("Specified list of YAML types (or a single Type object) contains a non-Type object.")});var a=Object.create(Rm.prototype);return a.implicit=(this.implicit||[]).concat(n),a.explicit=(this.explicit||[]).concat(r),a.compiledImplicit=o2(a,"implicit"),a.compiledExplicit=o2(a,"explicit"),a.compiledTypeMap=AB(a.compiledImplicit,a.compiledExplicit),a},"extend");var mfe=Rm,gfe=new yr("tag:yaml.org,2002:str",{kind:"scalar",construct:N(function(e){return e!==null?e:""},"construct")}),bfe=new yr("tag:yaml.org,2002:seq",{kind:"sequence",construct:N(function(e){return e!==null?e:[]},"construct")}),yfe=new yr("tag:yaml.org,2002:map",{kind:"mapping",construct:N(function(e){return e!==null?e:{}},"construct")}),vfe=new mfe({explicit:[gfe,bfe,yfe]});function RB(e){if(e===null)return!0;var t=e.length;return t===1&&e==="~"||t===4&&(e==="null"||e==="Null"||e==="NULL")}N(RB,"resolveYamlNull");function NB(){return null}N(NB,"constructYamlNull");function OB(e){return e===null}N(OB,"isNull");var xfe=new yr("tag:yaml.org,2002:null",{kind:"scalar",resolve:RB,construct:NB,predicate:OB,represent:{canonical:N(function(){return"~"},"canonical"),lowercase:N(function(){return"null"},"lowercase"),uppercase:N(function(){return"NULL"},"uppercase"),camelcase:N(function(){return"Null"},"camelcase"),empty:N(function(){return""},"empty")},defaultStyle:"lowercase"});function IB(e){if(e===null)return!1;var t=e.length;return t===4&&(e==="true"||e==="True"||e==="TRUE")||t===5&&(e==="false"||e==="False"||e==="FALSE")}N(IB,"resolveYamlBoolean");function LB(e){return e==="true"||e==="True"||e==="TRUE"}N(LB,"constructYamlBoolean");function DB(e){return Object.prototype.toString.call(e)==="[object Boolean]"}N(DB,"isBoolean");var Sfe=new yr("tag:yaml.org,2002:bool",{kind:"scalar",resolve:IB,construct:LB,predicate:DB,represent:{lowercase:N(function(e){return e?"true":"false"},"lowercase"),uppercase:N(function(e){return e?"TRUE":"FALSE"},"uppercase"),camelcase:N(function(e){return e?"True":"False"},"camelcase")},defaultStyle:"lowercase"});function MB(e){return 48<=e&&e<=57||65<=e&&e<=70||97<=e&&e<=102}N(MB,"isHexCode");function BB(e){return 48<=e&&e<=55}N(BB,"isOctCode");function FB(e){return 48<=e&&e<=57}N(FB,"isDecCode");function zB(e){if(e===null)return!1;var t=e.length,n=0,r=!1,a;if(!t)return!1;if(a=e[n],(a==="-"||a==="+")&&(a=e[++n]),a==="0"){if(n+1===t)return!0;if(a=e[++n],a==="b"){for(n++;n<t;n++)if(a=e[n],a!=="_"){if(a!=="0"&&a!=="1")return!1;r=!0}return r&&a!=="_"}if(a==="x"){for(n++;n<t;n++)if(a=e[n],a!=="_"){if(!MB(e.charCodeAt(n)))return!1;r=!0}return r&&a!=="_"}if(a==="o"){for(n++;n<t;n++)if(a=e[n],a!=="_"){if(!BB(e.charCodeAt(n)))return!1;r=!0}return r&&a!=="_"}}if(a==="_")return!1;for(;n<t;n++)if(a=e[n],a!=="_"){if(!FB(e.charCodeAt(n)))return!1;r=!0}return!(!r||a==="_")}N(zB,"resolveYamlInteger");function $B(e){var t=e,n=1,r;if(t.indexOf("_")!==-1&&(t=t.replace(/_/g,"")),r=t[0],(r==="-"||r==="+")&&(r==="-"&&(n=-1),t=t.slice(1),r=t[0]),t==="0")return 0;if(r==="0"){if(t[1]==="b")return n*parseInt(t.slice(2),2);if(t[1]==="x")return n*parseInt(t.slice(2),16);if(t[1]==="o")return n*parseInt(t.slice(2),8)}return n*parseInt(t,10)}N($B,"constructYamlInteger");function PB(e){return Object.prototype.toString.call(e)==="[object Number]"&&e%1===0&&!Xn.isNegativeZero(e)}N(PB,"isInteger");var wfe=new yr("tag:yaml.org,2002:int",{kind:"scalar",resolve:zB,construct:$B,predicate:PB,represent:{binary:N(function(e){return e>=0?"0b"+e.toString(2):"-0b"+e.toString(2).slice(1)},"binary"),octal:N(function(e){return e>=0?"0o"+e.toString(8):"-0o"+e.toString(8).slice(1)},"octal"),decimal:N(function(e){return e.toString(10)},"decimal"),hexadecimal:N(function(e){return e>=0?"0x"+e.toString(16).toUpperCase():"-0x"+e.toString(16).toUpperCase().slice(1)},"hexadecimal")},defaultStyle:"decimal",styleAliases:{binary:[2,"bin"],octal:[8,"oct"],decimal:[10,"dec"],hexadecimal:[16,"hex"]}}),Efe=new RegExp("^(?:[-+]?(?:[0-9][0-9_]*)(?:\\.[0-9_]*)?(?:[eE][-+]?[0-9]+)?|\\.[0-9_]+(?:[eE][-+]?[0-9]+)?|[-+]?\\.(?:inf|Inf|INF)|\\.(?:nan|NaN|NAN))$");function UB(e){return!(e===null||!Efe.test(e)||e[e.length-1]==="_")}N(UB,"resolveYamlFloat");function jB(e){var t,n;return t=e.replace(/_/g,"").toLowerCase(),n=t[0]==="-"?-1:1,"+-".indexOf(t[0])>=0&&(t=t.slice(1)),t===".inf"?n===1?Number.POSITIVE_INFINITY:Number.NEGATIVE_INFINITY:t===".nan"?NaN:n*parseFloat(t,10)}N(jB,"constructYamlFloat");var kfe=/^[-+]?[0-9]+e/;function HB(e,t){var n;if(isNaN(e))switch(t){case"lowercase":return".nan";case"uppercase":return".NAN";case"camelcase":return".NaN"}else if(Number.POSITIVE_INFINITY===e)switch(t){case"lowercase":return".inf";case"uppercase":return".INF";case"camelcase":return".Inf"}else if(Number.NEGATIVE_INFINITY===e)switch(t){case"lowercase":return"-.inf";case"uppercase":return"-.INF";case"camelcase":return"-.Inf"}else if(Xn.isNegativeZero(e))return"-0.0";return n=e.toString(10),kfe.test(n)?n.replace("e",".e"):n}N(HB,"representYamlFloat");function GB(e){return Object.prototype.toString.call(e)==="[object Number]"&&(e%1!==0||Xn.isNegativeZero(e))}N(GB,"isFloat");var Tfe=new yr("tag:yaml.org,2002:float",{kind:"scalar",resolve:UB,construct:jB,predicate:GB,represent:HB,defaultStyle:"lowercase"}),qB=vfe.extend({implicit:[xfe,Sfe,wfe,Tfe]}),_fe=qB,WB=new RegExp("^([0-9][0-9][0-9][0-9])-([0-9][0-9])-([0-9][0-9])$"),VB=new RegExp("^([0-9][0-9][0-9][0-9])-([0-9][0-9]?)-([0-9][0-9]?)(?:[Tt]|[ \\t]+)([0-9][0-9]?):([0-9][0-9]):([0-9][0-9])(?:\\.([0-9]*))?(?:[ \\t]*(Z|([-+])([0-9][0-9]?)(?::([0-9][0-9]))?))?$");function YB(e){return e===null?!1:WB.exec(e)!==null||VB.exec(e)!==null}N(YB,"resolveYamlTimestamp");function XB(e){var t,n,r,a,i,o,l,u=0,d=null,h,f,m;if(t=WB.exec(e),t===null&&(t=VB.exec(e)),t===null)throw new Error("Date resolve error");if(n=+t[1],r=+t[2]-1,a=+t[3],!t[4])return new Date(Date.UTC(n,r,a));if(i=+t[4],o=+t[5],l=+t[6],t[7]){for(u=t[7].slice(0,3);u.length<3;)u+="0";u=+u}return t[9]&&(h=+t[10],f=+(t[11]||0),d=(h*60+f)*6e4,t[9]==="-"&&(d=-d)),m=new Date(Date.UTC(n,r,a,i,o,l,u)),d&&m.setTime(m.getTime()-d),m}N(XB,"constructYamlTimestamp");function KB(e){return e.toISOString()}N(KB,"representYamlTimestamp");var Cfe=new yr("tag:yaml.org,2002:timestamp",{kind:"scalar",resolve:YB,construct:XB,instanceOf:Date,represent:KB});function ZB(e){return e==="<<"||e===null}N(ZB,"resolveYamlMerge");var Afe=new yr("tag:yaml.org,2002:merge",{kind:"scalar",resolve:ZB}),L_=`ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=
\r`;function QB(e){if(e===null)return!1;var t,n,r=0,a=e.length,i=L_;for(n=0;n<a;n++)if(t=i.indexOf(e.charAt(n)),!(t>64)){if(t<0)return!1;r+=6}return r%8===0}N(QB,"resolveYamlBinary");function JB(e){var t,n,r=e.replace(/[\r\n=]/g,""),a=r.length,i=L_,o=0,l=[];for(t=0;t<a;t++)t%4===0&&t&&(l.push(o>>16&255),l.push(o>>8&255),l.push(o&255)),o=o<<6|i.indexOf(r.charAt(t));return n=a%4*6,n===0?(l.push(o>>16&255),l.push(o>>8&255),l.push(o&255)):n===18?(l.push(o>>10&255),l.push(o>>2&255)):n===12&&l.push(o>>4&255),new Uint8Array(l)}N(JB,"constructYamlBinary");function eF(e){var t="",n=0,r,a,i=e.length,o=L_;for(r=0;r<i;r++)r%3===0&&r&&(t+=o[n>>18&63],t+=o[n>>12&63],t+=o[n>>6&63],t+=o[n&63]),n=(n<<8)+e[r];return a=i%3,a===0?(t+=o[n>>18&63],t+=o[n>>12&63],t+=o[n>>6&63],t+=o[n&63]):a===2?(t+=o[n>>10&63],t+=o[n>>4&63],t+=o[n<<2&63],t+=o[64]):a===1&&(t+=o[n>>2&63],t+=o[n<<4&63],t+=o[64],t+=o[64]),t}N(eF,"representYamlBinary");function tF(e){return Object.prototype.toString.call(e)==="[object Uint8Array]"}N(tF,"isBinary");var Rfe=new yr("tag:yaml.org,2002:binary",{kind:"scalar",resolve:QB,construct:JB,predicate:tF,represent:eF}),Nfe=Object.prototype.hasOwnProperty,Ofe=Object.prototype.toString;function nF(e){if(e===null)return!0;var t=[],n,r,a,i,o,l=e;for(n=0,r=l.length;n<r;n+=1){if(a=l[n],o=!1,Ofe.call(a)!=="[object Object]")return!1;for(i in a)if(Nfe.call(a,i))if(!o)o=!0;else return!1;if(!o)return!1;if(t.indexOf(i)===-1)t.push(i);else return!1}return!0}N(nF,"resolveYamlOmap");function rF(e){return e!==null?e:[]}N(rF,"constructYamlOmap");var Ife=new yr("tag:yaml.org,2002:omap",{kind:"sequence",resolve:nF,construct:rF}),Lfe=Object.prototype.toString;function aF(e){if(e===null)return!0;var t,n,r,a,i,o=e;for(i=new Array(o.length),t=0,n=o.length;t<n;t+=1){if(r=o[t],Lfe.call(r)!=="[object Object]"||(a=Object.keys(r),a.length!==1))return!1;i[t]=[a[0],r[a[0]]]}return!0}N(aF,"resolveYamlPairs");function iF(e){if(e===null)return[];var t,n,r,a,i,o=e;for(i=new Array(o.length),t=0,n=o.length;t<n;t+=1)r=o[t],a=Object.keys(r),i[t]=[a[0],r[a[0]]];return i}N(iF,"constructYamlPairs");var Dfe=new yr("tag:yaml.org,2002:pairs",{kind:"sequence",resolve:aF,construct:iF}),Mfe=Object.prototype.hasOwnProperty;function oF(e){if(e===null)return!0;var t,n=e;for(t in n)if(Mfe.call(n,t)&&n[t]!==null)return!1;return!0}N(oF,"resolveYamlSet");function sF(e){return e!==null?e:{}}N(sF,"constructYamlSet");var Bfe=new yr("tag:yaml.org,2002:set",{kind:"mapping",resolve:oF,construct:sF}),lF=_fe.extend({implicit:[Cfe,Afe],explicit:[Rfe,Ife,Dfe,Bfe]}),Cs=Object.prototype.hasOwnProperty,Nm=1,cF=2,uF=3,Om=4,Uv=1,Ffe=2,z7=3,zfe=/[\x00-\x08\x0B\x0C\x0E-\x1F\x7F-\x84\x86-\x9F\uFFFE\uFFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF]/,$fe=/[\x85\u2028\u2029]/,Pfe=/[,\[\]\{\}]/,dF=/^(?:!|!!|![a-z\-]+!)$/i,hF=/^(?:!|[^,\[\]\{\}])(?:%[0-9a-f]{2}|[0-9a-z\-#;\/\?:@&=\+\$,_\.!~\*'\(\)\[\]])*$/i;function s2(e){return Object.prototype.toString.call(e)}N(s2,"_class");function ai(e){return e===10||e===13}N(ai,"is_EOL");function vs(e){return e===9||e===32}N(vs,"is_WHITE_SPACE");function Mr(e){return e===9||e===32||e===10||e===13}N(Mr,"is_WS_OR_EOL");function hl(e){return e===44||e===91||e===93||e===123||e===125}N(hl,"is_FLOW_INDICATOR");function pF(e){var t;return 48<=e&&e<=57?e-48:(t=e|32,97<=t&&t<=102?t-97+10:-1)}N(pF,"fromHexCode");function fF(e){return e===120?2:e===117?4:e===85?8:0}N(fF,"escapedHexLen");function mF(e){return 48<=e&&e<=57?e-48:-1}N(mF,"fromDecimalCode");function l2(e){return e===48?"\0":e===97?"\x07":e===98?"\b":e===116||e===9?"	":e===110?`
`:e===118?"\v":e===102?"\f":e===114?"\r":e===101?"\x1B":e===32?" ":e===34?'"':e===47?"/":e===92?"\\":e===78?"":e===95?" ":e===76?"\u2028":e===80?"\u2029":""}N(l2,"simpleEscapeSequence");function gF(e){return e<=65535?String.fromCharCode(e):String.fromCharCode((e-65536>>10)+55296,(e-65536&1023)+56320)}N(gF,"charFromCodepoint");function D_(e,t,n){t==="__proto__"?Object.defineProperty(e,t,{configurable:!0,enumerable:!0,writable:!0,value:n}):e[t]=n}N(D_,"setProperty");var bF=new Array(256),yF=new Array(256);for(il=0;il<256;il++)bF[il]=l2(il)?1:0,yF[il]=l2(il);var il;function vF(e,t){this.input=e,this.filename=t.filename||null,this.schema=t.schema||lF,this.onWarning=t.onWarning||null,this.legacy=t.legacy||!1,this.json=t.json||!1,this.listener=t.listener||null,this.implicitTypes=this.schema.compiledImplicit,this.typeMap=this.schema.compiledTypeMap,this.length=e.length,this.position=0,this.line=0,this.lineStart=0,this.lineIndent=0,this.firstTabInLine=-1,this.documents=[]}N(vF,"State$1");function M_(e,t){var n={name:e.filename,buffer:e.input.slice(0,-1),position:e.position,line:e.line,column:e.position-e.lineStart};return n.snippet=hfe(n),new Jr(t,n)}N(M_,"generateError");function et(e,t){throw M_(e,t)}N(et,"throwError");function Bh(e,t){e.onWarning&&e.onWarning.call(null,M_(e,t))}N(Bh,"throwWarning");var $7={YAML:N(function(t,n,r){var a,i,o;t.version!==null&&et(t,"duplication of %YAML directive"),r.length!==1&&et(t,"YAML directive accepts exactly one argument"),a=/^([0-9]+)\.([0-9]+)$/.exec(r[0]),a===null&&et(t,"ill-formed argument of the YAML directive"),i=parseInt(a[1],10),o=parseInt(a[2],10),i!==1&&et(t,"unacceptable YAML version of the document"),t.version=r[0],t.checkLineBreaks=o<2,o!==1&&o!==2&&Bh(t,"unsupported YAML version of the document")},"handleYamlDirective"),TAG:N(function(t,n,r){var a,i;r.length!==2&&et(t,"TAG directive accepts exactly two arguments"),a=r[0],i=r[1],dF.test(a)||et(t,"ill-formed tag handle (first argument) of the TAG directive"),Cs.call(t.tagMap,a)&&et(t,'there is a previously declared suffix for "'+a+'" tag handle'),hF.test(i)||et(t,"ill-formed tag prefix (second argument) of the TAG directive");try{i=decodeURIComponent(i)}catch{et(t,"tag prefix is malformed: "+i)}t.tagMap[a]=i},"handleTagDirective")};function So(e,t,n,r){var a,i,o,l;if(t<n){if(l=e.input.slice(t,n),r)for(a=0,i=l.length;a<i;a+=1)o=l.charCodeAt(a),o===9||32<=o&&o<=1114111||et(e,"expected valid JSON character");else zfe.test(l)&&et(e,"the stream contains non-printable characters");e.result+=l}}N(So,"captureSegment");function c2(e,t,n,r){var a,i,o,l;for(Xn.isObject(n)||et(e,"cannot merge mappings; the provided source object is unacceptable"),a=Object.keys(n),o=0,l=a.length;o<l;o+=1)i=a[o],Cs.call(t,i)||(D_(t,i,n[i]),r[i]=!0)}N(c2,"mergeMappings");function pl(e,t,n,r,a,i,o,l,u){var d,h;if(Array.isArray(a))for(a=Array.prototype.slice.call(a),d=0,h=a.length;d<h;d+=1)Array.isArray(a[d])&&et(e,"nested arrays are not supported inside keys"),typeof a=="object"&&s2(a[d])==="[object Object]"&&(a[d]="[object Object]");if(typeof a=="object"&&s2(a)==="[object Object]"&&(a="[object Object]"),a=String(a),t===null&&(t={}),r==="tag:yaml.org,2002:merge")if(Array.isArray(i))for(d=0,h=i.length;d<h;d+=1)c2(e,t,i[d],n);else c2(e,t,i,n);else!e.json&&!Cs.call(n,a)&&Cs.call(t,a)&&(e.line=o||e.line,e.lineStart=l||e.lineStart,e.position=u||e.position,et(e,"duplicated mapping key")),D_(t,a,i),delete n[a];return t}N(pl,"storeMappingPair");function Yg(e){var t;t=e.input.charCodeAt(e.position),t===10?e.position++:t===13?(e.position++,e.input.charCodeAt(e.position)===10&&e.position++):et(e,"a line break is expected"),e.line+=1,e.lineStart=e.position,e.firstTabInLine=-1}N(Yg,"readLineBreak");function On(e,t,n){for(var r=0,a=e.input.charCodeAt(e.position);a!==0;){for(;vs(a);)a===9&&e.firstTabInLine===-1&&(e.firstTabInLine=e.position),a=e.input.charCodeAt(++e.position);if(t&&a===35)do a=e.input.charCodeAt(++e.position);while(a!==10&&a!==13&&a!==0);if(ai(a))for(Yg(e),a=e.input.charCodeAt(e.position),r++,e.lineIndent=0;a===32;)e.lineIndent++,a=e.input.charCodeAt(++e.position);else break}return n!==-1&&r!==0&&e.lineIndent<n&&Bh(e,"deficient indentation"),r}N(On,"skipSeparationSpace");function gp(e){var t=e.position,n;return n=e.input.charCodeAt(t),!!((n===45||n===46)&&n===e.input.charCodeAt(t+1)&&n===e.input.charCodeAt(t+2)&&(t+=3,n=e.input.charCodeAt(t),n===0||Mr(n)))}N(gp,"testDocumentSeparator");function Xg(e,t){t===1?e.result+=" ":t>1&&(e.result+=Xn.repeat(`
`,t-1))}N(Xg,"writeFoldedLines");function xF(e,t,n){var r,a,i,o,l,u,d,h,f=e.kind,m=e.result,b;if(b=e.input.charCodeAt(e.position),Mr(b)||hl(b)||b===35||b===38||b===42||b===33||b===124||b===62||b===39||b===34||b===37||b===64||b===96||(b===63||b===45)&&(a=e.input.charCodeAt(e.position+1),Mr(a)||n&&hl(a)))return!1;for(e.kind="scalar",e.result="",i=o=e.position,l=!1;b!==0;){if(b===58){if(a=e.input.charCodeAt(e.position+1),Mr(a)||n&&hl(a))break}else if(b===35){if(r=e.input.charCodeAt(e.position-1),Mr(r))break}else{if(e.position===e.lineStart&&gp(e)||n&&hl(b))break;if(ai(b))if(u=e.line,d=e.lineStart,h=e.lineIndent,On(e,!1,-1),e.lineIndent>=t){l=!0,b=e.input.charCodeAt(e.position);continue}else{e.position=o,e.line=u,e.lineStart=d,e.lineIndent=h;break}}l&&(So(e,i,o,!1),Xg(e,e.line-u),i=o=e.position,l=!1),vs(b)||(o=e.position+1),b=e.input.charCodeAt(++e.position)}return So(e,i,o,!1),e.result?!0:(e.kind=f,e.result=m,!1)}N(xF,"readPlainScalar");function SF(e,t){var n,r,a;if(n=e.input.charCodeAt(e.position),n!==39)return!1;for(e.kind="scalar",e.result="",e.position++,r=a=e.position;(n=e.input.charCodeAt(e.position))!==0;)if(n===39)if(So(e,r,e.position,!0),n=e.input.charCodeAt(++e.position),n===39)r=e.position,e.position++,a=e.position;else return!0;else ai(n)?(So(e,r,a,!0),Xg(e,On(e,!1,t)),r=a=e.position):e.position===e.lineStart&&gp(e)?et(e,"unexpected end of the document within a single quoted scalar"):(e.position++,a=e.position);et(e,"unexpected end of the stream within a single quoted scalar")}N(SF,"readSingleQuotedScalar");function wF(e,t){var n,r,a,i,o,l;if(l=e.input.charCodeAt(e.position),l!==34)return!1;for(e.kind="scalar",e.result="",e.position++,n=r=e.position;(l=e.input.charCodeAt(e.position))!==0;){if(l===34)return So(e,n,e.position,!0),e.position++,!0;if(l===92){if(So(e,n,e.position,!0),l=e.input.charCodeAt(++e.position),ai(l))On(e,!1,t);else if(l<256&&bF[l])e.result+=yF[l],e.position++;else if((o=fF(l))>0){for(a=o,i=0;a>0;a--)l=e.input.charCodeAt(++e.position),(o=pF(l))>=0?i=(i<<4)+o:et(e,"expected hexadecimal character");e.result+=gF(i),e.position++}else et(e,"unknown escape sequence");n=r=e.position}else ai(l)?(So(e,n,r,!0),Xg(e,On(e,!1,t)),n=r=e.position):e.position===e.lineStart&&gp(e)?et(e,"unexpected end of the document within a double quoted scalar"):(e.position++,r=e.position)}et(e,"unexpected end of the stream within a double quoted scalar")}N(wF,"readDoubleQuotedScalar");function EF(e,t){var n=!0,r,a,i,o=e.tag,l,u=e.anchor,d,h,f,m,b,y=Object.create(null),v,w,S,k;if(k=e.input.charCodeAt(e.position),k===91)h=93,b=!1,l=[];else if(k===123)h=125,b=!0,l={};else return!1;for(e.anchor!==null&&(e.anchorMap[e.anchor]=l),k=e.input.charCodeAt(++e.position);k!==0;){if(On(e,!0,t),k=e.input.charCodeAt(e.position),k===h)return e.position++,e.tag=o,e.anchor=u,e.kind=b?"mapping":"sequence",e.result=l,!0;n?k===44&&et(e,"expected the node content, but found ','"):et(e,"missed comma between flow collection entries"),w=v=S=null,f=m=!1,k===63&&(d=e.input.charCodeAt(e.position+1),Mr(d)&&(f=m=!0,e.position++,On(e,!0,t))),r=e.line,a=e.lineStart,i=e.position,wl(e,t,Nm,!1,!0),w=e.tag,v=e.result,On(e,!0,t),k=e.input.charCodeAt(e.position),(m||e.line===r)&&k===58&&(f=!0,k=e.input.charCodeAt(++e.position),On(e,!0,t),wl(e,t,Nm,!1,!0),S=e.result),b?pl(e,l,y,w,v,S,r,a,i):f?l.push(pl(e,null,y,w,v,S,r,a,i)):l.push(v),On(e,!0,t),k=e.input.charCodeAt(e.position),k===44?(n=!0,k=e.input.charCodeAt(++e.position)):n=!1}et(e,"unexpected end of the stream within a flow collection")}N(EF,"readFlowCollection");function kF(e,t){var n,r,a=Uv,i=!1,o=!1,l=t,u=0,d=!1,h,f;if(f=e.input.charCodeAt(e.position),f===124)r=!1;else if(f===62)r=!0;else return!1;for(e.kind="scalar",e.result="";f!==0;)if(f=e.input.charCodeAt(++e.position),f===43||f===45)Uv===a?a=f===43?z7:Ffe:et(e,"repeat of a chomping mode identifier");else if((h=mF(f))>=0)h===0?et(e,"bad explicit indentation width of a block scalar; it cannot be less than one"):o?et(e,"repeat of an indentation width identifier"):(l=t+h-1,o=!0);else break;if(vs(f)){do f=e.input.charCodeAt(++e.position);while(vs(f));if(f===35)do f=e.input.charCodeAt(++e.position);while(!ai(f)&&f!==0)}for(;f!==0;){for(Yg(e),e.lineIndent=0,f=e.input.charCodeAt(e.position);(!o||e.lineIndent<l)&&f===32;)e.lineIndent++,f=e.input.charCodeAt(++e.position);if(!o&&e.lineIndent>l&&(l=e.lineIndent),ai(f)){u++;continue}if(e.lineIndent<l){a===z7?e.result+=Xn.repeat(`
`,i?1+u:u):a===Uv&&i&&(e.result+=`
`);break}for(r?vs(f)?(d=!0,e.result+=Xn.repeat(`
`,i?1+u:u)):d?(d=!1,e.result+=Xn.repeat(`
`,u+1)):u===0?i&&(e.result+=" "):e.result+=Xn.repeat(`
`,u):e.result+=Xn.repeat(`
`,i?1+u:u),i=!0,o=!0,u=0,n=e.position;!ai(f)&&f!==0;)f=e.input.charCodeAt(++e.position);So(e,n,e.position,!1)}return!0}N(kF,"readBlockScalar");function u2(e,t){var n,r=e.tag,a=e.anchor,i=[],o,l=!1,u;if(e.firstTabInLine!==-1)return!1;for(e.anchor!==null&&(e.anchorMap[e.anchor]=i),u=e.input.charCodeAt(e.position);u!==0&&(e.firstTabInLine!==-1&&(e.position=e.firstTabInLine,et(e,"tab characters must not be used in indentation")),!(u!==45||(o=e.input.charCodeAt(e.position+1),!Mr(o))));){if(l=!0,e.position++,On(e,!0,-1)&&e.lineIndent<=t){i.push(null),u=e.input.charCodeAt(e.position);continue}if(n=e.line,wl(e,t,uF,!1,!0),i.push(e.result),On(e,!0,-1),u=e.input.charCodeAt(e.position),(e.line===n||e.lineIndent>t)&&u!==0)et(e,"bad indentation of a sequence entry");else if(e.lineIndent<t)break}return l?(e.tag=r,e.anchor=a,e.kind="sequence",e.result=i,!0):!1}N(u2,"readBlockSequence");function TF(e,t,n){var r,a,i,o,l,u,d=e.tag,h=e.anchor,f={},m=Object.create(null),b=null,y=null,v=null,w=!1,S=!1,k;if(e.firstTabInLine!==-1)return!1;for(e.anchor!==null&&(e.anchorMap[e.anchor]=f),k=e.input.charCodeAt(e.position);k!==0;){if(!w&&e.firstTabInLine!==-1&&(e.position=e.firstTabInLine,et(e,"tab characters must not be used in indentation")),r=e.input.charCodeAt(e.position+1),i=e.line,(k===63||k===58)&&Mr(r))k===63?(w&&(pl(e,f,m,b,y,null,o,l,u),b=y=v=null),S=!0,w=!0,a=!0):w?(w=!1,a=!0):et(e,"incomplete explicit mapping pair; a key node is missed; or followed by a non-tabulated empty line"),e.position+=1,k=r;else{if(o=e.line,l=e.lineStart,u=e.position,!wl(e,n,cF,!1,!0))break;if(e.line===i){for(k=e.input.charCodeAt(e.position);vs(k);)k=e.input.charCodeAt(++e.position);if(k===58)k=e.input.charCodeAt(++e.position),Mr(k)||et(e,"a whitespace character is expected after the key-value separator within a block mapping"),w&&(pl(e,f,m,b,y,null,o,l,u),b=y=v=null),S=!0,w=!1,a=!1,b=e.tag,y=e.result;else if(S)et(e,"can not read an implicit mapping pair; a colon is missed");else return e.tag=d,e.anchor=h,!0}else if(S)et(e,"can not read a block mapping entry; a multiline key may not be an implicit key");else return e.tag=d,e.anchor=h,!0}if((e.line===i||e.lineIndent>t)&&(w&&(o=e.line,l=e.lineStart,u=e.position),wl(e,t,Om,!0,a)&&(w?y=e.result:v=e.result),w||(pl(e,f,m,b,y,v,o,l,u),b=y=v=null),On(e,!0,-1),k=e.input.charCodeAt(e.position)),(e.line===i||e.lineIndent>t)&&k!==0)et(e,"bad indentation of a mapping entry");else if(e.lineIndent<t)break}return w&&pl(e,f,m,b,y,null,o,l,u),S&&(e.tag=d,e.anchor=h,e.kind="mapping",e.result=f),S}N(TF,"readBlockMapping");function _F(e){var t,n=!1,r=!1,a,i,o;if(o=e.input.charCodeAt(e.position),o!==33)return!1;if(e.tag!==null&&et(e,"duplication of a tag property"),o=e.input.charCodeAt(++e.position),o===60?(n=!0,o=e.input.charCodeAt(++e.position)):o===33?(r=!0,a="!!",o=e.input.charCodeAt(++e.position)):a="!",t=e.position,n){do o=e.input.charCodeAt(++e.position);while(o!==0&&o!==62);e.position<e.length?(i=e.input.slice(t,e.position),o=e.input.charCodeAt(++e.position)):et(e,"unexpected end of the stream within a verbatim tag")}else{for(;o!==0&&!Mr(o);)o===33&&(r?et(e,"tag suffix cannot contain exclamation marks"):(a=e.input.slice(t-1,e.position+1),dF.test(a)||et(e,"named tag handle cannot contain such characters"),r=!0,t=e.position+1)),o=e.input.charCodeAt(++e.position);i=e.input.slice(t,e.position),Pfe.test(i)&&et(e,"tag suffix cannot contain flow indicator characters")}i&&!hF.test(i)&&et(e,"tag name cannot contain such characters: "+i);try{i=decodeURIComponent(i)}catch{et(e,"tag name is malformed: "+i)}return n?e.tag=i:Cs.call(e.tagMap,a)?e.tag=e.tagMap[a]+i:a==="!"?e.tag="!"+i:a==="!!"?e.tag="tag:yaml.org,2002:"+i:et(e,'undeclared tag handle "'+a+'"'),!0}N(_F,"readTagProperty");function CF(e){var t,n;if(n=e.input.charCodeAt(e.position),n!==38)return!1;for(e.anchor!==null&&et(e,"duplication of an anchor property"),n=e.input.charCodeAt(++e.position),t=e.position;n!==0&&!Mr(n)&&!hl(n);)n=e.input.charCodeAt(++e.position);return e.position===t&&et(e,"name of an anchor node must contain at least one character"),e.anchor=e.input.slice(t,e.position),!0}N(CF,"readAnchorProperty");function AF(e){var t,n,r;if(r=e.input.charCodeAt(e.position),r!==42)return!1;for(r=e.input.charCodeAt(++e.position),t=e.position;r!==0&&!Mr(r)&&!hl(r);)r=e.input.charCodeAt(++e.position);return e.position===t&&et(e,"name of an alias node must contain at least one character"),n=e.input.slice(t,e.position),Cs.call(e.anchorMap,n)||et(e,'unidentified alias "'+n+'"'),e.result=e.anchorMap[n],On(e,!0,-1),!0}N(AF,"readAlias");function wl(e,t,n,r,a){var i,o,l,u=1,d=!1,h=!1,f,m,b,y,v,w;if(e.listener!==null&&e.listener("open",e),e.tag=null,e.anchor=null,e.kind=null,e.result=null,i=o=l=Om===n||uF===n,r&&On(e,!0,-1)&&(d=!0,e.lineIndent>t?u=1:e.lineIndent===t?u=0:e.lineIndent<t&&(u=-1)),u===1)for(;_F(e)||CF(e);)On(e,!0,-1)?(d=!0,l=i,e.lineIndent>t?u=1:e.lineIndent===t?u=0:e.lineIndent<t&&(u=-1)):l=!1;if(l&&(l=d||a),(u===1||Om===n)&&(Nm===n||cF===n?v=t:v=t+1,w=e.position-e.lineStart,u===1?l&&(u2(e,w)||TF(e,w,v))||EF(e,v)?h=!0:(o&&kF(e,v)||SF(e,v)||wF(e,v)?h=!0:AF(e)?(h=!0,(e.tag!==null||e.anchor!==null)&&et(e,"alias node should not have any properties")):xF(e,v,Nm===n)&&(h=!0,e.tag===null&&(e.tag="?")),e.anchor!==null&&(e.anchorMap[e.anchor]=e.result)):u===0&&(h=l&&u2(e,w))),e.tag===null)e.anchor!==null&&(e.anchorMap[e.anchor]=e.result);else if(e.tag==="?"){for(e.result!==null&&e.kind!=="scalar"&&et(e,'unacceptable node kind for !<?> tag; it should be "scalar", not "'+e.kind+'"'),f=0,m=e.implicitTypes.length;f<m;f+=1)if(y=e.implicitTypes[f],y.resolve(e.result)){e.result=y.construct(e.result),e.tag=y.tag,e.anchor!==null&&(e.anchorMap[e.anchor]=e.result);break}}else if(e.tag!=="!"){if(Cs.call(e.typeMap[e.kind||"fallback"],e.tag))y=e.typeMap[e.kind||"fallback"][e.tag];else for(y=null,b=e.typeMap.multi[e.kind||"fallback"],f=0,m=b.length;f<m;f+=1)if(e.tag.slice(0,b[f].tag.length)===b[f].tag){y=b[f];break}y||et(e,"unknown tag !<"+e.tag+">"),e.result!==null&&y.kind!==e.kind&&et(e,"unacceptable node kind for !<"+e.tag+'> tag; it should be "'+y.kind+'", not "'+e.kind+'"'),y.resolve(e.result,e.tag)?(e.result=y.construct(e.result,e.tag),e.anchor!==null&&(e.anchorMap[e.anchor]=e.result)):et(e,"cannot resolve a node with !<"+e.tag+"> explicit tag")}return e.listener!==null&&e.listener("close",e),e.tag!==null||e.anchor!==null||h}N(wl,"composeNode");function RF(e){var t=e.position,n,r,a,i=!1,o;for(e.version=null,e.checkLineBreaks=e.legacy,e.tagMap=Object.create(null),e.anchorMap=Object.create(null);(o=e.input.charCodeAt(e.position))!==0&&(On(e,!0,-1),o=e.input.charCodeAt(e.position),!(e.lineIndent>0||o!==37));){for(i=!0,o=e.input.charCodeAt(++e.position),n=e.position;o!==0&&!Mr(o);)o=e.input.charCodeAt(++e.position);for(r=e.input.slice(n,e.position),a=[],r.length<1&&et(e,"directive name must not be less than one character in length");o!==0;){for(;vs(o);)o=e.input.charCodeAt(++e.position);if(o===35){do o=e.input.charCodeAt(++e.position);while(o!==0&&!ai(o));break}if(ai(o))break;for(n=e.position;o!==0&&!Mr(o);)o=e.input.charCodeAt(++e.position);a.push(e.input.slice(n,e.position))}o!==0&&Yg(e),Cs.call($7,r)?$7[r](e,r,a):Bh(e,'unknown document directive "'+r+'"')}if(On(e,!0,-1),e.lineIndent===0&&e.input.charCodeAt(e.position)===45&&e.input.charCodeAt(e.position+1)===45&&e.input.charCodeAt(e.position+2)===45?(e.position+=3,On(e,!0,-1)):i&&et(e,"directives end mark is expected"),wl(e,e.lineIndent-1,Om,!1,!0),On(e,!0,-1),e.checkLineBreaks&&$fe.test(e.input.slice(t,e.position))&&Bh(e,"non-ASCII line breaks are interpreted as content"),e.documents.push(e.result),e.position===e.lineStart&&gp(e)){e.input.charCodeAt(e.position)===46&&(e.position+=3,On(e,!0,-1));return}if(e.position<e.length-1)et(e,"end of the stream or a document separator is expected");else return}N(RF,"readDocument");function B_(e,t){e=String(e),t=t||{},e.length!==0&&(e.charCodeAt(e.length-1)!==10&&e.charCodeAt(e.length-1)!==13&&(e+=`
`),e.charCodeAt(0)===65279&&(e=e.slice(1)));var n=new vF(e,t),r=e.indexOf("\0");for(r!==-1&&(n.position=r,et(n,"null byte is not allowed in input")),n.input+="\0";n.input.charCodeAt(n.position)===32;)n.lineIndent+=1,n.position+=1;for(;n.position<n.length-1;)RF(n);return n.documents}N(B_,"loadDocuments");function Ufe(e,t,n){t!==null&&typeof t=="object"&&typeof n>"u"&&(n=t,t=null);var r=B_(e,n);if(typeof t!="function")return r;for(var a=0,i=r.length;a<i;a+=1)t(r[a])}N(Ufe,"loadAll$1");function NF(e,t){var n=B_(e,t);if(n.length!==0){if(n.length===1)return n[0];throw new Jr("expected a single document in the stream, but found more")}}N(NF,"load$1");var jfe=NF,Hfe={load:jfe},OF=Object.prototype.toString,IF=Object.prototype.hasOwnProperty,F_=65279,Gfe=9,Fh=10,qfe=13,Wfe=32,Vfe=33,Yfe=34,d2=35,Xfe=37,Kfe=38,Zfe=39,Qfe=42,LF=44,Jfe=45,Im=58,e0e=61,t0e=62,n0e=63,r0e=64,DF=91,MF=93,a0e=96,BF=123,i0e=124,FF=125,kr={};kr[0]="\\0";kr[7]="\\a";kr[8]="\\b";kr[9]="\\t";kr[10]="\\n";kr[11]="\\v";kr[12]="\\f";kr[13]="\\r";kr[27]="\\e";kr[34]='\\"';kr[92]="\\\\";kr[133]="\\N";kr[160]="\\_";kr[8232]="\\L";kr[8233]="\\P";var o0e=["y","Y","yes","Yes","YES","on","On","ON","n","N","no","No","NO","off","Off","OFF"],s0e=/^[-+]?[0-9_]+(?::[0-9_]+)+(?:\.[0-9_]*)?$/;function zF(e,t){var n,r,a,i,o,l,u;if(t===null)return{};for(n={},r=Object.keys(t),a=0,i=r.length;a<i;a+=1)o=r[a],l=String(t[o]),o.slice(0,2)==="!!"&&(o="tag:yaml.org,2002:"+o.slice(2)),u=e.compiledTypeMap.fallback[o],u&&IF.call(u.styleAliases,l)&&(l=u.styleAliases[l]),n[o]=l;return n}N(zF,"compileStyleMap");function $F(e){var t,n,r;if(t=e.toString(16).toUpperCase(),e<=255)n="x",r=2;else if(e<=65535)n="u",r=4;else if(e<=4294967295)n="U",r=8;else throw new Jr("code point within a string may not be greater than 0xFFFFFFFF");return"\\"+n+Xn.repeat("0",r-t.length)+t}N($F,"encodeHex");var l0e=1,zh=2;function PF(e){this.schema=e.schema||lF,this.indent=Math.max(1,e.indent||2),this.noArrayIndent=e.noArrayIndent||!1,this.skipInvalid=e.skipInvalid||!1,this.flowLevel=Xn.isNothing(e.flowLevel)?-1:e.flowLevel,this.styleMap=zF(this.schema,e.styles||null),this.sortKeys=e.sortKeys||!1,this.lineWidth=e.lineWidth||80,this.noRefs=e.noRefs||!1,this.noCompatMode=e.noCompatMode||!1,this.condenseFlow=e.condenseFlow||!1,this.quotingType=e.quotingType==='"'?zh:l0e,this.forceQuotes=e.forceQuotes||!1,this.replacer=typeof e.replacer=="function"?e.replacer:null,this.implicitTypes=this.schema.compiledImplicit,this.explicitTypes=this.schema.compiledExplicit,this.tag=null,this.result="",this.duplicates=[],this.usedDuplicates=null}N(PF,"State");function h2(e,t){for(var n=Xn.repeat(" ",t),r=0,a=-1,i="",o,l=e.length;r<l;)a=e.indexOf(`
`,r),a===-1?(o=e.slice(r),r=l):(o=e.slice(r,a+1),r=a+1),o.length&&o!==`
`&&(i+=n),i+=o;return i}N(h2,"indentString");function Lm(e,t){return`
`+Xn.repeat(" ",e.indent*t)}N(Lm,"generateNextLine");function UF(e,t){var n,r,a;for(n=0,r=e.implicitTypes.length;n<r;n+=1)if(a=e.implicitTypes[n],a.resolve(t))return!0;return!1}N(UF,"testImplicitResolving");function $h(e){return e===Wfe||e===Gfe}N($h,"isWhitespace");function su(e){return 32<=e&&e<=126||161<=e&&e<=55295&&e!==8232&&e!==8233||57344<=e&&e<=65533&&e!==F_||65536<=e&&e<=1114111}N(su,"isPrintable");function p2(e){return su(e)&&e!==F_&&e!==qfe&&e!==Fh}N(p2,"isNsCharOrWhitespace");function f2(e,t,n){var r=p2(e),a=r&&!$h(e);return(n?r:r&&e!==LF&&e!==DF&&e!==MF&&e!==BF&&e!==FF)&&e!==d2&&!(t===Im&&!a)||p2(t)&&!$h(t)&&e===d2||t===Im&&a}N(f2,"isPlainSafe");function jF(e){return su(e)&&e!==F_&&!$h(e)&&e!==Jfe&&e!==n0e&&e!==Im&&e!==LF&&e!==DF&&e!==MF&&e!==BF&&e!==FF&&e!==d2&&e!==Kfe&&e!==Qfe&&e!==Vfe&&e!==i0e&&e!==e0e&&e!==t0e&&e!==Zfe&&e!==Yfe&&e!==Xfe&&e!==r0e&&e!==a0e}N(jF,"isPlainSafeFirst");function HF(e){return!$h(e)&&e!==Im}N(HF,"isPlainSafeLast");function Lc(e,t){var n=e.charCodeAt(t),r;return n>=55296&&n<=56319&&t+1<e.length&&(r=e.charCodeAt(t+1),r>=56320&&r<=57343)?(n-55296)*1024+r-56320+65536:n}N(Lc,"codePointAt");function z_(e){var t=/^\n* /;return t.test(e)}N(z_,"needIndentIndicator");var GF=1,m2=2,qF=3,WF=4,Nc=5;function VF(e,t,n,r,a,i,o,l){var u,d=0,h=null,f=!1,m=!1,b=r!==-1,y=-1,v=jF(Lc(e,0))&&HF(Lc(e,e.length-1));if(t||o)for(u=0;u<e.length;d>=65536?u+=2:u++){if(d=Lc(e,u),!su(d))return Nc;v=v&&f2(d,h,l),h=d}else{for(u=0;u<e.length;d>=65536?u+=2:u++){if(d=Lc(e,u),d===Fh)f=!0,b&&(m=m||u-y-1>r&&e[y+1]!==" ",y=u);else if(!su(d))return Nc;v=v&&f2(d,h,l),h=d}m=m||b&&u-y-1>r&&e[y+1]!==" "}return!f&&!m?v&&!o&&!a(e)?GF:i===zh?Nc:m2:n>9&&z_(e)?Nc:o?i===zh?Nc:m2:m?WF:qF}N(VF,"chooseScalarStyle");function YF(e,t,n,r,a){e.dump=(function(){if(t.length===0)return e.quotingType===zh?'""':"''";if(!e.noCompatMode&&(o0e.indexOf(t)!==-1||s0e.test(t)))return e.quotingType===zh?'"'+t+'"':"'"+t+"'";var i=e.indent*Math.max(1,n),o=e.lineWidth===-1?-1:Math.max(Math.min(e.lineWidth,40),e.lineWidth-i),l=r||e.flowLevel>-1&&n>=e.flowLevel;function u(d){return UF(e,d)}switch(N(u,"testAmbiguity"),VF(t,l,e.indent,o,u,e.quotingType,e.forceQuotes&&!r,a)){case GF:return t;case m2:return"'"+t.replace(/'/g,"''")+"'";case qF:return"|"+g2(t,e.indent)+b2(h2(t,i));case WF:return">"+g2(t,e.indent)+b2(h2(XF(t,o),i));case Nc:return'"'+KF(t)+'"';default:throw new Jr("impossible error: invalid scalar style")}})()}N(YF,"writeScalar");function g2(e,t){var n=z_(e)?String(t):"",r=e[e.length-1]===`
`,a=r&&(e[e.length-2]===`
`||e===`
`),i=a?"+":r?"":"-";return n+i+`
`}N(g2,"blockHeader");function b2(e){return e[e.length-1]===`
`?e.slice(0,-1):e}N(b2,"dropEndingNewline");function XF(e,t){for(var n=/(\n+)([^\n]*)/g,r=(function(){var d=e.indexOf(`
`);return d=d!==-1?d:e.length,n.lastIndex=d,y2(e.slice(0,d),t)})(),a=e[0]===`
`||e[0]===" ",i,o;o=n.exec(e);){var l=o[1],u=o[2];i=u[0]===" ",r+=l+(!a&&!i&&u!==""?`
`:"")+y2(u,t),a=i}return r}N(XF,"foldString");function y2(e,t){if(e===""||e[0]===" ")return e;for(var n=/ [^ ]/g,r,a=0,i,o=0,l=0,u="";r=n.exec(e);)l=r.index,l-a>t&&(i=o>a?o:l,u+=`
`+e.slice(a,i),a=i+1),o=l;return u+=`
`,e.length-a>t&&o>a?u+=e.slice(a,o)+`
`+e.slice(o+1):u+=e.slice(a),u.slice(1)}N(y2,"foldLine");function KF(e){for(var t="",n=0,r,a=0;a<e.length;n>=65536?a+=2:a++)n=Lc(e,a),r=kr[n],!r&&su(n)?(t+=e[a],n>=65536&&(t+=e[a+1])):t+=r||$F(n);return t}N(KF,"escapeString");function ZF(e,t,n){var r="",a=e.tag,i,o,l;for(i=0,o=n.length;i<o;i+=1)l=n[i],e.replacer&&(l=e.replacer.call(n,String(i),l)),(Oi(e,t,l,!1,!1)||typeof l>"u"&&Oi(e,t,null,!1,!1))&&(r!==""&&(r+=","+(e.condenseFlow?"":" ")),r+=e.dump);e.tag=a,e.dump="["+r+"]"}N(ZF,"writeFlowSequence");function v2(e,t,n,r){var a="",i=e.tag,o,l,u;for(o=0,l=n.length;o<l;o+=1)u=n[o],e.replacer&&(u=e.replacer.call(n,String(o),u)),(Oi(e,t+1,u,!0,!0,!1,!0)||typeof u>"u"&&Oi(e,t+1,null,!0,!0,!1,!0))&&((!r||a!=="")&&(a+=Lm(e,t)),e.dump&&Fh===e.dump.charCodeAt(0)?a+="-":a+="- ",a+=e.dump);e.tag=i,e.dump=a||"[]"}N(v2,"writeBlockSequence");function QF(e,t,n){var r="",a=e.tag,i=Object.keys(n),o,l,u,d,h;for(o=0,l=i.length;o<l;o+=1)h="",r!==""&&(h+=", "),e.condenseFlow&&(h+='"'),u=i[o],d=n[u],e.replacer&&(d=e.replacer.call(n,u,d)),Oi(e,t,u,!1,!1)&&(e.dump.length>1024&&(h+="? "),h+=e.dump+(e.condenseFlow?'"':"")+":"+(e.condenseFlow?"":" "),Oi(e,t,d,!1,!1)&&(h+=e.dump,r+=h));e.tag=a,e.dump="{"+r+"}"}N(QF,"writeFlowMapping");function JF(e,t,n,r){var a="",i=e.tag,o=Object.keys(n),l,u,d,h,f,m;if(e.sortKeys===!0)o.sort();else if(typeof e.sortKeys=="function")o.sort(e.sortKeys);else if(e.sortKeys)throw new Jr("sortKeys must be a boolean or a function");for(l=0,u=o.length;l<u;l+=1)m="",(!r||a!=="")&&(m+=Lm(e,t)),d=o[l],h=n[d],e.replacer&&(h=e.replacer.call(n,d,h)),Oi(e,t+1,d,!0,!0,!0)&&(f=e.tag!==null&&e.tag!=="?"||e.dump&&e.dump.length>1024,f&&(e.dump&&Fh===e.dump.charCodeAt(0)?m+="?":m+="? "),m+=e.dump,f&&(m+=Lm(e,t)),Oi(e,t+1,h,!0,f)&&(e.dump&&Fh===e.dump.charCodeAt(0)?m+=":":m+=": ",m+=e.dump,a+=m));e.tag=i,e.dump=a||"{}"}N(JF,"writeBlockMapping");function x2(e,t,n){var r,a,i,o,l,u;for(a=n?e.explicitTypes:e.implicitTypes,i=0,o=a.length;i<o;i+=1)if(l=a[i],(l.instanceOf||l.predicate)&&(!l.instanceOf||typeof t=="object"&&t instanceof l.instanceOf)&&(!l.predicate||l.predicate(t))){if(n?l.multi&&l.representName?e.tag=l.representName(t):e.tag=l.tag:e.tag="?",l.represent){if(u=e.styleMap[l.tag]||l.defaultStyle,OF.call(l.represent)==="[object Function]")r=l.represent(t,u);else if(IF.call(l.represent,u))r=l.represent[u](t,u);else throw new Jr("!<"+l.tag+'> tag resolver accepts not "'+u+'" style');e.dump=r}return!0}return!1}N(x2,"detectType");function Oi(e,t,n,r,a,i,o){e.tag=null,e.dump=n,x2(e,n,!1)||x2(e,n,!0);var l=OF.call(e.dump),u=r,d;r&&(r=e.flowLevel<0||e.flowLevel>t);var h=l==="[object Object]"||l==="[object Array]",f,m;if(h&&(f=e.duplicates.indexOf(n),m=f!==-1),(e.tag!==null&&e.tag!=="?"||m||e.indent!==2&&t>0)&&(a=!1),m&&e.usedDuplicates[f])e.dump="*ref_"+f;else{if(h&&m&&!e.usedDuplicates[f]&&(e.usedDuplicates[f]=!0),l==="[object Object]")r&&Object.keys(e.dump).length!==0?(JF(e,t,e.dump,a),m&&(e.dump="&ref_"+f+e.dump)):(QF(e,t,e.dump),m&&(e.dump="&ref_"+f+" "+e.dump));else if(l==="[object Array]")r&&e.dump.length!==0?(e.noArrayIndent&&!o&&t>0?v2(e,t-1,e.dump,a):v2(e,t,e.dump,a),m&&(e.dump="&ref_"+f+e.dump)):(ZF(e,t,e.dump),m&&(e.dump="&ref_"+f+" "+e.dump));else if(l==="[object String]")e.tag!=="?"&&YF(e,e.dump,t,i,u);else{if(l==="[object Undefined]")return!1;if(e.skipInvalid)return!1;throw new Jr("unacceptable kind of an object to dump "+l)}e.tag!==null&&e.tag!=="?"&&(d=encodeURI(e.tag[0]==="!"?e.tag.slice(1):e.tag).replace(/!/g,"%21"),e.tag[0]==="!"?d="!"+d:d.slice(0,18)==="tag:yaml.org,2002:"?d="!!"+d.slice(18):d="!<"+d+">",e.dump=d+" "+e.dump)}return!0}N(Oi,"writeNode");function ez(e,t){var n=[],r=[],a,i;for(Dm(e,n,r),a=0,i=r.length;a<i;a+=1)t.duplicates.push(n[r[a]]);t.usedDuplicates=new Array(i)}N(ez,"getDuplicateReferences");function Dm(e,t,n){var r,a,i;if(e!==null&&typeof e=="object")if(a=t.indexOf(e),a!==-1)n.indexOf(a)===-1&&n.push(a);else if(t.push(e),Array.isArray(e))for(a=0,i=e.length;a<i;a+=1)Dm(e[a],t,n);else for(r=Object.keys(e),a=0,i=r.length;a<i;a+=1)Dm(e[r[a]],t,n)}N(Dm,"inspectNode");function c0e(e,t){t=t||{};var n=new PF(t);n.noRefs||ez(e,n);var r=e;return n.replacer&&(r=n.replacer.call({"":r},"",r)),Oi(n,0,r,!0,!0)?n.dump+`
`:""}N(c0e,"dump$1");function u0e(e,t){return function(){throw new Error("Function yaml."+e+" is removed in js-yaml 4. Use yaml."+t+" instead, which is now safe by default.")}}N(u0e,"renamed");var d0e=qB,h0e=Hfe.load;/*! Bundled license information:

js-yaml/dist/js-yaml.mjs:
  (*! js-yaml 4.1.1 https://github.com/nodeca/js-yaml @license MIT *)
*/var Gd=N((e,t)=>{if(t)return"translate("+-e.width/2+", "+-e.height/2+")";const n=e.x??0,r=e.y??0;return"translate("+-(n+e.width/2)+", "+-(r+e.height/2)+")"},"computeLabelTransform"),pr={aggregation:17.25,extension:17.25,composition:17.25,dependency:6,lollipop:13.5,arrow_point:4},P7={arrow_point:9,arrow_cross:12.5,arrow_circle:12.5};function rh(e,t){if(e===void 0||t===void 0)return{angle:0,deltaX:0,deltaY:0};e=gn(e),t=gn(t);const[n,r]=[e.x,e.y],[a,i]=[t.x,t.y],o=a-n,l=i-r;return{angle:Math.atan(l/o),deltaX:o,deltaY:l}}N(rh,"calculateDeltaAndAngle");var gn=N(e=>Array.isArray(e)?{x:e[0],y:e[1]}:e,"pointTransformer"),p0e=N(e=>({x:N(function(t,n,r){let a=0;const i=gn(r[0]).x<gn(r[r.length-1]).x?"left":"right";if(n===0&&Object.hasOwn(pr,e.arrowTypeStart)){const{angle:b,deltaX:y}=rh(r[0],r[1]);a=pr[e.arrowTypeStart]*Math.cos(b)*(y>=0?1:-1)}else if(n===r.length-1&&Object.hasOwn(pr,e.arrowTypeEnd)){const{angle:b,deltaX:y}=rh(r[r.length-1],r[r.length-2]);a=pr[e.arrowTypeEnd]*Math.cos(b)*(y>=0?1:-1)}const o=Math.abs(gn(t).x-gn(r[r.length-1]).x),l=Math.abs(gn(t).y-gn(r[r.length-1]).y),u=Math.abs(gn(t).x-gn(r[0]).x),d=Math.abs(gn(t).y-gn(r[0]).y),h=pr[e.arrowTypeStart],f=pr[e.arrowTypeEnd],m=1;if(o<f&&o>0&&l<f){let b=f+m-o;b*=i==="right"?-1:1,a-=b}if(u<h&&u>0&&d<h){let b=h+m-u;b*=i==="right"?-1:1,a+=b}return gn(t).x+a},"x"),y:N(function(t,n,r){let a=0;const i=gn(r[0]).y<gn(r[r.length-1]).y?"down":"up";if(n===0&&Object.hasOwn(pr,e.arrowTypeStart)){const{angle:b,deltaY:y}=rh(r[0],r[1]);a=pr[e.arrowTypeStart]*Math.abs(Math.sin(b))*(y>=0?1:-1)}else if(n===r.length-1&&Object.hasOwn(pr,e.arrowTypeEnd)){const{angle:b,deltaY:y}=rh(r[r.length-1],r[r.length-2]);a=pr[e.arrowTypeEnd]*Math.abs(Math.sin(b))*(y>=0?1:-1)}const o=Math.abs(gn(t).y-gn(r[r.length-1]).y),l=Math.abs(gn(t).x-gn(r[r.length-1]).x),u=Math.abs(gn(t).y-gn(r[0]).y),d=Math.abs(gn(t).x-gn(r[0]).x),h=pr[e.arrowTypeStart],f=pr[e.arrowTypeEnd],m=1;if(o<f&&o>0&&l<f){let b=f+m-o;b*=i==="up"?-1:1,a-=b}if(u<h&&u>0&&d<h){let b=h+m-u;b*=i==="up"?-1:1,a+=b}return gn(t).y+a},"y")}),"getLineFunctionsWithOffset"),b0={},Vn={},U7;function f0e(){return U7||(U7=1,Object.defineProperty(Vn,"__esModule",{value:!0}),Vn.BLANK_URL=Vn.relativeFirstCharacters=Vn.whitespaceEscapeCharsRegex=Vn.urlSchemeRegex=Vn.ctrlCharactersRegex=Vn.htmlCtrlEntityRegex=Vn.htmlEntitiesRegex=Vn.invalidProtocolRegex=void 0,Vn.invalidProtocolRegex=/^([^\w]*)(javascript|data|vbscript)/im,Vn.htmlEntitiesRegex=/&#(\w+)(^\w|;)?/g,Vn.htmlCtrlEntityRegex=/&(newline|tab);/gi,Vn.ctrlCharactersRegex=/[\u0000-\u001F\u007F-\u009F\u2000-\u200D\uFEFF]/gim,Vn.urlSchemeRegex=/^.+(:|&colon;)/gim,Vn.whitespaceEscapeCharsRegex=/(\\|%5[cC])((%(6[eE]|72|74))|[nrt])/g,Vn.relativeFirstCharacters=[".","/"],Vn.BLANK_URL="about:blank"),Vn}var j7;function m0e(){if(j7)return b0;j7=1,Object.defineProperty(b0,"__esModule",{value:!0}),b0.sanitizeUrl=i;var e=f0e();function t(o){return e.relativeFirstCharacters.indexOf(o[0])>-1}function n(o){var l=o.replace(e.ctrlCharactersRegex,"");return l.replace(e.htmlEntitiesRegex,function(u,d){return String.fromCharCode(d)})}function r(o){return URL.canParse(o)}function a(o){try{return decodeURIComponent(o)}catch{return o}}function i(o){if(!o)return e.BLANK_URL;var l,u=a(o.trim());do u=n(u).replace(e.htmlCtrlEntityRegex,"").replace(e.ctrlCharactersRegex,"").replace(e.whitespaceEscapeCharsRegex,"").trim(),u=a(u),l=u.match(e.ctrlCharactersRegex)||u.match(e.htmlEntitiesRegex)||u.match(e.htmlCtrlEntityRegex)||u.match(e.whitespaceEscapeCharsRegex);while(l&&l.length>0);var d=u;if(!d)return e.BLANK_URL;if(t(d))return d;var h=d.trimStart(),f=h.match(e.urlSchemeRegex);if(!f)return d;var m=f[0].toLowerCase().trim();if(e.invalidProtocolRegex.test(m))return e.BLANK_URL;var b=h.replace(/\\/g,"/");if(m==="mailto:"||m.includes("://"))return b;if(m==="http:"||m==="https:"){if(!r(b))return e.BLANK_URL;var y=new URL(b);return y.protocol=y.protocol.toLowerCase(),y.hostname=y.hostname.toLowerCase(),y.toString()}return b}return b0}var g0e=m0e(),tz=typeof global=="object"&&global&&global.Object===Object&&global,b0e=typeof self=="object"&&self&&self.Object===Object&&self,Ui=tz||b0e||Function("return this")(),Mm=Ui.Symbol,nz=Object.prototype,y0e=nz.hasOwnProperty,v0e=nz.toString,qd=Mm?Mm.toStringTag:void 0;function x0e(e){var t=y0e.call(e,qd),n=e[qd];try{e[qd]=void 0;var r=!0}catch{}var a=v0e.call(e);return r&&(t?e[qd]=n:delete e[qd]),a}var S0e=Object.prototype,w0e=S0e.toString;function E0e(e){return w0e.call(e)}var k0e="[object Null]",T0e="[object Undefined]",H7=Mm?Mm.toStringTag:void 0;function Ru(e){return e==null?e===void 0?T0e:k0e:H7&&H7 in Object(e)?x0e(e):E0e(e)}function Dl(e){var t=typeof e;return e!=null&&(t=="object"||t=="function")}var _0e="[object AsyncFunction]",C0e="[object Function]",A0e="[object GeneratorFunction]",R0e="[object Proxy]";function $_(e){if(!Dl(e))return!1;var t=Ru(e);return t==C0e||t==A0e||t==_0e||t==R0e}var jv=Ui["__core-js_shared__"],G7=(function(){var e=/[^.]+$/.exec(jv&&jv.keys&&jv.keys.IE_PROTO||"");return e?"Symbol(src)_1."+e:""})();function N0e(e){return!!G7&&G7 in e}var O0e=Function.prototype,I0e=O0e.toString;function Ml(e){if(e!=null){try{return I0e.call(e)}catch{}try{return e+""}catch{}}return""}var L0e=/[\\^$.*+?()[\]{}|]/g,D0e=/^\[object .+?Constructor\]$/,M0e=Function.prototype,B0e=Object.prototype,F0e=M0e.toString,z0e=B0e.hasOwnProperty,$0e=RegExp("^"+F0e.call(z0e).replace(L0e,"\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g,"$1.*?")+"$");function P0e(e){if(!Dl(e)||N0e(e))return!1;var t=$_(e)?$0e:D0e;return t.test(Ml(e))}function U0e(e,t){return e==null?void 0:e[t]}function Bl(e,t){var n=U0e(e,t);return P0e(n)?n:void 0}var Ph=Bl(Object,"create");function j0e(){this.__data__=Ph?Ph(null):{},this.size=0}function H0e(e){var t=this.has(e)&&delete this.__data__[e];return this.size-=t?1:0,t}var G0e="__lodash_hash_undefined__",q0e=Object.prototype,W0e=q0e.hasOwnProperty;function V0e(e){var t=this.__data__;if(Ph){var n=t[e];return n===G0e?void 0:n}return W0e.call(t,e)?t[e]:void 0}var Y0e=Object.prototype,X0e=Y0e.hasOwnProperty;function K0e(e){var t=this.__data__;return Ph?t[e]!==void 0:X0e.call(t,e)}var Z0e="__lodash_hash_undefined__";function Q0e(e,t){var n=this.__data__;return this.size+=this.has(e)?0:1,n[e]=Ph&&t===void 0?Z0e:t,this}function El(e){var t=-1,n=e==null?0:e.length;for(this.clear();++t<n;){var r=e[t];this.set(r[0],r[1])}}El.prototype.clear=j0e;El.prototype.delete=H0e;El.prototype.get=V0e;El.prototype.has=K0e;El.prototype.set=Q0e;function J0e(){this.__data__=[],this.size=0}function Kg(e,t){return e===t||e!==e&&t!==t}function Zg(e,t){for(var n=e.length;n--;)if(Kg(e[n][0],t))return n;return-1}var eme=Array.prototype,tme=eme.splice;function nme(e){var t=this.__data__,n=Zg(t,e);if(n<0)return!1;var r=t.length-1;return n==r?t.pop():tme.call(t,n,1),--this.size,!0}function rme(e){var t=this.__data__,n=Zg(t,e);return n<0?void 0:t[n][1]}function ame(e){return Zg(this.__data__,e)>-1}function ime(e,t){var n=this.__data__,r=Zg(n,e);return r<0?(++this.size,n.push([e,t])):n[r][1]=t,this}function Lo(e){var t=-1,n=e==null?0:e.length;for(this.clear();++t<n;){var r=e[t];this.set(r[0],r[1])}}Lo.prototype.clear=J0e;Lo.prototype.delete=nme;Lo.prototype.get=rme;Lo.prototype.has=ame;Lo.prototype.set=ime;var Uh=Bl(Ui,"Map");function ome(){this.size=0,this.__data__={hash:new El,map:new(Uh||Lo),string:new El}}function sme(e){var t=typeof e;return t=="string"||t=="number"||t=="symbol"||t=="boolean"?e!=="__proto__":e===null}function Qg(e,t){var n=e.__data__;return sme(t)?n[typeof t=="string"?"string":"hash"]:n.map}function lme(e){var t=Qg(this,e).delete(e);return this.size-=t?1:0,t}function cme(e){return Qg(this,e).get(e)}function ume(e){return Qg(this,e).has(e)}function dme(e,t){var n=Qg(this,e),r=n.size;return n.set(e,t),this.size+=n.size==r?0:1,this}function Ms(e){var t=-1,n=e==null?0:e.length;for(this.clear();++t<n;){var r=e[t];this.set(r[0],r[1])}}Ms.prototype.clear=ome;Ms.prototype.delete=lme;Ms.prototype.get=cme;Ms.prototype.has=ume;Ms.prototype.set=dme;var hme="Expected a function";function bp(e,t){if(typeof e!="function"||t!=null&&typeof t!="function")throw new TypeError(hme);var n=function(){var r=arguments,a=t?t.apply(this,r):r[0],i=n.cache;if(i.has(a))return i.get(a);var o=e.apply(this,r);return n.cache=i.set(a,o)||i,o};return n.cache=new(bp.Cache||Ms),n}bp.Cache=Ms;function pme(){this.__data__=new Lo,this.size=0}function fme(e){var t=this.__data__,n=t.delete(e);return this.size=t.size,n}function mme(e){return this.__data__.get(e)}function gme(e){return this.__data__.has(e)}var bme=200;function yme(e,t){var n=this.__data__;if(n instanceof Lo){var r=n.__data__;if(!Uh||r.length<bme-1)return r.push([e,t]),this.size=++n.size,this;n=this.__data__=new Ms(r)}return n.set(e,t),this.size=n.size,this}function Nu(e){var t=this.__data__=new Lo(e);this.size=t.size}Nu.prototype.clear=pme;Nu.prototype.delete=fme;Nu.prototype.get=mme;Nu.prototype.has=gme;Nu.prototype.set=yme;var Bm=(function(){try{var e=Bl(Object,"defineProperty");return e({},"",{}),e}catch{}})();function P_(e,t,n){t=="__proto__"&&Bm?Bm(e,t,{configurable:!0,enumerable:!0,value:n,writable:!0}):e[t]=n}function S2(e,t,n){(n!==void 0&&!Kg(e[t],n)||n===void 0&&!(t in e))&&P_(e,t,n)}function vme(e){return function(t,n,r){for(var a=-1,i=Object(t),o=r(t),l=o.length;l--;){var u=o[++a];if(n(i[u],u,i)===!1)break}return t}}var xme=vme(),rz=typeof exports=="object"&&exports&&!exports.nodeType&&exports,q7=rz&&typeof module=="object"&&module&&!module.nodeType&&module,Sme=q7&&q7.exports===rz,W7=Sme?Ui.Buffer:void 0,V7=W7?W7.allocUnsafe:void 0;function wme(e,t){if(t)return e.slice();var n=e.length,r=V7?V7(n):new e.constructor(n);return e.copy(r),r}var Y7=Ui.Uint8Array;function Eme(e){var t=new e.constructor(e.byteLength);return new Y7(t).set(new Y7(e)),t}function kme(e,t){var n=t?Eme(e.buffer):e.buffer;return new e.constructor(n,e.byteOffset,e.length)}function Tme(e,t){var n=-1,r=e.length;for(t||(t=Array(r));++n<r;)t[n]=e[n];return t}var X7=Object.create,_me=(function(){function e(){}return function(t){if(!Dl(t))return{};if(X7)return X7(t);e.prototype=t;var n=new e;return e.prototype=void 0,n}})();function az(e,t){return function(n){return e(t(n))}}var iz=az(Object.getPrototypeOf,Object),Cme=Object.prototype;function Jg(e){var t=e&&e.constructor,n=typeof t=="function"&&t.prototype||Cme;return e===n}function Ame(e){return typeof e.constructor=="function"&&!Jg(e)?_me(iz(e)):{}}function yp(e){return e!=null&&typeof e=="object"}var Rme="[object Arguments]";function K7(e){return yp(e)&&Ru(e)==Rme}var oz=Object.prototype,Nme=oz.hasOwnProperty,Ome=oz.propertyIsEnumerable,Fm=K7((function(){return arguments})())?K7:function(e){return yp(e)&&Nme.call(e,"callee")&&!Ome.call(e,"callee")},zm=Array.isArray,Ime=9007199254740991;function sz(e){return typeof e=="number"&&e>-1&&e%1==0&&e<=Ime}function eb(e){return e!=null&&sz(e.length)&&!$_(e)}function Lme(e){return yp(e)&&eb(e)}function Dme(){return!1}var lz=typeof exports=="object"&&exports&&!exports.nodeType&&exports,Z7=lz&&typeof module=="object"&&module&&!module.nodeType&&module,Mme=Z7&&Z7.exports===lz,Q7=Mme?Ui.Buffer:void 0,Bme=Q7?Q7.isBuffer:void 0,U_=Bme||Dme,Fme="[object Object]",zme=Function.prototype,$me=Object.prototype,cz=zme.toString,Pme=$me.hasOwnProperty,Ume=cz.call(Object);function jme(e){if(!yp(e)||Ru(e)!=Fme)return!1;var t=iz(e);if(t===null)return!0;var n=Pme.call(t,"constructor")&&t.constructor;return typeof n=="function"&&n instanceof n&&cz.call(n)==Ume}var Hme="[object Arguments]",Gme="[object Array]",qme="[object Boolean]",Wme="[object Date]",Vme="[object Error]",Yme="[object Function]",Xme="[object Map]",Kme="[object Number]",Zme="[object Object]",Qme="[object RegExp]",Jme="[object Set]",ege="[object String]",tge="[object WeakMap]",nge="[object ArrayBuffer]",rge="[object DataView]",age="[object Float32Array]",ige="[object Float64Array]",oge="[object Int8Array]",sge="[object Int16Array]",lge="[object Int32Array]",cge="[object Uint8Array]",uge="[object Uint8ClampedArray]",dge="[object Uint16Array]",hge="[object Uint32Array]",cn={};cn[age]=cn[ige]=cn[oge]=cn[sge]=cn[lge]=cn[cge]=cn[uge]=cn[dge]=cn[hge]=!0;cn[Hme]=cn[Gme]=cn[nge]=cn[qme]=cn[rge]=cn[Wme]=cn[Vme]=cn[Yme]=cn[Xme]=cn[Kme]=cn[Zme]=cn[Qme]=cn[Jme]=cn[ege]=cn[tge]=!1;function pge(e){return yp(e)&&sz(e.length)&&!!cn[Ru(e)]}function fge(e){return function(t){return e(t)}}var uz=typeof exports=="object"&&exports&&!exports.nodeType&&exports,bh=uz&&typeof module=="object"&&module&&!module.nodeType&&module,mge=bh&&bh.exports===uz,Hv=mge&&tz.process,J7=(function(){try{var e=bh&&bh.require&&bh.require("util").types;return e||Hv&&Hv.binding&&Hv.binding("util")}catch{}})(),e8=J7&&J7.isTypedArray,j_=e8?fge(e8):pge;function w2(e,t){if(!(t==="constructor"&&typeof e[t]=="function")&&t!="__proto__")return e[t]}var gge=Object.prototype,bge=gge.hasOwnProperty;function yge(e,t,n){var r=e[t];(!(bge.call(e,t)&&Kg(r,n))||n===void 0&&!(t in e))&&P_(e,t,n)}function vge(e,t,n,r){var a=!n;n||(n={});for(var i=-1,o=t.length;++i<o;){var l=t[i],u=void 0;u===void 0&&(u=e[l]),a?P_(n,l,u):yge(n,l,u)}return n}function xge(e,t){for(var n=-1,r=Array(e);++n<e;)r[n]=t(n);return r}var Sge=9007199254740991,wge=/^(?:0|[1-9]\d*)$/;function dz(e,t){var n=typeof e;return t=t??Sge,!!t&&(n=="number"||n!="symbol"&&wge.test(e))&&e>-1&&e%1==0&&e<t}var Ege=Object.prototype,kge=Ege.hasOwnProperty;function Tge(e,t){var n=zm(e),r=!n&&Fm(e),a=!n&&!r&&U_(e),i=!n&&!r&&!a&&j_(e),o=n||r||a||i,l=o?xge(e.length,String):[],u=l.length;for(var d in e)(t||kge.call(e,d))&&!(o&&(d=="length"||a&&(d=="offset"||d=="parent")||i&&(d=="buffer"||d=="byteLength"||d=="byteOffset")||dz(d,u)))&&l.push(d);return l}function _ge(e){var t=[];if(e!=null)for(var n in Object(e))t.push(n);return t}var Cge=Object.prototype,Age=Cge.hasOwnProperty;function Rge(e){if(!Dl(e))return _ge(e);var t=Jg(e),n=[];for(var r in e)r=="constructor"&&(t||!Age.call(e,r))||n.push(r);return n}function hz(e){return eb(e)?Tge(e,!0):Rge(e)}function Nge(e){return vge(e,hz(e))}function Oge(e,t,n,r,a,i,o){var l=w2(e,n),u=w2(t,n),d=o.get(u);if(d){S2(e,n,d);return}var h=i?i(l,u,n+"",e,t,o):void 0,f=h===void 0;if(f){var m=zm(u),b=!m&&U_(u),y=!m&&!b&&j_(u);h=u,m||b||y?zm(l)?h=l:Lme(l)?h=Tme(l):b?(f=!1,h=wme(u,!0)):y?(f=!1,h=kme(u,!0)):h=[]:jme(u)||Fm(u)?(h=l,Fm(l)?h=Nge(l):(!Dl(l)||$_(l))&&(h=Ame(u))):f=!1}f&&(o.set(u,h),a(h,u,r,i,o),o.delete(u)),S2(e,n,h)}function pz(e,t,n,r,a){e!==t&&xme(t,function(i,o){if(a||(a=new Nu),Dl(i))Oge(e,t,o,n,pz,r,a);else{var l=r?r(w2(e,o),i,o+"",e,t,a):void 0;l===void 0&&(l=i),S2(e,o,l)}},hz)}function fz(e){return e}function Ige(e,t,n){switch(n.length){case 0:return e.call(t);case 1:return e.call(t,n[0]);case 2:return e.call(t,n[0],n[1]);case 3:return e.call(t,n[0],n[1],n[2])}return e.apply(t,n)}var t8=Math.max;function Lge(e,t,n){return t=t8(t===void 0?e.length-1:t,0),function(){for(var r=arguments,a=-1,i=t8(r.length-t,0),o=Array(i);++a<i;)o[a]=r[t+a];a=-1;for(var l=Array(t+1);++a<t;)l[a]=r[a];return l[t]=n(o),Ige(e,this,l)}}function Dge(e){return function(){return e}}var Mge=Bm?function(e,t){return Bm(e,"toString",{configurable:!0,enumerable:!1,value:Dge(t),writable:!0})}:fz,Bge=800,Fge=16,zge=Date.now;function $ge(e){var t=0,n=0;return function(){var r=zge(),a=Fge-(r-n);if(n=r,a>0){if(++t>=Bge)return arguments[0]}else t=0;return e.apply(void 0,arguments)}}var Pge=$ge(Mge);function Uge(e,t){return Pge(Lge(e,t,fz),e+"")}function jge(e,t,n){if(!Dl(n))return!1;var r=typeof t;return(r=="number"?eb(n)&&dz(t,n.length):r=="string"&&t in n)?Kg(n[t],e):!1}function Hge(e){return Uge(function(t,n){var r=-1,a=n.length,i=a>1?n[a-1]:void 0,o=a>2?n[2]:void 0;for(i=e.length>3&&typeof i=="function"?(a--,i):void 0,o&&jge(n[0],n[1],o)&&(i=a<3?void 0:i,a=1),t=Object(t);++r<a;){var l=n[r];l&&e(t,l,r,i)}return t})}var Gge=Hge(function(e,t,n){pz(e,t,n)}),qge="​",Wge={curveBasis:i2,curveBasisClosed:Zpe,curveBasisOpen:Qpe,curveBumpX:eB,curveBumpY:tB,curveBundle:Jpe,curveCardinalClosed:efe,curveCardinalOpen:tfe,curveCardinal:iB,curveCatmullRomClosed:nfe,curveCatmullRomOpen:rfe,curveCatmullRom:sB,curveLinear:gh,curveLinearClosed:afe,curveMonotoneX:pB,curveMonotoneY:fB,curveNatural:gB,curveStep:bB,curveStepAfter:vB,curveStepBefore:yB},Vge=/\s*(?:(\w+)(?=:):|(\w+))\s*(?:(\w+)|((?:(?!}%{2}).|\r?\n)*))?\s*(?:}%{2})?/gi,Yge=N(function(e,t){const n=mz(e,/(?:init\b)|(?:initialize\b)/);let r={};if(Array.isArray(n)){const o=n.map(l=>l.args);mm(o),r=Yn(r,[...o])}else r=n.args;if(!r)return;let a=p_(e,t);const i="config";return r[i]!==void 0&&(a==="flowchart-v2"&&(a="flowchart"),r[a]=r[i],delete r[i]),r},"detectInit"),mz=N(function(e,t=null){var n,r;try{const a=new RegExp(`[%]{2}(?![{]${Vge.source})(?=[}][%]{2}).*
`,"ig");e=e.trim().replace(a,"").replace(/'/gm,'"'),we.debug(`Detecting diagram directive${t!==null?" type:"+t:""} based on the text:${e}`);let i;const o=[];for(;(i=fh.exec(e))!==null;)if(i.index===fh.lastIndex&&fh.lastIndex++,i&&!t||t&&((n=i[1])!=null&&n.match(t))||t&&((r=i[2])!=null&&r.match(t))){const l=i[1]?i[1]:i[2],u=i[3]?i[3].trim():i[4]?JSON.parse(i[4].trim()):null;o.push({type:l,args:u})}return o.length===0?{type:e,args:null}:o.length===1?o[0]:o}catch(a){return we.error(`ERROR: ${a.message} - Unable to parse directive type: '${t}' based on the text: '${e}'`),{type:void 0,args:null}}},"detectDirective"),Xge=N(function(e){return e.replace(fh,"")},"removeDirectives"),Kge=N(function(e,t){for(const[n,r]of t.entries())if(r.match(e))return n;return-1},"isSubstringInArray");function H_(e,t){if(!e)return t;const n=`curve${e.charAt(0).toUpperCase()+e.slice(1)}`;return Wge[n]??t}N(H_,"interpolateToCurve");function gz(e,t){const n=e.trim();if(n)return t.securityLevel!=="loose"?g0e.sanitizeUrl(n):n}N(gz,"formatUrl");var Zge=N((e,...t)=>{const n=e.split("."),r=n.length-1,a=n[r];let i=window;for(let o=0;o<r;o++)if(i=i[n[o]],!i){we.error(`Function name: ${e} not found in window`);return}i[a](...t)},"runFunc");function G_(e,t){return!e||!t?0:Math.sqrt(Math.pow(t.x-e.x,2)+Math.pow(t.y-e.y,2))}N(G_,"distance");function bz(e){let t,n=0;e.forEach(a=>{n+=G_(a,t),t=a});const r=n/2;return q_(e,r)}N(bz,"traverseEdge");function yz(e){return e.length===1?e[0]:bz(e)}N(yz,"calcLabelPosition");var n8=N((e,t=2)=>{const n=Math.pow(10,t);return Math.round(e*n)/n},"roundNumber"),q_=N((e,t)=>{let n,r=t;for(const a of e){if(n){const i=G_(a,n);if(i===0)return n;if(i<r)r-=i;else{const o=r/i;if(o<=0)return n;if(o>=1)return{x:a.x,y:a.y};if(o>0&&o<1)return{x:n8((1-o)*n.x+o*a.x,5),y:n8((1-o)*n.y+o*a.y,5)}}}n=a}throw new Error("Could not find a suitable point for the given distance")},"calculatePoint"),Qge=N((e,t,n)=>{we.info(`our points ${JSON.stringify(t)}`),t[0]!==n&&(t=t.reverse());const a=q_(t,25),i=e?10:5,o=Math.atan2(t[0].y-a.y,t[0].x-a.x),l={x:0,y:0};return l.x=Math.sin(o)*i+(t[0].x+a.x)/2,l.y=-Math.cos(o)*i+(t[0].y+a.y)/2,l},"calcCardinalityPosition");function vz(e,t,n){const r=structuredClone(n);we.info("our points",r),t!=="start_left"&&t!=="start_right"&&r.reverse();const a=25+e,i=q_(r,a),o=10+e*.5,l=Math.atan2(r[0].y-i.y,r[0].x-i.x),u={x:0,y:0};return t==="start_left"?(u.x=Math.sin(l+Math.PI)*o+(r[0].x+i.x)/2,u.y=-Math.cos(l+Math.PI)*o+(r[0].y+i.y)/2):t==="end_right"?(u.x=Math.sin(l-Math.PI)*o+(r[0].x+i.x)/2-5,u.y=-Math.cos(l-Math.PI)*o+(r[0].y+i.y)/2-5):t==="end_left"?(u.x=Math.sin(l)*o+(r[0].x+i.x)/2-5,u.y=-Math.cos(l)*o+(r[0].y+i.y)/2-5):(u.x=Math.sin(l)*o+(r[0].x+i.x)/2,u.y=-Math.cos(l)*o+(r[0].y+i.y)/2),u}N(vz,"calcTerminalLabelPosition");function xz(e){let t="",n="";for(const r of e)r!==void 0&&(r.startsWith("color:")||r.startsWith("text-align:")?n=n+r+";":t=t+r+";");return{style:t,labelStyle:n}}N(xz,"getStylesFromArray");var r8=0,Jge=N(()=>(r8++,"id-"+Math.random().toString(36).substr(2,12)+"-"+r8),"generateId");function Sz(e){let t="";const n="0123456789abcdef",r=n.length;for(let a=0;a<e;a++)t+=n.charAt(Math.floor(Math.random()*r));return t}N(Sz,"makeRandomHex");var ebe=N(e=>Sz(e.length),"random"),tbe=N(function(){return{x:0,y:0,fill:void 0,anchor:"start",style:"#666",width:100,height:100,textMargin:0,rx:0,ry:0,valign:void 0,text:""}},"getTextObj"),nbe=N(function(e,t){const n=t.text.replace(pp.lineBreakRegex," "),[,r]=tb(t.fontSize),a=e.append("text");a.attr("x",t.x),a.attr("y",t.y),a.style("text-anchor",t.anchor),a.style("font-family",t.fontFamily),a.style("font-size",r),a.style("font-weight",t.fontWeight),a.attr("fill",t.fill),t.class!==void 0&&a.attr("class",t.class);const i=a.append("tspan");return i.attr("x",t.x+t.textMargin*2),i.attr("fill",t.fill),i.text(n),a},"drawSimpleText"),rbe=bp((e,t,n)=>{if(!e||(n=Object.assign({fontSize:12,fontWeight:400,fontFamily:"Arial",joinWith:"<br/>"},n),pp.lineBreakRegex.test(e)))return e;const r=e.split(" ").filter(Boolean),a=[];let i="";return r.forEach((o,l)=>{const u=Co(`${o} `,n),d=Co(i,n);if(u>t){const{hyphenatedStrings:m,remainingWord:b}=abe(o,t,"-",n);a.push(i,...m),i=b}else d+u>=t?(a.push(i),i=o):i=[i,o].filter(Boolean).join(" ");l+1===r.length&&a.push(i)}),a.filter(o=>o!=="").join(n.joinWith)},(e,t,n)=>`${e}${t}${n.fontSize}${n.fontWeight}${n.fontFamily}${n.joinWith}`),abe=bp((e,t,n="-",r)=>{r=Object.assign({fontSize:12,fontWeight:400,fontFamily:"Arial",margin:0},r);const a=[...e],i=[];let o="";return a.forEach((l,u)=>{const d=`${o}${l}`;if(Co(d,r)>=t){const f=u+1,m=a.length===f,b=`${d}${n}`;i.push(m?d:b),o=""}else o=d}),{hyphenatedStrings:i,remainingWord:o}},(e,t,n="-",r)=>`${e}${t}${n}${r.fontSize}${r.fontWeight}${r.fontFamily}`);function wz(e,t){return W_(e,t).height}N(wz,"calculateTextHeight");function Co(e,t){return W_(e,t).width}N(Co,"calculateTextWidth");var W_=bp((e,t)=>{const{fontSize:n=12,fontFamily:r="Arial",fontWeight:a=400}=t;if(!e)return{width:0,height:0};const[,i]=tb(n),o=["sans-serif",r],l=e.split(pp.lineBreakRegex),u=[],d=Et("body");if(!d.remove)return{width:0,height:0,lineHeight:0};const h=d.append("svg");for(const m of o){let b=0;const y={width:0,height:0,lineHeight:0};for(const v of l){const w=tbe();w.text=v||qge;const S=nbe(h,w).style("font-size",i).style("font-weight",a).style("font-family",m),k=(S._groups||S)[0][0].getBBox();if(k.width===0&&k.height===0)throw new Error("svg element not in render tree");y.width=Math.round(Math.max(y.width,k.width)),b=Math.round(k.height),y.height+=b,y.lineHeight=Math.round(Math.max(y.lineHeight,b))}u.push(y)}h.remove();const f=isNaN(u[1].height)||isNaN(u[1].width)||isNaN(u[1].lineHeight)||u[0].height>u[1].height&&u[0].width>u[1].width&&u[0].lineHeight>u[1].lineHeight?0:1;return u[f]},(e,t)=>`${e}${t.fontSize}${t.fontWeight}${t.fontFamily}`),Kc,ibe=(Kc=class{constructor(t=!1,n){this.count=0,this.count=n?n.length:0,this.next=t?()=>this.count++:()=>Date.now()}},N(Kc,"InitIDGenerator"),Kc),y0,obe=N(function(e){return y0=y0||document.createElement("div"),e=escape(e).replace(/%26/g,"&").replace(/%23/g,"#").replace(/%3B/g,";"),y0.innerHTML=e,unescape(y0.textContent)},"entityDecode");function V_(e){return"str"in e}N(V_,"isDetailedError");var sbe=N((e,t,n,r)=>{var i;if(!r)return;const a=(i=e.node())==null?void 0:i.getBBox();a&&e.append("text").text(r).attr("text-anchor","middle").attr("x",a.x+a.width/2).attr("y",-n).attr("class",t)},"insertTitle"),tb=N(e=>{if(typeof e=="number")return[e,e+"px"];const t=parseInt(e??"",10);return Number.isNaN(t)?[void 0,void 0]:e===String(t)?[t,e+"px"]:[t,e]},"parseFontSize");function Y_(e,t){return Gge({},e,t)}N(Y_,"cleanAndMerge");var ti={assignWithDepth:Yn,wrapLabel:rbe,calculateTextHeight:wz,calculateTextWidth:Co,calculateTextDimensions:W_,cleanAndMerge:Y_,detectInit:Yge,detectDirective:mz,isSubstringInArray:Kge,interpolateToCurve:H_,calcLabelPosition:yz,calcCardinalityPosition:Qge,calcTerminalLabelPosition:vz,formatUrl:gz,getStylesFromArray:xz,generateId:Jge,random:ebe,runFunc:Zge,entityDecode:obe,insertTitle:sbe,isLabelCoordinateInPath:Ez,parseFontSize:tb,InitIDGenerator:ibe},lbe=N(function(e){let t=e;return t=t.replace(/style.*:\S*#.*;/g,function(n){return n.substring(0,n.length-1)}),t=t.replace(/classDef.*:\S*#.*;/g,function(n){return n.substring(0,n.length-1)}),t=t.replace(/#\w+;/g,function(n){const r=n.substring(1,n.length-1);return/^\+?\d+$/.test(r)?"ﬂ°°"+r+"¶ß":"ﬂ°"+r+"¶ß"}),t},"encodeEntities"),Ou=N(function(e){return e.replace(/ﬂ°°/g,"&#").replace(/ﬂ°/g,"&").replace(/¶ß/g,";")},"decodeEntities"),kEe=N((e,t,{counter:n=0,prefix:r,suffix:a},i)=>i||`${r?`${r}_`:""}${e}_${t}_${n}${a?`_${a}`:""}`,"getEdgeId");function vr(e){return e??null}N(vr,"handleUndefinedAttr");function Ez(e,t){const n=Math.round(e.x),r=Math.round(e.y),a=t.replace(/(\d+\.\d+)/g,i=>Math.round(parseFloat(i)).toString());return a.includes(n.toString())||a.includes(r.toString())}N(Ez,"isLabelCoordinateInPath");var X_=N(({flowchart:e})=>{var a,i;const t=((a=e==null?void 0:e.subGraphTitleMargin)==null?void 0:a.top)??0,n=((i=e==null?void 0:e.subGraphTitleMargin)==null?void 0:i.bottom)??0,r=t+n;return{subGraphTitleTopMargin:t,subGraphTitleBottomMargin:n,subGraphTitleTotalMargin:r}},"getSubGraphTitleMargins");async function kz(e,t){const n=e.getElementsByTagName("img");if(!n||n.length===0)return;const r=t.replace(/<img[^>]*>/g,"").trim()==="";await Promise.all([...n].map(a=>new Promise(i=>{function o(){if(a.style.display="flex",a.style.flexDirection="column",r){const l=qt().fontSize?qt().fontSize:window.getComputedStyle(document.body).fontSize,u=5,[d=p9.fontSize]=tb(l),h=d*u+"px";a.style.minWidth=h,a.style.maxWidth=h}else a.style.width="100%";i(a)}N(o,"setupImage"),setTimeout(()=>{a.complete&&o()}),a.addEventListener("error",o),a.addEventListener("load",o)})))}N(kz,"configureLabelImages");var cbe=N(e=>{const{handDrawnSeed:t}=qt();return{fill:e,hachureAngle:120,hachureGap:4,fillWeight:2,roughness:.7,stroke:e,seed:t}},"solidStateFill"),Iu=N(e=>{const t=ube([...e.cssCompiledStyles||[],...e.cssStyles||[],...e.labelStyle||[]]);return{stylesMap:t,stylesArray:[...t]}},"compileStyles"),ube=N(e=>{const t=new Map;return e.forEach(n=>{const[r,a]=n.split(":");t.set(r.trim(),a==null?void 0:a.trim())}),t},"styles2Map"),Tz=N(e=>e==="color"||e==="font-size"||e==="font-family"||e==="font-weight"||e==="font-style"||e==="text-decoration"||e==="text-align"||e==="text-transform"||e==="line-height"||e==="letter-spacing"||e==="word-spacing"||e==="text-shadow"||e==="text-overflow"||e==="white-space"||e==="word-wrap"||e==="word-break"||e==="overflow-wrap"||e==="hyphens","isLabelStyle"),Ye=N(e=>{const{stylesArray:t}=Iu(e),n=[],r=[],a=[],i=[];return t.forEach(o=>{const l=o[0];Tz(l)?n.push(o.join(":")+" !important"):(r.push(o.join(":")+" !important"),l.includes("stroke")&&a.push(o.join(":")+" !important"),l==="fill"&&i.push(o.join(":")+" !important"))}),{labelStyles:n.join(";"),nodeStyles:r.join(";"),stylesArray:t,borderStyles:a,backgroundStyles:i}},"styles2String"),Ve=N((e,t)=>{var u;const{themeVariables:n,handDrawnSeed:r}=qt(),{nodeBorder:a,mainBkg:i}=n,{stylesMap:o}=Iu(e);return Object.assign({roughness:.7,fill:o.get("fill")||i,fillStyle:"hachure",fillWeight:4,hachureGap:5.2,stroke:o.get("stroke")||a,seed:r,strokeWidth:((u=o.get("stroke-width"))==null?void 0:u.replace("px",""))||1.3,fillLineDash:[0,0],strokeLineDash:dbe(o.get("stroke-dasharray"))},t)},"userNodeOverrides"),dbe=N(e=>{if(!e)return[0,0];const t=e.trim().split(/\s+/).map(Number);if(t.length===1){const a=isNaN(t[0])?0:t[0];return[a,a]}const n=isNaN(t[0])?0:t[0],r=isNaN(t[1])?0:t[1];return[n,r]},"getStrokeDashArray");const hbe=Object.freeze({left:0,top:0,width:16,height:16}),$m=Object.freeze({rotate:0,vFlip:!1,hFlip:!1}),_z=Object.freeze({...hbe,...$m}),pbe=Object.freeze({..._z,body:"",hidden:!1}),fbe=Object.freeze({width:null,height:null}),mbe=Object.freeze({...fbe,...$m}),gbe=(e,t,n,r="")=>{const a=e.split(":");if(e.slice(0,1)==="@"){if(a.length<2||a.length>3)return null;r=a.shift().slice(1)}if(a.length>3||!a.length)return null;if(a.length>1){const l=a.pop(),u=a.pop(),d={provider:a.length>0?a[0]:r,prefix:u,name:l};return Gv(d)?d:null}const i=a[0],o=i.split("-");if(o.length>1){const l={provider:r,prefix:o.shift(),name:o.join("-")};return Gv(l)?l:null}if(n&&r===""){const l={provider:r,prefix:"",name:i};return Gv(l,n)?l:null}return null},Gv=(e,t)=>e?!!((t&&e.prefix===""||e.prefix)&&e.name):!1;function bbe(e,t){const n={};!e.hFlip!=!t.hFlip&&(n.hFlip=!0),!e.vFlip!=!t.vFlip&&(n.vFlip=!0);const r=((e.rotate||0)+(t.rotate||0))%4;return r&&(n.rotate=r),n}function a8(e,t){const n=bbe(e,t);for(const r in pbe)r in $m?r in e&&!(r in n)&&(n[r]=$m[r]):r in t?n[r]=t[r]:r in e&&(n[r]=e[r]);return n}function ybe(e,t){const n=e.icons,r=e.aliases||Object.create(null),a=Object.create(null);function i(o){if(n[o])return a[o]=[];if(!(o in a)){a[o]=null;const l=r[o]&&r[o].parent,u=l&&i(l);u&&(a[o]=[l].concat(u))}return a[o]}return(t||Object.keys(n).concat(Object.keys(r))).forEach(i),a}function i8(e,t,n){const r=e.icons,a=e.aliases||Object.create(null);let i={};function o(l){i=a8(r[l]||a[l],i)}return o(t),n.forEach(o),a8(e,i)}function vbe(e,t){if(e.icons[t])return i8(e,t,[]);const n=ybe(e,[t])[t];return n?i8(e,t,n):null}const xbe=/(-?[0-9.]*[0-9]+[0-9.]*)/g,Sbe=/^-?[0-9.]*[0-9]+[0-9.]*$/g;function o8(e,t,n){if(t===1)return e;if(n=n||100,typeof e=="number")return Math.ceil(e*t*n)/n;if(typeof e!="string")return e;const r=e.split(xbe);if(r===null||!r.length)return e;const a=[];let i=r.shift(),o=Sbe.test(i);for(;;){if(o){const l=parseFloat(i);isNaN(l)?a.push(i):a.push(Math.ceil(l*t*n)/n)}else a.push(i);if(i=r.shift(),i===void 0)return a.join("");o=!o}}function wbe(e,t="defs"){let n="";const r=e.indexOf("<"+t);for(;r>=0;){const a=e.indexOf(">",r),i=e.indexOf("</"+t);if(a===-1||i===-1)break;const o=e.indexOf(">",i);if(o===-1)break;n+=e.slice(a+1,i).trim(),e=e.slice(0,r).trim()+e.slice(o+1)}return{defs:n,content:e}}function Ebe(e,t){return e?"<defs>"+e+"</defs>"+t:t}function kbe(e,t,n){const r=wbe(e);return Ebe(r.defs,t+r.content+n)}const Tbe=e=>e==="unset"||e==="undefined"||e==="none";function _be(e,t){const n={..._z,...e},r={...mbe,...t},a={left:n.left,top:n.top,width:n.width,height:n.height};let i=n.body;[n,r].forEach(v=>{const w=[],S=v.hFlip,k=v.vFlip;let R=v.rotate;S?k?R+=2:(w.push("translate("+(a.width+a.left).toString()+" "+(0-a.top).toString()+")"),w.push("scale(-1 1)"),a.top=a.left=0):k&&(w.push("translate("+(0-a.left).toString()+" "+(a.height+a.top).toString()+")"),w.push("scale(1 -1)"),a.top=a.left=0);let I;switch(R<0&&(R-=Math.floor(R/4)*4),R=R%4,R){case 1:I=a.height/2+a.top,w.unshift("rotate(90 "+I.toString()+" "+I.toString()+")");break;case 2:w.unshift("rotate(180 "+(a.width/2+a.left).toString()+" "+(a.height/2+a.top).toString()+")");break;case 3:I=a.width/2+a.left,w.unshift("rotate(-90 "+I.toString()+" "+I.toString()+")");break}R%2===1&&(a.left!==a.top&&(I=a.left,a.left=a.top,a.top=I),a.width!==a.height&&(I=a.width,a.width=a.height,a.height=I)),w.length&&(i=kbe(i,'<g transform="'+w.join(" ")+'">',"</g>"))});const o=r.width,l=r.height,u=a.width,d=a.height;let h,f;o===null?(f=l===null?"1em":l==="auto"?d:l,h=o8(f,u/d)):(h=o==="auto"?u:o,f=l===null?o8(h,d/u):l==="auto"?d:l);const m={},b=(v,w)=>{Tbe(w)||(m[v]=w.toString())};b("width",h),b("height",f);const y=[a.left,a.top,u,d];return m.viewBox=y.join(" "),{attributes:m,viewBox:y,body:i}}const Cbe=/\sid="(\S+)"/g,s8=new Map;function Abe(e){e=e.replace(/[0-9]+$/,"")||"a";const t=s8.get(e)||0;return s8.set(e,t+1),t?`${e}${t}`:e}function Rbe(e){const t=[];let n;for(;n=Cbe.exec(e);)t.push(n[1]);if(!t.length)return e;const r="suffix"+(Math.random()*16777216|Date.now()).toString(16);return t.forEach(a=>{const i=Abe(a),o=a.replace(/[.*+?^${}()|[\]\\]/g,"\\$&");e=e.replace(new RegExp('([#;"])('+o+')([")]|\\.[a-z])',"g"),"$1"+i+r+"$3")}),e=e.replace(new RegExp(r,"g"),""),e}function Nbe(e,t){let n=e.indexOf("xlink:")===-1?"":' xmlns:xlink="http://www.w3.org/1999/xlink"';for(const r in t)n+=" "+r+'="'+t[r]+'"';return'<svg xmlns="http://www.w3.org/2000/svg"'+n+">"+e+"</svg>"}function K_(){return{async:!1,breaks:!1,extensions:null,gfm:!0,hooks:null,pedantic:!1,renderer:null,silent:!1,tokenizer:null,walkTokens:null}}var Fl=K_();function Cz(e){Fl=e}var yh={exec:()=>null};function jt(e,t=""){let n=typeof e=="string"?e:e.source,r={replace:(a,i)=>{let o=typeof i=="string"?i:i.source;return o=o.replace(Br.caret,"$1"),n=n.replace(a,o),r},getRegex:()=>new RegExp(n,t)};return r}var Obe=(()=>{try{return!!new RegExp("(?<=1)(?<!1)")}catch{return!1}})(),Br={codeRemoveIndent:/^(?: {1,4}| {0,3}\t)/gm,outputLinkReplace:/\\([\[\]])/g,indentCodeCompensation:/^(\s+)(?:```)/,beginningSpace:/^\s+/,endingHash:/#$/,startingSpaceChar:/^ /,endingSpaceChar:/ $/,nonSpaceChar:/[^ ]/,newLineCharGlobal:/\n/g,tabCharGlobal:/\t/g,multipleSpaceGlobal:/\s+/g,blankLine:/^[ \t]*$/,doubleBlankLine:/\n[ \t]*\n[ \t]*$/,blockquoteStart:/^ {0,3}>/,blockquoteSetextReplace:/\n {0,3}((?:=+|-+) *)(?=\n|$)/g,blockquoteSetextReplace2:/^ {0,3}>[ \t]?/gm,listReplaceTabs:/^\t+/,listReplaceNesting:/^ {1,4}(?=( {4})*[^ ])/g,listIsTask:/^\[[ xX]\] /,listReplaceTask:/^\[[ xX]\] +/,anyLine:/\n.*\n/,hrefBrackets:/^<(.*)>$/,tableDelimiter:/[:|]/,tableAlignChars:/^\||\| *$/g,tableRowBlankLine:/\n[ \t]*$/,tableAlignRight:/^ *-+: *$/,tableAlignCenter:/^ *:-+: *$/,tableAlignLeft:/^ *:-+ *$/,startATag:/^<a /i,endATag:/^<\/a>/i,startPreScriptTag:/^<(pre|code|kbd|script)(\s|>)/i,endPreScriptTag:/^<\/(pre|code|kbd|script)(\s|>)/i,startAngleBracket:/^</,endAngleBracket:/>$/,pedanticHrefTitle:/^([^'"]*[^\s])\s+(['"])(.*)\2/,unicodeAlphaNumeric:/[\p{L}\p{N}]/u,escapeTest:/[&<>"']/,escapeReplace:/[&<>"']/g,escapeTestNoEncode:/[<>"']|&(?!(#\d{1,7}|#[Xx][a-fA-F0-9]{1,6}|\w+);)/,escapeReplaceNoEncode:/[<>"']|&(?!(#\d{1,7}|#[Xx][a-fA-F0-9]{1,6}|\w+);)/g,unescapeTest:/&(#(?:\d+)|(?:#x[0-9A-Fa-f]+)|(?:\w+));?/ig,caret:/(^|[^\[])\^/g,percentDecode:/%25/g,findPipe:/\|/g,splitPipe:/ \|/,slashPipe:/\\\|/g,carriageReturn:/\r\n|\r/g,spaceLine:/^ +$/gm,notSpaceStart:/^\S*/,endingNewline:/\n$/,listItemRegex:e=>new RegExp(`^( {0,3}${e})((?:[	 ][^\\n]*)?(?:\\n|$))`),nextBulletRegex:e=>new RegExp(`^ {0,${Math.min(3,e-1)}}(?:[*+-]|\\d{1,9}[.)])((?:[ 	][^\\n]*)?(?:\\n|$))`),hrRegex:e=>new RegExp(`^ {0,${Math.min(3,e-1)}}((?:- *){3,}|(?:_ *){3,}|(?:\\* *){3,})(?:\\n+|$)`),fencesBeginRegex:e=>new RegExp(`^ {0,${Math.min(3,e-1)}}(?:\`\`\`|~~~)`),headingBeginRegex:e=>new RegExp(`^ {0,${Math.min(3,e-1)}}#`),htmlBeginRegex:e=>new RegExp(`^ {0,${Math.min(3,e-1)}}<(?:[a-z].*>|!--)`,"i")},Ibe=/^(?:[ \t]*(?:\n|$))+/,Lbe=/^((?: {4}| {0,3}\t)[^\n]+(?:\n(?:[ \t]*(?:\n|$))*)?)+/,Dbe=/^ {0,3}(`{3,}(?=[^`\n]*(?:\n|$))|~{3,})([^\n]*)(?:\n|$)(?:|([\s\S]*?)(?:\n|$))(?: {0,3}\1[~`]* *(?=\n|$)|$)/,vp=/^ {0,3}((?:-[\t ]*){3,}|(?:_[ \t]*){3,}|(?:\*[ \t]*){3,})(?:\n+|$)/,Mbe=/^ {0,3}(#{1,6})(?=\s|$)(.*)(?:\n+|$)/,Z_=/(?:[*+-]|\d{1,9}[.)])/,Az=/^(?!bull |blockCode|fences|blockquote|heading|html|table)((?:.|\n(?!\s*?\n|bull |blockCode|fences|blockquote|heading|html|table))+?)\n {0,3}(=+|-+) *(?:\n+|$)/,Rz=jt(Az).replace(/bull/g,Z_).replace(/blockCode/g,/(?: {4}| {0,3}\t)/).replace(/fences/g,/ {0,3}(?:`{3,}|~{3,})/).replace(/blockquote/g,/ {0,3}>/).replace(/heading/g,/ {0,3}#{1,6}/).replace(/html/g,/ {0,3}<[^\n>]+>\n/).replace(/\|table/g,"").getRegex(),Bbe=jt(Az).replace(/bull/g,Z_).replace(/blockCode/g,/(?: {4}| {0,3}\t)/).replace(/fences/g,/ {0,3}(?:`{3,}|~{3,})/).replace(/blockquote/g,/ {0,3}>/).replace(/heading/g,/ {0,3}#{1,6}/).replace(/html/g,/ {0,3}<[^\n>]+>\n/).replace(/table/g,/ {0,3}\|?(?:[:\- ]*\|)+[\:\- ]*\n/).getRegex(),Q_=/^([^\n]+(?:\n(?!hr|heading|lheading|blockquote|fences|list|html|table| +\n)[^\n]+)*)/,Fbe=/^[^\n]+/,J_=/(?!\s*\])(?:\\[\s\S]|[^\[\]\\])+/,zbe=jt(/^ {0,3}\[(label)\]: *(?:\n[ \t]*)?([^<\s][^\s]*|<.*?>)(?:(?: +(?:\n[ \t]*)?| *\n[ \t]*)(title))? *(?:\n+|$)/).replace("label",J_).replace("title",/(?:"(?:\\"?|[^"\\])*"|'[^'\n]*(?:\n[^'\n]+)*\n?'|\([^()]*\))/).getRegex(),$be=jt(/^( {0,3}bull)([ \t][^\n]+?)?(?:\n|$)/).replace(/bull/g,Z_).getRegex(),nb="address|article|aside|base|basefont|blockquote|body|caption|center|col|colgroup|dd|details|dialog|dir|div|dl|dt|fieldset|figcaption|figure|footer|form|frame|frameset|h[1-6]|head|header|hr|html|iframe|legend|li|link|main|menu|menuitem|meta|nav|noframes|ol|optgroup|option|p|param|search|section|summary|table|tbody|td|tfoot|th|thead|title|tr|track|ul",eC=/<!--(?:-?>|[\s\S]*?(?:-->|$))/,Pbe=jt("^ {0,3}(?:<(script|pre|style|textarea)[\\s>][\\s\\S]*?(?:</\\1>[^\\n]*\\n+|$)|comment[^\\n]*(\\n+|$)|<\\?[\\s\\S]*?(?:\\?>\\n*|$)|<![A-Z][\\s\\S]*?(?:>\\n*|$)|<!\\[CDATA\\[[\\s\\S]*?(?:\\]\\]>\\n*|$)|</?(tag)(?: +|\\n|/?>)[\\s\\S]*?(?:(?:\\n[ 	]*)+\\n|$)|<(?!script|pre|style|textarea)([a-z][\\w-]*)(?:attribute)*? */?>(?=[ \\t]*(?:\\n|$))[\\s\\S]*?(?:(?:\\n[ 	]*)+\\n|$)|</(?!script|pre|style|textarea)[a-z][\\w-]*\\s*>(?=[ \\t]*(?:\\n|$))[\\s\\S]*?(?:(?:\\n[ 	]*)+\\n|$))","i").replace("comment",eC).replace("tag",nb).replace("attribute",/ +[a-zA-Z:_][\w.:-]*(?: *= *"[^"\n]*"| *= *'[^'\n]*'| *= *[^\s"'=<>`]+)?/).getRegex(),Nz=jt(Q_).replace("hr",vp).replace("heading"," {0,3}#{1,6}(?:\\s|$)").replace("|lheading","").replace("|table","").replace("blockquote"," {0,3}>").replace("fences"," {0,3}(?:`{3,}(?=[^`\\n]*\\n)|~{3,})[^\\n]*\\n").replace("list"," {0,3}(?:[*+-]|1[.)]) ").replace("html","</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|textarea|!--)").replace("tag",nb).getRegex(),Ube=jt(/^( {0,3}> ?(paragraph|[^\n]*)(?:\n|$))+/).replace("paragraph",Nz).getRegex(),tC={blockquote:Ube,code:Lbe,def:zbe,fences:Dbe,heading:Mbe,hr:vp,html:Pbe,lheading:Rz,list:$be,newline:Ibe,paragraph:Nz,table:yh,text:Fbe},l8=jt("^ *([^\\n ].*)\\n {0,3}((?:\\| *)?:?-+:? *(?:\\| *:?-+:? *)*(?:\\| *)?)(?:\\n((?:(?! *\\n|hr|heading|blockquote|code|fences|list|html).*(?:\\n|$))*)\\n*|$)").replace("hr",vp).replace("heading"," {0,3}#{1,6}(?:\\s|$)").replace("blockquote"," {0,3}>").replace("code","(?: {4}| {0,3}	)[^\\n]").replace("fences"," {0,3}(?:`{3,}(?=[^`\\n]*\\n)|~{3,})[^\\n]*\\n").replace("list"," {0,3}(?:[*+-]|1[.)]) ").replace("html","</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|textarea|!--)").replace("tag",nb).getRegex(),jbe={...tC,lheading:Bbe,table:l8,paragraph:jt(Q_).replace("hr",vp).replace("heading"," {0,3}#{1,6}(?:\\s|$)").replace("|lheading","").replace("table",l8).replace("blockquote"," {0,3}>").replace("fences"," {0,3}(?:`{3,}(?=[^`\\n]*\\n)|~{3,})[^\\n]*\\n").replace("list"," {0,3}(?:[*+-]|1[.)]) ").replace("html","</?(?:tag)(?: +|\\n|/?>)|<(?:script|pre|style|textarea|!--)").replace("tag",nb).getRegex()},Hbe={...tC,html:jt(`^ *(?:comment *(?:\\n|\\s*$)|<(tag)[\\s\\S]+?</\\1> *(?:\\n{2,}|\\s*$)|<tag(?:"[^"]*"|'[^']*'|\\s[^'"/>\\s]*)*?/?> *(?:\\n{2,}|\\s*$))`).replace("comment",eC).replace(/tag/g,"(?!(?:a|em|strong|small|s|cite|q|dfn|abbr|data|time|code|var|samp|kbd|sub|sup|i|b|u|mark|ruby|rt|rp|bdi|bdo|span|br|wbr|ins|del|img)\\b)\\w+(?!:|[^\\w\\s@]*@)\\b").getRegex(),def:/^ *\[([^\]]+)\]: *<?([^\s>]+)>?(?: +(["(][^\n]+[")]))? *(?:\n+|$)/,heading:/^(#{1,6})(.*)(?:\n+|$)/,fences:yh,lheading:/^(.+?)\n {0,3}(=+|-+) *(?:\n+|$)/,paragraph:jt(Q_).replace("hr",vp).replace("heading",` *#{1,6} *[^
]`).replace("lheading",Rz).replace("|table","").replace("blockquote"," {0,3}>").replace("|fences","").replace("|list","").replace("|html","").replace("|tag","").getRegex()},Gbe=/^\\([!"#$%&'()*+,\-./:;<=>?@\[\]\\^_`{|}~])/,qbe=/^(`+)([^`]|[^`][\s\S]*?[^`])\1(?!`)/,Oz=/^( {2,}|\\)\n(?!\s*$)/,Wbe=/^(`+|[^`])(?:(?= {2,}\n)|[\s\S]*?(?:(?=[\\<!\[`*_]|\b_|$)|[^ ](?= {2,}\n)))/,rb=/[\p{P}\p{S}]/u,nC=/[\s\p{P}\p{S}]/u,Iz=/[^\s\p{P}\p{S}]/u,Vbe=jt(/^((?![*_])punctSpace)/,"u").replace(/punctSpace/g,nC).getRegex(),Lz=/(?!~)[\p{P}\p{S}]/u,Ybe=/(?!~)[\s\p{P}\p{S}]/u,Xbe=/(?:[^\s\p{P}\p{S}]|~)/u,Kbe=jt(/link|precode-code|html/,"g").replace("link",/\[(?:[^\[\]`]|(?<a>`+)[^`]+\k<a>(?!`))*?\]\((?:\\[\s\S]|[^\\\(\)]|\((?:\\[\s\S]|[^\\\(\)])*\))*\)/).replace("precode-",Obe?"(?<!`)()":"(^^|[^`])").replace("code",/(?<b>`+)[^`]+\k<b>(?!`)/).replace("html",/<(?! )[^<>]*?>/).getRegex(),Dz=/^(?:\*+(?:((?!\*)punct)|[^\s*]))|^_+(?:((?!_)punct)|([^\s_]))/,Zbe=jt(Dz,"u").replace(/punct/g,rb).getRegex(),Qbe=jt(Dz,"u").replace(/punct/g,Lz).getRegex(),Mz="^[^_*]*?__[^_*]*?\\*[^_*]*?(?=__)|[^*]+(?=[^*])|(?!\\*)punct(\\*+)(?=[\\s]|$)|notPunctSpace(\\*+)(?!\\*)(?=punctSpace|$)|(?!\\*)punctSpace(\\*+)(?=notPunctSpace)|[\\s](\\*+)(?!\\*)(?=punct)|(?!\\*)punct(\\*+)(?!\\*)(?=punct)|notPunctSpace(\\*+)(?=notPunctSpace)",Jbe=jt(Mz,"gu").replace(/notPunctSpace/g,Iz).replace(/punctSpace/g,nC).replace(/punct/g,rb).getRegex(),eye=jt(Mz,"gu").replace(/notPunctSpace/g,Xbe).replace(/punctSpace/g,Ybe).replace(/punct/g,Lz).getRegex(),tye=jt("^[^_*]*?\\*\\*[^_*]*?_[^_*]*?(?=\\*\\*)|[^_]+(?=[^_])|(?!_)punct(_+)(?=[\\s]|$)|notPunctSpace(_+)(?!_)(?=punctSpace|$)|(?!_)punctSpace(_+)(?=notPunctSpace)|[\\s](_+)(?!_)(?=punct)|(?!_)punct(_+)(?!_)(?=punct)","gu").replace(/notPunctSpace/g,Iz).replace(/punctSpace/g,nC).replace(/punct/g,rb).getRegex(),nye=jt(/\\(punct)/,"gu").replace(/punct/g,rb).getRegex(),rye=jt(/^<(scheme:[^\s\x00-\x1f<>]*|email)>/).replace("scheme",/[a-zA-Z][a-zA-Z0-9+.-]{1,31}/).replace("email",/[a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+(@)[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)+(?![-_])/).getRegex(),aye=jt(eC).replace("(?:-->|$)","-->").getRegex(),iye=jt("^comment|^</[a-zA-Z][\\w:-]*\\s*>|^<[a-zA-Z][\\w-]*(?:attribute)*?\\s*/?>|^<\\?[\\s\\S]*?\\?>|^<![a-zA-Z]+\\s[\\s\\S]*?>|^<!\\[CDATA\\[[\\s\\S]*?\\]\\]>").replace("comment",aye).replace("attribute",/\s+[a-zA-Z:_][\w.:-]*(?:\s*=\s*"[^"]*"|\s*=\s*'[^']*'|\s*=\s*[^\s"'=<>`]+)?/).getRegex(),Pm=/(?:\[(?:\\[\s\S]|[^\[\]\\])*\]|\\[\s\S]|`+[^`]*?`+(?!`)|[^\[\]\\`])*?/,oye=jt(/^!?\[(label)\]\(\s*(href)(?:(?:[ \t]*(?:\n[ \t]*)?)(title))?\s*\)/).replace("label",Pm).replace("href",/<(?:\\.|[^\n<>\\])+>|[^ \t\n\x00-\x1f]*/).replace("title",/"(?:\\"?|[^"\\])*"|'(?:\\'?|[^'\\])*'|\((?:\\\)?|[^)\\])*\)/).getRegex(),Bz=jt(/^!?\[(label)\]\[(ref)\]/).replace("label",Pm).replace("ref",J_).getRegex(),Fz=jt(/^!?\[(ref)\](?:\[\])?/).replace("ref",J_).getRegex(),sye=jt("reflink|nolink(?!\\()","g").replace("reflink",Bz).replace("nolink",Fz).getRegex(),c8=/[hH][tT][tT][pP][sS]?|[fF][tT][pP]/,rC={_backpedal:yh,anyPunctuation:nye,autolink:rye,blockSkip:Kbe,br:Oz,code:qbe,del:yh,emStrongLDelim:Zbe,emStrongRDelimAst:Jbe,emStrongRDelimUnd:tye,escape:Gbe,link:oye,nolink:Fz,punctuation:Vbe,reflink:Bz,reflinkSearch:sye,tag:iye,text:Wbe,url:yh},lye={...rC,link:jt(/^!?\[(label)\]\((.*?)\)/).replace("label",Pm).getRegex(),reflink:jt(/^!?\[(label)\]\s*\[([^\]]*)\]/).replace("label",Pm).getRegex()},E2={...rC,emStrongRDelimAst:eye,emStrongLDelim:Qbe,url:jt(/^((?:protocol):\/\/|www\.)(?:[a-zA-Z0-9\-]+\.?)+[^\s<]*|^email/).replace("protocol",c8).replace("email",/[A-Za-z0-9._+-]+(@)[a-zA-Z0-9-_]+(?:\.[a-zA-Z0-9-_]*[a-zA-Z0-9])+(?![-_])/).getRegex(),_backpedal:/(?:[^?!.,:;*_'"~()&]+|\([^)]*\)|&(?![a-zA-Z0-9]+;$)|[?!.,:;*_'"~)]+(?!$))+/,del:/^(~~?)(?=[^\s~])((?:\\[\s\S]|[^\\])*?(?:\\[\s\S]|[^\s~\\]))\1(?=[^~]|$)/,text:jt(/^([`~]+|[^`~])(?:(?= {2,}\n)|(?=[a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-]+@)|[\s\S]*?(?:(?=[\\<!\[`*~_]|\b_|protocol:\/\/|www\.|$)|[^ ](?= {2,}\n)|[^a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-](?=[a-zA-Z0-9.!#$%&'*+\/=?_`{\|}~-]+@)))/).replace("protocol",c8).getRegex()},cye={...E2,br:jt(Oz).replace("{2,}","*").getRegex(),text:jt(E2.text).replace("\\b_","\\b_| {2,}\\n").replace(/\{2,\}/g,"*").getRegex()},v0={normal:tC,gfm:jbe,pedantic:Hbe},Wd={normal:rC,gfm:E2,breaks:cye,pedantic:lye},uye={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#39;"},u8=e=>uye[e];function yi(e,t){if(t){if(Br.escapeTest.test(e))return e.replace(Br.escapeReplace,u8)}else if(Br.escapeTestNoEncode.test(e))return e.replace(Br.escapeReplaceNoEncode,u8);return e}function d8(e){try{e=encodeURI(e).replace(Br.percentDecode,"%")}catch{return null}return e}function h8(e,t){var i;let n=e.replace(Br.findPipe,(o,l,u)=>{let d=!1,h=l;for(;--h>=0&&u[h]==="\\";)d=!d;return d?"|":" |"}),r=n.split(Br.splitPipe),a=0;if(r[0].trim()||r.shift(),r.length>0&&!((i=r.at(-1))!=null&&i.trim())&&r.pop(),t)if(r.length>t)r.splice(t);else for(;r.length<t;)r.push("");for(;a<r.length;a++)r[a]=r[a].trim().replace(Br.slashPipe,"|");return r}function Vd(e,t,n){let r=e.length;if(r===0)return"";let a=0;for(;a<r&&e.charAt(r-a-1)===t;)a++;return e.slice(0,r-a)}function dye(e,t){if(e.indexOf(t[1])===-1)return-1;let n=0;for(let r=0;r<e.length;r++)if(e[r]==="\\")r++;else if(e[r]===t[0])n++;else if(e[r]===t[1]&&(n--,n<0))return r;return n>0?-2:-1}function p8(e,t,n,r,a){let i=t.href,o=t.title||null,l=e[1].replace(a.other.outputLinkReplace,"$1");r.state.inLink=!0;let u={type:e[0].charAt(0)==="!"?"image":"link",raw:n,href:i,title:o,text:l,tokens:r.inlineTokens(l)};return r.state.inLink=!1,u}function hye(e,t,n){let r=e.match(n.other.indentCodeCompensation);if(r===null)return t;let a=r[1];return t.split(`
`).map(i=>{let o=i.match(n.other.beginningSpace);if(o===null)return i;let[l]=o;return l.length>=a.length?i.slice(a.length):i}).join(`
`)}var Um=class{constructor(t){tn(this,"options");tn(this,"rules");tn(this,"lexer");this.options=t||Fl}space(t){let n=this.rules.block.newline.exec(t);if(n&&n[0].length>0)return{type:"space",raw:n[0]}}code(t){let n=this.rules.block.code.exec(t);if(n){let r=n[0].replace(this.rules.other.codeRemoveIndent,"");return{type:"code",raw:n[0],codeBlockStyle:"indented",text:this.options.pedantic?r:Vd(r,`
`)}}}fences(t){let n=this.rules.block.fences.exec(t);if(n){let r=n[0],a=hye(r,n[3]||"",this.rules);return{type:"code",raw:r,lang:n[2]?n[2].trim().replace(this.rules.inline.anyPunctuation,"$1"):n[2],text:a}}}heading(t){let n=this.rules.block.heading.exec(t);if(n){let r=n[2].trim();if(this.rules.other.endingHash.test(r)){let a=Vd(r,"#");(this.options.pedantic||!a||this.rules.other.endingSpaceChar.test(a))&&(r=a.trim())}return{type:"heading",raw:n[0],depth:n[1].length,text:r,tokens:this.lexer.inline(r)}}}hr(t){let n=this.rules.block.hr.exec(t);if(n)return{type:"hr",raw:Vd(n[0],`
`)}}blockquote(t){let n=this.rules.block.blockquote.exec(t);if(n){let r=Vd(n[0],`
`).split(`
`),a="",i="",o=[];for(;r.length>0;){let l=!1,u=[],d;for(d=0;d<r.length;d++)if(this.rules.other.blockquoteStart.test(r[d]))u.push(r[d]),l=!0;else if(!l)u.push(r[d]);else break;r=r.slice(d);let h=u.join(`
`),f=h.replace(this.rules.other.blockquoteSetextReplace,`
    $1`).replace(this.rules.other.blockquoteSetextReplace2,"");a=a?`${a}
${h}`:h,i=i?`${i}
${f}`:f;let m=this.lexer.state.top;if(this.lexer.state.top=!0,this.lexer.blockTokens(f,o,!0),this.lexer.state.top=m,r.length===0)break;let b=o.at(-1);if((b==null?void 0:b.type)==="code")break;if((b==null?void 0:b.type)==="blockquote"){let y=b,v=y.raw+`
`+r.join(`
`),w=this.blockquote(v);o[o.length-1]=w,a=a.substring(0,a.length-y.raw.length)+w.raw,i=i.substring(0,i.length-y.text.length)+w.text;break}else if((b==null?void 0:b.type)==="list"){let y=b,v=y.raw+`
`+r.join(`
`),w=this.list(v);o[o.length-1]=w,a=a.substring(0,a.length-b.raw.length)+w.raw,i=i.substring(0,i.length-y.raw.length)+w.raw,r=v.substring(o.at(-1).raw.length).split(`
`);continue}}return{type:"blockquote",raw:a,tokens:o,text:i}}}list(t){let n=this.rules.block.list.exec(t);if(n){let r=n[1].trim(),a=r.length>1,i={type:"list",raw:"",ordered:a,start:a?+r.slice(0,-1):"",loose:!1,items:[]};r=a?`\\d{1,9}\\${r.slice(-1)}`:`\\${r}`,this.options.pedantic&&(r=a?r:"[*+-]");let o=this.rules.other.listItemRegex(r),l=!1;for(;t;){let d=!1,h="",f="";if(!(n=o.exec(t))||this.rules.block.hr.test(t))break;h=n[0],t=t.substring(h.length);let m=n[2].split(`
`,1)[0].replace(this.rules.other.listReplaceTabs,k=>" ".repeat(3*k.length)),b=t.split(`
`,1)[0],y=!m.trim(),v=0;if(this.options.pedantic?(v=2,f=m.trimStart()):y?v=n[1].length+1:(v=n[2].search(this.rules.other.nonSpaceChar),v=v>4?1:v,f=m.slice(v),v+=n[1].length),y&&this.rules.other.blankLine.test(b)&&(h+=b+`
`,t=t.substring(b.length+1),d=!0),!d){let k=this.rules.other.nextBulletRegex(v),R=this.rules.other.hrRegex(v),I=this.rules.other.fencesBeginRegex(v),L=this.rules.other.headingBeginRegex(v),A=this.rules.other.htmlBeginRegex(v);for(;t;){let M=t.split(`
`,1)[0],P;if(b=M,this.options.pedantic?(b=b.replace(this.rules.other.listReplaceNesting,"  "),P=b):P=b.replace(this.rules.other.tabCharGlobal,"    "),I.test(b)||L.test(b)||A.test(b)||k.test(b)||R.test(b))break;if(P.search(this.rules.other.nonSpaceChar)>=v||!b.trim())f+=`
`+P.slice(v);else{if(y||m.replace(this.rules.other.tabCharGlobal,"    ").search(this.rules.other.nonSpaceChar)>=4||I.test(m)||L.test(m)||R.test(m))break;f+=`
`+b}!y&&!b.trim()&&(y=!0),h+=M+`
`,t=t.substring(M.length+1),m=P.slice(v)}}i.loose||(l?i.loose=!0:this.rules.other.doubleBlankLine.test(h)&&(l=!0));let w=null,S;this.options.gfm&&(w=this.rules.other.listIsTask.exec(f),w&&(S=w[0]!=="[ ] ",f=f.replace(this.rules.other.listReplaceTask,""))),i.items.push({type:"list_item",raw:h,task:!!w,checked:S,loose:!1,text:f,tokens:[]}),i.raw+=h}let u=i.items.at(-1);if(u)u.raw=u.raw.trimEnd(),u.text=u.text.trimEnd();else return;i.raw=i.raw.trimEnd();for(let d=0;d<i.items.length;d++)if(this.lexer.state.top=!1,i.items[d].tokens=this.lexer.blockTokens(i.items[d].text,[]),!i.loose){let h=i.items[d].tokens.filter(m=>m.type==="space"),f=h.length>0&&h.some(m=>this.rules.other.anyLine.test(m.raw));i.loose=f}if(i.loose)for(let d=0;d<i.items.length;d++)i.items[d].loose=!0;return i}}html(t){let n=this.rules.block.html.exec(t);if(n)return{type:"html",block:!0,raw:n[0],pre:n[1]==="pre"||n[1]==="script"||n[1]==="style",text:n[0]}}def(t){let n=this.rules.block.def.exec(t);if(n){let r=n[1].toLowerCase().replace(this.rules.other.multipleSpaceGlobal," "),a=n[2]?n[2].replace(this.rules.other.hrefBrackets,"$1").replace(this.rules.inline.anyPunctuation,"$1"):"",i=n[3]?n[3].substring(1,n[3].length-1).replace(this.rules.inline.anyPunctuation,"$1"):n[3];return{type:"def",tag:r,raw:n[0],href:a,title:i}}}table(t){var l;let n=this.rules.block.table.exec(t);if(!n||!this.rules.other.tableDelimiter.test(n[2]))return;let r=h8(n[1]),a=n[2].replace(this.rules.other.tableAlignChars,"").split("|"),i=(l=n[3])!=null&&l.trim()?n[3].replace(this.rules.other.tableRowBlankLine,"").split(`
`):[],o={type:"table",raw:n[0],header:[],align:[],rows:[]};if(r.length===a.length){for(let u of a)this.rules.other.tableAlignRight.test(u)?o.align.push("right"):this.rules.other.tableAlignCenter.test(u)?o.align.push("center"):this.rules.other.tableAlignLeft.test(u)?o.align.push("left"):o.align.push(null);for(let u=0;u<r.length;u++)o.header.push({text:r[u],tokens:this.lexer.inline(r[u]),header:!0,align:o.align[u]});for(let u of i)o.rows.push(h8(u,o.header.length).map((d,h)=>({text:d,tokens:this.lexer.inline(d),header:!1,align:o.align[h]})));return o}}lheading(t){let n=this.rules.block.lheading.exec(t);if(n)return{type:"heading",raw:n[0],depth:n[2].charAt(0)==="="?1:2,text:n[1],tokens:this.lexer.inline(n[1])}}paragraph(t){let n=this.rules.block.paragraph.exec(t);if(n){let r=n[1].charAt(n[1].length-1)===`
`?n[1].slice(0,-1):n[1];return{type:"paragraph",raw:n[0],text:r,tokens:this.lexer.inline(r)}}}text(t){let n=this.rules.block.text.exec(t);if(n)return{type:"text",raw:n[0],text:n[0],tokens:this.lexer.inline(n[0])}}escape(t){let n=this.rules.inline.escape.exec(t);if(n)return{type:"escape",raw:n[0],text:n[1]}}tag(t){let n=this.rules.inline.tag.exec(t);if(n)return!this.lexer.state.inLink&&this.rules.other.startATag.test(n[0])?this.lexer.state.inLink=!0:this.lexer.state.inLink&&this.rules.other.endATag.test(n[0])&&(this.lexer.state.inLink=!1),!this.lexer.state.inRawBlock&&this.rules.other.startPreScriptTag.test(n[0])?this.lexer.state.inRawBlock=!0:this.lexer.state.inRawBlock&&this.rules.other.endPreScriptTag.test(n[0])&&(this.lexer.state.inRawBlock=!1),{type:"html",raw:n[0],inLink:this.lexer.state.inLink,inRawBlock:this.lexer.state.inRawBlock,block:!1,text:n[0]}}link(t){let n=this.rules.inline.link.exec(t);if(n){let r=n[2].trim();if(!this.options.pedantic&&this.rules.other.startAngleBracket.test(r)){if(!this.rules.other.endAngleBracket.test(r))return;let o=Vd(r.slice(0,-1),"\\");if((r.length-o.length)%2===0)return}else{let o=dye(n[2],"()");if(o===-2)return;if(o>-1){let l=(n[0].indexOf("!")===0?5:4)+n[1].length+o;n[2]=n[2].substring(0,o),n[0]=n[0].substring(0,l).trim(),n[3]=""}}let a=n[2],i="";if(this.options.pedantic){let o=this.rules.other.pedanticHrefTitle.exec(a);o&&(a=o[1],i=o[3])}else i=n[3]?n[3].slice(1,-1):"";return a=a.trim(),this.rules.other.startAngleBracket.test(a)&&(this.options.pedantic&&!this.rules.other.endAngleBracket.test(r)?a=a.slice(1):a=a.slice(1,-1)),p8(n,{href:a&&a.replace(this.rules.inline.anyPunctuation,"$1"),title:i&&i.replace(this.rules.inline.anyPunctuation,"$1")},n[0],this.lexer,this.rules)}}reflink(t,n){let r;if((r=this.rules.inline.reflink.exec(t))||(r=this.rules.inline.nolink.exec(t))){let a=(r[2]||r[1]).replace(this.rules.other.multipleSpaceGlobal," "),i=n[a.toLowerCase()];if(!i){let o=r[0].charAt(0);return{type:"text",raw:o,text:o}}return p8(r,i,r[0],this.lexer,this.rules)}}emStrong(t,n,r=""){let a=this.rules.inline.emStrongLDelim.exec(t);if(!(!a||a[3]&&r.match(this.rules.other.unicodeAlphaNumeric))&&(!(a[1]||a[2])||!r||this.rules.inline.punctuation.exec(r))){let i=[...a[0]].length-1,o,l,u=i,d=0,h=a[0][0]==="*"?this.rules.inline.emStrongRDelimAst:this.rules.inline.emStrongRDelimUnd;for(h.lastIndex=0,n=n.slice(-1*t.length+i);(a=h.exec(n))!=null;){if(o=a[1]||a[2]||a[3]||a[4]||a[5]||a[6],!o)continue;if(l=[...o].length,a[3]||a[4]){u+=l;continue}else if((a[5]||a[6])&&i%3&&!((i+l)%3)){d+=l;continue}if(u-=l,u>0)continue;l=Math.min(l,l+u+d);let f=[...a[0]][0].length,m=t.slice(0,i+a.index+f+l);if(Math.min(i,l)%2){let y=m.slice(1,-1);return{type:"em",raw:m,text:y,tokens:this.lexer.inlineTokens(y)}}let b=m.slice(2,-2);return{type:"strong",raw:m,text:b,tokens:this.lexer.inlineTokens(b)}}}}codespan(t){let n=this.rules.inline.code.exec(t);if(n){let r=n[2].replace(this.rules.other.newLineCharGlobal," "),a=this.rules.other.nonSpaceChar.test(r),i=this.rules.other.startingSpaceChar.test(r)&&this.rules.other.endingSpaceChar.test(r);return a&&i&&(r=r.substring(1,r.length-1)),{type:"codespan",raw:n[0],text:r}}}br(t){let n=this.rules.inline.br.exec(t);if(n)return{type:"br",raw:n[0]}}del(t){let n=this.rules.inline.del.exec(t);if(n)return{type:"del",raw:n[0],text:n[2],tokens:this.lexer.inlineTokens(n[2])}}autolink(t){let n=this.rules.inline.autolink.exec(t);if(n){let r,a;return n[2]==="@"?(r=n[1],a="mailto:"+r):(r=n[1],a=r),{type:"link",raw:n[0],text:r,href:a,tokens:[{type:"text",raw:r,text:r}]}}}url(t){var r;let n;if(n=this.rules.inline.url.exec(t)){let a,i;if(n[2]==="@")a=n[0],i="mailto:"+a;else{let o;do o=n[0],n[0]=((r=this.rules.inline._backpedal.exec(n[0]))==null?void 0:r[0])??"";while(o!==n[0]);a=n[0],n[1]==="www."?i="http://"+n[0]:i=n[0]}return{type:"link",raw:n[0],text:a,href:i,tokens:[{type:"text",raw:a,text:a}]}}}inlineText(t){let n=this.rules.inline.text.exec(t);if(n){let r=this.lexer.state.inRawBlock;return{type:"text",raw:n[0],text:n[0],escaped:r}}}},Qa=class k2{constructor(t){tn(this,"tokens");tn(this,"options");tn(this,"state");tn(this,"tokenizer");tn(this,"inlineQueue");this.tokens=[],this.tokens.links=Object.create(null),this.options=t||Fl,this.options.tokenizer=this.options.tokenizer||new Um,this.tokenizer=this.options.tokenizer,this.tokenizer.options=this.options,this.tokenizer.lexer=this,this.inlineQueue=[],this.state={inLink:!1,inRawBlock:!1,top:!0};let n={other:Br,block:v0.normal,inline:Wd.normal};this.options.pedantic?(n.block=v0.pedantic,n.inline=Wd.pedantic):this.options.gfm&&(n.block=v0.gfm,this.options.breaks?n.inline=Wd.breaks:n.inline=Wd.gfm),this.tokenizer.rules=n}static get rules(){return{block:v0,inline:Wd}}static lex(t,n){return new k2(n).lex(t)}static lexInline(t,n){return new k2(n).inlineTokens(t)}lex(t){t=t.replace(Br.carriageReturn,`
`),this.blockTokens(t,this.tokens);for(let n=0;n<this.inlineQueue.length;n++){let r=this.inlineQueue[n];this.inlineTokens(r.src,r.tokens)}return this.inlineQueue=[],this.tokens}blockTokens(t,n=[],r=!1){var a,i,o;for(this.options.pedantic&&(t=t.replace(Br.tabCharGlobal,"    ").replace(Br.spaceLine,""));t;){let l;if((i=(a=this.options.extensions)==null?void 0:a.block)!=null&&i.some(d=>(l=d.call({lexer:this},t,n))?(t=t.substring(l.raw.length),n.push(l),!0):!1))continue;if(l=this.tokenizer.space(t)){t=t.substring(l.raw.length);let d=n.at(-1);l.raw.length===1&&d!==void 0?d.raw+=`
`:n.push(l);continue}if(l=this.tokenizer.code(t)){t=t.substring(l.raw.length);let d=n.at(-1);(d==null?void 0:d.type)==="paragraph"||(d==null?void 0:d.type)==="text"?(d.raw+=(d.raw.endsWith(`
`)?"":`
`)+l.raw,d.text+=`
`+l.text,this.inlineQueue.at(-1).src=d.text):n.push(l);continue}if(l=this.tokenizer.fences(t)){t=t.substring(l.raw.length),n.push(l);continue}if(l=this.tokenizer.heading(t)){t=t.substring(l.raw.length),n.push(l);continue}if(l=this.tokenizer.hr(t)){t=t.substring(l.raw.length),n.push(l);continue}if(l=this.tokenizer.blockquote(t)){t=t.substring(l.raw.length),n.push(l);continue}if(l=this.tokenizer.list(t)){t=t.substring(l.raw.length),n.push(l);continue}if(l=this.tokenizer.html(t)){t=t.substring(l.raw.length),n.push(l);continue}if(l=this.tokenizer.def(t)){t=t.substring(l.raw.length);let d=n.at(-1);(d==null?void 0:d.type)==="paragraph"||(d==null?void 0:d.type)==="text"?(d.raw+=(d.raw.endsWith(`
`)?"":`
`)+l.raw,d.text+=`
`+l.raw,this.inlineQueue.at(-1).src=d.text):this.tokens.links[l.tag]||(this.tokens.links[l.tag]={href:l.href,title:l.title},n.push(l));continue}if(l=this.tokenizer.table(t)){t=t.substring(l.raw.length),n.push(l);continue}if(l=this.tokenizer.lheading(t)){t=t.substring(l.raw.length),n.push(l);continue}let u=t;if((o=this.options.extensions)!=null&&o.startBlock){let d=1/0,h=t.slice(1),f;this.options.extensions.startBlock.forEach(m=>{f=m.call({lexer:this},h),typeof f=="number"&&f>=0&&(d=Math.min(d,f))}),d<1/0&&d>=0&&(u=t.substring(0,d+1))}if(this.state.top&&(l=this.tokenizer.paragraph(u))){let d=n.at(-1);r&&(d==null?void 0:d.type)==="paragraph"?(d.raw+=(d.raw.endsWith(`
`)?"":`
`)+l.raw,d.text+=`
`+l.text,this.inlineQueue.pop(),this.inlineQueue.at(-1).src=d.text):n.push(l),r=u.length!==t.length,t=t.substring(l.raw.length);continue}if(l=this.tokenizer.text(t)){t=t.substring(l.raw.length);let d=n.at(-1);(d==null?void 0:d.type)==="text"?(d.raw+=(d.raw.endsWith(`
`)?"":`
`)+l.raw,d.text+=`
`+l.text,this.inlineQueue.pop(),this.inlineQueue.at(-1).src=d.text):n.push(l);continue}if(t){let d="Infinite loop on byte: "+t.charCodeAt(0);if(this.options.silent){console.error(d);break}else throw new Error(d)}}return this.state.top=!0,n}inline(t,n=[]){return this.inlineQueue.push({src:t,tokens:n}),n}inlineTokens(t,n=[]){var u,d,h,f,m;let r=t,a=null;if(this.tokens.links){let b=Object.keys(this.tokens.links);if(b.length>0)for(;(a=this.tokenizer.rules.inline.reflinkSearch.exec(r))!=null;)b.includes(a[0].slice(a[0].lastIndexOf("[")+1,-1))&&(r=r.slice(0,a.index)+"["+"a".repeat(a[0].length-2)+"]"+r.slice(this.tokenizer.rules.inline.reflinkSearch.lastIndex))}for(;(a=this.tokenizer.rules.inline.anyPunctuation.exec(r))!=null;)r=r.slice(0,a.index)+"++"+r.slice(this.tokenizer.rules.inline.anyPunctuation.lastIndex);let i;for(;(a=this.tokenizer.rules.inline.blockSkip.exec(r))!=null;)i=a[2]?a[2].length:0,r=r.slice(0,a.index+i)+"["+"a".repeat(a[0].length-i-2)+"]"+r.slice(this.tokenizer.rules.inline.blockSkip.lastIndex);r=((d=(u=this.options.hooks)==null?void 0:u.emStrongMask)==null?void 0:d.call({lexer:this},r))??r;let o=!1,l="";for(;t;){o||(l=""),o=!1;let b;if((f=(h=this.options.extensions)==null?void 0:h.inline)!=null&&f.some(v=>(b=v.call({lexer:this},t,n))?(t=t.substring(b.raw.length),n.push(b),!0):!1))continue;if(b=this.tokenizer.escape(t)){t=t.substring(b.raw.length),n.push(b);continue}if(b=this.tokenizer.tag(t)){t=t.substring(b.raw.length),n.push(b);continue}if(b=this.tokenizer.link(t)){t=t.substring(b.raw.length),n.push(b);continue}if(b=this.tokenizer.reflink(t,this.tokens.links)){t=t.substring(b.raw.length);let v=n.at(-1);b.type==="text"&&(v==null?void 0:v.type)==="text"?(v.raw+=b.raw,v.text+=b.text):n.push(b);continue}if(b=this.tokenizer.emStrong(t,r,l)){t=t.substring(b.raw.length),n.push(b);continue}if(b=this.tokenizer.codespan(t)){t=t.substring(b.raw.length),n.push(b);continue}if(b=this.tokenizer.br(t)){t=t.substring(b.raw.length),n.push(b);continue}if(b=this.tokenizer.del(t)){t=t.substring(b.raw.length),n.push(b);continue}if(b=this.tokenizer.autolink(t)){t=t.substring(b.raw.length),n.push(b);continue}if(!this.state.inLink&&(b=this.tokenizer.url(t))){t=t.substring(b.raw.length),n.push(b);continue}let y=t;if((m=this.options.extensions)!=null&&m.startInline){let v=1/0,w=t.slice(1),S;this.options.extensions.startInline.forEach(k=>{S=k.call({lexer:this},w),typeof S=="number"&&S>=0&&(v=Math.min(v,S))}),v<1/0&&v>=0&&(y=t.substring(0,v+1))}if(b=this.tokenizer.inlineText(y)){t=t.substring(b.raw.length),b.raw.slice(-1)!=="_"&&(l=b.raw.slice(-1)),o=!0;let v=n.at(-1);(v==null?void 0:v.type)==="text"?(v.raw+=b.raw,v.text+=b.text):n.push(b);continue}if(t){let v="Infinite loop on byte: "+t.charCodeAt(0);if(this.options.silent){console.error(v);break}else throw new Error(v)}}return n}},jm=class{constructor(t){tn(this,"options");tn(this,"parser");this.options=t||Fl}space(t){return""}code({text:t,lang:n,escaped:r}){var o;let a=(o=(n||"").match(Br.notSpaceStart))==null?void 0:o[0],i=t.replace(Br.endingNewline,"")+`
`;return a?'<pre><code class="language-'+yi(a)+'">'+(r?i:yi(i,!0))+`</code></pre>
`:"<pre><code>"+(r?i:yi(i,!0))+`</code></pre>
`}blockquote({tokens:t}){return`<blockquote>
${this.parser.parse(t)}</blockquote>
`}html({text:t}){return t}def(t){return""}heading({tokens:t,depth:n}){return`<h${n}>${this.parser.parseInline(t)}</h${n}>
`}hr(t){return`<hr>
`}list(t){let n=t.ordered,r=t.start,a="";for(let l=0;l<t.items.length;l++){let u=t.items[l];a+=this.listitem(u)}let i=n?"ol":"ul",o=n&&r!==1?' start="'+r+'"':"";return"<"+i+o+`>
`+a+"</"+i+`>
`}listitem(t){var r;let n="";if(t.task){let a=this.checkbox({checked:!!t.checked});t.loose?((r=t.tokens[0])==null?void 0:r.type)==="paragraph"?(t.tokens[0].text=a+" "+t.tokens[0].text,t.tokens[0].tokens&&t.tokens[0].tokens.length>0&&t.tokens[0].tokens[0].type==="text"&&(t.tokens[0].tokens[0].text=a+" "+yi(t.tokens[0].tokens[0].text),t.tokens[0].tokens[0].escaped=!0)):t.tokens.unshift({type:"text",raw:a+" ",text:a+" ",escaped:!0}):n+=a+" "}return n+=this.parser.parse(t.tokens,!!t.loose),`<li>${n}</li>
`}checkbox({checked:t}){return"<input "+(t?'checked="" ':"")+'disabled="" type="checkbox">'}paragraph({tokens:t}){return`<p>${this.parser.parseInline(t)}</p>
`}table(t){let n="",r="";for(let i=0;i<t.header.length;i++)r+=this.tablecell(t.header[i]);n+=this.tablerow({text:r});let a="";for(let i=0;i<t.rows.length;i++){let o=t.rows[i];r="";for(let l=0;l<o.length;l++)r+=this.tablecell(o[l]);a+=this.tablerow({text:r})}return a&&(a=`<tbody>${a}</tbody>`),`<table>
<thead>
`+n+`</thead>
`+a+`</table>
`}tablerow({text:t}){return`<tr>
${t}</tr>
`}tablecell(t){let n=this.parser.parseInline(t.tokens),r=t.header?"th":"td";return(t.align?`<${r} align="${t.align}">`:`<${r}>`)+n+`</${r}>
`}strong({tokens:t}){return`<strong>${this.parser.parseInline(t)}</strong>`}em({tokens:t}){return`<em>${this.parser.parseInline(t)}</em>`}codespan({text:t}){return`<code>${yi(t,!0)}</code>`}br(t){return"<br>"}del({tokens:t}){return`<del>${this.parser.parseInline(t)}</del>`}link({href:t,title:n,tokens:r}){let a=this.parser.parseInline(r),i=d8(t);if(i===null)return a;t=i;let o='<a href="'+t+'"';return n&&(o+=' title="'+yi(n)+'"'),o+=">"+a+"</a>",o}image({href:t,title:n,text:r,tokens:a}){a&&(r=this.parser.parseInline(a,this.parser.textRenderer));let i=d8(t);if(i===null)return yi(r);t=i;let o=`<img src="${t}" alt="${r}"`;return n&&(o+=` title="${yi(n)}"`),o+=">",o}text(t){return"tokens"in t&&t.tokens?this.parser.parseInline(t.tokens):"escaped"in t&&t.escaped?t.text:yi(t.text)}},aC=class{strong({text:t}){return t}em({text:t}){return t}codespan({text:t}){return t}del({text:t}){return t}html({text:t}){return t}text({text:t}){return t}link({text:t}){return""+t}image({text:t}){return""+t}br(){return""}},Ja=class T2{constructor(t){tn(this,"options");tn(this,"renderer");tn(this,"textRenderer");this.options=t||Fl,this.options.renderer=this.options.renderer||new jm,this.renderer=this.options.renderer,this.renderer.options=this.options,this.renderer.parser=this,this.textRenderer=new aC}static parse(t,n){return new T2(n).parse(t)}static parseInline(t,n){return new T2(n).parseInline(t)}parse(t,n=!0){var a,i;let r="";for(let o=0;o<t.length;o++){let l=t[o];if((i=(a=this.options.extensions)==null?void 0:a.renderers)!=null&&i[l.type]){let d=l,h=this.options.extensions.renderers[d.type].call({parser:this},d);if(h!==!1||!["space","hr","heading","code","table","blockquote","list","html","def","paragraph","text"].includes(d.type)){r+=h||"";continue}}let u=l;switch(u.type){case"space":{r+=this.renderer.space(u);continue}case"hr":{r+=this.renderer.hr(u);continue}case"heading":{r+=this.renderer.heading(u);continue}case"code":{r+=this.renderer.code(u);continue}case"table":{r+=this.renderer.table(u);continue}case"blockquote":{r+=this.renderer.blockquote(u);continue}case"list":{r+=this.renderer.list(u);continue}case"html":{r+=this.renderer.html(u);continue}case"def":{r+=this.renderer.def(u);continue}case"paragraph":{r+=this.renderer.paragraph(u);continue}case"text":{let d=u,h=this.renderer.text(d);for(;o+1<t.length&&t[o+1].type==="text";)d=t[++o],h+=`
`+this.renderer.text(d);n?r+=this.renderer.paragraph({type:"paragraph",raw:h,text:h,tokens:[{type:"text",raw:h,text:h,escaped:!0}]}):r+=h;continue}default:{let d='Token with "'+u.type+'" type was not found.';if(this.options.silent)return console.error(d),"";throw new Error(d)}}}return r}parseInline(t,n=this.renderer){var a,i;let r="";for(let o=0;o<t.length;o++){let l=t[o];if((i=(a=this.options.extensions)==null?void 0:a.renderers)!=null&&i[l.type]){let d=this.options.extensions.renderers[l.type].call({parser:this},l);if(d!==!1||!["escape","html","link","image","strong","em","codespan","br","del","text"].includes(l.type)){r+=d||"";continue}}let u=l;switch(u.type){case"escape":{r+=n.text(u);break}case"html":{r+=n.html(u);break}case"link":{r+=n.link(u);break}case"image":{r+=n.image(u);break}case"strong":{r+=n.strong(u);break}case"em":{r+=n.em(u);break}case"codespan":{r+=n.codespan(u);break}case"br":{r+=n.br(u);break}case"del":{r+=n.del(u);break}case"text":{r+=n.text(u);break}default:{let d='Token with "'+u.type+'" type was not found.';if(this.options.silent)return console.error(d),"";throw new Error(d)}}}return r}},k0,ah=(k0=class{constructor(t){tn(this,"options");tn(this,"block");this.options=t||Fl}preprocess(t){return t}postprocess(t){return t}processAllTokens(t){return t}emStrongMask(t){return t}provideLexer(){return this.block?Qa.lex:Qa.lexInline}provideParser(){return this.block?Ja.parse:Ja.parseInline}},tn(k0,"passThroughHooks",new Set(["preprocess","postprocess","processAllTokens","emStrongMask"])),tn(k0,"passThroughHooksRespectAsync",new Set(["preprocess","postprocess","processAllTokens"])),k0),pye=class{constructor(...t){tn(this,"defaults",K_());tn(this,"options",this.setOptions);tn(this,"parse",this.parseMarkdown(!0));tn(this,"parseInline",this.parseMarkdown(!1));tn(this,"Parser",Ja);tn(this,"Renderer",jm);tn(this,"TextRenderer",aC);tn(this,"Lexer",Qa);tn(this,"Tokenizer",Um);tn(this,"Hooks",ah);this.use(...t)}walkTokens(t,n){var a,i;let r=[];for(let o of t)switch(r=r.concat(n.call(this,o)),o.type){case"table":{let l=o;for(let u of l.header)r=r.concat(this.walkTokens(u.tokens,n));for(let u of l.rows)for(let d of u)r=r.concat(this.walkTokens(d.tokens,n));break}case"list":{let l=o;r=r.concat(this.walkTokens(l.items,n));break}default:{let l=o;(i=(a=this.defaults.extensions)==null?void 0:a.childTokens)!=null&&i[l.type]?this.defaults.extensions.childTokens[l.type].forEach(u=>{let d=l[u].flat(1/0);r=r.concat(this.walkTokens(d,n))}):l.tokens&&(r=r.concat(this.walkTokens(l.tokens,n)))}}return r}use(...t){let n=this.defaults.extensions||{renderers:{},childTokens:{}};return t.forEach(r=>{let a={...r};if(a.async=this.defaults.async||a.async||!1,r.extensions&&(r.extensions.forEach(i=>{if(!i.name)throw new Error("extension name required");if("renderer"in i){let o=n.renderers[i.name];o?n.renderers[i.name]=function(...l){let u=i.renderer.apply(this,l);return u===!1&&(u=o.apply(this,l)),u}:n.renderers[i.name]=i.renderer}if("tokenizer"in i){if(!i.level||i.level!=="block"&&i.level!=="inline")throw new Error("extension level must be 'block' or 'inline'");let o=n[i.level];o?o.unshift(i.tokenizer):n[i.level]=[i.tokenizer],i.start&&(i.level==="block"?n.startBlock?n.startBlock.push(i.start):n.startBlock=[i.start]:i.level==="inline"&&(n.startInline?n.startInline.push(i.start):n.startInline=[i.start]))}"childTokens"in i&&i.childTokens&&(n.childTokens[i.name]=i.childTokens)}),a.extensions=n),r.renderer){let i=this.defaults.renderer||new jm(this.defaults);for(let o in r.renderer){if(!(o in i))throw new Error(`renderer '${o}' does not exist`);if(["options","parser"].includes(o))continue;let l=o,u=r.renderer[l],d=i[l];i[l]=(...h)=>{let f=u.apply(i,h);return f===!1&&(f=d.apply(i,h)),f||""}}a.renderer=i}if(r.tokenizer){let i=this.defaults.tokenizer||new Um(this.defaults);for(let o in r.tokenizer){if(!(o in i))throw new Error(`tokenizer '${o}' does not exist`);if(["options","rules","lexer"].includes(o))continue;let l=o,u=r.tokenizer[l],d=i[l];i[l]=(...h)=>{let f=u.apply(i,h);return f===!1&&(f=d.apply(i,h)),f}}a.tokenizer=i}if(r.hooks){let i=this.defaults.hooks||new ah;for(let o in r.hooks){if(!(o in i))throw new Error(`hook '${o}' does not exist`);if(["options","block"].includes(o))continue;let l=o,u=r.hooks[l],d=i[l];ah.passThroughHooks.has(o)?i[l]=h=>{if(this.defaults.async&&ah.passThroughHooksRespectAsync.has(o))return(async()=>{let m=await u.call(i,h);return d.call(i,m)})();let f=u.call(i,h);return d.call(i,f)}:i[l]=(...h)=>{if(this.defaults.async)return(async()=>{let m=await u.apply(i,h);return m===!1&&(m=await d.apply(i,h)),m})();let f=u.apply(i,h);return f===!1&&(f=d.apply(i,h)),f}}a.hooks=i}if(r.walkTokens){let i=this.defaults.walkTokens,o=r.walkTokens;a.walkTokens=function(l){let u=[];return u.push(o.call(this,l)),i&&(u=u.concat(i.call(this,l))),u}}this.defaults={...this.defaults,...a}}),this}setOptions(t){return this.defaults={...this.defaults,...t},this}lexer(t,n){return Qa.lex(t,n??this.defaults)}parser(t,n){return Ja.parse(t,n??this.defaults)}parseMarkdown(t){return(n,r)=>{let a={...r},i={...this.defaults,...a},o=this.onError(!!i.silent,!!i.async);if(this.defaults.async===!0&&a.async===!1)return o(new Error("marked(): The async option was set to true by an extension. Remove async: false from the parse options object to return a Promise."));if(typeof n>"u"||n===null)return o(new Error("marked(): input parameter is undefined or null"));if(typeof n!="string")return o(new Error("marked(): input parameter is of type "+Object.prototype.toString.call(n)+", string expected"));if(i.hooks&&(i.hooks.options=i,i.hooks.block=t),i.async)return(async()=>{let l=i.hooks?await i.hooks.preprocess(n):n,u=await(i.hooks?await i.hooks.provideLexer():t?Qa.lex:Qa.lexInline)(l,i),d=i.hooks?await i.hooks.processAllTokens(u):u;i.walkTokens&&await Promise.all(this.walkTokens(d,i.walkTokens));let h=await(i.hooks?await i.hooks.provideParser():t?Ja.parse:Ja.parseInline)(d,i);return i.hooks?await i.hooks.postprocess(h):h})().catch(o);try{i.hooks&&(n=i.hooks.preprocess(n));let l=(i.hooks?i.hooks.provideLexer():t?Qa.lex:Qa.lexInline)(n,i);i.hooks&&(l=i.hooks.processAllTokens(l)),i.walkTokens&&this.walkTokens(l,i.walkTokens);let u=(i.hooks?i.hooks.provideParser():t?Ja.parse:Ja.parseInline)(l,i);return i.hooks&&(u=i.hooks.postprocess(u)),u}catch(l){return o(l)}}}onError(t,n){return r=>{if(r.message+=`
Please report this to https://github.com/markedjs/marked.`,t){let a="<p>An error occurred:</p><pre>"+yi(r.message+"",!0)+"</pre>";return n?Promise.resolve(a):a}if(n)return Promise.reject(r);throw r}}},kl=new pye;function Yt(e,t){return kl.parse(e,t)}Yt.options=Yt.setOptions=function(e){return kl.setOptions(e),Yt.defaults=kl.defaults,Cz(Yt.defaults),Yt};Yt.getDefaults=K_;Yt.defaults=Fl;Yt.use=function(...e){return kl.use(...e),Yt.defaults=kl.defaults,Cz(Yt.defaults),Yt};Yt.walkTokens=function(e,t){return kl.walkTokens(e,t)};Yt.parseInline=kl.parseInline;Yt.Parser=Ja;Yt.parser=Ja.parse;Yt.Renderer=jm;Yt.TextRenderer=aC;Yt.Lexer=Qa;Yt.lexer=Qa.lex;Yt.Tokenizer=Um;Yt.Hooks=ah;Yt.parse=Yt;Yt.options;Yt.setOptions;Yt.use;Yt.walkTokens;Yt.parseInline;Ja.parse;Qa.lex;function zz(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];var r=Array.from(typeof e=="string"?[e]:e);r[r.length-1]=r[r.length-1].replace(/\r?\n([\t ]*)$/,"");var a=r.reduce(function(l,u){var d=u.match(/\n([\t ]+|(?!\s).)/g);return d?l.concat(d.map(function(h){var f,m;return(m=(f=h.match(/[\t ]/g))===null||f===void 0?void 0:f.length)!==null&&m!==void 0?m:0})):l},[]);if(a.length){var i=new RegExp(`
[	 ]{`+Math.min.apply(Math,a)+"}","g");r=r.map(function(l){return l.replace(i,`
`)})}r[0]=r[0].replace(/^\r?\n/,"");var o=r[0];return t.forEach(function(l,u){var d=o.match(/(?:^|\n)( *)$/),h=d?d[1]:"",f=l;typeof l=="string"&&l.includes(`
`)&&(f=String(l).split(`
`).map(function(m,b){return b===0?m:""+h+m}).join(`
`)),o+=f+r[u+1]}),o}var fye={body:'<g><rect width="80" height="80" style="fill: #087ebf; stroke-width: 0px;"/><text transform="translate(21.16 64.67)" style="fill: #fff; font-family: ArialMT, Arial; font-size: 67.75px;"><tspan x="0" y="0">?</tspan></text></g>',height:80,width:80},_2=new Map,$z=new Map,mye=N(e=>{for(const t of e){if(!t.name)throw new Error('Invalid icon loader. Must have a "name" property with non-empty string value.');if(we.debug("Registering icon pack:",t.name),"loader"in t)$z.set(t.name,t.loader);else if("icons"in t)_2.set(t.name,t.icons);else throw we.error("Invalid icon loader:",t),new Error('Invalid icon loader. Must have either "icons" or "loader" property.')}},"registerIconPacks"),Pz=N(async(e,t)=>{const n=gbe(e,!0,t!==void 0);if(!n)throw new Error(`Invalid icon name: ${e}`);const r=n.prefix||t;if(!r)throw new Error(`Icon name must contain a prefix: ${e}`);let a=_2.get(r);if(!a){const o=$z.get(r);if(!o)throw new Error(`Icon set not found: ${n.prefix}`);try{a={...await o(),prefix:r},_2.set(r,a)}catch(l){throw we.error(l),new Error(`Failed to load icon set: ${n.prefix}`)}}const i=vbe(a,n.name);if(!i)throw new Error(`Icon not found: ${e}`);return i},"getRegisteredIconData"),gye=N(async e=>{try{return await Pz(e),!0}catch{return!1}},"isIconAvailable"),xp=N(async(e,t,n)=>{let r;try{r=await Pz(e,t==null?void 0:t.fallbackPrefix)}catch(o){we.error(o),r=fye}const a=_be(r,t),i=Nbe(Rbe(a.body),{...a.attributes,...n});return li(i,br())},"getIconSVG");function Uz(e,{markdownAutoWrap:t}){const r=e.replace(/<br\/>/g,`
`).replace(/\n{2,}/g,`
`);return zz(r)}N(Uz,"preprocessMarkdown");function jz(e){return e.split(/\\n|\n|<br\s*\/?>/gi).map(t=>{var n;return((n=t.trim().match(/<[^>]+>|[^\s<>]+/g))==null?void 0:n.map(r=>({content:r,type:"normal"})))??[]})}N(jz,"nonMarkdownToLines");function Hz(e,t={}){const n=Uz(e,t),r=Yt.lexer(n),a=[[]];let i=0;function o(l,u="normal"){l.type==="text"?l.text.split(`
`).forEach((h,f)=>{f!==0&&(i++,a.push([])),h.split(" ").forEach(m=>{m=m.replace(/&#39;/g,"'"),m&&a[i].push({content:m,type:u})})}):l.type==="strong"||l.type==="em"?l.tokens.forEach(d=>{o(d,l.type)}):l.type==="html"&&a[i].push({content:l.text,type:"normal"})}return N(o,"processNode"),r.forEach(l=>{var u;l.type==="paragraph"?(u=l.tokens)==null||u.forEach(d=>{o(d)}):l.type==="html"?a[i].push({content:l.text,type:"normal"}):a[i].push({content:l.raw,type:"normal"})}),a}N(Hz,"markdownToLines");function Gz(e){return e?`<p>${e.replace(/\\n|\n/g,"<br />")}</p>`:""}N(Gz,"nonMarkdownToHTML");function qz(e,{markdownAutoWrap:t}={}){const n=Yt.lexer(e);function r(a){var i,o,l;return a.type==="text"?t===!1?a.text.replace(/\n */g,"<br/>").replace(/ /g,"&nbsp;"):a.text.replace(/\n */g,"<br/>"):a.type==="strong"?`<strong>${(i=a.tokens)==null?void 0:i.map(r).join("")}</strong>`:a.type==="em"?`<em>${(o=a.tokens)==null?void 0:o.map(r).join("")}</em>`:a.type==="paragraph"?`<p>${(l=a.tokens)==null?void 0:l.map(r).join("")}</p>`:a.type==="space"?"":a.type==="html"?`${a.text}`:a.type==="escape"?a.text:(we.warn(`Unsupported markdown: ${a.type}`),a.raw)}return N(r,"output"),n.map(r).join("")}N(qz,"markdownToHTML");function Wz(e){return Intl.Segmenter?[...new Intl.Segmenter().segment(e)].map(t=>t.segment):[...e]}N(Wz,"splitTextToChars");function Vz(e,t){const n=Wz(t.content);return iC(e,[],n,t.type)}N(Vz,"splitWordToFitWidth");function iC(e,t,n,r){if(n.length===0)return[{content:t.join(""),type:r},{content:"",type:r}];const[a,...i]=n,o=[...t,a];return e([{content:o.join(""),type:r}])?iC(e,o,i,r):(t.length===0&&a&&(t.push(a),n.shift()),[{content:t.join(""),type:r},{content:n.join(""),type:r}])}N(iC,"splitWordToFitWidthRecursion");function Yz(e,t){if(e.some(({content:n})=>n.includes(`
`)))throw new Error("splitLineToFitWidth does not support newlines in the line");return Hm(e,t)}N(Yz,"splitLineToFitWidth");function Hm(e,t,n=[],r=[]){if(e.length===0)return r.length>0&&n.push(r),n.length>0?n:[];let a="";e[0].content===" "&&(a=" ",e.shift());const i=e.shift()??{content:" ",type:"normal"},o=[...r];if(a!==""&&o.push({content:a,type:"normal"}),o.push(i),t(o))return Hm(e,t,n,o);if(r.length>0)n.push(r),e.unshift(i);else if(i.content){const[l,u]=Vz(t,i);n.push([l]),u.content&&e.unshift(u)}return Hm(e,t,n)}N(Hm,"splitLineToFitWidthRecursion");function C2(e,t){t&&e.attr("style",t)}N(C2,"applyStyle");var f8=16384;async function Xz(e,t,n,r,a=!1,i=br()){const o=e.append("foreignObject");o.attr("width",`${Math.min(10*n,f8)}px`),o.attr("height",`${Math.min(10*n,f8)}px`);const l=o.append("xhtml:div"),u=Oh(t.label)?await w9(t.label.replace(pp.lineBreakRegex,`
`),i):li(t.label,i),d=t.isNode?"nodeLabel":"edgeLabel",h=l.append("span");h.html(u),C2(h,t.labelStyle),h.attr("class",`${d} ${r}`),C2(l,t.labelStyle),l.style("display","table-cell"),l.style("white-space","nowrap"),l.style("line-height","1.5"),n!==Number.POSITIVE_INFINITY&&(l.style("max-width",n+"px"),l.style("text-align","center")),l.attr("xmlns","http://www.w3.org/1999/xhtml"),a&&l.attr("class","labelBkg");let f=l.node().getBoundingClientRect();return f.width===n&&(l.style("display","table"),l.style("white-space","break-spaces"),l.style("width",n+"px"),f=l.node().getBoundingClientRect()),o.node()}N(Xz,"addHtmlSpan");function ab(e,t,n,r=!1){const a=e.append("tspan").attr("class","text-outer-tspan").attr("x",0).attr("y",t*n-.1+"em").attr("dy",n+"em");return r&&a.attr("text-anchor","middle"),a}N(ab,"createTspan");function Kz(e,t,n){const r=e.append("text"),a=ab(r,1,t);ib(a,n);const i=a.node().getComputedTextLength();return r.remove(),i}N(Kz,"computeWidthOfText");function bye(e,t,n){var o;const r=e.append("text"),a=ab(r,1,t);ib(a,[{content:n,type:"normal"}]);const i=(o=a.node())==null?void 0:o.getBoundingClientRect();return i&&r.remove(),i}N(bye,"computeDimensionOfText");function Zz(e,t,n,r=!1,a=!1){const o=t.append("g"),l=o.insert("rect").attr("class","background").attr("style","stroke: none"),u=o.append("text").attr("y","-10.1");a&&u.attr("text-anchor","middle");let d=0;for(const h of n){const f=N(b=>Kz(o,1.1,b)<=e,"checkWidth"),m=f(h)?[h]:Yz(h,f);for(const b of m){const y=ab(u,d,1.1,a);ib(y,b),d++}}if(r){const h=u.node().getBBox(),f=2;return l.attr("x",h.x-f).attr("y",h.y-f).attr("width",h.width+2*f).attr("height",h.height+2*f),o.node()}else return u.node()}N(Zz,"createFormattedText");function ib(e,t){e.text(""),t.forEach((n,r)=>{const a=e.append("tspan").attr("font-style",n.type==="em"?"italic":"normal").attr("class","text-inner-tspan").attr("font-weight",n.type==="strong"?"bold":"normal");r===0?a.text(n.content):a.text(" "+n.content)})}N(ib,"updateTextContentAndStyles");async function Qz(e,t={}){const n=[];e.replace(/(fa[bklrs]?):fa-([\w-]+)/g,(a,i,o)=>(n.push((async()=>{const l=`${i}:${o}`;return await gye(l)?await xp(l,void 0,{class:"label-icon"}):`<i class='${li(a,t).replace(":"," ")}'></i>`})()),a));const r=await Promise.all(n);return e.replace(/(fa[bklrs]?):fa-([\w-]+)/g,()=>r.shift()??"")}N(Qz,"replaceIconSubstring");var Do=N(async(e,t="",{style:n="",isTitle:r=!1,classes:a="",useHtmlLabels:i=!0,markdown:o=!0,isNode:l=!0,width:u=200,addSvgBackground:d=!1}={},h)=>{if(we.debug("XYZ createText",t,n,r,a,i,l,"addSvgBackground: ",d),i){const f=o?qz(t,h):Gz(t),m=await Qz(Ou(f),h),b=t.replace(/\\\\/g,"\\"),y={isNode:l,label:Oh(t)?b:m,labelStyle:n.replace("fill:","color:")};return await Xz(e,y,u,a,d,h)}else{const f=t.replace(/<br\s*\/?>/g,"<br/>"),m=o?Hz(f.replace("<br>","<br/>"),h):jz(f),b=Zz(u,e,m,t?d:!1,!l);if(l){/stroke:/.exec(n)&&(n=n.replace("stroke:","lineColor:"));const y=n.replace(/stroke:[^;]+;?/g,"").replace(/stroke-width:[^;]+;?/g,"").replace(/fill:[^;]+;?/g,"").replace(/color:/g,"fill:");Et(b).attr("style",y)}else{const y=n.replace(/stroke:[^;]+;?/g,"").replace(/stroke-width:[^;]+;?/g,"").replace(/fill:[^;]+;?/g,"").replace(/background:/g,"fill:");Et(b).select("rect").attr("style",y.replace(/background:/g,"fill:"));const v=n.replace(/stroke:[^;]+;?/g,"").replace(/stroke-width:[^;]+;?/g,"").replace(/fill:[^;]+;?/g,"").replace(/color:/g,"fill:");Et(b).select("text").attr("style",v)}return r?Et(b).selectAll("tspan.text-outer-tspan").classed("title-row",!0):Et(b).selectAll("tspan.text-outer-tspan").classed("row",!0),b}},"createText");function qv(e,t,n){if(e&&e.length){const[r,a]=t,i=Math.PI/180*n,o=Math.cos(i),l=Math.sin(i);for(const u of e){const[d,h]=u;u[0]=(d-r)*o-(h-a)*l+r,u[1]=(d-r)*l+(h-a)*o+a}}}function yye(e,t){return e[0]===t[0]&&e[1]===t[1]}function vye(e,t,n,r=1){const a=n,i=Math.max(t,.1),o=e[0]&&e[0][0]&&typeof e[0][0]=="number"?[e]:e,l=[0,0];if(a)for(const d of o)qv(d,l,a);const u=(function(d,h,f){const m=[];for(const k of d){const R=[...k];yye(R[0],R[R.length-1])||R.push([R[0][0],R[0][1]]),R.length>2&&m.push(R)}const b=[];h=Math.max(h,.1);const y=[];for(const k of m)for(let R=0;R<k.length-1;R++){const I=k[R],L=k[R+1];if(I[1]!==L[1]){const A=Math.min(I[1],L[1]);y.push({ymin:A,ymax:Math.max(I[1],L[1]),x:A===I[1]?I[0]:L[0],islope:(L[0]-I[0])/(L[1]-I[1])})}}if(y.sort(((k,R)=>k.ymin<R.ymin?-1:k.ymin>R.ymin?1:k.x<R.x?-1:k.x>R.x?1:k.ymax===R.ymax?0:(k.ymax-R.ymax)/Math.abs(k.ymax-R.ymax))),!y.length)return b;let v=[],w=y[0].ymin,S=0;for(;v.length||y.length;){if(y.length){let k=-1;for(let R=0;R<y.length&&!(y[R].ymin>w);R++)k=R;y.splice(0,k+1).forEach((R=>{v.push({s:w,edge:R})}))}if(v=v.filter((k=>!(k.edge.ymax<=w))),v.sort(((k,R)=>k.edge.x===R.edge.x?0:(k.edge.x-R.edge.x)/Math.abs(k.edge.x-R.edge.x))),(f!==1||S%h==0)&&v.length>1)for(let k=0;k<v.length;k+=2){const R=k+1;if(R>=v.length)break;const I=v[k].edge,L=v[R].edge;b.push([[Math.round(I.x),w],[Math.round(L.x),w]])}w+=f,v.forEach((k=>{k.edge.x=k.edge.x+f*k.edge.islope})),S++}return b})(o,i,r);if(a){for(const d of o)qv(d,l,-a);(function(d,h,f){const m=[];d.forEach((b=>m.push(...b))),qv(m,h,f)})(u,l,-a)}return u}function Sp(e,t){var n;const r=t.hachureAngle+90;let a=t.hachureGap;a<0&&(a=4*t.strokeWidth),a=Math.round(Math.max(a,.1));let i=1;return t.roughness>=1&&(((n=t.randomizer)===null||n===void 0?void 0:n.next())||Math.random())>.7&&(i=a),vye(e,a,r,i||1)}class oC{constructor(t){this.helper=t}fillPolygons(t,n){return this._fillPolygons(t,n)}_fillPolygons(t,n){const r=Sp(t,n);return{type:"fillSketch",ops:this.renderLines(r,n)}}renderLines(t,n){const r=[];for(const a of t)r.push(...this.helper.doubleLineOps(a[0][0],a[0][1],a[1][0],a[1][1],n));return r}}function ob(e){const t=e[0],n=e[1];return Math.sqrt(Math.pow(t[0]-n[0],2)+Math.pow(t[1]-n[1],2))}class xye extends oC{fillPolygons(t,n){let r=n.hachureGap;r<0&&(r=4*n.strokeWidth),r=Math.max(r,.1);const a=Sp(t,Object.assign({},n,{hachureGap:r})),i=Math.PI/180*n.hachureAngle,o=[],l=.5*r*Math.cos(i),u=.5*r*Math.sin(i);for(const[d,h]of a)ob([d,h])&&o.push([[d[0]-l,d[1]+u],[...h]],[[d[0]+l,d[1]-u],[...h]]);return{type:"fillSketch",ops:this.renderLines(o,n)}}}class Sye extends oC{fillPolygons(t,n){const r=this._fillPolygons(t,n),a=Object.assign({},n,{hachureAngle:n.hachureAngle+90}),i=this._fillPolygons(t,a);return r.ops=r.ops.concat(i.ops),r}}class wye{constructor(t){this.helper=t}fillPolygons(t,n){const r=Sp(t,n=Object.assign({},n,{hachureAngle:0}));return this.dotsOnLines(r,n)}dotsOnLines(t,n){const r=[];let a=n.hachureGap;a<0&&(a=4*n.strokeWidth),a=Math.max(a,.1);let i=n.fillWeight;i<0&&(i=n.strokeWidth/2);const o=a/4;for(const l of t){const u=ob(l),d=u/a,h=Math.ceil(d)-1,f=u-h*a,m=(l[0][0]+l[1][0])/2-a/4,b=Math.min(l[0][1],l[1][1]);for(let y=0;y<h;y++){const v=b+f+y*a,w=m-o+2*Math.random()*o,S=v-o+2*Math.random()*o,k=this.helper.ellipse(w,S,i,i,n);r.push(...k.ops)}}return{type:"fillSketch",ops:r}}}class Eye{constructor(t){this.helper=t}fillPolygons(t,n){const r=Sp(t,n);return{type:"fillSketch",ops:this.dashedLine(r,n)}}dashedLine(t,n){const r=n.dashOffset<0?n.hachureGap<0?4*n.strokeWidth:n.hachureGap:n.dashOffset,a=n.dashGap<0?n.hachureGap<0?4*n.strokeWidth:n.hachureGap:n.dashGap,i=[];return t.forEach((o=>{const l=ob(o),u=Math.floor(l/(r+a)),d=(l+a-u*(r+a))/2;let h=o[0],f=o[1];h[0]>f[0]&&(h=o[1],f=o[0]);const m=Math.atan((f[1]-h[1])/(f[0]-h[0]));for(let b=0;b<u;b++){const y=b*(r+a),v=y+r,w=[h[0]+y*Math.cos(m)+d*Math.cos(m),h[1]+y*Math.sin(m)+d*Math.sin(m)],S=[h[0]+v*Math.cos(m)+d*Math.cos(m),h[1]+v*Math.sin(m)+d*Math.sin(m)];i.push(...this.helper.doubleLineOps(w[0],w[1],S[0],S[1],n))}})),i}}class kye{constructor(t){this.helper=t}fillPolygons(t,n){const r=n.hachureGap<0?4*n.strokeWidth:n.hachureGap,a=n.zigzagOffset<0?r:n.zigzagOffset,i=Sp(t,n=Object.assign({},n,{hachureGap:r+a}));return{type:"fillSketch",ops:this.zigzagLines(i,a,n)}}zigzagLines(t,n,r){const a=[];return t.forEach((i=>{const o=ob(i),l=Math.round(o/(2*n));let u=i[0],d=i[1];u[0]>d[0]&&(u=i[1],d=i[0]);const h=Math.atan((d[1]-u[1])/(d[0]-u[0]));for(let f=0;f<l;f++){const m=2*f*n,b=2*(f+1)*n,y=Math.sqrt(2*Math.pow(n,2)),v=[u[0]+m*Math.cos(h),u[1]+m*Math.sin(h)],w=[u[0]+b*Math.cos(h),u[1]+b*Math.sin(h)],S=[v[0]+y*Math.cos(h+Math.PI/4),v[1]+y*Math.sin(h+Math.PI/4)];a.push(...this.helper.doubleLineOps(v[0],v[1],S[0],S[1],r),...this.helper.doubleLineOps(S[0],S[1],w[0],w[1],r))}})),a}}const Xr={};class Tye{constructor(t){this.seed=t}next(){return this.seed?(2**31-1&(this.seed=Math.imul(48271,this.seed)))/2**31:Math.random()}}const _ye=0,Wv=1,m8=2,x0={A:7,a:7,C:6,c:6,H:1,h:1,L:2,l:2,M:2,m:2,Q:4,q:4,S:4,s:4,T:2,t:2,V:1,v:1,Z:0,z:0};function Vv(e,t){return e.type===t}function sC(e){const t=[],n=(function(o){const l=new Array;for(;o!=="";)if(o.match(/^([ \t\r\n,]+)/))o=o.substr(RegExp.$1.length);else if(o.match(/^([aAcChHlLmMqQsStTvVzZ])/))l[l.length]={type:_ye,text:RegExp.$1},o=o.substr(RegExp.$1.length);else{if(!o.match(/^(([-+]?[0-9]+(\.[0-9]*)?|[-+]?\.[0-9]+)([eE][-+]?[0-9]+)?)/))return[];l[l.length]={type:Wv,text:`${parseFloat(RegExp.$1)}`},o=o.substr(RegExp.$1.length)}return l[l.length]={type:m8,text:""},l})(e);let r="BOD",a=0,i=n[a];for(;!Vv(i,m8);){let o=0;const l=[];if(r==="BOD"){if(i.text!=="M"&&i.text!=="m")return sC("M0,0"+e);a++,o=x0[i.text],r=i.text}else Vv(i,Wv)?o=x0[r]:(a++,o=x0[i.text],r=i.text);if(!(a+o<n.length))throw new Error("Path data ended short");for(let u=a;u<a+o;u++){const d=n[u];if(!Vv(d,Wv))throw new Error("Param not a number: "+r+","+d.text);l[l.length]=+d.text}if(typeof x0[r]!="number")throw new Error("Bad segment: "+r);{const u={key:r,data:l};t.push(u),a+=o,i=n[a],r==="M"&&(r="L"),r==="m"&&(r="l")}}return t}function Jz(e){let t=0,n=0,r=0,a=0;const i=[];for(const{key:o,data:l}of e)switch(o){case"M":i.push({key:"M",data:[...l]}),[t,n]=l,[r,a]=l;break;case"m":t+=l[0],n+=l[1],i.push({key:"M",data:[t,n]}),r=t,a=n;break;case"L":i.push({key:"L",data:[...l]}),[t,n]=l;break;case"l":t+=l[0],n+=l[1],i.push({key:"L",data:[t,n]});break;case"C":i.push({key:"C",data:[...l]}),t=l[4],n=l[5];break;case"c":{const u=l.map(((d,h)=>h%2?d+n:d+t));i.push({key:"C",data:u}),t=u[4],n=u[5];break}case"Q":i.push({key:"Q",data:[...l]}),t=l[2],n=l[3];break;case"q":{const u=l.map(((d,h)=>h%2?d+n:d+t));i.push({key:"Q",data:u}),t=u[2],n=u[3];break}case"A":i.push({key:"A",data:[...l]}),t=l[5],n=l[6];break;case"a":t+=l[5],n+=l[6],i.push({key:"A",data:[l[0],l[1],l[2],l[3],l[4],t,n]});break;case"H":i.push({key:"H",data:[...l]}),t=l[0];break;case"h":t+=l[0],i.push({key:"H",data:[t]});break;case"V":i.push({key:"V",data:[...l]}),n=l[0];break;case"v":n+=l[0],i.push({key:"V",data:[n]});break;case"S":i.push({key:"S",data:[...l]}),t=l[2],n=l[3];break;case"s":{const u=l.map(((d,h)=>h%2?d+n:d+t));i.push({key:"S",data:u}),t=u[2],n=u[3];break}case"T":i.push({key:"T",data:[...l]}),t=l[0],n=l[1];break;case"t":t+=l[0],n+=l[1],i.push({key:"T",data:[t,n]});break;case"Z":case"z":i.push({key:"Z",data:[]}),t=r,n=a}return i}function e$(e){const t=[];let n="",r=0,a=0,i=0,o=0,l=0,u=0;for(const{key:d,data:h}of e){switch(d){case"M":t.push({key:"M",data:[...h]}),[r,a]=h,[i,o]=h;break;case"C":t.push({key:"C",data:[...h]}),r=h[4],a=h[5],l=h[2],u=h[3];break;case"L":t.push({key:"L",data:[...h]}),[r,a]=h;break;case"H":r=h[0],t.push({key:"L",data:[r,a]});break;case"V":a=h[0],t.push({key:"L",data:[r,a]});break;case"S":{let f=0,m=0;n==="C"||n==="S"?(f=r+(r-l),m=a+(a-u)):(f=r,m=a),t.push({key:"C",data:[f,m,...h]}),l=h[0],u=h[1],r=h[2],a=h[3];break}case"T":{const[f,m]=h;let b=0,y=0;n==="Q"||n==="T"?(b=r+(r-l),y=a+(a-u)):(b=r,y=a);const v=r+2*(b-r)/3,w=a+2*(y-a)/3,S=f+2*(b-f)/3,k=m+2*(y-m)/3;t.push({key:"C",data:[v,w,S,k,f,m]}),l=b,u=y,r=f,a=m;break}case"Q":{const[f,m,b,y]=h,v=r+2*(f-r)/3,w=a+2*(m-a)/3,S=b+2*(f-b)/3,k=y+2*(m-y)/3;t.push({key:"C",data:[v,w,S,k,b,y]}),l=f,u=m,r=b,a=y;break}case"A":{const f=Math.abs(h[0]),m=Math.abs(h[1]),b=h[2],y=h[3],v=h[4],w=h[5],S=h[6];f===0||m===0?(t.push({key:"C",data:[r,a,w,S,w,S]}),r=w,a=S):(r!==w||a!==S)&&(t$(r,a,w,S,f,m,b,y,v).forEach((function(k){t.push({key:"C",data:k})})),r=w,a=S);break}case"Z":t.push({key:"Z",data:[]}),r=i,a=o}n=d}return t}function Yd(e,t,n){return[e*Math.cos(n)-t*Math.sin(n),e*Math.sin(n)+t*Math.cos(n)]}function t$(e,t,n,r,a,i,o,l,u,d){const h=(f=o,Math.PI*f/180);var f;let m=[],b=0,y=0,v=0,w=0;if(d)[b,y,v,w]=d;else{[e,t]=Yd(e,t,-h),[n,r]=Yd(n,r,-h);const V=(e-n)/2,q=(t-r)/2;let X=V*V/(a*a)+q*q/(i*i);X>1&&(X=Math.sqrt(X),a*=X,i*=X);const $=a*a,Q=i*i,J=$*Q-$*q*q-Q*V*V,ie=$*q*q+Q*V*V,F=(l===u?-1:1)*Math.sqrt(Math.abs(J/ie));v=F*a*q/i+(e+n)/2,w=F*-i*V/a+(t+r)/2,b=Math.asin(parseFloat(((t-w)/i).toFixed(9))),y=Math.asin(parseFloat(((r-w)/i).toFixed(9))),e<v&&(b=Math.PI-b),n<v&&(y=Math.PI-y),b<0&&(b=2*Math.PI+b),y<0&&(y=2*Math.PI+y),u&&b>y&&(b-=2*Math.PI),!u&&y>b&&(y-=2*Math.PI)}let S=y-b;if(Math.abs(S)>120*Math.PI/180){const V=y,q=n,X=r;y=u&&y>b?b+120*Math.PI/180*1:b+120*Math.PI/180*-1,m=t$(n=v+a*Math.cos(y),r=w+i*Math.sin(y),q,X,a,i,o,0,u,[y,V,v,w])}S=y-b;const k=Math.cos(b),R=Math.sin(b),I=Math.cos(y),L=Math.sin(y),A=Math.tan(S/4),M=4/3*a*A,P=4/3*i*A,G=[e,t],B=[e+M*R,t-P*k],H=[n+M*L,r-P*I],Z=[n,r];if(B[0]=2*G[0]-B[0],B[1]=2*G[1]-B[1],d)return[B,H,Z].concat(m);{m=[B,H,Z].concat(m);const V=[];for(let q=0;q<m.length;q+=3){const X=Yd(m[q][0],m[q][1],h),$=Yd(m[q+1][0],m[q+1][1],h),Q=Yd(m[q+2][0],m[q+2][1],h);V.push([X[0],X[1],$[0],$[1],Q[0],Q[1]])}return V}}const Cye={randOffset:function(e,t){return ct(e,t)},randOffsetWithRange:function(e,t,n){return Gm(e,t,n)},ellipse:function(e,t,n,r,a){const i=r$(n,r,a);return A2(e,t,a,i).opset},doubleLineOps:function(e,t,n,r,a){return As(e,t,n,r,a,!0)}};function n$(e,t,n,r,a){return{type:"path",ops:As(e,t,n,r,a)}}function q0(e,t,n){const r=(e||[]).length;if(r>2){const a=[];for(let i=0;i<r-1;i++)a.push(...As(e[i][0],e[i][1],e[i+1][0],e[i+1][1],n));return t&&a.push(...As(e[r-1][0],e[r-1][1],e[0][0],e[0][1],n)),{type:"path",ops:a}}return r===2?n$(e[0][0],e[0][1],e[1][0],e[1][1],n):{type:"path",ops:[]}}function Aye(e,t,n,r,a){return(function(i,o){return q0(i,!0,o)})([[e,t],[e+n,t],[e+n,t+r],[e,t+r]],a)}function g8(e,t){if(e.length){const n=typeof e[0][0]=="number"?[e]:e,r=S0(n[0],1*(1+.2*t.roughness),t),a=t.disableMultiStroke?[]:S0(n[0],1.5*(1+.22*t.roughness),v8(t));for(let i=1;i<n.length;i++){const o=n[i];if(o.length){const l=S0(o,1*(1+.2*t.roughness),t),u=t.disableMultiStroke?[]:S0(o,1.5*(1+.22*t.roughness),v8(t));for(const d of l)d.op!=="move"&&r.push(d);for(const d of u)d.op!=="move"&&a.push(d)}}return{type:"path",ops:r.concat(a)}}return{type:"path",ops:[]}}function r$(e,t,n){const r=Math.sqrt(2*Math.PI*Math.sqrt((Math.pow(e/2,2)+Math.pow(t/2,2))/2)),a=Math.ceil(Math.max(n.curveStepCount,n.curveStepCount/Math.sqrt(200)*r)),i=2*Math.PI/a;let o=Math.abs(e/2),l=Math.abs(t/2);const u=1-n.curveFitting;return o+=ct(o*u,n),l+=ct(l*u,n),{increment:i,rx:o,ry:l}}function A2(e,t,n,r){const[a,i]=x8(r.increment,e,t,r.rx,r.ry,1,r.increment*Gm(.1,Gm(.4,1,n),n),n);let o=qm(a,null,n);if(!n.disableMultiStroke&&n.roughness!==0){const[l]=x8(r.increment,e,t,r.rx,r.ry,1.5,0,n),u=qm(l,null,n);o=o.concat(u)}return{estimatedPoints:i,opset:{type:"path",ops:o}}}function b8(e,t,n,r,a,i,o,l,u){const d=e,h=t;let f=Math.abs(n/2),m=Math.abs(r/2);f+=ct(.01*f,u),m+=ct(.01*m,u);let b=a,y=i;for(;b<0;)b+=2*Math.PI,y+=2*Math.PI;y-b>2*Math.PI&&(b=0,y=2*Math.PI);const v=2*Math.PI/u.curveStepCount,w=Math.min(v/2,(y-b)/2),S=S8(w,d,h,f,m,b,y,1,u);if(!u.disableMultiStroke){const k=S8(w,d,h,f,m,b,y,1.5,u);S.push(...k)}return o&&(l?S.push(...As(d,h,d+f*Math.cos(b),h+m*Math.sin(b),u),...As(d,h,d+f*Math.cos(y),h+m*Math.sin(y),u)):S.push({op:"lineTo",data:[d,h]},{op:"lineTo",data:[d+f*Math.cos(b),h+m*Math.sin(b)]})),{type:"path",ops:S}}function y8(e,t){const n=e$(Jz(sC(e))),r=[];let a=[0,0],i=[0,0];for(const{key:o,data:l}of n)switch(o){case"M":i=[l[0],l[1]],a=[l[0],l[1]];break;case"L":r.push(...As(i[0],i[1],l[0],l[1],t)),i=[l[0],l[1]];break;case"C":{const[u,d,h,f,m,b]=l;r.push(...Rye(u,d,h,f,m,b,i,t)),i=[m,b];break}case"Z":r.push(...As(i[0],i[1],a[0],a[1],t)),i=[a[0],a[1]]}return{type:"path",ops:r}}function Yv(e,t){const n=[];for(const r of e)if(r.length){const a=t.maxRandomnessOffset||0,i=r.length;if(i>2){n.push({op:"move",data:[r[0][0]+ct(a,t),r[0][1]+ct(a,t)]});for(let o=1;o<i;o++)n.push({op:"lineTo",data:[r[o][0]+ct(a,t),r[o][1]+ct(a,t)]})}}return{type:"fillPath",ops:n}}function Cc(e,t){return(function(n,r){let a=n.fillStyle||"hachure";if(!Xr[a])switch(a){case"zigzag":Xr[a]||(Xr[a]=new xye(r));break;case"cross-hatch":Xr[a]||(Xr[a]=new Sye(r));break;case"dots":Xr[a]||(Xr[a]=new wye(r));break;case"dashed":Xr[a]||(Xr[a]=new Eye(r));break;case"zigzag-line":Xr[a]||(Xr[a]=new kye(r));break;default:a="hachure",Xr[a]||(Xr[a]=new oC(r))}return Xr[a]})(t,Cye).fillPolygons(e,t)}function v8(e){const t=Object.assign({},e);return t.randomizer=void 0,e.seed&&(t.seed=e.seed+1),t}function a$(e){return e.randomizer||(e.randomizer=new Tye(e.seed||0)),e.randomizer.next()}function Gm(e,t,n,r=1){return n.roughness*r*(a$(n)*(t-e)+e)}function ct(e,t,n=1){return Gm(-e,e,t,n)}function As(e,t,n,r,a,i=!1){const o=i?a.disableMultiStrokeFill:a.disableMultiStroke,l=R2(e,t,n,r,a,!0,!1);if(o)return l;const u=R2(e,t,n,r,a,!0,!0);return l.concat(u)}function R2(e,t,n,r,a,i,o){const l=Math.pow(e-n,2)+Math.pow(t-r,2),u=Math.sqrt(l);let d=1;d=u<200?1:u>500?.4:-.0016668*u+1.233334;let h=a.maxRandomnessOffset||0;h*h*100>l&&(h=u/10);const f=h/2,m=.2+.2*a$(a);let b=a.bowing*a.maxRandomnessOffset*(r-t)/200,y=a.bowing*a.maxRandomnessOffset*(e-n)/200;b=ct(b,a,d),y=ct(y,a,d);const v=[],w=()=>ct(f,a,d),S=()=>ct(h,a,d),k=a.preserveVertices;return o?v.push({op:"move",data:[e+(k?0:w()),t+(k?0:w())]}):v.push({op:"move",data:[e+(k?0:ct(h,a,d)),t+(k?0:ct(h,a,d))]}),o?v.push({op:"bcurveTo",data:[b+e+(n-e)*m+w(),y+t+(r-t)*m+w(),b+e+2*(n-e)*m+w(),y+t+2*(r-t)*m+w(),n+(k?0:w()),r+(k?0:w())]}):v.push({op:"bcurveTo",data:[b+e+(n-e)*m+S(),y+t+(r-t)*m+S(),b+e+2*(n-e)*m+S(),y+t+2*(r-t)*m+S(),n+(k?0:S()),r+(k?0:S())]}),v}function S0(e,t,n){if(!e.length)return[];const r=[];r.push([e[0][0]+ct(t,n),e[0][1]+ct(t,n)]),r.push([e[0][0]+ct(t,n),e[0][1]+ct(t,n)]);for(let a=1;a<e.length;a++)r.push([e[a][0]+ct(t,n),e[a][1]+ct(t,n)]),a===e.length-1&&r.push([e[a][0]+ct(t,n),e[a][1]+ct(t,n)]);return qm(r,null,n)}function qm(e,t,n){const r=e.length,a=[];if(r>3){const i=[],o=1-n.curveTightness;a.push({op:"move",data:[e[1][0],e[1][1]]});for(let l=1;l+2<r;l++){const u=e[l];i[0]=[u[0],u[1]],i[1]=[u[0]+(o*e[l+1][0]-o*e[l-1][0])/6,u[1]+(o*e[l+1][1]-o*e[l-1][1])/6],i[2]=[e[l+1][0]+(o*e[l][0]-o*e[l+2][0])/6,e[l+1][1]+(o*e[l][1]-o*e[l+2][1])/6],i[3]=[e[l+1][0],e[l+1][1]],a.push({op:"bcurveTo",data:[i[1][0],i[1][1],i[2][0],i[2][1],i[3][0],i[3][1]]})}}else r===3?(a.push({op:"move",data:[e[1][0],e[1][1]]}),a.push({op:"bcurveTo",data:[e[1][0],e[1][1],e[2][0],e[2][1],e[2][0],e[2][1]]})):r===2&&a.push(...R2(e[0][0],e[0][1],e[1][0],e[1][1],n,!0,!0));return a}function x8(e,t,n,r,a,i,o,l){const u=[],d=[];if(l.roughness===0){e/=4,d.push([t+r*Math.cos(-e),n+a*Math.sin(-e)]);for(let h=0;h<=2*Math.PI;h+=e){const f=[t+r*Math.cos(h),n+a*Math.sin(h)];u.push(f),d.push(f)}d.push([t+r*Math.cos(0),n+a*Math.sin(0)]),d.push([t+r*Math.cos(e),n+a*Math.sin(e)])}else{const h=ct(.5,l)-Math.PI/2;d.push([ct(i,l)+t+.9*r*Math.cos(h-e),ct(i,l)+n+.9*a*Math.sin(h-e)]);const f=2*Math.PI+h-.01;for(let m=h;m<f;m+=e){const b=[ct(i,l)+t+r*Math.cos(m),ct(i,l)+n+a*Math.sin(m)];u.push(b),d.push(b)}d.push([ct(i,l)+t+r*Math.cos(h+2*Math.PI+.5*o),ct(i,l)+n+a*Math.sin(h+2*Math.PI+.5*o)]),d.push([ct(i,l)+t+.98*r*Math.cos(h+o),ct(i,l)+n+.98*a*Math.sin(h+o)]),d.push([ct(i,l)+t+.9*r*Math.cos(h+.5*o),ct(i,l)+n+.9*a*Math.sin(h+.5*o)])}return[d,u]}function S8(e,t,n,r,a,i,o,l,u){const d=i+ct(.1,u),h=[];h.push([ct(l,u)+t+.9*r*Math.cos(d-e),ct(l,u)+n+.9*a*Math.sin(d-e)]);for(let f=d;f<=o;f+=e)h.push([ct(l,u)+t+r*Math.cos(f),ct(l,u)+n+a*Math.sin(f)]);return h.push([t+r*Math.cos(o),n+a*Math.sin(o)]),h.push([t+r*Math.cos(o),n+a*Math.sin(o)]),qm(h,null,u)}function Rye(e,t,n,r,a,i,o,l){const u=[],d=[l.maxRandomnessOffset||1,(l.maxRandomnessOffset||1)+.3];let h=[0,0];const f=l.disableMultiStroke?1:2,m=l.preserveVertices;for(let b=0;b<f;b++)b===0?u.push({op:"move",data:[o[0],o[1]]}):u.push({op:"move",data:[o[0]+(m?0:ct(d[0],l)),o[1]+(m?0:ct(d[0],l))]}),h=m?[a,i]:[a+ct(d[b],l),i+ct(d[b],l)],u.push({op:"bcurveTo",data:[e+ct(d[b],l),t+ct(d[b],l),n+ct(d[b],l),r+ct(d[b],l),h[0],h[1]]});return u}function Xd(e){return[...e]}function w8(e,t=0){const n=e.length;if(n<3)throw new Error("A curve must have at least three points.");const r=[];if(n===3)r.push(Xd(e[0]),Xd(e[1]),Xd(e[2]),Xd(e[2]));else{const a=[];a.push(e[0],e[0]);for(let l=1;l<e.length;l++)a.push(e[l]),l===e.length-1&&a.push(e[l]);const i=[],o=1-t;r.push(Xd(a[0]));for(let l=1;l+2<a.length;l++){const u=a[l];i[0]=[u[0],u[1]],i[1]=[u[0]+(o*a[l+1][0]-o*a[l-1][0])/6,u[1]+(o*a[l+1][1]-o*a[l-1][1])/6],i[2]=[a[l+1][0]+(o*a[l][0]-o*a[l+2][0])/6,a[l+1][1]+(o*a[l][1]-o*a[l+2][1])/6],i[3]=[a[l+1][0],a[l+1][1]],r.push(i[1],i[2],i[3])}}return r}function W0(e,t){return Math.pow(e[0]-t[0],2)+Math.pow(e[1]-t[1],2)}function Nye(e,t,n){const r=W0(t,n);if(r===0)return W0(e,t);let a=((e[0]-t[0])*(n[0]-t[0])+(e[1]-t[1])*(n[1]-t[1]))/r;return a=Math.max(0,Math.min(1,a)),W0(e,sl(t,n,a))}function sl(e,t,n){return[e[0]+(t[0]-e[0])*n,e[1]+(t[1]-e[1])*n]}function N2(e,t,n,r){const a=r||[];if((function(l,u){const d=l[u+0],h=l[u+1],f=l[u+2],m=l[u+3];let b=3*h[0]-2*d[0]-m[0];b*=b;let y=3*h[1]-2*d[1]-m[1];y*=y;let v=3*f[0]-2*m[0]-d[0];v*=v;let w=3*f[1]-2*m[1]-d[1];return w*=w,b<v&&(b=v),y<w&&(y=w),b+y})(e,t)<n){const l=e[t+0];a.length?(i=a[a.length-1],o=l,Math.sqrt(W0(i,o))>1&&a.push(l)):a.push(l),a.push(e[t+3])}else{const u=e[t+0],d=e[t+1],h=e[t+2],f=e[t+3],m=sl(u,d,.5),b=sl(d,h,.5),y=sl(h,f,.5),v=sl(m,b,.5),w=sl(b,y,.5),S=sl(v,w,.5);N2([u,m,v,S],0,n,a),N2([S,w,y,f],0,n,a)}var i,o;return a}function Oye(e,t){return Wm(e,0,e.length,t)}function Wm(e,t,n,r,a){const i=a||[],o=e[t],l=e[n-1];let u=0,d=1;for(let h=t+1;h<n-1;++h){const f=Nye(e[h],o,l);f>u&&(u=f,d=h)}return Math.sqrt(u)>r?(Wm(e,t,d+1,r,i),Wm(e,d,n,r,i)):(i.length||i.push(o),i.push(l)),i}function Xv(e,t=.15,n){const r=[],a=(e.length-1)/3;for(let i=0;i<a;i++)N2(e,3*i,t,r);return n&&n>0?Wm(r,0,r.length,n):r}const ua="none";class Vm{constructor(t){this.defaultOptions={maxRandomnessOffset:2,roughness:1,bowing:1,stroke:"#000",strokeWidth:1,curveTightness:0,curveFitting:.95,curveStepCount:9,fillStyle:"hachure",fillWeight:-1,hachureAngle:-41,hachureGap:-1,dashOffset:-1,dashGap:-1,zigzagOffset:-1,seed:0,disableMultiStroke:!1,disableMultiStrokeFill:!1,preserveVertices:!1,fillShapeRoughnessGain:.8},this.config=t||{},this.config.options&&(this.defaultOptions=this._o(this.config.options))}static newSeed(){return Math.floor(Math.random()*2**31)}_o(t){return t?Object.assign({},this.defaultOptions,t):this.defaultOptions}_d(t,n,r){return{shape:t,sets:n||[],options:r||this.defaultOptions}}line(t,n,r,a,i){const o=this._o(i);return this._d("line",[n$(t,n,r,a,o)],o)}rectangle(t,n,r,a,i){const o=this._o(i),l=[],u=Aye(t,n,r,a,o);if(o.fill){const d=[[t,n],[t+r,n],[t+r,n+a],[t,n+a]];o.fillStyle==="solid"?l.push(Yv([d],o)):l.push(Cc([d],o))}return o.stroke!==ua&&l.push(u),this._d("rectangle",l,o)}ellipse(t,n,r,a,i){const o=this._o(i),l=[],u=r$(r,a,o),d=A2(t,n,o,u);if(o.fill)if(o.fillStyle==="solid"){const h=A2(t,n,o,u).opset;h.type="fillPath",l.push(h)}else l.push(Cc([d.estimatedPoints],o));return o.stroke!==ua&&l.push(d.opset),this._d("ellipse",l,o)}circle(t,n,r,a){const i=this.ellipse(t,n,r,r,a);return i.shape="circle",i}linearPath(t,n){const r=this._o(n);return this._d("linearPath",[q0(t,!1,r)],r)}arc(t,n,r,a,i,o,l=!1,u){const d=this._o(u),h=[],f=b8(t,n,r,a,i,o,l,!0,d);if(l&&d.fill)if(d.fillStyle==="solid"){const m=Object.assign({},d);m.disableMultiStroke=!0;const b=b8(t,n,r,a,i,o,!0,!1,m);b.type="fillPath",h.push(b)}else h.push((function(m,b,y,v,w,S,k){const R=m,I=b;let L=Math.abs(y/2),A=Math.abs(v/2);L+=ct(.01*L,k),A+=ct(.01*A,k);let M=w,P=S;for(;M<0;)M+=2*Math.PI,P+=2*Math.PI;P-M>2*Math.PI&&(M=0,P=2*Math.PI);const G=(P-M)/k.curveStepCount,B=[];for(let H=M;H<=P;H+=G)B.push([R+L*Math.cos(H),I+A*Math.sin(H)]);return B.push([R+L*Math.cos(P),I+A*Math.sin(P)]),B.push([R,I]),Cc([B],k)})(t,n,r,a,i,o,d));return d.stroke!==ua&&h.push(f),this._d("arc",h,d)}curve(t,n){const r=this._o(n),a=[],i=g8(t,r);if(r.fill&&r.fill!==ua)if(r.fillStyle==="solid"){const o=g8(t,Object.assign(Object.assign({},r),{disableMultiStroke:!0,roughness:r.roughness?r.roughness+r.fillShapeRoughnessGain:0}));a.push({type:"fillPath",ops:this._mergedShape(o.ops)})}else{const o=[],l=t;if(l.length){const u=typeof l[0][0]=="number"?[l]:l;for(const d of u)d.length<3?o.push(...d):d.length===3?o.push(...Xv(w8([d[0],d[0],d[1],d[2]]),10,(1+r.roughness)/2)):o.push(...Xv(w8(d),10,(1+r.roughness)/2))}o.length&&a.push(Cc([o],r))}return r.stroke!==ua&&a.push(i),this._d("curve",a,r)}polygon(t,n){const r=this._o(n),a=[],i=q0(t,!0,r);return r.fill&&(r.fillStyle==="solid"?a.push(Yv([t],r)):a.push(Cc([t],r))),r.stroke!==ua&&a.push(i),this._d("polygon",a,r)}path(t,n){const r=this._o(n),a=[];if(!t)return this._d("path",a,r);t=(t||"").replace(/\n/g," ").replace(/(-\s)/g,"-").replace("/(ss)/g"," ");const i=r.fill&&r.fill!=="transparent"&&r.fill!==ua,o=r.stroke!==ua,l=!!(r.simplification&&r.simplification<1),u=(function(h,f,m){const b=e$(Jz(sC(h))),y=[];let v=[],w=[0,0],S=[];const k=()=>{S.length>=4&&v.push(...Xv(S,f)),S=[]},R=()=>{k(),v.length&&(y.push(v),v=[])};for(const{key:L,data:A}of b)switch(L){case"M":R(),w=[A[0],A[1]],v.push(w);break;case"L":k(),v.push([A[0],A[1]]);break;case"C":if(!S.length){const M=v.length?v[v.length-1]:w;S.push([M[0],M[1]])}S.push([A[0],A[1]]),S.push([A[2],A[3]]),S.push([A[4],A[5]]);break;case"Z":k(),v.push([w[0],w[1]])}if(R(),!m)return y;const I=[];for(const L of y){const A=Oye(L,m);A.length&&I.push(A)}return I})(t,1,l?4-4*(r.simplification||1):(1+r.roughness)/2),d=y8(t,r);if(i)if(r.fillStyle==="solid")if(u.length===1){const h=y8(t,Object.assign(Object.assign({},r),{disableMultiStroke:!0,roughness:r.roughness?r.roughness+r.fillShapeRoughnessGain:0}));a.push({type:"fillPath",ops:this._mergedShape(h.ops)})}else a.push(Yv(u,r));else a.push(Cc(u,r));return o&&(l?u.forEach((h=>{a.push(q0(h,!1,r))})):a.push(d)),this._d("path",a,r)}opsToPath(t,n){let r="";for(const a of t.ops){const i=typeof n=="number"&&n>=0?a.data.map((o=>+o.toFixed(n))):a.data;switch(a.op){case"move":r+=`M${i[0]} ${i[1]} `;break;case"bcurveTo":r+=`C${i[0]} ${i[1]}, ${i[2]} ${i[3]}, ${i[4]} ${i[5]} `;break;case"lineTo":r+=`L${i[0]} ${i[1]} `}}return r.trim()}toPaths(t){const n=t.sets||[],r=t.options||this.defaultOptions,a=[];for(const i of n){let o=null;switch(i.type){case"path":o={d:this.opsToPath(i),stroke:r.stroke,strokeWidth:r.strokeWidth,fill:ua};break;case"fillPath":o={d:this.opsToPath(i),stroke:ua,strokeWidth:0,fill:r.fill||ua};break;case"fillSketch":o=this.fillSketch(i,r)}o&&a.push(o)}return a}fillSketch(t,n){let r=n.fillWeight;return r<0&&(r=n.strokeWidth/2),{d:this.opsToPath(t),stroke:n.fill||ua,strokeWidth:r,fill:ua}}_mergedShape(t){return t.filter(((n,r)=>r===0||n.op!=="move"))}}class Iye{constructor(t,n){this.canvas=t,this.ctx=this.canvas.getContext("2d"),this.gen=new Vm(n)}draw(t){const n=t.sets||[],r=t.options||this.getDefaultOptions(),a=this.ctx,i=t.options.fixedDecimalPlaceDigits;for(const o of n)switch(o.type){case"path":a.save(),a.strokeStyle=r.stroke==="none"?"transparent":r.stroke,a.lineWidth=r.strokeWidth,r.strokeLineDash&&a.setLineDash(r.strokeLineDash),r.strokeLineDashOffset&&(a.lineDashOffset=r.strokeLineDashOffset),this._drawToContext(a,o,i),a.restore();break;case"fillPath":{a.save(),a.fillStyle=r.fill||"";const l=t.shape==="curve"||t.shape==="polygon"||t.shape==="path"?"evenodd":"nonzero";this._drawToContext(a,o,i,l),a.restore();break}case"fillSketch":this.fillSketch(a,o,r)}}fillSketch(t,n,r){let a=r.fillWeight;a<0&&(a=r.strokeWidth/2),t.save(),r.fillLineDash&&t.setLineDash(r.fillLineDash),r.fillLineDashOffset&&(t.lineDashOffset=r.fillLineDashOffset),t.strokeStyle=r.fill||"",t.lineWidth=a,this._drawToContext(t,n,r.fixedDecimalPlaceDigits),t.restore()}_drawToContext(t,n,r,a="nonzero"){t.beginPath();for(const i of n.ops){const o=typeof r=="number"&&r>=0?i.data.map((l=>+l.toFixed(r))):i.data;switch(i.op){case"move":t.moveTo(o[0],o[1]);break;case"bcurveTo":t.bezierCurveTo(o[0],o[1],o[2],o[3],o[4],o[5]);break;case"lineTo":t.lineTo(o[0],o[1])}}n.type==="fillPath"?t.fill(a):t.stroke()}get generator(){return this.gen}getDefaultOptions(){return this.gen.defaultOptions}line(t,n,r,a,i){const o=this.gen.line(t,n,r,a,i);return this.draw(o),o}rectangle(t,n,r,a,i){const o=this.gen.rectangle(t,n,r,a,i);return this.draw(o),o}ellipse(t,n,r,a,i){const o=this.gen.ellipse(t,n,r,a,i);return this.draw(o),o}circle(t,n,r,a){const i=this.gen.circle(t,n,r,a);return this.draw(i),i}linearPath(t,n){const r=this.gen.linearPath(t,n);return this.draw(r),r}polygon(t,n){const r=this.gen.polygon(t,n);return this.draw(r),r}arc(t,n,r,a,i,o,l=!1,u){const d=this.gen.arc(t,n,r,a,i,o,l,u);return this.draw(d),d}curve(t,n){const r=this.gen.curve(t,n);return this.draw(r),r}path(t,n){const r=this.gen.path(t,n);return this.draw(r),r}}const w0="http://www.w3.org/2000/svg";class Lye{constructor(t,n){this.svg=t,this.gen=new Vm(n)}draw(t){const n=t.sets||[],r=t.options||this.getDefaultOptions(),a=this.svg.ownerDocument||window.document,i=a.createElementNS(w0,"g"),o=t.options.fixedDecimalPlaceDigits;for(const l of n){let u=null;switch(l.type){case"path":u=a.createElementNS(w0,"path"),u.setAttribute("d",this.opsToPath(l,o)),u.setAttribute("stroke",r.stroke),u.setAttribute("stroke-width",r.strokeWidth+""),u.setAttribute("fill","none"),r.strokeLineDash&&u.setAttribute("stroke-dasharray",r.strokeLineDash.join(" ").trim()),r.strokeLineDashOffset&&u.setAttribute("stroke-dashoffset",`${r.strokeLineDashOffset}`);break;case"fillPath":u=a.createElementNS(w0,"path"),u.setAttribute("d",this.opsToPath(l,o)),u.setAttribute("stroke","none"),u.setAttribute("stroke-width","0"),u.setAttribute("fill",r.fill||""),t.shape!=="curve"&&t.shape!=="polygon"||u.setAttribute("fill-rule","evenodd");break;case"fillSketch":u=this.fillSketch(a,l,r)}u&&i.appendChild(u)}return i}fillSketch(t,n,r){let a=r.fillWeight;a<0&&(a=r.strokeWidth/2);const i=t.createElementNS(w0,"path");return i.setAttribute("d",this.opsToPath(n,r.fixedDecimalPlaceDigits)),i.setAttribute("stroke",r.fill||""),i.setAttribute("stroke-width",a+""),i.setAttribute("fill","none"),r.fillLineDash&&i.setAttribute("stroke-dasharray",r.fillLineDash.join(" ").trim()),r.fillLineDashOffset&&i.setAttribute("stroke-dashoffset",`${r.fillLineDashOffset}`),i}get generator(){return this.gen}getDefaultOptions(){return this.gen.defaultOptions}opsToPath(t,n){return this.gen.opsToPath(t,n)}line(t,n,r,a,i){const o=this.gen.line(t,n,r,a,i);return this.draw(o)}rectangle(t,n,r,a,i){const o=this.gen.rectangle(t,n,r,a,i);return this.draw(o)}ellipse(t,n,r,a,i){const o=this.gen.ellipse(t,n,r,a,i);return this.draw(o)}circle(t,n,r,a){const i=this.gen.circle(t,n,r,a);return this.draw(i)}linearPath(t,n){const r=this.gen.linearPath(t,n);return this.draw(r)}polygon(t,n){const r=this.gen.polygon(t,n);return this.draw(r)}arc(t,n,r,a,i,o,l=!1,u){const d=this.gen.arc(t,n,r,a,i,o,l,u);return this.draw(d)}curve(t,n){const r=this.gen.curve(t,n);return this.draw(r)}path(t,n){const r=this.gen.path(t,n);return this.draw(r)}}var Ge={canvas:(e,t)=>new Iye(e,t),svg:(e,t)=>new Lye(e,t),generator:e=>new Vm(e),newSeed:()=>Vm.newSeed()},lt=N(async(e,t,n)=>{var b,y;let r;const a=t.useHtmlLabels||Ds((b=qt())==null?void 0:b.htmlLabels);n?r=n:r="node default";const i=e.insert("g").attr("class",r).attr("id",t.domId||t.id),o=i.insert("g").attr("class","label").attr("style",vr(t.labelStyle));let l;t.label===void 0?l="":l=typeof t.label=="string"?t.label:t.label[0];const u=!!t.icon||!!t.img,d=t.labelType==="markdown",h=await Do(o,li(Ou(l),qt()),{useHtmlLabels:a,width:t.width||((y=qt().flowchart)==null?void 0:y.wrappingWidth),cssClasses:d?"markdown-node-label":void 0,style:t.labelStyle,addSvgBackground:u,markdown:d},qt());let f=h.getBBox();const m=((t==null?void 0:t.padding)??0)/2;if(a){const v=h.children[0],w=Et(h);await kz(v,l),f=v.getBoundingClientRect(),w.attr("width",f.width),w.attr("height",f.height)}return a?o.attr("transform","translate("+-f.width/2+", "+-f.height/2+")"):o.attr("transform","translate(0, "+-f.height/2+")"),t.centerLabel&&o.attr("transform","translate("+-f.width/2+", "+-f.height/2+")"),o.insert("rect",":first-child"),{shapeSvg:i,bbox:f,halfPadding:m,label:o}},"labelHelper"),Kv=N(async(e,t,n)=>{var u,d;const r=n.useHtmlLabels??xr(qt()),a=e.insert("g").attr("class","label").attr("style",n.labelStyle||""),i=await Do(a,li(Ou(t),qt()),{useHtmlLabels:r,width:n.width||((d=(u=qt())==null?void 0:u.flowchart)==null?void 0:d.wrappingWidth),style:n.labelStyle,addSvgBackground:!!n.icon||!!n.img});let o=i.getBBox();const l=n.padding/2;if(xr(qt())){const h=i.children[0],f=Et(i);o=h.getBoundingClientRect(),f.attr("width",o.width),f.attr("height",o.height)}return r?a.attr("transform","translate("+-o.width/2+", "+-o.height/2+")"):a.attr("transform","translate(0, "+-o.height/2+")"),n.centerLabel&&a.attr("transform","translate("+-o.width/2+", "+-o.height/2+")"),a.insert("rect",":first-child"),{shapeSvg:e,bbox:o,halfPadding:l,label:a}},"insertLabel"),Qe=N((e,t)=>{const n=t.node().getBBox();e.width=n.width,e.height=n.height},"updateNodeBounds"),it=N((e,t)=>(e.look==="handDrawn"?"rough-node":"node")+" "+e.cssClasses+" "+(t||""),"getNodeClasses");function Ft(e){const t=e.map((n,r)=>`${r===0?"M":"L"}${n.x},${n.y}`);return t.push("Z"),t.join(" ")}N(Ft,"createPathFromPoints");function Rs(e,t,n,r,a,i){const o=[],u=n-e,d=r-t,h=u/i,f=2*Math.PI/h,m=t+d/2;for(let b=0;b<=50;b++){const y=b/50,v=e+y*u,w=m+a*Math.sin(f*(v-e));o.push({x:v,y:w})}return o}N(Rs,"generateFullSineWavePoints");function jh(e,t,n,r,a,i){const o=[],l=a*Math.PI/180,h=(i*Math.PI/180-l)/(r-1);for(let f=0;f<r;f++){const m=l+f*h,b=e+n*Math.cos(m),y=t+n*Math.sin(m);o.push({x:-b,y:-y})}return o}N(jh,"generateCirclePoints");var Dye=N((e,t)=>{var n=e.x,r=e.y,a=t.x-n,i=t.y-r,o=e.width/2,l=e.height/2,u,d;return Math.abs(i)*o>Math.abs(a)*l?(i<0&&(l=-l),u=i===0?0:l*a/i,d=l):(a<0&&(o=-o),u=o,d=a===0?0:o*i/a),{x:n+u,y:r+d}},"intersectRect"),Lu=Dye,Mye=N(async(e,t,n,r=!1,a=!1)=>{let i=t||"";typeof i=="object"&&(i=i[0]);const o=qt(),l=xr(o);return await Do(e,i,{style:n,isTitle:r,useHtmlLabels:l,markdown:!1,isNode:a,width:Number.POSITIVE_INFINITY},o)},"createLabel"),bs=Mye,Bs=N((e,t,n,r,a)=>["M",e+a,t,"H",e+n-a,"A",a,a,0,0,1,e+n,t+a,"V",t+r-a,"A",a,a,0,0,1,e+n-a,t+r,"H",e+a,"A",a,a,0,0,1,e,t+r-a,"V",t+a,"A",a,a,0,0,1,e+a,t,"Z"].join(" "),"createRoundedRectPathD"),i$=N(async(e,t)=>{we.info("Creating subgraph rect for ",t.id,t);const n=qt(),{themeVariables:r,handDrawnSeed:a}=n,{clusterBkg:i,clusterBorder:o}=r,{labelStyles:l,nodeStyles:u,borderStyles:d,backgroundStyles:h}=Ye(t),f=e.insert("g").attr("class","cluster "+t.cssClasses).attr("id",t.id).attr("data-look",t.look),m=xr(n),b=f.insert("g").attr("class","cluster-label ");let y;t.labelType==="markdown"?y=await Do(b,t.label,{style:t.labelStyle,useHtmlLabels:m,isNode:!0,width:t.width}):y=await bs(b,t.label,t.labelStyle||"",!1,!0);let v=y.getBBox();if(xr(n)){const M=y.children[0],P=Et(y);v=M.getBoundingClientRect(),P.attr("width",v.width),P.attr("height",v.height)}const w=t.width<=v.width+t.padding?v.width+t.padding:t.width;t.width<=v.width+t.padding?t.diff=(w-t.width)/2-t.padding:t.diff=-t.padding;const S=t.height,k=t.x-w/2,R=t.y-S/2;we.trace("Data ",t,JSON.stringify(t));let I;if(t.look==="handDrawn"){const M=Ge.svg(f),P=Ve(t,{roughness:.7,fill:i,stroke:o,fillWeight:3,seed:a}),G=M.path(Bs(k,R,w,S,0),P);I=f.insert(()=>(we.debug("Rough node insert CXC",G),G),":first-child"),I.select("path:nth-child(2)").attr("style",d.join(";")),I.select("path").attr("style",h.join(";").replace("fill","stroke"))}else I=f.insert("rect",":first-child"),I.attr("style",u).attr("rx",t.rx).attr("ry",t.ry).attr("x",k).attr("y",R).attr("width",w).attr("height",S);const{subGraphTitleTopMargin:L}=X_(n);if(b.attr("transform",`translate(${t.x-v.width/2}, ${t.y-t.height/2+L})`),l){const M=b.select("span");M&&M.attr("style",l)}const A=I.node().getBBox();return t.offsetX=0,t.width=A.width,t.height=A.height,t.offsetY=v.height-t.padding/2,t.intersect=function(M){return Lu(t,M)},{cluster:f,labelBBox:v}},"rect"),Bye=N((e,t)=>{const n=e.insert("g").attr("class","note-cluster").attr("id",t.id),r=n.insert("rect",":first-child"),a=0*t.padding,i=a/2;r.attr("rx",t.rx).attr("ry",t.ry).attr("x",t.x-t.width/2-i).attr("y",t.y-t.height/2-i).attr("width",t.width+a).attr("height",t.height+a).attr("fill","none");const o=r.node().getBBox();return t.width=o.width,t.height=o.height,t.intersect=function(l){return Lu(t,l)},{cluster:n,labelBBox:{width:0,height:0}}},"noteGroup"),Fye=N(async(e,t)=>{const n=qt(),{themeVariables:r,handDrawnSeed:a}=n,{altBackground:i,compositeBackground:o,compositeTitleBackground:l,nodeBorder:u}=r,d=e.insert("g").attr("class",t.cssClasses).attr("id",t.id).attr("data-id",t.id).attr("data-look",t.look),h=d.insert("g",":first-child"),f=d.insert("g").attr("class","cluster-label");let m=d.append("rect");const b=await bs(f,t.label,t.labelStyle,void 0,!0);let y=b.getBBox();if(xr(n)){const G=b.children[0],B=Et(b);y=G.getBoundingClientRect(),B.attr("width",y.width),B.attr("height",y.height)}const v=0*t.padding,w=v/2,S=(t.width<=y.width+t.padding?y.width+t.padding:t.width)+v;t.width<=y.width+t.padding?t.diff=(S-t.width)/2-t.padding:t.diff=-t.padding;const k=t.height+v,R=t.height+v-y.height-6,I=t.x-S/2,L=t.y-k/2;t.width=S;const A=t.y-t.height/2-w+y.height+2;let M;if(t.look==="handDrawn"){const G=t.cssClasses.includes("statediagram-cluster-alt"),B=Ge.svg(d),H=t.rx||t.ry?B.path(Bs(I,L,S,k,10),{roughness:.7,fill:l,fillStyle:"solid",stroke:u,seed:a}):B.rectangle(I,L,S,k,{seed:a});M=d.insert(()=>H,":first-child");const Z=B.rectangle(I,A,S,R,{fill:G?i:o,fillStyle:G?"hachure":"solid",stroke:u,seed:a});M=d.insert(()=>H,":first-child"),m=d.insert(()=>Z)}else M=h.insert("rect",":first-child"),M.attr("class","outer").attr("x",I).attr("y",L).attr("width",S).attr("height",k).attr("data-look",t.look),m.attr("class","inner").attr("x",I).attr("y",A).attr("width",S).attr("height",R);f.attr("transform",`translate(${t.x-y.width/2}, ${L+1-(xr(n)?0:3)})`);const P=M.node().getBBox();return t.height=P.height,t.offsetX=0,t.offsetY=y.height-t.padding/2,t.labelBBox=y,t.intersect=function(G){return Lu(t,G)},{cluster:d,labelBBox:y}},"roundedWithTitle"),zye=N(async(e,t)=>{we.info("Creating subgraph rect for ",t.id,t);const n=qt(),{themeVariables:r,handDrawnSeed:a}=n,{clusterBkg:i,clusterBorder:o}=r,{labelStyles:l,nodeStyles:u,borderStyles:d,backgroundStyles:h}=Ye(t),f=e.insert("g").attr("class","cluster "+t.cssClasses).attr("id",t.id).attr("data-look",t.look),m=xr(n),b=f.insert("g").attr("class","cluster-label "),y=await Do(b,t.label,{style:t.labelStyle,useHtmlLabels:m,isNode:!0,width:t.width});let v=y.getBBox();if(xr(n)){const M=y.children[0],P=Et(y);v=M.getBoundingClientRect(),P.attr("width",v.width),P.attr("height",v.height)}const w=t.width<=v.width+t.padding?v.width+t.padding:t.width;t.width<=v.width+t.padding?t.diff=(w-t.width)/2-t.padding:t.diff=-t.padding;const S=t.height,k=t.x-w/2,R=t.y-S/2;we.trace("Data ",t,JSON.stringify(t));let I;if(t.look==="handDrawn"){const M=Ge.svg(f),P=Ve(t,{roughness:.7,fill:i,stroke:o,fillWeight:4,seed:a}),G=M.path(Bs(k,R,w,S,t.rx),P);I=f.insert(()=>(we.debug("Rough node insert CXC",G),G),":first-child"),I.select("path:nth-child(2)").attr("style",d.join(";")),I.select("path").attr("style",h.join(";").replace("fill","stroke"))}else I=f.insert("rect",":first-child"),I.attr("style",u).attr("rx",t.rx).attr("ry",t.ry).attr("x",k).attr("y",R).attr("width",w).attr("height",S);const{subGraphTitleTopMargin:L}=X_(n);if(b.attr("transform",`translate(${t.x-v.width/2}, ${t.y-t.height/2+L})`),l){const M=b.select("span");M&&M.attr("style",l)}const A=I.node().getBBox();return t.offsetX=0,t.width=A.width,t.height=A.height,t.offsetY=v.height-t.padding/2,t.intersect=function(M){return Lu(t,M)},{cluster:f,labelBBox:v}},"kanbanSection"),$ye=N((e,t)=>{const n=qt(),{themeVariables:r,handDrawnSeed:a}=n,{nodeBorder:i}=r,o=e.insert("g").attr("class",t.cssClasses).attr("id",t.id).attr("data-look",t.look),l=o.insert("g",":first-child"),u=0*t.padding,d=t.width+u;t.diff=-t.padding;const h=t.height+u,f=t.x-d/2,m=t.y-h/2;t.width=d;let b;if(t.look==="handDrawn"){const w=Ge.svg(o).rectangle(f,m,d,h,{fill:"lightgrey",roughness:.5,strokeLineDash:[5],stroke:i,seed:a});b=o.insert(()=>w,":first-child")}else b=l.insert("rect",":first-child"),b.attr("class","divider").attr("x",f).attr("y",m).attr("width",d).attr("height",h).attr("data-look",t.look);const y=b.node().getBBox();return t.height=y.height,t.offsetX=0,t.offsetY=0,t.intersect=function(v){return Lu(t,v)},{cluster:o,labelBBox:{}}},"divider"),Pye=i$,Uye={rect:i$,squareRect:Pye,roundedWithTitle:Fye,noteGroup:Bye,divider:$ye,kanbanSection:zye},o$=new Map,jye=N(async(e,t)=>{const n=t.shape||"rect",r=await Uye[n](e,t);return o$.set(t.id,r),r},"insertCluster"),NEe=N(()=>{o$=new Map},"clear");function s$(e,t){return e.intersect(t)}N(s$,"intersectNode");var Hye=s$;function l$(e,t,n,r){var a=e.x,i=e.y,o=a-r.x,l=i-r.y,u=Math.sqrt(t*t*l*l+n*n*o*o),d=Math.abs(t*n*o/u);r.x<a&&(d=-d);var h=Math.abs(t*n*l/u);return r.y<i&&(h=-h),{x:a+d,y:i+h}}N(l$,"intersectEllipse");var c$=l$;function u$(e,t,n){return c$(e,t,t,n)}N(u$,"intersectCircle");var Gye=u$;function d$(e,t,n,r){{const a=t.y-e.y,i=e.x-t.x,o=t.x*e.y-e.x*t.y,l=a*n.x+i*n.y+o,u=a*r.x+i*r.y+o,d=1e-6;if(l!==0&&u!==0&&O2(l,u))return;const h=r.y-n.y,f=n.x-r.x,m=r.x*n.y-n.x*r.y,b=h*e.x+f*e.y+m,y=h*t.x+f*t.y+m;if(Math.abs(b)<d&&Math.abs(y)<d&&O2(b,y))return;const v=a*f-h*i;if(v===0)return;const w=Math.abs(v/2);let S=i*m-f*o;const k=S<0?(S-w)/v:(S+w)/v;S=h*o-a*m;const R=S<0?(S-w)/v:(S+w)/v;return{x:k,y:R}}}N(d$,"intersectLine");function O2(e,t){return e*t>0}N(O2,"sameSign");var qye=d$;function h$(e,t,n){let r=e.x,a=e.y,i=[],o=Number.POSITIVE_INFINITY,l=Number.POSITIVE_INFINITY;typeof t.forEach=="function"?t.forEach(function(h){o=Math.min(o,h.x),l=Math.min(l,h.y)}):(o=Math.min(o,t.x),l=Math.min(l,t.y));let u=r-e.width/2-o,d=a-e.height/2-l;for(let h=0;h<t.length;h++){let f=t[h],m=t[h<t.length-1?h+1:0],b=qye(e,n,{x:u+f.x,y:d+f.y},{x:u+m.x,y:d+m.y});b&&i.push(b)}return i.length?(i.length>1&&i.sort(function(h,f){let m=h.x-n.x,b=h.y-n.y,y=Math.sqrt(m*m+b*b),v=f.x-n.x,w=f.y-n.y,S=Math.sqrt(v*v+w*w);return y<S?-1:y===S?0:1}),i[0]):e}N(h$,"intersectPolygon");var Wye=h$,Fe={node:Hye,circle:Gye,ellipse:c$,polygon:Wye,rect:Lu};function p$(e,t){const{labelStyles:n}=Ye(t);t.labelStyle=n;const r=it(t);let a=r;r||(a="anchor");const i=e.insert("g").attr("class",a).attr("id",t.domId||t.id),o=1,{cssStyles:l}=t,u=Ge.svg(i),d=Ve(t,{fill:"black",stroke:"none",fillStyle:"solid"});t.look!=="handDrawn"&&(d.roughness=0);const h=u.circle(0,0,o*2,d),f=i.insert(()=>h,":first-child");return f.attr("class","anchor").attr("style",vr(l)),Qe(t,f),t.intersect=function(m){return we.info("Circle intersect",t,o,m),Fe.circle(t,o,m)},i}N(p$,"anchor");function I2(e,t,n,r,a,i,o){const u=(e+n)/2,d=(t+r)/2,h=Math.atan2(r-t,n-e),f=(n-e)/2,m=(r-t)/2,b=f/a,y=m/i,v=Math.sqrt(b**2+y**2);if(v>1)throw new Error("The given radii are too small to create an arc between the points.");const w=Math.sqrt(1-v**2),S=u+w*i*Math.sin(h)*(o?-1:1),k=d-w*a*Math.cos(h)*(o?-1:1),R=Math.atan2((t-k)/i,(e-S)/a);let L=Math.atan2((r-k)/i,(n-S)/a)-R;o&&L<0&&(L+=2*Math.PI),!o&&L>0&&(L-=2*Math.PI);const A=[];for(let M=0;M<20;M++){const P=M/19,G=R+P*L,B=S+a*Math.cos(G),H=k+i*Math.sin(G);A.push({x:B,y:H})}return A}N(I2,"generateArcPoints");async function f$(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i}=await lt(e,t,it(t)),o=i.width+t.padding+20,l=i.height+t.padding,u=l/2,d=u/(2.5+l/50),{cssStyles:h}=t,f=[{x:o/2,y:-l/2},{x:-o/2,y:-l/2},...I2(-o/2,-l/2,-o/2,l/2,d,u,!1),{x:o/2,y:l/2},...I2(o/2,l/2,o/2,-l/2,d,u,!0)],m=Ge.svg(a),b=Ve(t,{});t.look!=="handDrawn"&&(b.roughness=0,b.fillStyle="solid");const y=Ft(f),v=m.path(y,b),w=a.insert(()=>v,":first-child");return w.attr("class","basic label-container"),h&&t.look!=="handDrawn"&&w.selectAll("path").attr("style",h),r&&t.look!=="handDrawn"&&w.selectAll("path").attr("style",r),w.attr("transform",`translate(${d/2}, 0)`),Qe(t,w),t.intersect=function(S){return Fe.polygon(t,f,S)},a}N(f$,"bowTieRect");function Mo(e,t,n,r){return e.insert("polygon",":first-child").attr("points",r.map(function(a){return a.x+","+a.y}).join(" ")).attr("class","label-container").attr("transform","translate("+-t/2+","+n/2+")")}N(Mo,"insertPolygonShape");async function m$(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i}=await lt(e,t,it(t)),o=i.height+t.padding,l=12,u=i.width+t.padding+l,d=0,h=u,f=-o,m=0,b=[{x:d+l,y:f},{x:h,y:f},{x:h,y:m},{x:d,y:m},{x:d,y:f+l},{x:d+l,y:f}];let y;const{cssStyles:v}=t;if(t.look==="handDrawn"){const w=Ge.svg(a),S=Ve(t,{}),k=Ft(b),R=w.path(k,S);y=a.insert(()=>R,":first-child").attr("transform",`translate(${-u/2}, ${o/2})`),v&&y.attr("style",v)}else y=Mo(a,u,o,b);return r&&y.attr("style",r),Qe(t,y),t.intersect=function(w){return Fe.polygon(t,b,w)},a}N(m$,"card");function g$(e,t){const{nodeStyles:n}=Ye(t);t.label="";const r=e.insert("g").attr("class",it(t)).attr("id",t.domId??t.id),{cssStyles:a}=t,i=Math.max(28,t.width??0),o=[{x:0,y:i/2},{x:i/2,y:0},{x:0,y:-i/2},{x:-i/2,y:0}],l=Ge.svg(r),u=Ve(t,{});t.look!=="handDrawn"&&(u.roughness=0,u.fillStyle="solid");const d=Ft(o),h=l.path(d,u),f=r.insert(()=>h,":first-child");return a&&t.look!=="handDrawn"&&f.selectAll("path").attr("style",a),n&&t.look!=="handDrawn"&&f.selectAll("path").attr("style",n),t.width=28,t.height=28,t.intersect=function(m){return Fe.polygon(t,o,m)},r}N(g$,"choice");async function lC(e,t,n){const{labelStyles:r,nodeStyles:a}=Ye(t);t.labelStyle=r;const{shapeSvg:i,bbox:o,halfPadding:l}=await lt(e,t,it(t)),u=(n==null?void 0:n.padding)??l,d=o.width/2+u;let h;const{cssStyles:f}=t;if(t.look==="handDrawn"){const m=Ge.svg(i),b=Ve(t,{}),y=m.circle(0,0,d*2,b);h=i.insert(()=>y,":first-child"),h.attr("class","basic label-container").attr("style",vr(f))}else h=i.insert("circle",":first-child").attr("class","basic label-container").attr("style",a).attr("r",d).attr("cx",0).attr("cy",0);return Qe(t,h),t.calcIntersect=function(m,b){const y=m.width/2;return Fe.circle(m,y,b)},t.intersect=function(m){return we.info("Circle intersect",t,d,m),Fe.circle(t,d,m)},i}N(lC,"circle");function b$(e){const t=Math.cos(Math.PI/4),n=Math.sin(Math.PI/4),r=e*2,a={x:r/2*t,y:r/2*n},i={x:-(r/2)*t,y:r/2*n},o={x:-(r/2)*t,y:-(r/2)*n},l={x:r/2*t,y:-(r/2)*n};return`M ${i.x},${i.y} L ${l.x},${l.y}
                   M ${a.x},${a.y} L ${o.x},${o.y}`}N(b$,"createLine");function y$(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n,t.label="";const a=e.insert("g").attr("class",it(t)).attr("id",t.domId??t.id),i=Math.max(30,(t==null?void 0:t.width)??0),{cssStyles:o}=t,l=Ge.svg(a),u=Ve(t,{});t.look!=="handDrawn"&&(u.roughness=0,u.fillStyle="solid");const d=l.circle(0,0,i*2,u),h=b$(i),f=l.path(h,u),m=a.insert(()=>d,":first-child");return m.insert(()=>f),o&&t.look!=="handDrawn"&&m.selectAll("path").attr("style",o),r&&t.look!=="handDrawn"&&m.selectAll("path").attr("style",r),Qe(t,m),t.intersect=function(b){return we.info("crossedCircle intersect",t,{radius:i,point:b}),Fe.circle(t,i,b)},a}N(y$,"crossedCircle");function go(e,t,n,r=100,a=0,i=180){const o=[],l=a*Math.PI/180,h=(i*Math.PI/180-l)/(r-1);for(let f=0;f<r;f++){const m=l+f*h,b=e+n*Math.cos(m),y=t+n*Math.sin(m);o.push({x:-b,y:-y})}return o}N(go,"generateCirclePoints");async function v$(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i,label:o}=await lt(e,t,it(t)),l=i.width+(t.padding??0),u=i.height+(t.padding??0),d=Math.max(5,u*.1),{cssStyles:h}=t,f=[...go(l/2,-u/2,d,30,-90,0),{x:-l/2-d,y:d},...go(l/2+d*2,-d,d,20,-180,-270),...go(l/2+d*2,d,d,20,-90,-180),{x:-l/2-d,y:-u/2},...go(l/2,u/2,d,20,0,90)],m=[{x:l/2,y:-u/2-d},{x:-l/2,y:-u/2-d},...go(l/2,-u/2,d,20,-90,0),{x:-l/2-d,y:-d},...go(l/2+l*.1,-d,d,20,-180,-270),...go(l/2+l*.1,d,d,20,-90,-180),{x:-l/2-d,y:u/2},...go(l/2,u/2,d,20,0,90),{x:-l/2,y:u/2+d},{x:l/2,y:u/2+d}],b=Ge.svg(a),y=Ve(t,{fill:"none"});t.look!=="handDrawn"&&(y.roughness=0,y.fillStyle="solid");const w=Ft(f).replace("Z",""),S=b.path(w,y),k=Ft(m),R=b.path(k,{...y}),I=a.insert("g",":first-child");return I.insert(()=>R,":first-child").attr("stroke-opacity",0),I.insert(()=>S,":first-child"),I.attr("class","text"),h&&t.look!=="handDrawn"&&I.selectAll("path").attr("style",h),r&&t.look!=="handDrawn"&&I.selectAll("path").attr("style",r),I.attr("transform",`translate(${d}, 0)`),o.attr("transform",`translate(${-l/2+d-(i.x-(i.left??0))},${-u/2+(t.padding??0)/2-(i.y-(i.top??0))})`),Qe(t,I),t.intersect=function(L){return Fe.polygon(t,m,L)},a}N(v$,"curlyBraceLeft");function bo(e,t,n,r=100,a=0,i=180){const o=[],l=a*Math.PI/180,h=(i*Math.PI/180-l)/(r-1);for(let f=0;f<r;f++){const m=l+f*h,b=e+n*Math.cos(m),y=t+n*Math.sin(m);o.push({x:b,y})}return o}N(bo,"generateCirclePoints");async function x$(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i,label:o}=await lt(e,t,it(t)),l=i.width+(t.padding??0),u=i.height+(t.padding??0),d=Math.max(5,u*.1),{cssStyles:h}=t,f=[...bo(l/2,-u/2,d,20,-90,0),{x:l/2+d,y:-d},...bo(l/2+d*2,-d,d,20,-180,-270),...bo(l/2+d*2,d,d,20,-90,-180),{x:l/2+d,y:u/2},...bo(l/2,u/2,d,20,0,90)],m=[{x:-l/2,y:-u/2-d},{x:l/2,y:-u/2-d},...bo(l/2,-u/2,d,20,-90,0),{x:l/2+d,y:-d},...bo(l/2+d*2,-d,d,20,-180,-270),...bo(l/2+d*2,d,d,20,-90,-180),{x:l/2+d,y:u/2},...bo(l/2,u/2,d,20,0,90),{x:l/2,y:u/2+d},{x:-l/2,y:u/2+d}],b=Ge.svg(a),y=Ve(t,{fill:"none"});t.look!=="handDrawn"&&(y.roughness=0,y.fillStyle="solid");const w=Ft(f).replace("Z",""),S=b.path(w,y),k=Ft(m),R=b.path(k,{...y}),I=a.insert("g",":first-child");return I.insert(()=>R,":first-child").attr("stroke-opacity",0),I.insert(()=>S,":first-child"),I.attr("class","text"),h&&t.look!=="handDrawn"&&I.selectAll("path").attr("style",h),r&&t.look!=="handDrawn"&&I.selectAll("path").attr("style",r),I.attr("transform",`translate(${-d}, 0)`),o.attr("transform",`translate(${-l/2+(t.padding??0)/2-(i.x-(i.left??0))},${-u/2+(t.padding??0)/2-(i.y-(i.top??0))})`),Qe(t,I),t.intersect=function(L){return Fe.polygon(t,m,L)},a}N(x$,"curlyBraceRight");function or(e,t,n,r=100,a=0,i=180){const o=[],l=a*Math.PI/180,h=(i*Math.PI/180-l)/(r-1);for(let f=0;f<r;f++){const m=l+f*h,b=e+n*Math.cos(m),y=t+n*Math.sin(m);o.push({x:-b,y:-y})}return o}N(or,"generateCirclePoints");async function S$(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i,label:o}=await lt(e,t,it(t)),l=i.width+(t.padding??0),u=i.height+(t.padding??0),d=Math.max(5,u*.1),{cssStyles:h}=t,f=[...or(l/2,-u/2,d,30,-90,0),{x:-l/2-d,y:d},...or(l/2+d*2,-d,d,20,-180,-270),...or(l/2+d*2,d,d,20,-90,-180),{x:-l/2-d,y:-u/2},...or(l/2,u/2,d,20,0,90)],m=[...or(-l/2+d+d/2,-u/2,d,20,-90,-180),{x:l/2-d/2,y:d},...or(-l/2-d/2,-d,d,20,0,90),...or(-l/2-d/2,d,d,20,-90,0),{x:l/2-d/2,y:-d},...or(-l/2+d+d/2,u/2,d,30,-180,-270)],b=[{x:l/2,y:-u/2-d},{x:-l/2,y:-u/2-d},...or(l/2,-u/2,d,20,-90,0),{x:-l/2-d,y:-d},...or(l/2+d*2,-d,d,20,-180,-270),...or(l/2+d*2,d,d,20,-90,-180),{x:-l/2-d,y:u/2},...or(l/2,u/2,d,20,0,90),{x:-l/2,y:u/2+d},{x:l/2-d-d/2,y:u/2+d},...or(-l/2+d+d/2,-u/2,d,20,-90,-180),{x:l/2-d/2,y:d},...or(-l/2-d/2,-d,d,20,0,90),...or(-l/2-d/2,d,d,20,-90,0),{x:l/2-d/2,y:-d},...or(-l/2+d+d/2,u/2,d,30,-180,-270)],y=Ge.svg(a),v=Ve(t,{fill:"none"});t.look!=="handDrawn"&&(v.roughness=0,v.fillStyle="solid");const S=Ft(f).replace("Z",""),k=y.path(S,v),I=Ft(m).replace("Z",""),L=y.path(I,v),A=Ft(b),M=y.path(A,{...v}),P=a.insert("g",":first-child");return P.insert(()=>M,":first-child").attr("stroke-opacity",0),P.insert(()=>k,":first-child"),P.insert(()=>L,":first-child"),P.attr("class","text"),h&&t.look!=="handDrawn"&&P.selectAll("path").attr("style",h),r&&t.look!=="handDrawn"&&P.selectAll("path").attr("style",r),P.attr("transform",`translate(${d-d/4}, 0)`),o.attr("transform",`translate(${-l/2+(t.padding??0)/2-(i.x-(i.left??0))},${-u/2+(t.padding??0)/2-(i.y-(i.top??0))})`),Qe(t,P),t.intersect=function(G){return Fe.polygon(t,b,G)},a}N(S$,"curlyBraces");async function w$(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i}=await lt(e,t,it(t)),o=80,l=20,u=Math.max(o,(i.width+(t.padding??0)*2)*1.25,(t==null?void 0:t.width)??0),d=Math.max(l,i.height+(t.padding??0)*2,(t==null?void 0:t.height)??0),h=d/2,{cssStyles:f}=t,m=Ge.svg(a),b=Ve(t,{});t.look!=="handDrawn"&&(b.roughness=0,b.fillStyle="solid");const y=u,v=d,w=y-h,S=v/4,k=[{x:w,y:0},{x:S,y:0},{x:0,y:v/2},{x:S,y:v},{x:w,y:v},...jh(-w,-v/2,h,50,270,90)],R=Ft(k),I=m.path(R,b),L=a.insert(()=>I,":first-child");return L.attr("class","basic label-container"),f&&t.look!=="handDrawn"&&L.selectChildren("path").attr("style",f),r&&t.look!=="handDrawn"&&L.selectChildren("path").attr("style",r),L.attr("transform",`translate(${-u/2}, ${-d/2})`),Qe(t,L),t.intersect=function(A){return Fe.polygon(t,k,A)},a}N(w$,"curvedTrapezoid");var Vye=N((e,t,n,r,a,i)=>[`M${e},${t+i}`,`a${a},${i} 0,0,0 ${n},0`,`a${a},${i} 0,0,0 ${-n},0`,`l0,${r}`,`a${a},${i} 0,0,0 ${n},0`,`l0,${-r}`].join(" "),"createCylinderPathD"),Yye=N((e,t,n,r,a,i)=>[`M${e},${t+i}`,`M${e+n},${t+i}`,`a${a},${i} 0,0,0 ${-n},0`,`l0,${r}`,`a${a},${i} 0,0,0 ${n},0`,`l0,${-r}`].join(" "),"createOuterCylinderPathD"),Xye=N((e,t,n,r,a,i)=>[`M${e-n/2},${-r/2}`,`a${a},${i} 0,0,0 ${n},0`].join(" "),"createInnerCylinderPathD");async function E$(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i,label:o}=await lt(e,t,it(t)),l=Math.max(i.width+t.padding,t.width??0),u=l/2,d=u/(2.5+l/50),h=Math.max(i.height+d+t.padding,t.height??0);let f;const{cssStyles:m}=t;if(t.look==="handDrawn"){const b=Ge.svg(a),y=Yye(0,0,l,h,u,d),v=Xye(0,d,l,h,u,d),w=b.path(y,Ve(t,{})),S=b.path(v,Ve(t,{fill:"none"}));f=a.insert(()=>S,":first-child"),f=a.insert(()=>w,":first-child"),f.attr("class","basic label-container"),m&&f.attr("style",m)}else{const b=Vye(0,0,l,h,u,d);f=a.insert("path",":first-child").attr("d",b).attr("class","basic label-container").attr("style",vr(m)).attr("style",r)}return f.attr("label-offset-y",d),f.attr("transform",`translate(${-l/2}, ${-(h/2+d)})`),Qe(t,f),o.attr("transform",`translate(${-(i.width/2)-(i.x-(i.left??0))}, ${-(i.height/2)+(t.padding??0)/1.5-(i.y-(i.top??0))})`),t.intersect=function(b){const y=Fe.rect(t,b),v=y.x-(t.x??0);if(u!=0&&(Math.abs(v)<(t.width??0)/2||Math.abs(v)==(t.width??0)/2&&Math.abs(y.y-(t.y??0))>(t.height??0)/2-d)){let w=d*d*(1-v*v/(u*u));w>0&&(w=Math.sqrt(w)),w=d-w,b.y-(t.y??0)>0&&(w=-w),y.y+=w}return y},a}N(E$,"cylinder");async function k$(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i,label:o}=await lt(e,t,it(t)),l=i.width+t.padding,u=i.height+t.padding,d=u*.2,h=-l/2,f=-u/2-d/2,{cssStyles:m}=t,b=Ge.svg(a),y=Ve(t,{});t.look!=="handDrawn"&&(y.roughness=0,y.fillStyle="solid");const v=[{x:h,y:f+d},{x:-h,y:f+d},{x:-h,y:-f},{x:h,y:-f},{x:h,y:f},{x:-h,y:f},{x:-h,y:f+d}],w=b.polygon(v.map(k=>[k.x,k.y]),y),S=a.insert(()=>w,":first-child");return S.attr("class","basic label-container"),m&&t.look!=="handDrawn"&&S.selectAll("path").attr("style",m),r&&t.look!=="handDrawn"&&S.selectAll("path").attr("style",r),o.attr("transform",`translate(${h+(t.padding??0)/2-(i.x-(i.left??0))}, ${f+d+(t.padding??0)/2-(i.y-(i.top??0))})`),Qe(t,S),t.intersect=function(k){return Fe.rect(t,k)},a}N(k$,"dividedRectangle");async function T$(e,t){var m,b;const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i,halfPadding:o}=await lt(e,t,it(t)),u=i.width/2+o+5,d=i.width/2+o;let h;const{cssStyles:f}=t;if(t.look==="handDrawn"){const y=Ge.svg(a),v=Ve(t,{roughness:.2,strokeWidth:2.5}),w=Ve(t,{roughness:.2,strokeWidth:1.5}),S=y.circle(0,0,u*2,v),k=y.circle(0,0,d*2,w);h=a.insert("g",":first-child"),h.attr("class",vr(t.cssClasses)).attr("style",vr(f)),(m=h.node())==null||m.appendChild(S),(b=h.node())==null||b.appendChild(k)}else{h=a.insert("g",":first-child");const y=h.insert("circle",":first-child"),v=h.insert("circle");h.attr("class","basic label-container").attr("style",r),y.attr("class","outer-circle").attr("style",r).attr("r",u).attr("cx",0).attr("cy",0),v.attr("class","inner-circle").attr("style",r).attr("r",d).attr("cx",0).attr("cy",0)}return Qe(t,h),t.intersect=function(y){return we.info("DoubleCircle intersect",t,u,y),Fe.circle(t,u,y)},a}N(T$,"doublecircle");function _$(e,t,{config:{themeVariables:n}}){const{labelStyles:r,nodeStyles:a}=Ye(t);t.label="",t.labelStyle=r;const i=e.insert("g").attr("class",it(t)).attr("id",t.domId??t.id),o=7,{cssStyles:l}=t,u=Ge.svg(i),{nodeBorder:d}=n,h=Ve(t,{fillStyle:"solid"});t.look!=="handDrawn"&&(h.roughness=0);const f=u.circle(0,0,o*2,h),m=i.insert(()=>f,":first-child");return m.selectAll("path").attr("style",`fill: ${d} !important;`),l&&l.length>0&&t.look!=="handDrawn"&&m.selectAll("path").attr("style",l),a&&t.look!=="handDrawn"&&m.selectAll("path").attr("style",a),Qe(t,m),t.intersect=function(b){return we.info("filledCircle intersect",t,{radius:o,point:b}),Fe.circle(t,o,b)},i}N(_$,"filledCircle");async function C$(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i,label:o}=await lt(e,t,it(t)),l=i.width+(t.padding??0),u=l+i.height,d=l+i.height,h=[{x:0,y:-u},{x:d,y:-u},{x:d/2,y:0}],{cssStyles:f}=t,m=Ge.svg(a),b=Ve(t,{});t.look!=="handDrawn"&&(b.roughness=0,b.fillStyle="solid");const y=Ft(h),v=m.path(y,b),w=a.insert(()=>v,":first-child").attr("transform",`translate(${-u/2}, ${u/2})`);return f&&t.look!=="handDrawn"&&w.selectChildren("path").attr("style",f),r&&t.look!=="handDrawn"&&w.selectChildren("path").attr("style",r),t.width=l,t.height=u,Qe(t,w),o.attr("transform",`translate(${-i.width/2-(i.x-(i.left??0))}, ${-u/2+(t.padding??0)/2+(i.y-(i.top??0))})`),t.intersect=function(S){return we.info("Triangle intersect",t,h,S),Fe.polygon(t,h,S)},a}N(C$,"flippedTriangle");function A$(e,t,{dir:n,config:{state:r,themeVariables:a}}){const{nodeStyles:i}=Ye(t);t.label="";const o=e.insert("g").attr("class",it(t)).attr("id",t.domId??t.id),{cssStyles:l}=t;let u=Math.max(70,(t==null?void 0:t.width)??0),d=Math.max(10,(t==null?void 0:t.height)??0);n==="LR"&&(u=Math.max(10,(t==null?void 0:t.width)??0),d=Math.max(70,(t==null?void 0:t.height)??0));const h=-1*u/2,f=-1*d/2,m=Ge.svg(o),b=Ve(t,{stroke:a.lineColor,fill:a.lineColor});t.look!=="handDrawn"&&(b.roughness=0,b.fillStyle="solid");const y=m.rectangle(h,f,u,d,b),v=o.insert(()=>y,":first-child");l&&t.look!=="handDrawn"&&v.selectAll("path").attr("style",l),i&&t.look!=="handDrawn"&&v.selectAll("path").attr("style",i),Qe(t,v);const w=(r==null?void 0:r.padding)??0;return t.width&&t.height&&(t.width+=w/2||0,t.height+=w/2||0),t.intersect=function(S){return Fe.rect(t,S)},o}N(A$,"forkJoin");async function R$(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const a=80,i=50,{shapeSvg:o,bbox:l}=await lt(e,t,it(t)),u=Math.max(a,l.width+(t.padding??0)*2,(t==null?void 0:t.width)??0),d=Math.max(i,l.height+(t.padding??0)*2,(t==null?void 0:t.height)??0),h=d/2,{cssStyles:f}=t,m=Ge.svg(o),b=Ve(t,{});t.look!=="handDrawn"&&(b.roughness=0,b.fillStyle="solid");const y=[{x:-u/2,y:-d/2},{x:u/2-h,y:-d/2},...jh(-u/2+h,0,h,50,90,270),{x:u/2-h,y:d/2},{x:-u/2,y:d/2}],v=Ft(y),w=m.path(v,b),S=o.insert(()=>w,":first-child");return S.attr("class","basic label-container"),f&&t.look!=="handDrawn"&&S.selectChildren("path").attr("style",f),r&&t.look!=="handDrawn"&&S.selectChildren("path").attr("style",r),Qe(t,S),t.intersect=function(k){return we.info("Pill intersect",t,{radius:h,point:k}),Fe.polygon(t,y,k)},o}N(R$,"halfRoundedRectangle");var Kye=N((e,t,n,r,a)=>[`M${e+a},${t}`,`L${e+n-a},${t}`,`L${e+n},${t-r/2}`,`L${e+n-a},${t-r}`,`L${e+a},${t-r}`,`L${e},${t-r/2}`,"Z"].join(" "),"createHexagonPathD");async function N$(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i}=await lt(e,t,it(t)),o=4,l=i.height+t.padding,u=l/o,d=i.width+2*u+t.padding,h=[{x:u,y:0},{x:d-u,y:0},{x:d,y:-l/2},{x:d-u,y:-l},{x:u,y:-l},{x:0,y:-l/2}];let f;const{cssStyles:m}=t;if(t.look==="handDrawn"){const b=Ge.svg(a),y=Ve(t,{}),v=Kye(0,0,d,l,u),w=b.path(v,y);f=a.insert(()=>w,":first-child").attr("transform",`translate(${-d/2}, ${l/2})`),m&&f.attr("style",m)}else f=Mo(a,d,l,h);return r&&f.attr("style",r),t.width=d,t.height=l,Qe(t,f),t.intersect=function(b){return Fe.polygon(t,h,b)},a}N(N$,"hexagon");async function O$(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.label="",t.labelStyle=n;const{shapeSvg:a}=await lt(e,t,it(t)),i=Math.max(30,(t==null?void 0:t.width)??0),o=Math.max(30,(t==null?void 0:t.height)??0),{cssStyles:l}=t,u=Ge.svg(a),d=Ve(t,{});t.look!=="handDrawn"&&(d.roughness=0,d.fillStyle="solid");const h=[{x:0,y:0},{x:i,y:0},{x:0,y:o},{x:i,y:o}],f=Ft(h),m=u.path(f,d),b=a.insert(()=>m,":first-child");return b.attr("class","basic label-container"),l&&t.look!=="handDrawn"&&b.selectChildren("path").attr("style",l),r&&t.look!=="handDrawn"&&b.selectChildren("path").attr("style",r),b.attr("transform",`translate(${-i/2}, ${-o/2})`),Qe(t,b),t.intersect=function(y){return we.info("Pill intersect",t,{points:h}),Fe.polygon(t,h,y)},a}N(O$,"hourglass");async function I$(e,t,{config:{themeVariables:n,flowchart:r}}){const{labelStyles:a}=Ye(t);t.labelStyle=a;const i=t.assetHeight??48,o=t.assetWidth??48,l=Math.max(i,o),u=r==null?void 0:r.wrappingWidth;t.width=Math.max(l,u??0);const{shapeSvg:d,bbox:h,label:f}=await lt(e,t,"icon-shape default"),m=t.pos==="t",b=l,y=l,{nodeBorder:v}=n,{stylesMap:w}=Iu(t),S=-y/2,k=-b/2,R=t.label?8:0,I=Ge.svg(d),L=Ve(t,{stroke:"none",fill:"none"});t.look!=="handDrawn"&&(L.roughness=0,L.fillStyle="solid");const A=I.rectangle(S,k,y,b,L),M=Math.max(y,h.width),P=b+h.height+R,G=I.rectangle(-M/2,-P/2,M,P,{...L,fill:"transparent",stroke:"none"}),B=d.insert(()=>A,":first-child"),H=d.insert(()=>G);if(t.icon){const Z=d.append("g");Z.html(`<g>${await xp(t.icon,{height:l,width:l,fallbackPrefix:""})}</g>`);const V=Z.node().getBBox(),q=V.width,X=V.height,$=V.x,Q=V.y;Z.attr("transform",`translate(${-q/2-$},${m?h.height/2+R/2-X/2-Q:-h.height/2-R/2-X/2-Q})`),Z.attr("style",`color: ${w.get("stroke")??v};`)}return f.attr("transform",`translate(${-h.width/2-(h.x-(h.left??0))},${m?-P/2:P/2-h.height})`),B.attr("transform",`translate(0,${m?h.height/2+R/2:-h.height/2-R/2})`),Qe(t,H),t.intersect=function(Z){if(we.info("iconSquare intersect",t,Z),!t.label)return Fe.rect(t,Z);const V=t.x??0,q=t.y??0,X=t.height??0;let $=[];return m?$=[{x:V-h.width/2,y:q-X/2},{x:V+h.width/2,y:q-X/2},{x:V+h.width/2,y:q-X/2+h.height+R},{x:V+y/2,y:q-X/2+h.height+R},{x:V+y/2,y:q+X/2},{x:V-y/2,y:q+X/2},{x:V-y/2,y:q-X/2+h.height+R},{x:V-h.width/2,y:q-X/2+h.height+R}]:$=[{x:V-y/2,y:q-X/2},{x:V+y/2,y:q-X/2},{x:V+y/2,y:q-X/2+b},{x:V+h.width/2,y:q-X/2+b},{x:V+h.width/2/2,y:q+X/2},{x:V-h.width/2,y:q+X/2},{x:V-h.width/2,y:q-X/2+b},{x:V-y/2,y:q-X/2+b}],Fe.polygon(t,$,Z)},d}N(I$,"icon");async function L$(e,t,{config:{themeVariables:n,flowchart:r}}){const{labelStyles:a}=Ye(t);t.labelStyle=a;const i=t.assetHeight??48,o=t.assetWidth??48,l=Math.max(i,o),u=r==null?void 0:r.wrappingWidth;t.width=Math.max(l,u??0);const{shapeSvg:d,bbox:h,label:f}=await lt(e,t,"icon-shape default"),m=20,b=t.label?8:0,y=t.pos==="t",{nodeBorder:v,mainBkg:w}=n,{stylesMap:S}=Iu(t),k=Ge.svg(d),R=Ve(t,{});t.look!=="handDrawn"&&(R.roughness=0,R.fillStyle="solid");const I=S.get("fill");R.stroke=I??w;const L=d.append("g");t.icon&&L.html(`<g>${await xp(t.icon,{height:l,width:l,fallbackPrefix:""})}</g>`);const A=L.node().getBBox(),M=A.width,P=A.height,G=A.x,B=A.y,H=Math.max(M,P)*Math.SQRT2+m*2,Z=k.circle(0,0,H,R),V=Math.max(H,h.width),q=H+h.height+b,X=k.rectangle(-V/2,-q/2,V,q,{...R,fill:"transparent",stroke:"none"}),$=d.insert(()=>Z,":first-child"),Q=d.insert(()=>X);return L.attr("transform",`translate(${-M/2-G},${y?h.height/2+b/2-P/2-B:-h.height/2-b/2-P/2-B})`),L.attr("style",`color: ${S.get("stroke")??v};`),f.attr("transform",`translate(${-h.width/2-(h.x-(h.left??0))},${y?-q/2:q/2-h.height})`),$.attr("transform",`translate(0,${y?h.height/2+b/2:-h.height/2-b/2})`),Qe(t,Q),t.intersect=function(J){return we.info("iconSquare intersect",t,J),Fe.rect(t,J)},d}N(L$,"iconCircle");async function D$(e,t,{config:{themeVariables:n,flowchart:r}}){const{labelStyles:a}=Ye(t);t.labelStyle=a;const i=t.assetHeight??48,o=t.assetWidth??48,l=Math.max(i,o),u=r==null?void 0:r.wrappingWidth;t.width=Math.max(l,u??0);const{shapeSvg:d,bbox:h,halfPadding:f,label:m}=await lt(e,t,"icon-shape default"),b=t.pos==="t",y=l+f*2,v=l+f*2,{nodeBorder:w,mainBkg:S}=n,{stylesMap:k}=Iu(t),R=-v/2,I=-y/2,L=t.label?8:0,A=Ge.svg(d),M=Ve(t,{});t.look!=="handDrawn"&&(M.roughness=0,M.fillStyle="solid");const P=k.get("fill");M.stroke=P??S;const G=A.path(Bs(R,I,v,y,5),M),B=Math.max(v,h.width),H=y+h.height+L,Z=A.rectangle(-B/2,-H/2,B,H,{...M,fill:"transparent",stroke:"none"}),V=d.insert(()=>G,":first-child").attr("class","icon-shape2"),q=d.insert(()=>Z);if(t.icon){const X=d.append("g");X.html(`<g>${await xp(t.icon,{height:l,width:l,fallbackPrefix:""})}</g>`);const $=X.node().getBBox(),Q=$.width,J=$.height,ie=$.x,F=$.y;X.attr("transform",`translate(${-Q/2-ie},${b?h.height/2+L/2-J/2-F:-h.height/2-L/2-J/2-F})`),X.attr("style",`color: ${k.get("stroke")??w};`)}return m.attr("transform",`translate(${-h.width/2-(h.x-(h.left??0))},${b?-H/2:H/2-h.height})`),V.attr("transform",`translate(0,${b?h.height/2+L/2:-h.height/2-L/2})`),Qe(t,q),t.intersect=function(X){if(we.info("iconSquare intersect",t,X),!t.label)return Fe.rect(t,X);const $=t.x??0,Q=t.y??0,J=t.height??0;let ie=[];return b?ie=[{x:$-h.width/2,y:Q-J/2},{x:$+h.width/2,y:Q-J/2},{x:$+h.width/2,y:Q-J/2+h.height+L},{x:$+v/2,y:Q-J/2+h.height+L},{x:$+v/2,y:Q+J/2},{x:$-v/2,y:Q+J/2},{x:$-v/2,y:Q-J/2+h.height+L},{x:$-h.width/2,y:Q-J/2+h.height+L}]:ie=[{x:$-v/2,y:Q-J/2},{x:$+v/2,y:Q-J/2},{x:$+v/2,y:Q-J/2+y},{x:$+h.width/2,y:Q-J/2+y},{x:$+h.width/2/2,y:Q+J/2},{x:$-h.width/2,y:Q+J/2},{x:$-h.width/2,y:Q-J/2+y},{x:$-v/2,y:Q-J/2+y}],Fe.polygon(t,ie,X)},d}N(D$,"iconRounded");async function M$(e,t,{config:{themeVariables:n,flowchart:r}}){const{labelStyles:a}=Ye(t);t.labelStyle=a;const i=t.assetHeight??48,o=t.assetWidth??48,l=Math.max(i,o),u=r==null?void 0:r.wrappingWidth;t.width=Math.max(l,u??0);const{shapeSvg:d,bbox:h,halfPadding:f,label:m}=await lt(e,t,"icon-shape default"),b=t.pos==="t",y=l+f*2,v=l+f*2,{nodeBorder:w,mainBkg:S}=n,{stylesMap:k}=Iu(t),R=-v/2,I=-y/2,L=t.label?8:0,A=Ge.svg(d),M=Ve(t,{});t.look!=="handDrawn"&&(M.roughness=0,M.fillStyle="solid");const P=k.get("fill");M.stroke=P??S;const G=A.path(Bs(R,I,v,y,.1),M),B=Math.max(v,h.width),H=y+h.height+L,Z=A.rectangle(-B/2,-H/2,B,H,{...M,fill:"transparent",stroke:"none"}),V=d.insert(()=>G,":first-child"),q=d.insert(()=>Z);if(t.icon){const X=d.append("g");X.html(`<g>${await xp(t.icon,{height:l,width:l,fallbackPrefix:""})}</g>`);const $=X.node().getBBox(),Q=$.width,J=$.height,ie=$.x,F=$.y;X.attr("transform",`translate(${-Q/2-ie},${b?h.height/2+L/2-J/2-F:-h.height/2-L/2-J/2-F})`),X.attr("style",`color: ${k.get("stroke")??w};`)}return m.attr("transform",`translate(${-h.width/2-(h.x-(h.left??0))},${b?-H/2:H/2-h.height})`),V.attr("transform",`translate(0,${b?h.height/2+L/2:-h.height/2-L/2})`),Qe(t,q),t.intersect=function(X){if(we.info("iconSquare intersect",t,X),!t.label)return Fe.rect(t,X);const $=t.x??0,Q=t.y??0,J=t.height??0;let ie=[];return b?ie=[{x:$-h.width/2,y:Q-J/2},{x:$+h.width/2,y:Q-J/2},{x:$+h.width/2,y:Q-J/2+h.height+L},{x:$+v/2,y:Q-J/2+h.height+L},{x:$+v/2,y:Q+J/2},{x:$-v/2,y:Q+J/2},{x:$-v/2,y:Q-J/2+h.height+L},{x:$-h.width/2,y:Q-J/2+h.height+L}]:ie=[{x:$-v/2,y:Q-J/2},{x:$+v/2,y:Q-J/2},{x:$+v/2,y:Q-J/2+y},{x:$+h.width/2,y:Q-J/2+y},{x:$+h.width/2/2,y:Q+J/2},{x:$-h.width/2,y:Q+J/2},{x:$-h.width/2,y:Q-J/2+y},{x:$-v/2,y:Q-J/2+y}],Fe.polygon(t,ie,X)},d}N(M$,"iconSquare");async function B$(e,t,{config:{flowchart:n}}){const r=new Image;r.src=(t==null?void 0:t.img)??"",await r.decode();const a=Number(r.naturalWidth.toString().replace("px","")),i=Number(r.naturalHeight.toString().replace("px",""));t.imageAspectRatio=a/i;const{labelStyles:o}=Ye(t);t.labelStyle=o;const l=n==null?void 0:n.wrappingWidth;t.defaultWidth=n==null?void 0:n.wrappingWidth;const u=Math.max(t.label?l??0:0,(t==null?void 0:t.assetWidth)??a),d=t.constraint==="on"&&t!=null&&t.assetHeight?t.assetHeight*t.imageAspectRatio:u,h=t.constraint==="on"?d/t.imageAspectRatio:(t==null?void 0:t.assetHeight)??i;t.width=Math.max(d,l??0);const{shapeSvg:f,bbox:m,label:b}=await lt(e,t,"image-shape default"),y=t.pos==="t",v=-d/2,w=-h/2,S=t.label?8:0,k=Ge.svg(f),R=Ve(t,{});t.look!=="handDrawn"&&(R.roughness=0,R.fillStyle="solid");const I=k.rectangle(v,w,d,h,R),L=Math.max(d,m.width),A=h+m.height+S,M=k.rectangle(-L/2,-A/2,L,A,{...R,fill:"none",stroke:"none"}),P=f.insert(()=>I,":first-child"),G=f.insert(()=>M);if(t.img){const B=f.append("image");B.attr("href",t.img),B.attr("width",d),B.attr("height",h),B.attr("preserveAspectRatio","none"),B.attr("transform",`translate(${-d/2},${y?A/2-h:-A/2})`)}return b.attr("transform",`translate(${-m.width/2-(m.x-(m.left??0))},${y?-h/2-m.height/2-S/2:h/2-m.height/2+S/2})`),P.attr("transform",`translate(0,${y?m.height/2+S/2:-m.height/2-S/2})`),Qe(t,G),t.intersect=function(B){if(we.info("iconSquare intersect",t,B),!t.label)return Fe.rect(t,B);const H=t.x??0,Z=t.y??0,V=t.height??0;let q=[];return y?q=[{x:H-m.width/2,y:Z-V/2},{x:H+m.width/2,y:Z-V/2},{x:H+m.width/2,y:Z-V/2+m.height+S},{x:H+d/2,y:Z-V/2+m.height+S},{x:H+d/2,y:Z+V/2},{x:H-d/2,y:Z+V/2},{x:H-d/2,y:Z-V/2+m.height+S},{x:H-m.width/2,y:Z-V/2+m.height+S}]:q=[{x:H-d/2,y:Z-V/2},{x:H+d/2,y:Z-V/2},{x:H+d/2,y:Z-V/2+h},{x:H+m.width/2,y:Z-V/2+h},{x:H+m.width/2/2,y:Z+V/2},{x:H-m.width/2,y:Z+V/2},{x:H-m.width/2,y:Z-V/2+h},{x:H-d/2,y:Z-V/2+h}],Fe.polygon(t,q,B)},f}N(B$,"imageSquare");async function F$(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i}=await lt(e,t,it(t)),o=Math.max(i.width+(t.padding??0)*2,(t==null?void 0:t.width)??0),l=Math.max(i.height+(t.padding??0)*2,(t==null?void 0:t.height)??0),u=[{x:0,y:0},{x:o,y:0},{x:o+3*l/6,y:-l},{x:-3*l/6,y:-l}];let d;const{cssStyles:h}=t;if(t.look==="handDrawn"){const f=Ge.svg(a),m=Ve(t,{}),b=Ft(u),y=f.path(b,m);d=a.insert(()=>y,":first-child").attr("transform",`translate(${-o/2}, ${l/2})`),h&&d.attr("style",h)}else d=Mo(a,o,l,u);return r&&d.attr("style",r),t.width=o,t.height=l,Qe(t,d),t.intersect=function(f){return Fe.polygon(t,u,f)},a}N(F$,"inv_trapezoid");async function wp(e,t,n){const{labelStyles:r,nodeStyles:a}=Ye(t);t.labelStyle=r;const{shapeSvg:i,bbox:o}=await lt(e,t,it(t)),l=Math.max(o.width+n.labelPaddingX*2,(t==null?void 0:t.width)||0),u=Math.max(o.height+n.labelPaddingY*2,(t==null?void 0:t.height)||0),d=-l/2,h=-u/2;let f,{rx:m,ry:b}=t;const{cssStyles:y}=t;if(n!=null&&n.rx&&n.ry&&(m=n.rx,b=n.ry),t.look==="handDrawn"){const v=Ge.svg(i),w=Ve(t,{}),S=m||b?v.path(Bs(d,h,l,u,m||0),w):v.rectangle(d,h,l,u,w);f=i.insert(()=>S,":first-child"),f.attr("class","basic label-container").attr("style",vr(y))}else f=i.insert("rect",":first-child"),f.attr("class","basic label-container").attr("style",a).attr("rx",vr(m)).attr("ry",vr(b)).attr("x",d).attr("y",h).attr("width",l).attr("height",u);return Qe(t,f),t.calcIntersect=function(v,w){return Fe.rect(v,w)},t.intersect=function(v){return Fe.rect(t,v)},i}N(wp,"drawRect");async function z$(e,t){const{shapeSvg:n,bbox:r,label:a}=await lt(e,t,"label"),i=n.insert("rect",":first-child");return i.attr("width",.1).attr("height",.1),n.attr("class","label edgeLabel"),a.attr("transform",`translate(${-(r.width/2)-(r.x-(r.left??0))}, ${-(r.height/2)-(r.y-(r.top??0))})`),Qe(t,i),t.intersect=function(u){return Fe.rect(t,u)},n}N(z$,"labelRect");async function $$(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i}=await lt(e,t,it(t)),o=Math.max(i.width+(t.padding??0),(t==null?void 0:t.width)??0),l=Math.max(i.height+(t.padding??0),(t==null?void 0:t.height)??0),u=[{x:0,y:0},{x:o+3*l/6,y:0},{x:o,y:-l},{x:-(3*l)/6,y:-l}];let d;const{cssStyles:h}=t;if(t.look==="handDrawn"){const f=Ge.svg(a),m=Ve(t,{}),b=Ft(u),y=f.path(b,m);d=a.insert(()=>y,":first-child").attr("transform",`translate(${-o/2}, ${l/2})`),h&&d.attr("style",h)}else d=Mo(a,o,l,u);return r&&d.attr("style",r),t.width=o,t.height=l,Qe(t,d),t.intersect=function(f){return Fe.polygon(t,u,f)},a}N($$,"lean_left");async function P$(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i}=await lt(e,t,it(t)),o=Math.max(i.width+(t.padding??0),(t==null?void 0:t.width)??0),l=Math.max(i.height+(t.padding??0),(t==null?void 0:t.height)??0),u=[{x:-3*l/6,y:0},{x:o,y:0},{x:o+3*l/6,y:-l},{x:0,y:-l}];let d;const{cssStyles:h}=t;if(t.look==="handDrawn"){const f=Ge.svg(a),m=Ve(t,{}),b=Ft(u),y=f.path(b,m);d=a.insert(()=>y,":first-child").attr("transform",`translate(${-o/2}, ${l/2})`),h&&d.attr("style",h)}else d=Mo(a,o,l,u);return r&&d.attr("style",r),t.width=o,t.height=l,Qe(t,d),t.intersect=function(f){return Fe.polygon(t,u,f)},a}N(P$,"lean_right");function U$(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.label="",t.labelStyle=n;const a=e.insert("g").attr("class",it(t)).attr("id",t.domId??t.id),{cssStyles:i}=t,o=Math.max(35,(t==null?void 0:t.width)??0),l=Math.max(35,(t==null?void 0:t.height)??0),u=7,d=[{x:o,y:0},{x:0,y:l+u/2},{x:o-2*u,y:l+u/2},{x:0,y:2*l},{x:o,y:l-u/2},{x:2*u,y:l-u/2}],h=Ge.svg(a),f=Ve(t,{});t.look!=="handDrawn"&&(f.roughness=0,f.fillStyle="solid");const m=Ft(d),b=h.path(m,f),y=a.insert(()=>b,":first-child");return i&&t.look!=="handDrawn"&&y.selectAll("path").attr("style",i),r&&t.look!=="handDrawn"&&y.selectAll("path").attr("style",r),y.attr("transform",`translate(-${o/2},${-l})`),Qe(t,y),t.intersect=function(v){return we.info("lightningBolt intersect",t,v),Fe.polygon(t,d,v)},a}N(U$,"lightningBolt");var Zye=N((e,t,n,r,a,i,o)=>[`M${e},${t+i}`,`a${a},${i} 0,0,0 ${n},0`,`a${a},${i} 0,0,0 ${-n},0`,`l0,${r}`,`a${a},${i} 0,0,0 ${n},0`,`l0,${-r}`,`M${e},${t+i+o}`,`a${a},${i} 0,0,0 ${n},0`].join(" "),"createCylinderPathD"),Qye=N((e,t,n,r,a,i,o)=>[`M${e},${t+i}`,`M${e+n},${t+i}`,`a${a},${i} 0,0,0 ${-n},0`,`l0,${r}`,`a${a},${i} 0,0,0 ${n},0`,`l0,${-r}`,`M${e},${t+i+o}`,`a${a},${i} 0,0,0 ${n},0`].join(" "),"createOuterCylinderPathD"),Jye=N((e,t,n,r,a,i)=>[`M${e-n/2},${-r/2}`,`a${a},${i} 0,0,0 ${n},0`].join(" "),"createInnerCylinderPathD");async function j$(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i,label:o}=await lt(e,t,it(t)),l=Math.max(i.width+(t.padding??0),t.width??0),u=l/2,d=u/(2.5+l/50),h=Math.max(i.height+d+(t.padding??0),t.height??0),f=h*.1;let m;const{cssStyles:b}=t;if(t.look==="handDrawn"){const y=Ge.svg(a),v=Qye(0,0,l,h,u,d,f),w=Jye(0,d,l,h,u,d),S=Ve(t,{}),k=y.path(v,S),R=y.path(w,S);a.insert(()=>R,":first-child").attr("class","line"),m=a.insert(()=>k,":first-child"),m.attr("class","basic label-container"),b&&m.attr("style",b)}else{const y=Zye(0,0,l,h,u,d,f);m=a.insert("path",":first-child").attr("d",y).attr("class","basic label-container").attr("style",vr(b)).attr("style",r)}return m.attr("label-offset-y",d),m.attr("transform",`translate(${-l/2}, ${-(h/2+d)})`),Qe(t,m),o.attr("transform",`translate(${-(i.width/2)-(i.x-(i.left??0))}, ${-(i.height/2)+d-(i.y-(i.top??0))})`),t.intersect=function(y){const v=Fe.rect(t,y),w=v.x-(t.x??0);if(u!=0&&(Math.abs(w)<(t.width??0)/2||Math.abs(w)==(t.width??0)/2&&Math.abs(v.y-(t.y??0))>(t.height??0)/2-d)){let S=d*d*(1-w*w/(u*u));S>0&&(S=Math.sqrt(S)),S=d-S,y.y-(t.y??0)>0&&(S=-S),v.y+=S}return v},a}N(j$,"linedCylinder");async function H$(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i,label:o}=await lt(e,t,it(t)),l=Math.max(i.width+(t.padding??0)*2,(t==null?void 0:t.width)??0),u=Math.max(i.height+(t.padding??0)*2,(t==null?void 0:t.height)??0),d=u/4,h=u+d,{cssStyles:f}=t,m=Ge.svg(a),b=Ve(t,{});t.look!=="handDrawn"&&(b.roughness=0,b.fillStyle="solid");const y=[{x:-l/2-l/2*.1,y:-h/2},{x:-l/2-l/2*.1,y:h/2},...Rs(-l/2-l/2*.1,h/2,l/2+l/2*.1,h/2,d,.8),{x:l/2+l/2*.1,y:-h/2},{x:-l/2-l/2*.1,y:-h/2},{x:-l/2,y:-h/2},{x:-l/2,y:h/2*1.1},{x:-l/2,y:-h/2}],v=m.polygon(y.map(S=>[S.x,S.y]),b),w=a.insert(()=>v,":first-child");return w.attr("class","basic label-container"),f&&t.look!=="handDrawn"&&w.selectAll("path").attr("style",f),r&&t.look!=="handDrawn"&&w.selectAll("path").attr("style",r),w.attr("transform",`translate(0,${-d/2})`),o.attr("transform",`translate(${-l/2+(t.padding??0)+l/2*.1/2-(i.x-(i.left??0))},${-u/2+(t.padding??0)-d/2-(i.y-(i.top??0))})`),Qe(t,w),t.intersect=function(S){return Fe.polygon(t,y,S)},a}N(H$,"linedWaveEdgedRect");async function G$(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i,label:o}=await lt(e,t,it(t)),l=Math.max(i.width+(t.padding??0)*2,(t==null?void 0:t.width)??0),u=Math.max(i.height+(t.padding??0)*2,(t==null?void 0:t.height)??0),d=5,h=-l/2,f=-u/2,{cssStyles:m}=t,b=Ge.svg(a),y=Ve(t,{}),v=[{x:h-d,y:f+d},{x:h-d,y:f+u+d},{x:h+l-d,y:f+u+d},{x:h+l-d,y:f+u},{x:h+l,y:f+u},{x:h+l,y:f+u-d},{x:h+l+d,y:f+u-d},{x:h+l+d,y:f-d},{x:h+d,y:f-d},{x:h+d,y:f},{x:h,y:f},{x:h,y:f+d}],w=[{x:h,y:f+d},{x:h+l-d,y:f+d},{x:h+l-d,y:f+u},{x:h+l,y:f+u},{x:h+l,y:f},{x:h,y:f}];t.look!=="handDrawn"&&(y.roughness=0,y.fillStyle="solid");const S=Ft(v),k=b.path(S,y),R=Ft(w),I=b.path(R,{...y,fill:"none"}),L=a.insert(()=>I,":first-child");return L.insert(()=>k,":first-child"),L.attr("class","basic label-container"),m&&t.look!=="handDrawn"&&L.selectAll("path").attr("style",m),r&&t.look!=="handDrawn"&&L.selectAll("path").attr("style",r),o.attr("transform",`translate(${-(i.width/2)-d-(i.x-(i.left??0))}, ${-(i.height/2)+d-(i.y-(i.top??0))})`),Qe(t,L),t.intersect=function(A){return Fe.polygon(t,v,A)},a}N(G$,"multiRect");async function q$(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i,label:o}=await lt(e,t,it(t)),l=Math.max(i.width+(t.padding??0)*2,(t==null?void 0:t.width)??0),u=Math.max(i.height+(t.padding??0)*2,(t==null?void 0:t.height)??0),d=u/4,h=u+d,f=-l/2,m=-h/2,b=5,{cssStyles:y}=t,v=Rs(f-b,m+h+b,f+l-b,m+h+b,d,.8),w=v==null?void 0:v[v.length-1],S=[{x:f-b,y:m+b},{x:f-b,y:m+h+b},...v,{x:f+l-b,y:w.y-b},{x:f+l,y:w.y-b},{x:f+l,y:w.y-2*b},{x:f+l+b,y:w.y-2*b},{x:f+l+b,y:m-b},{x:f+b,y:m-b},{x:f+b,y:m},{x:f,y:m},{x:f,y:m+b}],k=[{x:f,y:m+b},{x:f+l-b,y:m+b},{x:f+l-b,y:w.y-b},{x:f+l,y:w.y-b},{x:f+l,y:m},{x:f,y:m}],R=Ge.svg(a),I=Ve(t,{});t.look!=="handDrawn"&&(I.roughness=0,I.fillStyle="solid");const L=Ft(S),A=R.path(L,I),M=Ft(k),P=R.path(M,I),G=a.insert(()=>A,":first-child");return G.insert(()=>P),G.attr("class","basic label-container"),y&&t.look!=="handDrawn"&&G.selectAll("path").attr("style",y),r&&t.look!=="handDrawn"&&G.selectAll("path").attr("style",r),G.attr("transform",`translate(0,${-d/2})`),o.attr("transform",`translate(${-(i.width/2)-b-(i.x-(i.left??0))}, ${-(i.height/2)+b-d/2-(i.y-(i.top??0))})`),Qe(t,G),t.intersect=function(B){return Fe.polygon(t,S,B)},a}N(q$,"multiWaveEdgedRectangle");async function W$(e,t,{config:{themeVariables:n}}){const{labelStyles:r,nodeStyles:a}=Ye(t);t.labelStyle=r,t.useHtmlLabels||xr(br())||(t.centerLabel=!0);const{shapeSvg:o,bbox:l,label:u}=await lt(e,t,it(t)),d=Math.max(l.width+(t.padding??0)*2,(t==null?void 0:t.width)??0),h=Math.max(l.height+(t.padding??0)*2,(t==null?void 0:t.height)??0),f=-d/2,m=-h/2,{cssStyles:b}=t,y=Ge.svg(o),v=Ve(t,{fill:n.noteBkgColor,stroke:n.noteBorderColor});t.look!=="handDrawn"&&(v.roughness=0,v.fillStyle="solid");const w=y.rectangle(f,m,d,h,v),S=o.insert(()=>w,":first-child");return S.attr("class","basic label-container"),b&&t.look!=="handDrawn"&&S.selectAll("path").attr("style",b),a&&t.look!=="handDrawn"&&S.selectAll("path").attr("style",a),u.attr("transform",`translate(${-l.width/2-(l.x-(l.left??0))}, ${-(l.height/2)-(l.y-(l.top??0))})`),Qe(t,S),t.intersect=function(k){return Fe.rect(t,k)},o}N(W$,"note");var e1e=N((e,t,n)=>[`M${e+n/2},${t}`,`L${e+n},${t-n/2}`,`L${e+n/2},${t-n}`,`L${e},${t-n/2}`,"Z"].join(" "),"createDecisionBoxPathD");async function V$(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i}=await lt(e,t,it(t)),o=i.width+t.padding,l=i.height+t.padding,u=o+l,d=.5,h=[{x:u/2,y:0},{x:u,y:-u/2},{x:u/2,y:-u},{x:0,y:-u/2}];let f;const{cssStyles:m}=t;if(t.look==="handDrawn"){const b=Ge.svg(a),y=Ve(t,{}),v=e1e(0,0,u),w=b.path(v,y);f=a.insert(()=>w,":first-child").attr("transform",`translate(${-u/2+d}, ${u/2})`),m&&f.attr("style",m)}else f=Mo(a,u,u,h),f.attr("transform",`translate(${-u/2+d}, ${u/2})`);return r&&f.attr("style",r),Qe(t,f),t.calcIntersect=function(b,y){const v=b.width,w=[{x:v/2,y:0},{x:v,y:-v/2},{x:v/2,y:-v},{x:0,y:-v/2}],S=Fe.polygon(b,w,y);return{x:S.x-.5,y:S.y-.5}},t.intersect=function(b){return this.calcIntersect(t,b)},a}N(V$,"question");async function Y$(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i,label:o}=await lt(e,t,it(t)),l=Math.max(i.width+(t.padding??0),(t==null?void 0:t.width)??0),u=Math.max(i.height+(t.padding??0),(t==null?void 0:t.height)??0),d=-l/2,h=-u/2,f=h/2,m=[{x:d+f,y:h},{x:d,y:0},{x:d+f,y:-h},{x:-d,y:-h},{x:-d,y:h}],{cssStyles:b}=t,y=Ge.svg(a),v=Ve(t,{});t.look!=="handDrawn"&&(v.roughness=0,v.fillStyle="solid");const w=Ft(m),S=y.path(w,v),k=a.insert(()=>S,":first-child");return k.attr("class","basic label-container"),b&&t.look!=="handDrawn"&&k.selectAll("path").attr("style",b),r&&t.look!=="handDrawn"&&k.selectAll("path").attr("style",r),k.attr("transform",`translate(${-f/2},0)`),o.attr("transform",`translate(${-f/2-i.width/2-(i.x-(i.left??0))}, ${-(i.height/2)-(i.y-(i.top??0))})`),Qe(t,k),t.intersect=function(R){return Fe.polygon(t,m,R)},a}N(Y$,"rect_left_inv_arrow");async function X$(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;let a;t.cssClasses?a="node "+t.cssClasses:a="node default";const i=e.insert("g").attr("class",a).attr("id",t.domId||t.id),o=i.insert("g"),l=i.insert("g").attr("class","label").attr("style",r),u=t.description,d=t.label,h=await bs(l,d,t.labelStyle,!0,!0);let f={width:0,height:0};if(xr(qt())){const P=h.children[0],G=Et(h);f=P.getBoundingClientRect(),G.attr("width",f.width),G.attr("height",f.height)}we.info("Text 2",u);const m=u||[],b=h.getBBox(),y=await bs(l,Array.isArray(m)?m.join("<br/>"):m,t.labelStyle,!0,!0),v=y.children[0],w=Et(y);f=v.getBoundingClientRect(),w.attr("width",f.width),w.attr("height",f.height);const S=(t.padding||0)/2;Et(y).attr("transform","translate( "+(f.width>b.width?0:(b.width-f.width)/2)+", "+(b.height+S+5)+")"),Et(h).attr("transform","translate( "+(f.width<b.width?0:-(b.width-f.width)/2)+", 0)"),f=l.node().getBBox(),l.attr("transform","translate("+-f.width/2+", "+(-f.height/2-S+3)+")");const k=f.width+(t.padding||0),R=f.height+(t.padding||0),I=-f.width/2-S,L=-f.height/2-S;let A,M;if(t.look==="handDrawn"){const P=Ge.svg(i),G=Ve(t,{}),B=P.path(Bs(I,L,k,R,t.rx||0),G),H=P.line(-f.width/2-S,-f.height/2-S+b.height+S,f.width/2+S,-f.height/2-S+b.height+S,G);M=i.insert(()=>(we.debug("Rough node insert CXC",B),H),":first-child"),A=i.insert(()=>(we.debug("Rough node insert CXC",B),B),":first-child")}else A=o.insert("rect",":first-child"),M=o.insert("line"),A.attr("class","outer title-state").attr("style",r).attr("x",-f.width/2-S).attr("y",-f.height/2-S).attr("width",f.width+(t.padding||0)).attr("height",f.height+(t.padding||0)),M.attr("class","divider").attr("x1",-f.width/2-S).attr("x2",f.width/2+S).attr("y1",-f.height/2-S+b.height+S).attr("y2",-f.height/2-S+b.height+S);return Qe(t,A),t.intersect=function(P){return Fe.rect(t,P)},i}N(X$,"rectWithTitle");async function K$(e,t){const n={rx:5,ry:5,labelPaddingX:((t==null?void 0:t.padding)||0)*1,labelPaddingY:((t==null?void 0:t.padding)||0)*1};return wp(e,t,n)}N(K$,"roundedRect");async function Z$(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i,label:o}=await lt(e,t,it(t)),l=(t==null?void 0:t.padding)??0,u=Math.max(i.width+(t.padding??0)*2,(t==null?void 0:t.width)??0),d=Math.max(i.height+(t.padding??0)*2,(t==null?void 0:t.height)??0),h=-i.width/2-l,f=-i.height/2-l,{cssStyles:m}=t,b=Ge.svg(a),y=Ve(t,{});t.look!=="handDrawn"&&(y.roughness=0,y.fillStyle="solid");const v=[{x:h,y:f},{x:h+u+8,y:f},{x:h+u+8,y:f+d},{x:h-8,y:f+d},{x:h-8,y:f},{x:h,y:f},{x:h,y:f+d}],w=b.polygon(v.map(k=>[k.x,k.y]),y),S=a.insert(()=>w,":first-child");return S.attr("class","basic label-container").attr("style",vr(m)),r&&t.look!=="handDrawn"&&S.selectAll("path").attr("style",r),m&&t.look!=="handDrawn"&&S.selectAll("path").attr("style",r),o.attr("transform",`translate(${-u/2+4+(t.padding??0)-(i.x-(i.left??0))},${-d/2+(t.padding??0)-(i.y-(i.top??0))})`),Qe(t,S),t.intersect=function(k){return Fe.rect(t,k)},a}N(Z$,"shadedProcess");async function Q$(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i,label:o}=await lt(e,t,it(t)),l=Math.max(i.width+(t.padding??0)*2,(t==null?void 0:t.width)??0),u=Math.max(i.height+(t.padding??0)*2,(t==null?void 0:t.height)??0),d=-l/2,h=-u/2,{cssStyles:f}=t,m=Ge.svg(a),b=Ve(t,{});t.look!=="handDrawn"&&(b.roughness=0,b.fillStyle="solid");const y=[{x:d,y:h},{x:d,y:h+u},{x:d+l,y:h+u},{x:d+l,y:h-u/2}],v=Ft(y),w=m.path(v,b),S=a.insert(()=>w,":first-child");return S.attr("class","basic label-container"),f&&t.look!=="handDrawn"&&S.selectChildren("path").attr("style",f),r&&t.look!=="handDrawn"&&S.selectChildren("path").attr("style",r),S.attr("transform",`translate(0, ${u/4})`),o.attr("transform",`translate(${-l/2+(t.padding??0)-(i.x-(i.left??0))}, ${-u/4+(t.padding??0)-(i.y-(i.top??0))})`),Qe(t,S),t.intersect=function(k){return Fe.polygon(t,y,k)},a}N(Q$,"slopedRect");async function J$(e,t){const n={rx:0,ry:0,labelPaddingX:t.labelPaddingX??((t==null?void 0:t.padding)||0)*2,labelPaddingY:((t==null?void 0:t.padding)||0)*1};return wp(e,t,n)}N(J$,"squareRect");async function eP(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i}=await lt(e,t,it(t)),o=i.height+t.padding,l=i.width+o/4+t.padding,u=o/2,{cssStyles:d}=t,h=Ge.svg(a),f=Ve(t,{});t.look!=="handDrawn"&&(f.roughness=0,f.fillStyle="solid");const m=[{x:-l/2+u,y:-o/2},{x:l/2-u,y:-o/2},...jh(-l/2+u,0,u,50,90,270),{x:l/2-u,y:o/2},...jh(l/2-u,0,u,50,270,450)],b=Ft(m),y=h.path(b,f),v=a.insert(()=>y,":first-child");return v.attr("class","basic label-container outer-path"),d&&t.look!=="handDrawn"&&v.selectChildren("path").attr("style",d),r&&t.look!=="handDrawn"&&v.selectChildren("path").attr("style",r),Qe(t,v),t.intersect=function(w){return Fe.polygon(t,m,w)},a}N(eP,"stadium");async function tP(e,t){return wp(e,t,{rx:5,ry:5})}N(tP,"state");function nP(e,t,{config:{themeVariables:n}}){const{labelStyles:r,nodeStyles:a}=Ye(t);t.labelStyle=r;const{cssStyles:i}=t,{lineColor:o,stateBorder:l,nodeBorder:u}=n,d=e.insert("g").attr("class","node default").attr("id",t.domId||t.id),h=Ge.svg(d),f=Ve(t,{});t.look!=="handDrawn"&&(f.roughness=0,f.fillStyle="solid");const m=h.circle(0,0,14,{...f,stroke:o,strokeWidth:2}),b=l??u,y=h.circle(0,0,5,{...f,fill:b,stroke:b,strokeWidth:2,fillStyle:"solid"}),v=d.insert(()=>m,":first-child");return v.insert(()=>y),i&&v.selectAll("path").attr("style",i),a&&v.selectAll("path").attr("style",a),Qe(t,v),t.intersect=function(w){return Fe.circle(t,7,w)},d}N(nP,"stateEnd");function rP(e,t,{config:{themeVariables:n}}){const{lineColor:r}=n,a=e.insert("g").attr("class","node default").attr("id",t.domId||t.id);let i;if(t.look==="handDrawn"){const l=Ge.svg(a).circle(0,0,14,cbe(r));i=a.insert(()=>l),i.attr("class","state-start").attr("r",7).attr("width",14).attr("height",14)}else i=a.insert("circle",":first-child"),i.attr("class","state-start").attr("r",7).attr("width",14).attr("height",14);return Qe(t,i),t.intersect=function(o){return Fe.circle(t,7,o)},a}N(rP,"stateStart");async function aP(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i}=await lt(e,t,it(t)),o=((t==null?void 0:t.padding)||0)/2,l=i.width+t.padding,u=i.height+t.padding,d=-i.width/2-o,h=-i.height/2-o,f=[{x:0,y:0},{x:l,y:0},{x:l,y:-u},{x:0,y:-u},{x:0,y:0},{x:-8,y:0},{x:l+8,y:0},{x:l+8,y:-u},{x:-8,y:-u},{x:-8,y:0}];if(t.look==="handDrawn"){const m=Ge.svg(a),b=Ve(t,{}),y=m.rectangle(d-8,h,l+16,u,b),v=m.line(d,h,d,h+u,b),w=m.line(d+l,h,d+l,h+u,b);a.insert(()=>v,":first-child"),a.insert(()=>w,":first-child");const S=a.insert(()=>y,":first-child"),{cssStyles:k}=t;S.attr("class","basic label-container").attr("style",vr(k)),Qe(t,S)}else{const m=Mo(a,l,u,f);r&&m.attr("style",r),Qe(t,m)}return t.intersect=function(m){return Fe.polygon(t,f,m)},a}N(aP,"subroutine");async function iP(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i}=await lt(e,t,it(t)),o=Math.max(i.width+(t.padding??0)*2,(t==null?void 0:t.width)??0),l=Math.max(i.height+(t.padding??0)*2,(t==null?void 0:t.height)??0),u=-o/2,d=-l/2,h=.2*l,f=.2*l,{cssStyles:m}=t,b=Ge.svg(a),y=Ve(t,{}),v=[{x:u-h/2,y:d},{x:u+o+h/2,y:d},{x:u+o+h/2,y:d+l},{x:u-h/2,y:d+l}],w=[{x:u+o-h/2,y:d+l},{x:u+o+h/2,y:d+l},{x:u+o+h/2,y:d+l-f}];t.look!=="handDrawn"&&(y.roughness=0,y.fillStyle="solid");const S=Ft(v),k=b.path(S,y),R=Ft(w),I=b.path(R,{...y,fillStyle:"solid"}),L=a.insert(()=>I,":first-child");return L.insert(()=>k,":first-child"),L.attr("class","basic label-container"),m&&t.look!=="handDrawn"&&L.selectAll("path").attr("style",m),r&&t.look!=="handDrawn"&&L.selectAll("path").attr("style",r),Qe(t,L),t.intersect=function(A){return Fe.polygon(t,v,A)},a}N(iP,"taggedRect");async function oP(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i,label:o}=await lt(e,t,it(t)),l=Math.max(i.width+(t.padding??0)*2,(t==null?void 0:t.width)??0),u=Math.max(i.height+(t.padding??0)*2,(t==null?void 0:t.height)??0),d=u/4,h=.2*l,f=.2*u,m=u+d,{cssStyles:b}=t,y=Ge.svg(a),v=Ve(t,{});t.look!=="handDrawn"&&(v.roughness=0,v.fillStyle="solid");const w=[{x:-l/2-l/2*.1,y:m/2},...Rs(-l/2-l/2*.1,m/2,l/2+l/2*.1,m/2,d,.8),{x:l/2+l/2*.1,y:-m/2},{x:-l/2-l/2*.1,y:-m/2}],S=-l/2+l/2*.1,k=-m/2-f*.4,R=[{x:S+l-h,y:(k+u)*1.4},{x:S+l,y:k+u-f},{x:S+l,y:(k+u)*.9},...Rs(S+l,(k+u)*1.3,S+l-h,(k+u)*1.5,-u*.03,.5)],I=Ft(w),L=y.path(I,v),A=Ft(R),M=y.path(A,{...v,fillStyle:"solid"}),P=a.insert(()=>M,":first-child");return P.insert(()=>L,":first-child"),P.attr("class","basic label-container"),b&&t.look!=="handDrawn"&&P.selectAll("path").attr("style",b),r&&t.look!=="handDrawn"&&P.selectAll("path").attr("style",r),P.attr("transform",`translate(0,${-d/2})`),o.attr("transform",`translate(${-l/2+(t.padding??0)-(i.x-(i.left??0))},${-u/2+(t.padding??0)-d/2-(i.y-(i.top??0))})`),Qe(t,P),t.intersect=function(G){return Fe.polygon(t,w,G)},a}N(oP,"taggedWaveEdgedRectangle");async function sP(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i}=await lt(e,t,it(t)),o=Math.max(i.width+t.padding,(t==null?void 0:t.width)||0),l=Math.max(i.height+t.padding,(t==null?void 0:t.height)||0),u=-o/2,d=-l/2,h=a.insert("rect",":first-child");return h.attr("class","text").attr("style",r).attr("rx",0).attr("ry",0).attr("x",u).attr("y",d).attr("width",o).attr("height",l),Qe(t,h),t.intersect=function(f){return Fe.rect(t,f)},a}N(sP,"text");var t1e=N((e,t,n,r,a,i)=>`M${e},${t}
    a${a},${i} 0,0,1 0,${-r}
    l${n},0
    a${a},${i} 0,0,1 0,${r}
    M${n},${-r}
    a${a},${i} 0,0,0 0,${r}
    l${-n},0`,"createCylinderPathD"),n1e=N((e,t,n,r,a,i)=>[`M${e},${t}`,`M${e+n},${t}`,`a${a},${i} 0,0,0 0,${-r}`,`l${-n},0`,`a${a},${i} 0,0,0 0,${r}`,`l${n},0`].join(" "),"createOuterCylinderPathD"),r1e=N((e,t,n,r,a,i)=>[`M${e+n/2},${-r/2}`,`a${a},${i} 0,0,0 0,${r}`].join(" "),"createInnerCylinderPathD");async function lP(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i,label:o,halfPadding:l}=await lt(e,t,it(t)),u=t.look==="neo"?l*2:l,d=i.height+u,h=d/2,f=h/(2.5+d/50),m=i.width+f+u,{cssStyles:b}=t;let y;if(t.look==="handDrawn"){const v=Ge.svg(a),w=n1e(0,0,m,d,f,h),S=r1e(0,0,m,d,f,h),k=v.path(w,Ve(t,{})),R=v.path(S,Ve(t,{fill:"none"}));y=a.insert(()=>R,":first-child"),y=a.insert(()=>k,":first-child"),y.attr("class","basic label-container"),b&&y.attr("style",b)}else{const v=t1e(0,0,m,d,f,h);y=a.insert("path",":first-child").attr("d",v).attr("class","basic label-container").attr("style",vr(b)).attr("style",r),y.attr("class","basic label-container"),b&&y.selectAll("path").attr("style",b),r&&y.selectAll("path").attr("style",r)}return y.attr("label-offset-x",f),y.attr("transform",`translate(${-m/2}, ${d/2} )`),o.attr("transform",`translate(${-(i.width/2)-f-(i.x-(i.left??0))}, ${-(i.height/2)-(i.y-(i.top??0))})`),Qe(t,y),t.intersect=function(v){const w=Fe.rect(t,v),S=w.y-(t.y??0);if(h!=0&&(Math.abs(S)<(t.height??0)/2||Math.abs(S)==(t.height??0)/2&&Math.abs(w.x-(t.x??0))>(t.width??0)/2-f)){let k=f*f*(1-S*S/(h*h));k!=0&&(k=Math.sqrt(Math.abs(k))),k=f-k,v.x-(t.x??0)>0&&(k=-k),w.x+=k}return w},a}N(lP,"tiltedCylinder");async function cP(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i}=await lt(e,t,it(t)),o=i.width+t.padding,l=i.height+t.padding,u=[{x:-3*l/6,y:0},{x:o+3*l/6,y:0},{x:o,y:-l},{x:0,y:-l}];let d;const{cssStyles:h}=t;if(t.look==="handDrawn"){const f=Ge.svg(a),m=Ve(t,{}),b=Ft(u),y=f.path(b,m);d=a.insert(()=>y,":first-child").attr("transform",`translate(${-o/2}, ${l/2})`),h&&d.attr("style",h)}else d=Mo(a,o,l,u);return r&&d.attr("style",r),t.width=o,t.height=l,Qe(t,d),t.intersect=function(f){return Fe.polygon(t,u,f)},a}N(cP,"trapezoid");async function uP(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i}=await lt(e,t,it(t)),o=60,l=20,u=Math.max(o,i.width+(t.padding??0)*2,(t==null?void 0:t.width)??0),d=Math.max(l,i.height+(t.padding??0)*2,(t==null?void 0:t.height)??0),{cssStyles:h}=t,f=Ge.svg(a),m=Ve(t,{});t.look!=="handDrawn"&&(m.roughness=0,m.fillStyle="solid");const b=[{x:-u/2*.8,y:-d/2},{x:u/2*.8,y:-d/2},{x:u/2,y:-d/2*.6},{x:u/2,y:d/2},{x:-u/2,y:d/2},{x:-u/2,y:-d/2*.6}],y=Ft(b),v=f.path(y,m),w=a.insert(()=>v,":first-child");return w.attr("class","basic label-container"),h&&t.look!=="handDrawn"&&w.selectChildren("path").attr("style",h),r&&t.look!=="handDrawn"&&w.selectChildren("path").attr("style",r),Qe(t,w),t.intersect=function(S){return Fe.polygon(t,b,S)},a}N(uP,"trapezoidalPentagon");async function dP(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i,label:o}=await lt(e,t,it(t)),l=t.useHtmlLabels||xr(qt()),u=i.width+(t.padding??0),d=u+i.height,h=u+i.height,f=[{x:0,y:0},{x:h,y:0},{x:h/2,y:-d}],{cssStyles:m}=t,b=Ge.svg(a),y=Ve(t,{});t.look!=="handDrawn"&&(y.roughness=0,y.fillStyle="solid");const v=Ft(f),w=b.path(v,y),S=a.insert(()=>w,":first-child").attr("transform",`translate(${-d/2}, ${d/2})`);return m&&t.look!=="handDrawn"&&S.selectChildren("path").attr("style",m),r&&t.look!=="handDrawn"&&S.selectChildren("path").attr("style",r),t.width=u,t.height=d,Qe(t,S),o.attr("transform",`translate(${-i.width/2-(i.x-(i.left??0))}, ${d/2-(i.height+(t.padding??0)/(l?2:1)-(i.y-(i.top??0)))})`),t.intersect=function(k){return we.info("Triangle intersect",t,f,k),Fe.polygon(t,f,k)},a}N(dP,"triangle");async function hP(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i,label:o}=await lt(e,t,it(t)),l=Math.max(i.width+(t.padding??0)*2,(t==null?void 0:t.width)??0),u=Math.max(i.height+(t.padding??0)*2,(t==null?void 0:t.height)??0),d=u/8,h=u+d,{cssStyles:f}=t,b=70-l,y=b>0?b/2:0,v=Ge.svg(a),w=Ve(t,{});t.look!=="handDrawn"&&(w.roughness=0,w.fillStyle="solid");const S=[{x:-l/2-y,y:h/2},...Rs(-l/2-y,h/2,l/2+y,h/2,d,.8),{x:l/2+y,y:-h/2},{x:-l/2-y,y:-h/2}],k=Ft(S),R=v.path(k,w),I=a.insert(()=>R,":first-child");return I.attr("class","basic label-container"),f&&t.look!=="handDrawn"&&I.selectAll("path").attr("style",f),r&&t.look!=="handDrawn"&&I.selectAll("path").attr("style",r),I.attr("transform",`translate(0,${-d/2})`),o.attr("transform",`translate(${-l/2+(t.padding??0)-(i.x-(i.left??0))},${-u/2+(t.padding??0)-d-(i.y-(i.top??0))})`),Qe(t,I),t.intersect=function(L){return Fe.polygon(t,S,L)},a}N(hP,"waveEdgedRectangle");async function pP(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i}=await lt(e,t,it(t)),o=100,l=50,u=Math.max(i.width+(t.padding??0)*2,(t==null?void 0:t.width)??0),d=Math.max(i.height+(t.padding??0)*2,(t==null?void 0:t.height)??0),h=u/d;let f=u,m=d;f>m*h?m=f/h:f=m*h,f=Math.max(f,o),m=Math.max(m,l);const b=Math.min(m*.2,m/4),y=m+b*2,{cssStyles:v}=t,w=Ge.svg(a),S=Ve(t,{});t.look!=="handDrawn"&&(S.roughness=0,S.fillStyle="solid");const k=[{x:-f/2,y:y/2},...Rs(-f/2,y/2,f/2,y/2,b,1),{x:f/2,y:-y/2},...Rs(f/2,-y/2,-f/2,-y/2,b,-1)],R=Ft(k),I=w.path(R,S),L=a.insert(()=>I,":first-child");return L.attr("class","basic label-container"),v&&t.look!=="handDrawn"&&L.selectAll("path").attr("style",v),r&&t.look!=="handDrawn"&&L.selectAll("path").attr("style",r),Qe(t,L),t.intersect=function(A){return Fe.polygon(t,k,A)},a}N(pP,"waveRectangle");async function fP(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i,label:o}=await lt(e,t,it(t)),l=Math.max(i.width+(t.padding??0)*2,(t==null?void 0:t.width)??0),u=Math.max(i.height+(t.padding??0)*2,(t==null?void 0:t.height)??0),d=5,h=-l/2,f=-u/2,{cssStyles:m}=t,b=Ge.svg(a),y=Ve(t,{}),v=[{x:h-d,y:f-d},{x:h-d,y:f+u},{x:h+l,y:f+u},{x:h+l,y:f-d}],w=`M${h-d},${f-d} L${h+l},${f-d} L${h+l},${f+u} L${h-d},${f+u} L${h-d},${f-d}
                M${h-d},${f} L${h+l},${f}
                M${h},${f-d} L${h},${f+u}`;t.look!=="handDrawn"&&(y.roughness=0,y.fillStyle="solid");const S=b.path(w,y),k=a.insert(()=>S,":first-child");return k.attr("transform",`translate(${d/2}, ${d/2})`),k.attr("class","basic label-container"),m&&t.look!=="handDrawn"&&k.selectAll("path").attr("style",m),r&&t.look!=="handDrawn"&&k.selectAll("path").attr("style",r),o.attr("transform",`translate(${-(i.width/2)+d/2-(i.x-(i.left??0))}, ${-(i.height/2)+d/2-(i.y-(i.top??0))})`),Qe(t,k),t.intersect=function(R){return Fe.polygon(t,v,R)},a}N(fP,"windowPane");async function cC(e,t){var oe,U,be,ge;const n=t;if(n.alias&&(t.label=n.alias),t.look==="handDrawn"){const{themeVariables:fe}=br(),{background:Ee}=fe,Ae={...t,id:t.id+"-background",look:"default",cssStyles:["stroke: none",`fill: ${Ee}`]};await cC(e,Ae)}const r=br();t.useHtmlLabels=r.htmlLabels;let a=((oe=r.er)==null?void 0:oe.diagramPadding)??10,i=((U=r.er)==null?void 0:U.entityPadding)??6;const{cssStyles:o}=t,{labelStyles:l,nodeStyles:u}=Ye(t);if(n.attributes.length===0&&t.label){const fe={rx:0,ry:0,labelPaddingX:a,labelPaddingY:a*1.5};Co(t.label,r)+fe.labelPaddingX*2<r.er.minEntityWidth&&(t.width=r.er.minEntityWidth);const Ee=await wp(e,t,fe);if(!Ds(r.htmlLabels)){const Ae=Ee.select("text"),ve=(be=Ae.node())==null?void 0:be.getBBox();Ae.attr("transform",`translate(${-ve.width/2}, 0)`)}return Ee}r.htmlLabels||(a*=1.25,i*=1.25);let d=it(t);d||(d="node default");const h=e.insert("g").attr("class",d).attr("id",t.domId||t.id),f=await Oc(h,t.label??"",r,0,0,["name"],l);f.height+=i;let m=0;const b=[],y=[];let v=0,w=0,S=0,k=0,R=!0,I=!0;for(const fe of n.attributes){const Ee=await Oc(h,fe.type,r,0,m,["attribute-type"],l);v=Math.max(v,Ee.width+a);const Ae=await Oc(h,fe.name,r,0,m,["attribute-name"],l);w=Math.max(w,Ae.width+a);const ve=await Oc(h,fe.keys.join(),r,0,m,["attribute-keys"],l);S=Math.max(S,ve.width+a);const De=await Oc(h,fe.comment,r,0,m,["attribute-comment"],l);k=Math.max(k,De.width+a);const Le=Math.max(Ee.height,Ae.height,ve.height,De.height)+i;y.push({yOffset:m,rowHeight:Le}),m+=Le}let L=4;S<=a&&(R=!1,S=0,L--),k<=a&&(I=!1,k=0,L--);const A=h.node().getBBox();if(f.width+a*2-(v+w+S+k)>0){const fe=f.width+a*2-(v+w+S+k);v+=fe/L,w+=fe/L,S>0&&(S+=fe/L),k>0&&(k+=fe/L)}const M=v+w+S+k,P=Ge.svg(h),G=Ve(t,{});t.look!=="handDrawn"&&(G.roughness=0,G.fillStyle="solid");let B=0;y.length>0&&(B=y.reduce((fe,Ee)=>fe+((Ee==null?void 0:Ee.rowHeight)??0),0));const H=Math.max(A.width+a*2,(t==null?void 0:t.width)||0,M),Z=Math.max((B??0)+f.height,(t==null?void 0:t.height)||0),V=-H/2,q=-Z/2;h.selectAll("g:not(:first-child)").each((fe,Ee,Ae)=>{const ve=Et(Ae[Ee]),De=ve.attr("transform");let Le=0,rt=0;if(De){const gt=RegExp(/translate\(([^,]+),([^)]+)\)/).exec(De);gt&&(Le=parseFloat(gt[1]),rt=parseFloat(gt[2]),ve.attr("class").includes("attribute-name")?Le+=v:ve.attr("class").includes("attribute-keys")?Le+=v+w:ve.attr("class").includes("attribute-comment")&&(Le+=v+w+S))}ve.attr("transform",`translate(${V+a/2+Le}, ${rt+q+f.height+i/2})`)}),h.select(".name").attr("transform","translate("+-f.width/2+", "+(q+i/2)+")");const X=P.rectangle(V,q,H,Z,G),$=h.insert(()=>X,":first-child").attr("style",o.join("")),{themeVariables:Q}=br(),{rowEven:J,rowOdd:ie,nodeBorder:F}=Q;b.push(0);for(const[fe,Ee]of y.entries()){const ve=(fe+1)%2===0&&Ee.yOffset!==0,De=P.rectangle(V,f.height+q+(Ee==null?void 0:Ee.yOffset),H,Ee==null?void 0:Ee.rowHeight,{...G,fill:ve?J:ie,stroke:F});h.insert(()=>De,"g.label").attr("style",o.join("")).attr("class",`row-rect-${ve?"even":"odd"}`)}let Y=P.line(V,f.height+q,H+V,f.height+q,G);h.insert(()=>Y).attr("class","divider"),Y=P.line(v+V,f.height+q,v+V,Z+q,G),h.insert(()=>Y).attr("class","divider"),R&&(Y=P.line(v+w+V,f.height+q,v+w+V,Z+q,G),h.insert(()=>Y).attr("class","divider")),I&&(Y=P.line(v+w+S+V,f.height+q,v+w+S+V,Z+q,G),h.insert(()=>Y).attr("class","divider"));for(const fe of b)Y=P.line(V,f.height+q+fe,H+V,f.height+q+fe,G),h.insert(()=>Y).attr("class","divider");if(Qe(t,$),u&&t.look!=="handDrawn"){const fe=u.split(";"),Ee=(ge=fe==null?void 0:fe.filter(Ae=>Ae.includes("stroke")))==null?void 0:ge.map(Ae=>`${Ae}`).join("; ");h.selectAll("path").attr("style",Ee??""),h.selectAll(".row-rect-even path").attr("style",u)}return t.intersect=function(fe){return Fe.rect(t,fe)},h}N(cC,"erBox");async function Oc(e,t,n,r=0,a=0,i=[],o=""){const l=e.insert("g").attr("class",`label ${i.join(" ")}`).attr("transform",`translate(${r}, ${a})`).attr("style",o);t!==p7(t)&&(t=p7(t),t=t.replaceAll("<","&lt;").replaceAll(">","&gt;"));const u=l.node().appendChild(await Do(l,t,{width:Co(t,n)+100,style:o,useHtmlLabels:n.htmlLabels},n));if(t.includes("&lt;")||t.includes("&gt;")){let h=u.children[0];for(h.textContent=h.textContent.replaceAll("&lt;","<").replaceAll("&gt;",">");h.childNodes[0];)h=h.childNodes[0],h.textContent=h.textContent.replaceAll("&lt;","<").replaceAll("&gt;",">")}let d=u.getBBox();if(Ds(n.htmlLabels)){const h=u.children[0];h.style.textAlign="start";const f=Et(u);d=h.getBoundingClientRect(),f.attr("width",d.width),f.attr("height",d.height)}return d}N(Oc,"addText");async function mP(e,t,n,r,a=n.class.padding??12){const i=r?0:3,o=e.insert("g").attr("class",it(t)).attr("id",t.domId||t.id);let l=null,u=null,d=null,h=null,f=0,m=0,b=0;if(l=o.insert("g").attr("class","annotation-group text"),t.annotations.length>0){const k=t.annotations[0];await ih(l,{text:`«${k}»`},0),f=l.node().getBBox().height}u=o.insert("g").attr("class","label-group text"),await ih(u,t,0,["font-weight: bolder"]);const y=u.node().getBBox();m=y.height,d=o.insert("g").attr("class","members-group text");let v=0;for(const k of t.members){const R=await ih(d,k,v,[k.parseClassifier()]);v+=R+i}b=d.node().getBBox().height,b<=0&&(b=a/2),h=o.insert("g").attr("class","methods-group text");let w=0;for(const k of t.methods){const R=await ih(h,k,w,[k.parseClassifier()]);w+=R+i}let S=o.node().getBBox();if(l!==null){const k=l.node().getBBox();l.attr("transform",`translate(${-k.width/2})`)}return u.attr("transform",`translate(${-y.width/2}, ${f})`),S=o.node().getBBox(),d.attr("transform",`translate(0, ${f+m+a*2})`),S=o.node().getBBox(),h.attr("transform",`translate(0, ${f+m+(b?b+a*4:a*2)})`),S=o.node().getBBox(),{shapeSvg:o,bbox:S}}N(mP,"textHelper");async function ih(e,t,n,r=[]){const a=e.insert("g").attr("class","label").attr("style",r.join("; ")),i=br();let o="useHtmlLabels"in t?t.useHtmlLabels:Ds(i.htmlLabels)??!0,l="";"text"in t?l=t.text:l=t.label,!o&&l.startsWith("\\")&&(l=l.substring(1)),Oh(l)&&(o=!0);const u=await Do(a,y_(Ou(l)),{width:Co(l,i)+50,classes:"markdown-node-label",useHtmlLabels:o},i);let d,h=1;if(o){const f=u.children[0],m=Et(u);h=f.innerHTML.split("<br>").length,f.innerHTML.includes("</math>")&&(h+=f.innerHTML.split("<mrow>").length-1);const b=f.getElementsByTagName("img");if(b){const y=l.replace(/<img[^>]*>/g,"").trim()==="";await Promise.all([...b].map(v=>new Promise(w=>{function S(){var k;if(v.style.display="flex",v.style.flexDirection="column",y){const R=((k=i.fontSize)==null?void 0:k.toString())??window.getComputedStyle(document.body).fontSize,L=parseInt(R,10)*5+"px";v.style.minWidth=L,v.style.maxWidth=L}else v.style.width="100%";w(v)}N(S,"setupImage"),setTimeout(()=>{v.complete&&S()}),v.addEventListener("error",S),v.addEventListener("load",S)})))}d=f.getBoundingClientRect(),m.attr("width",d.width),m.attr("height",d.height)}else{r.includes("font-weight: bolder")&&Et(u).selectAll("tspan").attr("font-weight",""),h=u.children.length;const f=u.children[0];(u.textContent===""||u.textContent.includes("&gt"))&&(f.textContent=l[0]+l.substring(1).replaceAll("&gt;",">").replaceAll("&lt;","<").trim(),l[1]===" "&&(f.textContent=f.textContent[0]+" "+f.textContent.substring(1))),f.textContent==="undefined"&&(f.textContent=""),d=u.getBBox()}return a.attr("transform","translate(0,"+(-d.height/(2*h)+n)+")"),d.height}N(ih,"addText");async function gP(e,t){var G,B;const n=qt(),r=n.class.padding??12,a=r,i=t.useHtmlLabels??Ds(n.htmlLabels)??!0,o=t;o.annotations=o.annotations??[],o.members=o.members??[],o.methods=o.methods??[];const{shapeSvg:l,bbox:u}=await mP(e,t,n,i,a),{labelStyles:d,nodeStyles:h}=Ye(t);t.labelStyle=d,t.cssStyles=o.styles||"";const f=((G=o.styles)==null?void 0:G.join(";"))||h||"";t.cssStyles||(t.cssStyles=f.replaceAll("!important","").split(";"));const m=o.members.length===0&&o.methods.length===0&&!((B=n.class)!=null&&B.hideEmptyMembersBox),b=Ge.svg(l),y=Ve(t,{});t.look!=="handDrawn"&&(y.roughness=0,y.fillStyle="solid");const v=u.width;let w=u.height;o.members.length===0&&o.methods.length===0?w+=a:o.members.length>0&&o.methods.length===0&&(w+=a*2);const S=-v/2,k=-w/2,R=b.rectangle(S-r,k-r-(m?r:o.members.length===0&&o.methods.length===0?-r/2:0),v+2*r,w+2*r+(m?r*2:o.members.length===0&&o.methods.length===0?-r:0),y),I=l.insert(()=>R,":first-child");I.attr("class","basic label-container");const L=I.node().getBBox();l.selectAll(".text").each((H,Z,V)=>{var ie;const q=Et(V[Z]),X=q.attr("transform");let $=0;if(X){const Y=RegExp(/translate\(([^,]+),([^)]+)\)/).exec(X);Y&&($=parseFloat(Y[2]))}let Q=$+k+r-(m?r:o.members.length===0&&o.methods.length===0?-r/2:0);i||(Q-=4);let J=S;(q.attr("class").includes("label-group")||q.attr("class").includes("annotation-group"))&&(J=-((ie=q.node())==null?void 0:ie.getBBox().width)/2||0,l.selectAll("text").each(function(F,Y,oe){window.getComputedStyle(oe[Y]).textAnchor==="middle"&&(J=0)})),q.attr("transform",`translate(${J}, ${Q})`)});const A=l.select(".annotation-group").node().getBBox().height-(m?r/2:0)||0,M=l.select(".label-group").node().getBBox().height-(m?r/2:0)||0,P=l.select(".members-group").node().getBBox().height-(m?r/2:0)||0;if(o.members.length>0||o.methods.length>0||m){const H=b.line(L.x,A+M+k+r,L.x+L.width,A+M+k+r,y);l.insert(()=>H).attr("class","divider").attr("style",f)}if(m||o.members.length>0||o.methods.length>0){const H=b.line(L.x,A+M+P+k+a*2+r,L.x+L.width,A+M+P+k+r+a*2,y);l.insert(()=>H).attr("class","divider").attr("style",f)}if(o.look!=="handDrawn"&&l.selectAll("path").attr("style",f),I.select(":nth-child(2)").attr("style",f),l.selectAll(".divider").select("path").attr("style",f),t.labelStyle?l.selectAll("span").attr("style",t.labelStyle):l.selectAll("span").attr("style",f),!i){const H=RegExp(/color\s*:\s*([^;]*)/),Z=H.exec(f);if(Z){const V=Z[0].replace("color","fill");l.selectAll("tspan").attr("style",V)}else if(d){const V=H.exec(d);if(V){const q=V[0].replace("color","fill");l.selectAll("tspan").attr("style",q)}}}return Qe(t,I),t.intersect=function(H){return Fe.rect(t,H)},l}N(gP,"classBox");async function bP(e,t){var A,M;const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const a=t,i=t,o=20,l=20,u="verifyMethod"in t,d=it(t),h=e.insert("g").attr("class",d).attr("id",t.domId??t.id);let f;u?f=await vi(h,`&lt;&lt;${a.type}&gt;&gt;`,0,t.labelStyle):f=await vi(h,"&lt;&lt;Element&gt;&gt;",0,t.labelStyle);let m=f;const b=await vi(h,a.name,m,t.labelStyle+"; font-weight: bold;");if(m+=b+l,u){const P=await vi(h,`${a.requirementId?`ID: ${a.requirementId}`:""}`,m,t.labelStyle);m+=P;const G=await vi(h,`${a.text?`Text: ${a.text}`:""}`,m,t.labelStyle);m+=G;const B=await vi(h,`${a.risk?`Risk: ${a.risk}`:""}`,m,t.labelStyle);m+=B,await vi(h,`${a.verifyMethod?`Verification: ${a.verifyMethod}`:""}`,m,t.labelStyle)}else{const P=await vi(h,`${i.type?`Type: ${i.type}`:""}`,m,t.labelStyle);m+=P,await vi(h,`${i.docRef?`Doc Ref: ${i.docRef}`:""}`,m,t.labelStyle)}const y=(((A=h.node())==null?void 0:A.getBBox().width)??200)+o,v=(((M=h.node())==null?void 0:M.getBBox().height)??200)+o,w=-y/2,S=-v/2,k=Ge.svg(h),R=Ve(t,{});t.look!=="handDrawn"&&(R.roughness=0,R.fillStyle="solid");const I=k.rectangle(w,S,y,v,R),L=h.insert(()=>I,":first-child");if(L.attr("class","basic label-container").attr("style",r),h.selectAll(".label").each((P,G,B)=>{const H=Et(B[G]),Z=H.attr("transform");let V=0,q=0;if(Z){const J=RegExp(/translate\(([^,]+),([^)]+)\)/).exec(Z);J&&(V=parseFloat(J[1]),q=parseFloat(J[2]))}const X=q-v/2;let $=w+o/2;(G===0||G===1)&&($=V),H.attr("transform",`translate(${$}, ${X+o})`)}),m>f+b+l){const P=k.line(w,S+f+b+l,w+y,S+f+b+l,R);h.insert(()=>P).attr("style",r)}return Qe(t,L),t.intersect=function(P){return Fe.rect(t,P)},h}N(bP,"requirementBox");async function vi(e,t,n,r=""){if(t==="")return 0;const a=e.insert("g").attr("class","label").attr("style",r),i=qt(),o=i.htmlLabels??!0,l=await Do(a,y_(Ou(t)),{width:Co(t,i)+50,classes:"markdown-node-label",useHtmlLabels:o,style:r},i);let u;if(o){const d=l.children[0],h=Et(l);u=d.getBoundingClientRect(),h.attr("width",u.width),h.attr("height",u.height)}else{const d=l.children[0];for(const h of d.children)h.textContent=h.textContent.replaceAll("&gt;",">").replaceAll("&lt;","<"),r&&h.setAttribute("style",r);u=l.getBBox(),u.height+=6}return a.attr("transform",`translate(${-u.width/2},${-u.height/2+n})`),u.height}N(vi,"addText");var a1e=N(e=>{switch(e){case"Very High":return"red";case"High":return"orange";case"Medium":return null;case"Low":return"blue";case"Very Low":return"lightblue"}},"colorFromPriority");async function yP(e,t,{config:n}){var Z,V;const{labelStyles:r,nodeStyles:a}=Ye(t);t.labelStyle=r||"";const i=10,o=t.width;t.width=(t.width??200)-10;const{shapeSvg:l,bbox:u,label:d}=await lt(e,t,it(t)),h=t.padding||10;let f="",m;"ticket"in t&&t.ticket&&((Z=n==null?void 0:n.kanban)!=null&&Z.ticketBaseUrl)&&(f=(V=n==null?void 0:n.kanban)==null?void 0:V.ticketBaseUrl.replace("#TICKET#",t.ticket),m=l.insert("svg:a",":first-child").attr("class","kanban-ticket-link").attr("xlink:href",f).attr("target","_blank"));const b={useHtmlLabels:t.useHtmlLabels,labelStyle:t.labelStyle||"",width:t.width,img:t.img,padding:t.padding||8,centerLabel:!1};let y,v;m?{label:y,bbox:v}=await Kv(m,"ticket"in t&&t.ticket||"",b):{label:y,bbox:v}=await Kv(l,"ticket"in t&&t.ticket||"",b);const{label:w,bbox:S}=await Kv(l,"assigned"in t&&t.assigned||"",b);t.width=o;const k=10,R=(t==null?void 0:t.width)||0,I=Math.max(v.height,S.height)/2,L=Math.max(u.height+k*2,(t==null?void 0:t.height)||0)+I,A=-R/2,M=-L/2;d.attr("transform","translate("+(h-R/2)+", "+(-I-u.height/2)+")"),y.attr("transform","translate("+(h-R/2)+", "+(-I+u.height/2)+")"),w.attr("transform","translate("+(h+R/2-S.width-2*i)+", "+(-I+u.height/2)+")");let P;const{rx:G,ry:B}=t,{cssStyles:H}=t;if(t.look==="handDrawn"){const q=Ge.svg(l),X=Ve(t,{}),$=G||B?q.path(Bs(A,M,R,L,G||0),X):q.rectangle(A,M,R,L,X);P=l.insert(()=>$,":first-child"),P.attr("class","basic label-container").attr("style",H||null)}else{P=l.insert("rect",":first-child"),P.attr("class","basic label-container __APA__").attr("style",a).attr("rx",G??5).attr("ry",B??5).attr("x",A).attr("y",M).attr("width",R).attr("height",L);const q="priority"in t&&t.priority;if(q){const X=l.append("line"),$=A+2,Q=M+Math.floor((G??0)/2),J=M+L-Math.floor((G??0)/2);X.attr("x1",$).attr("y1",Q).attr("x2",$).attr("y2",J).attr("stroke-width","4").attr("stroke",a1e(q))}}return Qe(t,P),t.height=L,t.intersect=function(q){return Fe.rect(t,q)},l}N(yP,"kanbanItem");async function vP(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i,halfPadding:o,label:l}=await lt(e,t,it(t)),u=i.width+10*o,d=i.height+8*o,h=.15*u,{cssStyles:f}=t,m=i.width+20,b=i.height+20,y=Math.max(u,m),v=Math.max(d,b);l.attr("transform",`translate(${-i.width/2}, ${-i.height/2})`);let w;const S=`M0 0 
    a${h},${h} 1 0,0 ${y*.25},${-1*v*.1}
    a${h},${h} 1 0,0 ${y*.25},0
    a${h},${h} 1 0,0 ${y*.25},0
    a${h},${h} 1 0,0 ${y*.25},${v*.1}

    a${h},${h} 1 0,0 ${y*.15},${v*.33}
    a${h*.8},${h*.8} 1 0,0 0,${v*.34}
    a${h},${h} 1 0,0 ${-1*y*.15},${v*.33}

    a${h},${h} 1 0,0 ${-1*y*.25},${v*.15}
    a${h},${h} 1 0,0 ${-1*y*.25},0
    a${h},${h} 1 0,0 ${-1*y*.25},0
    a${h},${h} 1 0,0 ${-1*y*.25},${-1*v*.15}

    a${h},${h} 1 0,0 ${-1*y*.1},${-1*v*.33}
    a${h*.8},${h*.8} 1 0,0 0,${-1*v*.34}
    a${h},${h} 1 0,0 ${y*.1},${-1*v*.33}
  H0 V0 Z`;if(t.look==="handDrawn"){const k=Ge.svg(a),R=Ve(t,{}),I=k.path(S,R);w=a.insert(()=>I,":first-child"),w.attr("class","basic label-container").attr("style",vr(f))}else w=a.insert("path",":first-child").attr("class","basic label-container").attr("style",r).attr("d",S);return w.attr("transform",`translate(${-y/2}, ${-v/2})`),Qe(t,w),t.calcIntersect=function(k,R){return Fe.rect(k,R)},t.intersect=function(k){return we.info("Bang intersect",t,k),Fe.rect(t,k)},a}N(vP,"bang");async function xP(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i,halfPadding:o,label:l}=await lt(e,t,it(t)),u=i.width+2*o,d=i.height+2*o,h=.15*u,f=.25*u,m=.35*u,b=.2*u,{cssStyles:y}=t;let v;const w=`M0 0 
    a${h},${h} 0 0,1 ${u*.25},${-1*u*.1}
    a${m},${m} 1 0,1 ${u*.4},${-1*u*.1}
    a${f},${f} 1 0,1 ${u*.35},${u*.2}

    a${h},${h} 1 0,1 ${u*.15},${d*.35}
    a${b},${b} 1 0,1 ${-1*u*.15},${d*.65}

    a${f},${h} 1 0,1 ${-1*u*.25},${u*.15}
    a${m},${m} 1 0,1 ${-1*u*.5},0
    a${h},${h} 1 0,1 ${-1*u*.25},${-1*u*.15}

    a${h},${h} 1 0,1 ${-1*u*.1},${-1*d*.35}
    a${b},${b} 1 0,1 ${u*.1},${-1*d*.65}
  H0 V0 Z`;if(t.look==="handDrawn"){const S=Ge.svg(a),k=Ve(t,{}),R=S.path(w,k);v=a.insert(()=>R,":first-child"),v.attr("class","basic label-container").attr("style",vr(y))}else v=a.insert("path",":first-child").attr("class","basic label-container").attr("style",r).attr("d",w);return l.attr("transform",`translate(${-i.width/2}, ${-i.height/2})`),v.attr("transform",`translate(${-u/2}, ${-d/2})`),Qe(t,v),t.calcIntersect=function(S,k){return Fe.rect(S,k)},t.intersect=function(S){return we.info("Cloud intersect",t,S),Fe.rect(t,S)},a}N(xP,"cloud");async function SP(e,t){const{labelStyles:n,nodeStyles:r}=Ye(t);t.labelStyle=n;const{shapeSvg:a,bbox:i,halfPadding:o,label:l}=await lt(e,t,it(t)),u=i.width+8*o,d=i.height+2*o,h=5,f=`
    M${-u/2} ${d/2-h}
    v${-d+2*h}
    q0,-${h} ${h},-${h}
    h${u-2*h}
    q${h},0 ${h},${h}
    v${d-2*h}
    q0,${h} -${h},${h}
    h${-u+2*h}
    q-${h},0 -${h},-${h}
    Z
  `,m=a.append("path").attr("id","node-"+t.id).attr("class","node-bkg node-"+t.type).attr("style",r).attr("d",f);return a.append("line").attr("class","node-line-").attr("x1",-u/2).attr("y1",d/2).attr("x2",u/2).attr("y2",d/2),l.attr("transform",`translate(${-i.width/2}, ${-i.height/2})`),a.append(()=>l.node()),Qe(t,m),t.calcIntersect=function(b,y){return Fe.rect(b,y)},t.intersect=function(b){return Fe.rect(t,b)},a}N(SP,"defaultMindmapNode");async function wP(e,t){const n={padding:t.padding??0};return lC(e,t,n)}N(wP,"mindmapCircle");var i1e=[{semanticName:"Process",name:"Rectangle",shortName:"rect",description:"Standard process shape",aliases:["proc","process","rectangle"],internalAliases:["squareRect"],handler:J$},{semanticName:"Event",name:"Rounded Rectangle",shortName:"rounded",description:"Represents an event",aliases:["event"],internalAliases:["roundedRect"],handler:K$},{semanticName:"Terminal Point",name:"Stadium",shortName:"stadium",description:"Terminal point",aliases:["terminal","pill"],handler:eP},{semanticName:"Subprocess",name:"Framed Rectangle",shortName:"fr-rect",description:"Subprocess",aliases:["subprocess","subproc","framed-rectangle","subroutine"],handler:aP},{semanticName:"Database",name:"Cylinder",shortName:"cyl",description:"Database storage",aliases:["db","database","cylinder"],handler:E$},{semanticName:"Start",name:"Circle",shortName:"circle",description:"Starting point",aliases:["circ"],handler:lC},{semanticName:"Bang",name:"Bang",shortName:"bang",description:"Bang",aliases:["bang"],handler:vP},{semanticName:"Cloud",name:"Cloud",shortName:"cloud",description:"cloud",aliases:["cloud"],handler:xP},{semanticName:"Decision",name:"Diamond",shortName:"diam",description:"Decision-making step",aliases:["decision","diamond","question"],handler:V$},{semanticName:"Prepare Conditional",name:"Hexagon",shortName:"hex",description:"Preparation or condition step",aliases:["hexagon","prepare"],handler:N$},{semanticName:"Data Input/Output",name:"Lean Right",shortName:"lean-r",description:"Represents input or output",aliases:["lean-right","in-out"],internalAliases:["lean_right"],handler:P$},{semanticName:"Data Input/Output",name:"Lean Left",shortName:"lean-l",description:"Represents output or input",aliases:["lean-left","out-in"],internalAliases:["lean_left"],handler:$$},{semanticName:"Priority Action",name:"Trapezoid Base Bottom",shortName:"trap-b",description:"Priority action",aliases:["priority","trapezoid-bottom","trapezoid"],handler:cP},{semanticName:"Manual Operation",name:"Trapezoid Base Top",shortName:"trap-t",description:"Represents a manual task",aliases:["manual","trapezoid-top","inv-trapezoid"],internalAliases:["inv_trapezoid"],handler:F$},{semanticName:"Stop",name:"Double Circle",shortName:"dbl-circ",description:"Represents a stop point",aliases:["double-circle"],internalAliases:["doublecircle"],handler:T$},{semanticName:"Text Block",name:"Text Block",shortName:"text",description:"Text block",handler:sP},{semanticName:"Card",name:"Notched Rectangle",shortName:"notch-rect",description:"Represents a card",aliases:["card","notched-rectangle"],handler:m$},{semanticName:"Lined/Shaded Process",name:"Lined Rectangle",shortName:"lin-rect",description:"Lined process shape",aliases:["lined-rectangle","lined-process","lin-proc","shaded-process"],handler:Z$},{semanticName:"Start",name:"Small Circle",shortName:"sm-circ",description:"Small starting point",aliases:["start","small-circle"],internalAliases:["stateStart"],handler:rP},{semanticName:"Stop",name:"Framed Circle",shortName:"fr-circ",description:"Stop point",aliases:["stop","framed-circle"],internalAliases:["stateEnd"],handler:nP},{semanticName:"Fork/Join",name:"Filled Rectangle",shortName:"fork",description:"Fork or join in process flow",aliases:["join"],internalAliases:["forkJoin"],handler:A$},{semanticName:"Collate",name:"Hourglass",shortName:"hourglass",description:"Represents a collate operation",aliases:["hourglass","collate"],handler:O$},{semanticName:"Comment",name:"Curly Brace",shortName:"brace",description:"Adds a comment",aliases:["comment","brace-l"],handler:v$},{semanticName:"Comment Right",name:"Curly Brace",shortName:"brace-r",description:"Adds a comment",handler:x$},{semanticName:"Comment with braces on both sides",name:"Curly Braces",shortName:"braces",description:"Adds a comment",handler:S$},{semanticName:"Com Link",name:"Lightning Bolt",shortName:"bolt",description:"Communication link",aliases:["com-link","lightning-bolt"],handler:U$},{semanticName:"Document",name:"Document",shortName:"doc",description:"Represents a document",aliases:["doc","document"],handler:hP},{semanticName:"Delay",name:"Half-Rounded Rectangle",shortName:"delay",description:"Represents a delay",aliases:["half-rounded-rectangle"],handler:R$},{semanticName:"Direct Access Storage",name:"Horizontal Cylinder",shortName:"h-cyl",description:"Direct access storage",aliases:["das","horizontal-cylinder"],handler:lP},{semanticName:"Disk Storage",name:"Lined Cylinder",shortName:"lin-cyl",description:"Disk storage",aliases:["disk","lined-cylinder"],handler:j$},{semanticName:"Display",name:"Curved Trapezoid",shortName:"curv-trap",description:"Represents a display",aliases:["curved-trapezoid","display"],handler:w$},{semanticName:"Divided Process",name:"Divided Rectangle",shortName:"div-rect",description:"Divided process shape",aliases:["div-proc","divided-rectangle","divided-process"],handler:k$},{semanticName:"Extract",name:"Triangle",shortName:"tri",description:"Extraction process",aliases:["extract","triangle"],handler:dP},{semanticName:"Internal Storage",name:"Window Pane",shortName:"win-pane",description:"Internal storage",aliases:["internal-storage","window-pane"],handler:fP},{semanticName:"Junction",name:"Filled Circle",shortName:"f-circ",description:"Junction point",aliases:["junction","filled-circle"],handler:_$},{semanticName:"Loop Limit",name:"Trapezoidal Pentagon",shortName:"notch-pent",description:"Loop limit step",aliases:["loop-limit","notched-pentagon"],handler:uP},{semanticName:"Manual File",name:"Flipped Triangle",shortName:"flip-tri",description:"Manual file operation",aliases:["manual-file","flipped-triangle"],handler:C$},{semanticName:"Manual Input",name:"Sloped Rectangle",shortName:"sl-rect",description:"Manual input step",aliases:["manual-input","sloped-rectangle"],handler:Q$},{semanticName:"Multi-Document",name:"Stacked Document",shortName:"docs",description:"Multiple documents",aliases:["documents","st-doc","stacked-document"],handler:q$},{semanticName:"Multi-Process",name:"Stacked Rectangle",shortName:"st-rect",description:"Multiple processes",aliases:["procs","processes","stacked-rectangle"],handler:G$},{semanticName:"Stored Data",name:"Bow Tie Rectangle",shortName:"bow-rect",description:"Stored data",aliases:["stored-data","bow-tie-rectangle"],handler:f$},{semanticName:"Summary",name:"Crossed Circle",shortName:"cross-circ",description:"Summary",aliases:["summary","crossed-circle"],handler:y$},{semanticName:"Tagged Document",name:"Tagged Document",shortName:"tag-doc",description:"Tagged document",aliases:["tag-doc","tagged-document"],handler:oP},{semanticName:"Tagged Process",name:"Tagged Rectangle",shortName:"tag-rect",description:"Tagged process",aliases:["tagged-rectangle","tag-proc","tagged-process"],handler:iP},{semanticName:"Paper Tape",name:"Flag",shortName:"flag",description:"Paper tape",aliases:["paper-tape"],handler:pP},{semanticName:"Odd",name:"Odd",shortName:"odd",description:"Odd shape",internalAliases:["rect_left_inv_arrow"],handler:Y$},{semanticName:"Lined Document",name:"Lined Document",shortName:"lin-doc",description:"Lined document",aliases:["lined-document"],handler:H$}],o1e=N(()=>{const t=[...Object.entries({state:tP,choice:g$,note:W$,rectWithTitle:X$,labelRect:z$,iconSquare:M$,iconCircle:L$,icon:I$,iconRounded:D$,imageSquare:B$,anchor:p$,kanbanItem:yP,mindmapCircle:wP,defaultMindmapNode:SP,classBox:gP,erBox:cC,requirementBox:bP}),...i1e.flatMap(n=>[n.shortName,..."aliases"in n?n.aliases:[],..."internalAliases"in n?n.internalAliases:[]].map(a=>[a,n.handler]))];return Object.fromEntries(t)},"generateShapeMap"),EP=o1e();function s1e(e){return e in EP}N(s1e,"isValidShape");var sb=new Map;async function kP(e,t,n){let r,a;t.shape==="rect"&&(t.rx&&t.ry?t.shape="roundedRect":t.shape="squareRect");const i=t.shape?EP[t.shape]:void 0;if(!i)throw new Error(`No such shape: ${t.shape}. Please check your syntax.`);if(t.link){let o;n.config.securityLevel==="sandbox"?o="_top":t.linkTarget&&(o=t.linkTarget||"_blank"),r=e.insert("svg:a").attr("xlink:href",t.link).attr("target",o??null),a=await i(r,t,n)}else a=await i(e,t,n),r=a;return t.tooltip&&a.attr("title",t.tooltip),sb.set(t.id,r),t.haveCallback&&r.attr("class",r.attr("class")+" clickable"),r}N(kP,"insertNode");var OEe=N((e,t)=>{sb.set(t.id,e)},"setNodeElem"),IEe=N(()=>{sb.clear()},"clear"),LEe=N(e=>{const t=sb.get(e.id);we.trace("Transforming node",e.diff,e,"translate("+(e.x-e.width/2-5)+", "+e.width/2+")");const n=8,r=e.diff||0;return e.clusterNode?t.attr("transform","translate("+(e.x+r-e.width/2)+", "+(e.y-e.height/2-n)+")"):t.attr("transform","translate("+e.x+", "+e.y+")"),r},"positionNode"),l1e=N((e,t,n,r,a,i)=>{t.arrowTypeStart&&E8(e,"start",t.arrowTypeStart,n,r,a,i),t.arrowTypeEnd&&E8(e,"end",t.arrowTypeEnd,n,r,a,i)},"addEdgeMarkers"),c1e={arrow_cross:{type:"cross",fill:!1},arrow_point:{type:"point",fill:!0},arrow_barb:{type:"barb",fill:!0},arrow_circle:{type:"circle",fill:!1},aggregation:{type:"aggregation",fill:!1},extension:{type:"extension",fill:!1},composition:{type:"composition",fill:!0},dependency:{type:"dependency",fill:!0},lollipop:{type:"lollipop",fill:!1},only_one:{type:"onlyOne",fill:!1},zero_or_one:{type:"zeroOrOne",fill:!1},one_or_more:{type:"oneOrMore",fill:!1},zero_or_more:{type:"zeroOrMore",fill:!1},requirement_arrow:{type:"requirement_arrow",fill:!1},requirement_contains:{type:"requirement_contains",fill:!1}},E8=N((e,t,n,r,a,i,o)=>{var f;const l=c1e[n];if(!l){we.warn(`Unknown arrow type: ${n}`);return}const u=l.type,h=`${a}_${i}-${u}${t==="start"?"Start":"End"}`;if(o&&o.trim()!==""){const m=o.replace(/[^\dA-Za-z]/g,"_"),b=`${h}_${m}`;if(!document.getElementById(b)){const y=document.getElementById(h);if(y){const v=y.cloneNode(!0);v.id=b,v.querySelectorAll("path, circle, line").forEach(S=>{S.setAttribute("stroke",o),l.fill&&S.setAttribute("fill",o)}),(f=y.parentNode)==null||f.appendChild(v)}}e.attr(`marker-${t}`,`url(${r}#${b})`)}else e.attr(`marker-${t}`,`url(${r}#${h})`)},"addEdgeMarker"),u1e=N(e=>{var t,n;return typeof e=="string"?e:(n=(t=qt())==null?void 0:t.flowchart)==null?void 0:n.curve},"resolveEdgeCurveType"),Ym=new Map,sr=new Map,DEe=N(()=>{Ym.clear(),sr.clear()},"clear"),Kd=N(e=>e?typeof e=="string"?e:e.reduce((t,n)=>t+";"+n,""):"","getLabelStyles"),d1e=N(async(e,t)=>{const n=qt();let r=xr(n);const{labelStyles:a}=Ye(t);t.labelStyle=a;const i=e.insert("g").attr("class","edgeLabel"),o=i.insert("g").attr("class","label").attr("data-id",t.id),l=t.labelType==="markdown",d=await Do(e,t.label,{style:Kd(t.labelStyle),useHtmlLabels:r,addSvgBackground:!0,isNode:!1,markdown:l,width:l?void 0:void 0},n);o.node().appendChild(d),we.info("abc82",t,t.labelType);let h=d.getBBox(),f=h;if(r){const b=d.children[0],y=Et(d);h=b.getBoundingClientRect(),f=h,y.attr("width",h.width),y.attr("height",h.height)}else{const b=Et(d).select("text").node();b&&typeof b.getBBox=="function"&&(f=b.getBBox())}o.attr("transform",Gd(f,r)),Ym.set(t.id,i),t.width=h.width,t.height=h.height;let m;if(t.startLabelLeft){const b=e.insert("g").attr("class","edgeTerminals"),y=b.insert("g").attr("class","inner"),v=await bs(y,t.startLabelLeft,Kd(t.labelStyle)||"",!1,!1);m=v;let w=v.getBBox();if(r){const S=v.children[0],k=Et(v);w=S.getBoundingClientRect(),k.attr("width",w.width),k.attr("height",w.height)}y.attr("transform",Gd(w,r)),sr.get(t.id)||sr.set(t.id,{}),sr.get(t.id).startLeft=b,oh(m,t.startLabelLeft)}if(t.startLabelRight){const b=e.insert("g").attr("class","edgeTerminals"),y=b.insert("g").attr("class","inner"),v=await bs(y,t.startLabelRight,Kd(t.labelStyle)||"",!1,!1);m=v,y.node().appendChild(v);let w=v.getBBox();if(r){const S=v.children[0],k=Et(v);w=S.getBoundingClientRect(),k.attr("width",w.width),k.attr("height",w.height)}y.attr("transform",Gd(w,r)),sr.get(t.id)||sr.set(t.id,{}),sr.get(t.id).startRight=b,oh(m,t.startLabelRight)}if(t.endLabelLeft){const b=e.insert("g").attr("class","edgeTerminals"),y=b.insert("g").attr("class","inner"),v=await bs(y,t.endLabelLeft,Kd(t.labelStyle)||"",!1,!1);m=v;let w=v.getBBox();if(r){const S=v.children[0],k=Et(v);w=S.getBoundingClientRect(),k.attr("width",w.width),k.attr("height",w.height)}y.attr("transform",Gd(w,r)),b.node().appendChild(v),sr.get(t.id)||sr.set(t.id,{}),sr.get(t.id).endLeft=b,oh(m,t.endLabelLeft)}if(t.endLabelRight){const b=e.insert("g").attr("class","edgeTerminals"),y=b.insert("g").attr("class","inner"),v=await bs(y,t.endLabelRight,Kd(t.labelStyle)||"",!1,!1);m=v;let w=v.getBBox();if(r){const S=v.children[0],k=Et(v);w=S.getBoundingClientRect(),k.attr("width",w.width),k.attr("height",w.height)}y.attr("transform",Gd(w,r)),b.node().appendChild(v),sr.get(t.id)||sr.set(t.id,{}),sr.get(t.id).endRight=b,oh(m,t.endLabelRight)}return d},"insertEdgeLabel");function oh(e,t){xr(qt())&&e&&(e.style.width=t.length*9+"px",e.style.height="12px")}N(oh,"setTerminalWidth");var h1e=N((e,t)=>{we.debug("Moving label abc88 ",e.id,e.label,Ym.get(e.id),t);let n=t.updatedPath?t.updatedPath:t.originalPath;const r=qt(),{subGraphTitleTotalMargin:a}=X_(r);if(e.label){const i=Ym.get(e.id);let o=e.x,l=e.y;if(n){const u=ti.calcLabelPosition(n);we.debug("Moving label "+e.label+" from (",o,",",l,") to (",u.x,",",u.y,") abc88"),t.updatedPath&&(o=u.x,l=u.y)}i.attr("transform",`translate(${o}, ${l+a/2})`)}if(e.startLabelLeft){const i=sr.get(e.id).startLeft;let o=e.x,l=e.y;if(n){const u=ti.calcTerminalLabelPosition(e.arrowTypeStart?10:0,"start_left",n);o=u.x,l=u.y}i.attr("transform",`translate(${o}, ${l})`)}if(e.startLabelRight){const i=sr.get(e.id).startRight;let o=e.x,l=e.y;if(n){const u=ti.calcTerminalLabelPosition(e.arrowTypeStart?10:0,"start_right",n);o=u.x,l=u.y}i.attr("transform",`translate(${o}, ${l})`)}if(e.endLabelLeft){const i=sr.get(e.id).endLeft;let o=e.x,l=e.y;if(n){const u=ti.calcTerminalLabelPosition(e.arrowTypeEnd?10:0,"end_left",n);o=u.x,l=u.y}i.attr("transform",`translate(${o}, ${l})`)}if(e.endLabelRight){const i=sr.get(e.id).endRight;let o=e.x,l=e.y;if(n){const u=ti.calcTerminalLabelPosition(e.arrowTypeEnd?10:0,"end_right",n);o=u.x,l=u.y}i.attr("transform",`translate(${o}, ${l})`)}},"positionEdgeLabel"),p1e=N((e,t)=>{const n=e.x,r=e.y,a=Math.abs(t.x-n),i=Math.abs(t.y-r),o=e.width/2,l=e.height/2;return a>=o||i>=l},"outsideNode"),f1e=N((e,t,n)=>{we.debug(`intersection calc abc89:
  outsidePoint: ${JSON.stringify(t)}
  insidePoint : ${JSON.stringify(n)}
  node        : x:${e.x} y:${e.y} w:${e.width} h:${e.height}`);const r=e.x,a=e.y,i=Math.abs(r-n.x),o=e.width/2;let l=n.x<t.x?o-i:o+i;const u=e.height/2,d=Math.abs(t.y-n.y),h=Math.abs(t.x-n.x);if(Math.abs(a-t.y)*o>Math.abs(r-t.x)*u){let f=n.y<t.y?t.y-u-a:a-u-t.y;l=h*f/d;const m={x:n.x<t.x?n.x+l:n.x-h+l,y:n.y<t.y?n.y+d-f:n.y-d+f};return l===0&&(m.x=t.x,m.y=t.y),h===0&&(m.x=t.x),d===0&&(m.y=t.y),we.debug(`abc89 top/bottom calc, Q ${d}, q ${f}, R ${h}, r ${l}`,m),m}else{n.x<t.x?l=t.x-o-r:l=r-o-t.x;let f=d*l/h,m=n.x<t.x?n.x+h-l:n.x-h+l,b=n.y<t.y?n.y+f:n.y-f;return we.debug(`sides calc abc89, Q ${d}, q ${f}, R ${h}, r ${l}`,{_x:m,_y:b}),l===0&&(m=t.x,b=t.y),h===0&&(m=t.x),d===0&&(b=t.y),{x:m,y:b}}},"intersection"),k8=N((e,t)=>{we.warn("abc88 cutPathAtIntersect",e,t);let n=[],r=e[0],a=!1;return e.forEach(i=>{if(we.info("abc88 checking point",i,t),!p1e(t,i)&&!a){const o=f1e(t,r,i);we.debug("abc88 inside",i,r,o),we.debug("abc88 intersection",o,t);let l=!1;n.forEach(u=>{l=l||u.x===o.x&&u.y===o.y}),n.some(u=>u.x===o.x&&u.y===o.y)?we.warn("abc88 no intersect",o,n):n.push(o),a=!0}else we.warn("abc88 outside",i,r),r=i,a||n.push(i)}),we.debug("returning points",n),n},"cutPathAtIntersect");function TP(e){const t=[],n=[];for(let r=1;r<e.length-1;r++){const a=e[r-1],i=e[r],o=e[r+1];(a.x===i.x&&i.y===o.y&&Math.abs(i.x-o.x)>5&&Math.abs(i.y-a.y)>5||a.y===i.y&&i.x===o.x&&Math.abs(i.x-a.x)>5&&Math.abs(i.y-o.y)>5)&&(t.push(i),n.push(r))}return{cornerPoints:t,cornerPointPositions:n}}N(TP,"extractCornerPoints");var T8=N(function(e,t,n){const r=t.x-e.x,a=t.y-e.y,i=Math.sqrt(r*r+a*a),o=n/i;return{x:t.x-o*r,y:t.y-o*a}},"findAdjacentPoint"),m1e=N(function(e){const{cornerPointPositions:t}=TP(e),n=[];for(let r=0;r<e.length;r++)if(t.includes(r)){const a=e[r-1],i=e[r+1],o=e[r],l=T8(a,o,5),u=T8(i,o,5),d=u.x-l.x,h=u.y-l.y;n.push(l);const f=Math.sqrt(2)*2;let m={x:o.x,y:o.y};if(Math.abs(i.x-a.x)>10&&Math.abs(i.y-a.y)>=10){we.debug("Corner point fixing",Math.abs(i.x-a.x),Math.abs(i.y-a.y));const b=5;o.x===l.x?m={x:d<0?l.x-b+f:l.x+b-f,y:h<0?l.y-f:l.y+f}:m={x:d<0?l.x-f:l.x+f,y:h<0?l.y-b+f:l.y+b-f}}else we.debug("Corner point skipping fixing",Math.abs(i.x-a.x),Math.abs(i.y-a.y));n.push(m,u)}else n.push(e[r]);return n},"fixCorners"),g1e=N((e,t,n)=>{const r=e-t-n,a=2,i=2,o=a+i,l=Math.floor(r/o),u=Array(l).fill(`${a} ${i}`).join(" ");return`0 ${t} ${u} ${n}`},"generateDashArray"),b1e=N(function(e,t,n,r,a,i,o,l=!1){var $;const{handDrawnSeed:u}=qt();let d=t.points,h=!1;const f=a;var m=i;const b=[];for(const Q in t.cssCompiledStyles)Tz(Q)||b.push(t.cssCompiledStyles[Q]);we.debug("UIO intersect check",t.points,m.x,f.x),m.intersect&&f.intersect&&!l&&(d=d.slice(1,t.points.length-1),d.unshift(f.intersect(d[0])),we.debug("Last point UIO",t.start,"-->",t.end,d[d.length-1],m,m.intersect(d[d.length-1])),d.push(m.intersect(d[d.length-1])));const y=btoa(JSON.stringify(d));t.toCluster&&(we.info("to cluster abc88",n.get(t.toCluster)),d=k8(t.points,n.get(t.toCluster).node),h=!0),t.fromCluster&&(we.debug("from cluster abc88",n.get(t.fromCluster),JSON.stringify(d,null,2)),d=k8(d.reverse(),n.get(t.fromCluster).node).reverse(),h=!0);let v=d.filter(Q=>!Number.isNaN(Q.y));const w=u1e(t.curve);w!=="rounded"&&(v=m1e(v));let S=gh;switch(w){case"linear":S=gh;break;case"basis":S=i2;break;case"cardinal":S=iB;break;case"bumpX":S=eB;break;case"bumpY":S=tB;break;case"catmullRom":S=sB;break;case"monotoneX":S=pB;break;case"monotoneY":S=fB;break;case"natural":S=gB;break;case"step":S=bB;break;case"stepAfter":S=vB;break;case"stepBefore":S=yB;break;case"rounded":S=gh;break;default:S=i2}const{x:k,y:R}=p0e(t),I=Kpe().x(k).y(R).curve(S);let L;switch(t.thickness){case"normal":L="edge-thickness-normal";break;case"thick":L="edge-thickness-thick";break;case"invisible":L="edge-thickness-invisible";break;default:L="edge-thickness-normal"}switch(t.pattern){case"solid":L+=" edge-pattern-solid";break;case"dotted":L+=" edge-pattern-dotted";break;case"dashed":L+=" edge-pattern-dashed";break;default:L+=" edge-pattern-solid"}let A,M=w==="rounded"?_P(CP(v,t),5):I(v);const P=Array.isArray(t.style)?t.style:[t.style];let G=P.find(Q=>Q==null?void 0:Q.startsWith("stroke:")),B="";t.animate&&(B="edge-animation-fast"),t.animation&&(B="edge-animation-"+t.animation);let H=!1;if(t.look==="handDrawn"){const Q=Ge.svg(e);Object.assign([],v);const J=Q.path(M,{roughness:.3,seed:u});L+=" transition",A=Et(J).select("path").attr("id",t.id).attr("class"," "+L+(t.classes?" "+t.classes:"")+(B?" "+B:"")).attr("style",P?P.reduce((F,Y)=>F+";"+Y,""):"");let ie=A.attr("d");A.attr("d",ie),e.node().appendChild(A.node())}else{const Q=b.join(";"),J=P?P.reduce((be,ge)=>be+ge+";",""):"",ie=(Q?Q+";"+J+";":J)+";"+(P?P.reduce((be,ge)=>be+";"+ge,""):"");A=e.append("path").attr("d",M).attr("id",t.id).attr("class"," "+L+(t.classes?" "+t.classes:"")+(B?" "+B:"")).attr("style",ie),G=($=ie.match(/stroke:([^;]+)/))==null?void 0:$[1],H=t.animate===!0||!!t.animation||Q.includes("animation");const F=A.node(),Y=typeof F.getTotalLength=="function"?F.getTotalLength():0,oe=P7[t.arrowTypeStart]||0,U=P7[t.arrowTypeEnd]||0;if(t.look==="neo"&&!H){const ge=`stroke-dasharray: ${t.pattern==="dotted"||t.pattern==="dashed"?g1e(Y,oe,U):`0 ${oe} ${Y-oe-U} ${U}`}; stroke-dashoffset: 0;`;A.attr("style",ge+A.attr("style"))}}A.attr("data-edge",!0),A.attr("data-et","edge"),A.attr("data-id",t.id),A.attr("data-points",y),t.showPoints&&v.forEach(Q=>{e.append("circle").style("stroke","red").style("fill","red").attr("r",1).attr("cx",Q.x).attr("cy",Q.y)});let Z="";(qt().flowchart.arrowMarkerAbsolute||qt().state.arrowMarkerAbsolute)&&(Z=window.location.protocol+"//"+window.location.host+window.location.pathname+window.location.search,Z=Z.replace(/\(/g,"\\(").replace(/\)/g,"\\)")),we.info("arrowTypeStart",t.arrowTypeStart),we.info("arrowTypeEnd",t.arrowTypeEnd),l1e(A,t,Z,o,r,G);const V=Math.floor(d.length/2),q=d[V];ti.isLabelCoordinateInPath(q,A.attr("d"))||(h=!0);let X={};return h&&(X.updatedPath=d),X.originalPath=t.points,X},"insertEdge");function _P(e,t){if(e.length<2)return"";let n="";const r=e.length,a=1e-5;for(let i=0;i<r;i++){const o=e[i],l=e[i-1],u=e[i+1];if(i===0)n+=`M${o.x},${o.y}`;else if(i===r-1)n+=`L${o.x},${o.y}`;else{const d=o.x-l.x,h=o.y-l.y,f=u.x-o.x,m=u.y-o.y,b=Math.hypot(d,h),y=Math.hypot(f,m);if(b<a||y<a){n+=`L${o.x},${o.y}`;continue}const v=d/b,w=h/b,S=f/y,k=m/y,R=v*S+w*k,I=Math.max(-1,Math.min(1,R)),L=Math.acos(I);if(L<a||Math.abs(Math.PI-L)<a){n+=`L${o.x},${o.y}`;continue}const A=Math.min(t/Math.sin(L/2),b/2,y/2),M=o.x-v*A,P=o.y-w*A,G=o.x+S*A,B=o.y+k*A;n+=`L${M},${P}`,n+=`Q${o.x},${o.y} ${G},${B}`}}return n}N(_P,"generateRoundedPath");function L2(e,t){if(!e||!t)return{angle:0,deltaX:0,deltaY:0};const n=t.x-e.x,r=t.y-e.y;return{angle:Math.atan2(r,n),deltaX:n,deltaY:r}}N(L2,"calculateDeltaAndAngle");function CP(e,t){const n=e.map(a=>({...a}));if(e.length>=2&&pr[t.arrowTypeStart]){const a=pr[t.arrowTypeStart],i=e[0],o=e[1],{angle:l}=L2(i,o),u=a*Math.cos(l),d=a*Math.sin(l);n[0].x=i.x+u,n[0].y=i.y+d}const r=e.length;if(r>=2&&pr[t.arrowTypeEnd]){const a=pr[t.arrowTypeEnd],i=e[r-1],o=e[r-2],{angle:l}=L2(o,i),u=a*Math.cos(l),d=a*Math.sin(l);n[r-1].x=i.x-u,n[r-1].y=i.y-d}return n}N(CP,"applyMarkerOffsetsToPoints");var y1e=N((e,t,n,r)=>{t.forEach(a=>{D1e[a](e,n,r)})},"insertMarkers"),v1e=N((e,t,n)=>{we.trace("Making markers for ",n),e.append("defs").append("marker").attr("id",n+"_"+t+"-extensionStart").attr("class","marker extension "+t).attr("refX",18).attr("refY",7).attr("markerWidth",190).attr("markerHeight",240).attr("orient","auto").append("path").attr("d","M 1,7 L18,13 V 1 Z"),e.append("defs").append("marker").attr("id",n+"_"+t+"-extensionEnd").attr("class","marker extension "+t).attr("refX",1).attr("refY",7).attr("markerWidth",20).attr("markerHeight",28).attr("orient","auto").append("path").attr("d","M 1,1 V 13 L18,7 Z")},"extension"),x1e=N((e,t,n)=>{e.append("defs").append("marker").attr("id",n+"_"+t+"-compositionStart").attr("class","marker composition "+t).attr("refX",18).attr("refY",7).attr("markerWidth",190).attr("markerHeight",240).attr("orient","auto").append("path").attr("d","M 18,7 L9,13 L1,7 L9,1 Z"),e.append("defs").append("marker").attr("id",n+"_"+t+"-compositionEnd").attr("class","marker composition "+t).attr("refX",1).attr("refY",7).attr("markerWidth",20).attr("markerHeight",28).attr("orient","auto").append("path").attr("d","M 18,7 L9,13 L1,7 L9,1 Z")},"composition"),S1e=N((e,t,n)=>{e.append("defs").append("marker").attr("id",n+"_"+t+"-aggregationStart").attr("class","marker aggregation "+t).attr("refX",18).attr("refY",7).attr("markerWidth",190).attr("markerHeight",240).attr("orient","auto").append("path").attr("d","M 18,7 L9,13 L1,7 L9,1 Z"),e.append("defs").append("marker").attr("id",n+"_"+t+"-aggregationEnd").attr("class","marker aggregation "+t).attr("refX",1).attr("refY",7).attr("markerWidth",20).attr("markerHeight",28).attr("orient","auto").append("path").attr("d","M 18,7 L9,13 L1,7 L9,1 Z")},"aggregation"),w1e=N((e,t,n)=>{e.append("defs").append("marker").attr("id",n+"_"+t+"-dependencyStart").attr("class","marker dependency "+t).attr("refX",6).attr("refY",7).attr("markerWidth",190).attr("markerHeight",240).attr("orient","auto").append("path").attr("d","M 5,7 L9,13 L1,7 L9,1 Z"),e.append("defs").append("marker").attr("id",n+"_"+t+"-dependencyEnd").attr("class","marker dependency "+t).attr("refX",13).attr("refY",7).attr("markerWidth",20).attr("markerHeight",28).attr("orient","auto").append("path").attr("d","M 18,7 L9,13 L14,7 L9,1 Z")},"dependency"),E1e=N((e,t,n)=>{e.append("defs").append("marker").attr("id",n+"_"+t+"-lollipopStart").attr("class","marker lollipop "+t).attr("refX",13).attr("refY",7).attr("markerWidth",190).attr("markerHeight",240).attr("orient","auto").append("circle").attr("fill","transparent").attr("cx",7).attr("cy",7).attr("r",6),e.append("defs").append("marker").attr("id",n+"_"+t+"-lollipopEnd").attr("class","marker lollipop "+t).attr("refX",1).attr("refY",7).attr("markerWidth",190).attr("markerHeight",240).attr("orient","auto").append("circle").attr("fill","transparent").attr("cx",7).attr("cy",7).attr("r",6)},"lollipop"),k1e=N((e,t,n)=>{e.append("marker").attr("id",n+"_"+t+"-pointEnd").attr("class","marker "+t).attr("viewBox","0 0 10 10").attr("refX",5).attr("refY",5).attr("markerUnits","userSpaceOnUse").attr("markerWidth",8).attr("markerHeight",8).attr("orient","auto").append("path").attr("d","M 0 0 L 10 5 L 0 10 z").attr("class","arrowMarkerPath").style("stroke-width",1).style("stroke-dasharray","1,0"),e.append("marker").attr("id",n+"_"+t+"-pointStart").attr("class","marker "+t).attr("viewBox","0 0 10 10").attr("refX",4.5).attr("refY",5).attr("markerUnits","userSpaceOnUse").attr("markerWidth",8).attr("markerHeight",8).attr("orient","auto").append("path").attr("d","M 0 5 L 10 10 L 10 0 z").attr("class","arrowMarkerPath").style("stroke-width",1).style("stroke-dasharray","1,0")},"point"),T1e=N((e,t,n)=>{e.append("marker").attr("id",n+"_"+t+"-circleEnd").attr("class","marker "+t).attr("viewBox","0 0 10 10").attr("refX",11).attr("refY",5).attr("markerUnits","userSpaceOnUse").attr("markerWidth",11).attr("markerHeight",11).attr("orient","auto").append("circle").attr("cx","5").attr("cy","5").attr("r","5").attr("class","arrowMarkerPath").style("stroke-width",1).style("stroke-dasharray","1,0"),e.append("marker").attr("id",n+"_"+t+"-circleStart").attr("class","marker "+t).attr("viewBox","0 0 10 10").attr("refX",-1).attr("refY",5).attr("markerUnits","userSpaceOnUse").attr("markerWidth",11).attr("markerHeight",11).attr("orient","auto").append("circle").attr("cx","5").attr("cy","5").attr("r","5").attr("class","arrowMarkerPath").style("stroke-width",1).style("stroke-dasharray","1,0")},"circle"),_1e=N((e,t,n)=>{e.append("marker").attr("id",n+"_"+t+"-crossEnd").attr("class","marker cross "+t).attr("viewBox","0 0 11 11").attr("refX",12).attr("refY",5.2).attr("markerUnits","userSpaceOnUse").attr("markerWidth",11).attr("markerHeight",11).attr("orient","auto").append("path").attr("d","M 1,1 l 9,9 M 10,1 l -9,9").attr("class","arrowMarkerPath").style("stroke-width",2).style("stroke-dasharray","1,0"),e.append("marker").attr("id",n+"_"+t+"-crossStart").attr("class","marker cross "+t).attr("viewBox","0 0 11 11").attr("refX",-1).attr("refY",5.2).attr("markerUnits","userSpaceOnUse").attr("markerWidth",11).attr("markerHeight",11).attr("orient","auto").append("path").attr("d","M 1,1 l 9,9 M 10,1 l -9,9").attr("class","arrowMarkerPath").style("stroke-width",2).style("stroke-dasharray","1,0")},"cross"),C1e=N((e,t,n)=>{e.append("defs").append("marker").attr("id",n+"_"+t+"-barbEnd").attr("refX",19).attr("refY",7).attr("markerWidth",20).attr("markerHeight",14).attr("markerUnits","userSpaceOnUse").attr("orient","auto").append("path").attr("d","M 19,7 L9,13 L14,7 L9,1 Z")},"barb"),A1e=N((e,t,n)=>{e.append("defs").append("marker").attr("id",n+"_"+t+"-onlyOneStart").attr("class","marker onlyOne "+t).attr("refX",0).attr("refY",9).attr("markerWidth",18).attr("markerHeight",18).attr("orient","auto").append("path").attr("d","M9,0 L9,18 M15,0 L15,18"),e.append("defs").append("marker").attr("id",n+"_"+t+"-onlyOneEnd").attr("class","marker onlyOne "+t).attr("refX",18).attr("refY",9).attr("markerWidth",18).attr("markerHeight",18).attr("orient","auto").append("path").attr("d","M3,0 L3,18 M9,0 L9,18")},"only_one"),R1e=N((e,t,n)=>{const r=e.append("defs").append("marker").attr("id",n+"_"+t+"-zeroOrOneStart").attr("class","marker zeroOrOne "+t).attr("refX",0).attr("refY",9).attr("markerWidth",30).attr("markerHeight",18).attr("orient","auto");r.append("circle").attr("fill","white").attr("cx",21).attr("cy",9).attr("r",6),r.append("path").attr("d","M9,0 L9,18");const a=e.append("defs").append("marker").attr("id",n+"_"+t+"-zeroOrOneEnd").attr("class","marker zeroOrOne "+t).attr("refX",30).attr("refY",9).attr("markerWidth",30).attr("markerHeight",18).attr("orient","auto");a.append("circle").attr("fill","white").attr("cx",9).attr("cy",9).attr("r",6),a.append("path").attr("d","M21,0 L21,18")},"zero_or_one"),N1e=N((e,t,n)=>{e.append("defs").append("marker").attr("id",n+"_"+t+"-oneOrMoreStart").attr("class","marker oneOrMore "+t).attr("refX",18).attr("refY",18).attr("markerWidth",45).attr("markerHeight",36).attr("orient","auto").append("path").attr("d","M0,18 Q 18,0 36,18 Q 18,36 0,18 M42,9 L42,27"),e.append("defs").append("marker").attr("id",n+"_"+t+"-oneOrMoreEnd").attr("class","marker oneOrMore "+t).attr("refX",27).attr("refY",18).attr("markerWidth",45).attr("markerHeight",36).attr("orient","auto").append("path").attr("d","M3,9 L3,27 M9,18 Q27,0 45,18 Q27,36 9,18")},"one_or_more"),O1e=N((e,t,n)=>{const r=e.append("defs").append("marker").attr("id",n+"_"+t+"-zeroOrMoreStart").attr("class","marker zeroOrMore "+t).attr("refX",18).attr("refY",18).attr("markerWidth",57).attr("markerHeight",36).attr("orient","auto");r.append("circle").attr("fill","white").attr("cx",48).attr("cy",18).attr("r",6),r.append("path").attr("d","M0,18 Q18,0 36,18 Q18,36 0,18");const a=e.append("defs").append("marker").attr("id",n+"_"+t+"-zeroOrMoreEnd").attr("class","marker zeroOrMore "+t).attr("refX",39).attr("refY",18).attr("markerWidth",57).attr("markerHeight",36).attr("orient","auto");a.append("circle").attr("fill","white").attr("cx",9).attr("cy",18).attr("r",6),a.append("path").attr("d","M21,18 Q39,0 57,18 Q39,36 21,18")},"zero_or_more"),I1e=N((e,t,n)=>{e.append("defs").append("marker").attr("id",n+"_"+t+"-requirement_arrowEnd").attr("refX",20).attr("refY",10).attr("markerWidth",20).attr("markerHeight",20).attr("orient","auto").append("path").attr("d",`M0,0
      L20,10
      M20,10
      L0,20`)},"requirement_arrow"),L1e=N((e,t,n)=>{const r=e.append("defs").append("marker").attr("id",n+"_"+t+"-requirement_containsStart").attr("refX",0).attr("refY",10).attr("markerWidth",20).attr("markerHeight",20).attr("orient","auto").append("g");r.append("circle").attr("cx",10).attr("cy",10).attr("r",9).attr("fill","none"),r.append("line").attr("x1",1).attr("x2",19).attr("y1",10).attr("y2",10),r.append("line").attr("y1",1).attr("y2",19).attr("x1",10).attr("x2",10)},"requirement_contains"),D1e={extension:v1e,composition:x1e,aggregation:S1e,dependency:w1e,lollipop:E1e,point:k1e,circle:T1e,cross:_1e,barb:C1e,only_one:A1e,zero_or_one:R1e,one_or_more:N1e,zero_or_more:O1e,requirement_arrow:I1e,requirement_contains:L1e},M1e=y1e,B1e={common:pp,getConfig:br,insertCluster:jye,insertEdge:b1e,insertEdgeLabel:d1e,insertMarkers:M1e,insertNode:kP,interpolateToCurve:H_,labelHelper:lt,log:we,positionEdgeLabel:h1e},Hh={},AP=N(e=>{for(const t of e)Hh[t.name]=t},"registerLayoutLoaders"),F1e=N(()=>{AP([{name:"dagre",loader:N(async()=>await Ut(()=>import("./dagre-KLK3FWXG-DYoQLW-T.js"),__vite__mapDeps([0,1,2,3,4,5])),"loader")},{name:"cose-bilkent",loader:N(async()=>await Ut(()=>import("./cose-bilkent-S5V4N54A-C3_YBITk.js"),__vite__mapDeps([6,7])),"loader")}])},"registerDefaultLayoutLoaders");F1e();var MEe=N(async(e,t)=>{if(!(e.layoutAlgorithm in Hh))throw new Error(`Unknown layout algorithm: ${e.layoutAlgorithm}`);const n=Hh[e.layoutAlgorithm];return(await n.loader()).render(e,t,B1e,{algorithm:n.algorithm})},"render"),BEe=N((e="",{fallback:t="dagre"}={})=>{if(e in Hh)return e;if(t in Hh)return we.warn(`Layout algorithm ${e} is not registered. Using ${t} as fallback.`),t;throw new Error(`Both layout algorithms ${e} and ${t} are not registered.`)},"getRegisteredLayoutAlgorithm"),RP="comm",NP="rule",OP="decl",z1e="@import",$1e="@namespace",P1e="@keyframes",U1e="@layer",IP=Math.abs,uC=String.fromCharCode;function LP(e){return e.trim()}function V0(e,t,n){return e.replace(t,n)}function j1e(e,t,n){return e.indexOf(t,n)}function Uc(e,t){return e.charCodeAt(t)|0}function lu(e,t,n){return e.slice(t,n)}function Si(e){return e.length}function H1e(e){return e.length}function E0(e,t){return t.push(e),e}var lb=1,cu=1,DP=0,qa=0,$n=0,Du="";function dC(e,t,n,r,a,i,o,l){return{value:e,root:t,parent:n,type:r,props:a,children:i,line:lb,column:cu,length:o,return:"",siblings:l}}function G1e(){return $n}function q1e(){return $n=qa>0?Uc(Du,--qa):0,cu--,$n===10&&(cu=1,lb--),$n}function ii(){return $n=qa<DP?Uc(Du,qa++):0,cu++,$n===10&&(cu=1,lb++),$n}function ys(){return Uc(Du,qa)}function Y0(){return qa}function cb(e,t){return lu(Du,e,t)}function Gh(e){switch(e){case 0:case 9:case 10:case 13:case 32:return 5;case 33:case 43:case 44:case 47:case 62:case 64:case 126:case 59:case 123:case 125:return 4;case 58:return 3;case 34:case 39:case 40:case 91:return 2;case 41:case 93:return 1}return 0}function W1e(e){return lb=cu=1,DP=Si(Du=e),qa=0,[]}function V1e(e){return Du="",e}function Zv(e){return LP(cb(qa-1,D2(e===91?e+2:e===40?e+1:e)))}function Y1e(e){for(;($n=ys())&&$n<33;)ii();return Gh(e)>2||Gh($n)>3?"":" "}function X1e(e,t){for(;--t&&ii()&&!($n<48||$n>102||$n>57&&$n<65||$n>70&&$n<97););return cb(e,Y0()+(t<6&&ys()==32&&ii()==32))}function D2(e){for(;ii();)switch($n){case e:return qa;case 34:case 39:e!==34&&e!==39&&D2($n);break;case 40:e===41&&D2(e);break;case 92:ii();break}return qa}function K1e(e,t){for(;ii()&&e+$n!==57;)if(e+$n===84&&ys()===47)break;return"/*"+cb(t,qa-1)+"*"+uC(e===47?e:ii())}function Z1e(e){for(;!Gh(ys());)ii();return cb(e,qa)}function Q1e(e){return V1e(X0("",null,null,null,[""],e=W1e(e),0,[0],e))}function X0(e,t,n,r,a,i,o,l,u){for(var d=0,h=0,f=o,m=0,b=0,y=0,v=1,w=1,S=1,k=0,R="",I=a,L=i,A=r,M=R;w;)switch(y=k,k=ii()){case 40:if(y!=108&&Uc(M,f-1)==58){j1e(M+=V0(Zv(k),"&","&\f"),"&\f",IP(d?l[d-1]:0))!=-1&&(S=-1);break}case 34:case 39:case 91:M+=Zv(k);break;case 9:case 10:case 13:case 32:M+=Y1e(y);break;case 92:M+=X1e(Y0()-1,7);continue;case 47:switch(ys()){case 42:case 47:E0(J1e(K1e(ii(),Y0()),t,n,u),u),(Gh(y||1)==5||Gh(ys()||1)==5)&&Si(M)&&lu(M,-1,void 0)!==" "&&(M+=" ");break;default:M+="/"}break;case 123*v:l[d++]=Si(M)*S;case 125*v:case 59:case 0:switch(k){case 0:case 125:w=0;case 59+h:S==-1&&(M=V0(M,/\f/g,"")),b>0&&(Si(M)-f||v===0&&y===47)&&E0(b>32?C8(M+";",r,n,f-1,u):C8(V0(M," ","")+";",r,n,f-2,u),u);break;case 59:M+=";";default:if(E0(A=_8(M,t,n,d,h,a,l,R,I=[],L=[],f,i),i),k===123)if(h===0)X0(M,t,A,A,I,i,f,l,L);else{switch(m){case 99:if(Uc(M,3)===110)break;case 108:if(Uc(M,2)===97)break;default:h=0;case 100:case 109:case 115:}h?X0(e,A,A,r&&E0(_8(e,A,A,0,0,a,l,R,a,I=[],f,L),L),a,L,f,l,r?I:L):X0(M,A,A,A,[""],L,0,l,L)}}d=h=b=0,v=S=1,R=M="",f=o;break;case 58:f=1+Si(M),b=y;default:if(v<1){if(k==123)--v;else if(k==125&&v++==0&&q1e()==125)continue}switch(M+=uC(k),k*v){case 38:S=h>0?1:(M+="\f",-1);break;case 44:l[d++]=(Si(M)-1)*S,S=1;break;case 64:ys()===45&&(M+=Zv(ii())),m=ys(),h=f=Si(R=M+=Z1e(Y0())),k++;break;case 45:y===45&&Si(M)==2&&(v=0)}}return i}function _8(e,t,n,r,a,i,o,l,u,d,h,f){for(var m=a-1,b=a===0?i:[""],y=H1e(b),v=0,w=0,S=0;v<r;++v)for(var k=0,R=lu(e,m+1,m=IP(w=o[v])),I=e;k<y;++k)(I=LP(w>0?b[k]+" "+R:V0(R,/&\f/g,b[k])))&&(u[S++]=I);return dC(e,t,n,a===0?NP:l,u,d,h,f)}function J1e(e,t,n,r){return dC(e,t,n,RP,uC(G1e()),lu(e,2,-2),0,r)}function C8(e,t,n,r,a){return dC(e,t,n,OP,lu(e,0,r),lu(e,r+1,-1),r,a)}function M2(e,t){for(var n="",r=0;r<e.length;r++)n+=t(e[r],r,e,t)||"";return n}function eve(e,t,n,r){switch(e.type){case U1e:if(e.children.length)break;case z1e:case $1e:case OP:return e.return=e.return||e.value;case RP:return"";case P1e:return e.return=e.value+"{"+M2(e.children,r)+"}";case NP:if(!Si(e.value=e.props.join(",")))return""}return Si(n=M2(e.children,r))?e.return=e.value+"{"+n+"}":""}var tve=az(Object.keys,Object),nve=Object.prototype,rve=nve.hasOwnProperty;function ave(e){if(!Jg(e))return tve(e);var t=[];for(var n in Object(e))rve.call(e,n)&&n!="constructor"&&t.push(n);return t}var B2=Bl(Ui,"DataView"),F2=Bl(Ui,"Promise"),z2=Bl(Ui,"Set"),$2=Bl(Ui,"WeakMap"),A8="[object Map]",ive="[object Object]",R8="[object Promise]",N8="[object Set]",O8="[object WeakMap]",I8="[object DataView]",ove=Ml(B2),sve=Ml(Uh),lve=Ml(F2),cve=Ml(z2),uve=Ml($2),ll=Ru;(B2&&ll(new B2(new ArrayBuffer(1)))!=I8||Uh&&ll(new Uh)!=A8||F2&&ll(F2.resolve())!=R8||z2&&ll(new z2)!=N8||$2&&ll(new $2)!=O8)&&(ll=function(e){var t=Ru(e),n=t==ive?e.constructor:void 0,r=n?Ml(n):"";if(r)switch(r){case ove:return I8;case sve:return A8;case lve:return R8;case cve:return N8;case uve:return O8}return t});var dve="[object Map]",hve="[object Set]",pve=Object.prototype,fve=pve.hasOwnProperty;function L8(e){if(e==null)return!0;if(eb(e)&&(zm(e)||typeof e=="string"||typeof e.splice=="function"||U_(e)||j_(e)||Fm(e)))return!e.length;var t=ll(e);if(t==dve||t==hve)return!e.size;if(Jg(e))return!ave(e).length;for(var n in e)if(fve.call(e,n))return!1;return!0}var MP="c4",mve=N(e=>/^\s*C4Context|C4Container|C4Component|C4Dynamic|C4Deployment/.test(e),"detector"),gve=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./c4Diagram-IC4MRINW-BaXTKGs2.js");return{diagram:t}},__vite__mapDeps([8,9]));return{id:MP,diagram:e}},"loader"),bve={id:MP,detector:mve,loader:gve},yve=bve,BP="flowchart",vve=N((e,t)=>{var n,r;return((n=t==null?void 0:t.flowchart)==null?void 0:n.defaultRenderer)==="dagre-wrapper"||((r=t==null?void 0:t.flowchart)==null?void 0:r.defaultRenderer)==="elk"?!1:/^\s*graph/.test(e)},"detector"),xve=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./flowDiagram-PKNHOUZH-BaREyS8h.js");return{diagram:t}},__vite__mapDeps([10,11,9,12,13,14]));return{id:BP,diagram:e}},"loader"),Sve={id:BP,detector:vve,loader:xve},wve=Sve,FP="flowchart-v2",Eve=N((e,t)=>{var n,r,a;return((n=t==null?void 0:t.flowchart)==null?void 0:n.defaultRenderer)==="dagre-d3"?!1:(((r=t==null?void 0:t.flowchart)==null?void 0:r.defaultRenderer)==="elk"&&(t.layout="elk"),/^\s*graph/.test(e)&&((a=t==null?void 0:t.flowchart)==null?void 0:a.defaultRenderer)==="dagre-wrapper"?!0:/^\s*flowchart/.test(e))},"detector"),kve=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./flowDiagram-PKNHOUZH-BaREyS8h.js");return{diagram:t}},__vite__mapDeps([10,11,9,12,13,14]));return{id:FP,diagram:e}},"loader"),Tve={id:FP,detector:Eve,loader:kve},_ve=Tve,zP="er",Cve=N(e=>/^\s*erDiagram/.test(e),"detector"),Ave=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./erDiagram-INFDFZHY-DlYNFU2m.js");return{diagram:t}},__vite__mapDeps([15,12,13,14]));return{id:zP,diagram:e}},"loader"),Rve={id:zP,detector:Cve,loader:Ave},Nve=Rve,$P="gitGraph",Ove=N(e=>/^\s*gitGraph/.test(e),"detector"),Ive=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./gitGraphDiagram-K3NZZRJ6-CNWI3sZx.js");return{diagram:t}},__vite__mapDeps([16,17,18,19,2,4,5]));return{id:$P,diagram:e}},"loader"),Lve={id:$P,detector:Ove,loader:Ive},Dve=Lve,PP="gantt",Mve=N(e=>/^\s*gantt/.test(e),"detector"),Bve=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./ganttDiagram-A5KZAMGK-Ceb4PZms.js");return{diagram:t}},__vite__mapDeps([20,21,22,23]));return{id:PP,diagram:e}},"loader"),Fve={id:PP,detector:Mve,loader:Bve},zve=Fve,UP="info",$ve=N(e=>/^\s*info/.test(e),"detector"),Pve=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./infoDiagram-LFFYTUFH-B6ydU_iG.js");return{diagram:t}},__vite__mapDeps([24,19,2,4,5]));return{id:UP,diagram:e}},"loader"),Uve={id:UP,detector:$ve,loader:Pve},jP="pie",jve=N(e=>/^\s*pie/.test(e),"detector"),Hve=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./pieDiagram-SKSYHLDU-C1INl7Ml.js");return{diagram:t}},__vite__mapDeps([25,17,19,2,4,5,26,27,22]));return{id:jP,diagram:e}},"loader"),Gve={id:jP,detector:jve,loader:Hve},HP="quadrantChart",qve=N(e=>/^\s*quadrantChart/.test(e),"detector"),Wve=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./quadrantDiagram-337W2JSQ-DGfdmrvg.js");return{diagram:t}},__vite__mapDeps([28,21,22,23]));return{id:HP,diagram:e}},"loader"),Vve={id:HP,detector:qve,loader:Wve},Yve=Vve,GP="xychart",Xve=N(e=>/^\s*xychart(-beta)?/.test(e),"detector"),Kve=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./xychartDiagram-JWTSCODW-Dtt2ETxZ.js");return{diagram:t}},__vite__mapDeps([29,22,27,21,23]));return{id:GP,diagram:e}},"loader"),Zve={id:GP,detector:Xve,loader:Kve},Qve=Zve,qP="requirement",Jve=N(e=>/^\s*requirement(Diagram)?/.test(e),"detector"),exe=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./requirementDiagram-Z7DCOOCP-CyRB6RdG.js");return{diagram:t}},__vite__mapDeps([30,12,13]));return{id:qP,diagram:e}},"loader"),txe={id:qP,detector:Jve,loader:exe},nxe=txe,WP="sequence",rxe=N(e=>/^\s*sequenceDiagram/.test(e),"detector"),axe=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./sequenceDiagram-2WXFIKYE-DKBJvqmJ.js");return{diagram:t}},__vite__mapDeps([31,9,18]));return{id:WP,diagram:e}},"loader"),ixe={id:WP,detector:rxe,loader:axe},oxe=ixe,VP="class",sxe=N((e,t)=>{var n;return((n=t==null?void 0:t.class)==null?void 0:n.defaultRenderer)==="dagre-wrapper"?!1:/^\s*classDiagram/.test(e)},"detector"),lxe=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./classDiagram-VBA2DB6C-BL2VNw79.js");return{diagram:t}},__vite__mapDeps([32,33,11,9,12,13]));return{id:VP,diagram:e}},"loader"),cxe={id:VP,detector:sxe,loader:lxe},uxe=cxe,YP="classDiagram",dxe=N((e,t)=>{var n;return/^\s*classDiagram/.test(e)&&((n=t==null?void 0:t.class)==null?void 0:n.defaultRenderer)==="dagre-wrapper"?!0:/^\s*classDiagram-v2/.test(e)},"detector"),hxe=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./classDiagram-v2-RAHNMMFH-BL2VNw79.js");return{diagram:t}},__vite__mapDeps([34,33,11,9,12,13]));return{id:YP,diagram:e}},"loader"),pxe={id:YP,detector:dxe,loader:hxe},fxe=pxe,XP="state",mxe=N((e,t)=>{var n;return((n=t==null?void 0:t.state)==null?void 0:n.defaultRenderer)==="dagre-wrapper"?!1:/^\s*stateDiagram/.test(e)},"detector"),gxe=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./stateDiagram-RAJIS63D-BLT77eAV.js");return{diagram:t}},__vite__mapDeps([35,36,12,13,1,2,3,4]));return{id:XP,diagram:e}},"loader"),bxe={id:XP,detector:mxe,loader:gxe},yxe=bxe,KP="stateDiagram",vxe=N((e,t)=>{var n;return!!(/^\s*stateDiagram-v2/.test(e)||/^\s*stateDiagram/.test(e)&&((n=t==null?void 0:t.state)==null?void 0:n.defaultRenderer)==="dagre-wrapper")},"detector"),xxe=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./stateDiagram-v2-FVOUBMTO-DcuudiXa.js");return{diagram:t}},__vite__mapDeps([37,36,12,13]));return{id:KP,diagram:e}},"loader"),Sxe={id:KP,detector:vxe,loader:xxe},wxe=Sxe,ZP="journey",Exe=N(e=>/^\s*journey/.test(e),"detector"),kxe=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./journeyDiagram-4ABVD52K-CUkYVcgS.js");return{diagram:t}},__vite__mapDeps([38,11,9,26]));return{id:ZP,diagram:e}},"loader"),Txe={id:ZP,detector:Exe,loader:kxe},_xe=Txe,Cxe=N((e,t,n)=>{we.debug(`rendering svg for syntax error
`);const r=ife(t),a=r.append("g");r.attr("viewBox","0 0 2412 512"),E9(r,100,512,!0),a.append("path").attr("class","error-icon").attr("d","m411.313,123.313c6.25-6.25 6.25-16.375 0-22.625s-16.375-6.25-22.625,0l-32,32-9.375,9.375-20.688-20.688c-12.484-12.5-32.766-12.5-45.25,0l-16,16c-1.261,1.261-2.304,2.648-3.31,4.051-21.739-8.561-45.324-13.426-70.065-13.426-105.867,0-192,86.133-192,192s86.133,192 192,192 192-86.133 192-192c0-24.741-4.864-48.327-13.426-70.065 1.402-1.007 2.79-2.049 4.051-3.31l16-16c12.5-12.492 12.5-32.758 0-45.25l-20.688-20.688 9.375-9.375 32.001-31.999zm-219.313,100.687c-52.938,0-96,43.063-96,96 0,8.836-7.164,16-16,16s-16-7.164-16-16c0-70.578 57.422-128 128-128 8.836,0 16,7.164 16,16s-7.164,16-16,16z"),a.append("path").attr("class","error-icon").attr("d","m459.02,148.98c-6.25-6.25-16.375-6.25-22.625,0s-6.25,16.375 0,22.625l16,16c3.125,3.125 7.219,4.688 11.313,4.688 4.094,0 8.188-1.563 11.313-4.688 6.25-6.25 6.25-16.375 0-22.625l-16.001-16z"),a.append("path").attr("class","error-icon").attr("d","m340.395,75.605c3.125,3.125 7.219,4.688 11.313,4.688 4.094,0 8.188-1.563 11.313-4.688 6.25-6.25 6.25-16.375 0-22.625l-16-16c-6.25-6.25-16.375-6.25-22.625,0s-6.25,16.375 0,22.625l15.999,16z"),a.append("path").attr("class","error-icon").attr("d","m400,64c8.844,0 16-7.164 16-16v-32c0-8.836-7.156-16-16-16-8.844,0-16,7.164-16,16v32c0,8.836 7.156,16 16,16z"),a.append("path").attr("class","error-icon").attr("d","m496,96.586h-32c-8.844,0-16,7.164-16,16 0,8.836 7.156,16 16,16h32c8.844,0 16-7.164 16-16 0-8.836-7.156-16-16-16z"),a.append("path").attr("class","error-icon").attr("d","m436.98,75.605c3.125,3.125 7.219,4.688 11.313,4.688 4.094,0 8.188-1.563 11.313-4.688l32-32c6.25-6.25 6.25-16.375 0-22.625s-16.375-6.25-22.625,0l-32,32c-6.251,6.25-6.251,16.375-0.001,22.625z"),a.append("text").attr("class","error-text").attr("x",1440).attr("y",250).attr("font-size","150px").style("text-anchor","middle").text("Syntax error in text"),a.append("text").attr("class","error-text").attr("x",1250).attr("y",400).attr("font-size","100px").style("text-anchor","middle").text(`mermaid version ${n}`)},"draw"),QP={draw:Cxe},Axe=QP,Rxe={db:{},renderer:QP,parser:{parse:N(()=>{},"parse")}},Nxe=Rxe,JP="flowchart-elk",Oxe=N((e,t={})=>{var n;return/^\s*flowchart-elk/.test(e)||/^\s*(flowchart|graph)/.test(e)&&((n=t==null?void 0:t.flowchart)==null?void 0:n.defaultRenderer)==="elk"?(t.layout="elk",!0):!1},"detector"),Ixe=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./flowDiagram-PKNHOUZH-BaREyS8h.js");return{diagram:t}},__vite__mapDeps([10,11,9,12,13,14]));return{id:JP,diagram:e}},"loader"),Lxe={id:JP,detector:Oxe,loader:Ixe},Dxe=Lxe,eU="timeline",Mxe=N(e=>/^\s*timeline/.test(e),"detector"),Bxe=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./timeline-definition-YZTLITO2-CDM6T3Yp.js");return{diagram:t}},__vite__mapDeps([39,26]));return{id:eU,diagram:e}},"loader"),Fxe={id:eU,detector:Mxe,loader:Bxe},zxe=Fxe,tU="mindmap",$xe=N(e=>/^\s*mindmap/.test(e),"detector"),Pxe=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./mindmap-definition-YRQLILUH-KtHN9f12.js");return{diagram:t}},__vite__mapDeps([40,12,13]));return{id:tU,diagram:e}},"loader"),Uxe={id:tU,detector:$xe,loader:Pxe},jxe=Uxe,nU="kanban",Hxe=N(e=>/^\s*kanban/.test(e),"detector"),Gxe=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./kanban-definition-K7BYSVSG-eHoob3tt.js");return{diagram:t}},__vite__mapDeps([41,11]));return{id:nU,diagram:e}},"loader"),qxe={id:nU,detector:Hxe,loader:Gxe},Wxe=qxe,rU="sankey",Vxe=N(e=>/^\s*sankey(-beta)?/.test(e),"detector"),Yxe=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./sankeyDiagram-WA2Y5GQK-DwafNq5T.js");return{diagram:t}},__vite__mapDeps([42,27,22]));return{id:rU,diagram:e}},"loader"),Xxe={id:rU,detector:Vxe,loader:Yxe},Kxe=Xxe,aU="packet",Zxe=N(e=>/^\s*packet(-beta)?/.test(e),"detector"),Qxe=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./diagram-P4PSJMXO-DBDi3c6t.js");return{diagram:t}},__vite__mapDeps([43,17,19,2,4,5]));return{id:aU,diagram:e}},"loader"),Jxe={id:aU,detector:Zxe,loader:Qxe},iU="radar",e2e=N(e=>/^\s*radar-beta/.test(e),"detector"),t2e=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./diagram-IFDJBPK2-C-1rIxmK.js");return{diagram:t}},__vite__mapDeps([44,17,19,2,4,5]));return{id:iU,diagram:e}},"loader"),n2e={id:iU,detector:e2e,loader:t2e},oU="block",r2e=N(e=>/^\s*block(-beta)?/.test(e),"detector"),a2e=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./blockDiagram-WCTKOSBZ-BTJGh8U1.js");return{diagram:t}},__vite__mapDeps([45,11,5,2,1,14]));return{id:oU,diagram:e}},"loader"),i2e={id:oU,detector:r2e,loader:a2e},o2e=i2e,sU="architecture",s2e=N(e=>/^\s*architecture/.test(e),"detector"),l2e=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./architectureDiagram-2XIMDMQ5-C2oMw5nu.js");return{diagram:t}},__vite__mapDeps([46,17,19,2,4,5,7]));return{id:sU,diagram:e}},"loader"),c2e={id:sU,detector:s2e,loader:l2e},u2e=c2e,lU="ishikawa",d2e=N(e=>/^\s*ishikawa(-beta)?\b/i.test(e),"detector"),h2e=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./ishikawaDiagram-PHBUUO56-SvNlS1tb.js");return{diagram:t}},[]);return{id:lU,diagram:e}},"loader"),p2e={id:lU,detector:d2e,loader:h2e},cU="venn",f2e=N(e=>/^\s*venn-beta/.test(e),"detector"),m2e=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./vennDiagram-LZ73GAT5-B_4_Dwa6.js");return{diagram:t}},[]);return{id:cU,diagram:e}},"loader"),g2e={id:cU,detector:f2e,loader:m2e},b2e=g2e,uU="treemap",y2e=N(e=>/^\s*treemap/.test(e),"detector"),v2e=N(async()=>{const{diagram:e}=await Ut(async()=>{const{diagram:t}=await import("./diagram-E7M64L7V-C85R0vod.js");return{diagram:t}},__vite__mapDeps([47,13,17,19,2,4,5,23,27,22]));return{id:uU,diagram:e}},"loader"),x2e={id:uU,detector:y2e,loader:v2e},D8=!1,ub=N(()=>{D8||(D8=!0,vm("error",Nxe,e=>e.toLowerCase().trim()==="error"),vm("---",{db:{clear:N(()=>{},"clear")},styles:{},renderer:{draw:N(()=>{},"draw")},parser:{parse:N(()=>{throw new Error("Diagrams beginning with --- are not valid. If you were trying to use a YAML front-matter, please ensure that you've correctly opened and closed the YAML front-matter with un-indented `---` blocks")},"parse")},init:N(()=>null,"init")},e=>e.toLowerCase().trimStart().startsWith("---")),qx(Dxe,jxe,u2e),qx(yve,Wxe,fxe,uxe,Nve,zve,Uve,Gve,nxe,oxe,_ve,wve,zxe,Dve,wxe,yxe,_xe,Yve,Kxe,Jxe,Qve,o2e,n2e,p2e,x2e,b2e))},"addDiagrams"),S2e=N(async()=>{we.debug("Loading registered diagrams");const t=(await Promise.allSettled(Object.entries(vl).map(async([n,{detector:r,loader:a}])=>{if(a)try{Xx(n)}catch{try{const{diagram:i,id:o}=await a();vm(o,i,r)}catch(i){throw we.error(`Failed to load external diagram with key ${n}. Removing from detectors.`),delete vl[n],i}}}))).filter(n=>n.status==="rejected");if(t.length>0){we.error(`Failed to load ${t.length} external diagrams`);for(const n of t)we.error(n);throw new Error(`Failed to load ${t.length} external diagrams`)}},"loadRegisteredDiagrams"),w2e="graphics-document document";function dU(e,t){e.attr("role",w2e),t!==""&&e.attr("aria-roledescription",t)}N(dU,"setA11yDiagramInfo");function hU(e,t,n,r){if(e.insert!==void 0){if(n){const a=`chart-desc-${r}`;e.attr("aria-describedby",a),e.insert("desc",":first-child").attr("id",a).text(n)}if(t){const a=`chart-title-${r}`;e.attr("aria-labelledby",a),e.insert("title",":first-child").attr("id",a).text(t)}}}N(hU,"addSVGa11yTitleDescription");var ml,P2=(ml=class{constructor(t,n,r,a,i){this.type=t,this.text=n,this.db=r,this.parser=a,this.renderer=i}static async fromText(t,n={}){var d,h;const r=br(),a=p_(t,r);t=lbe(t)+`
`;try{Xx(a)}catch{const f=Bce(a);if(!f)throw new c9(`Diagram ${a} not found.`);const{id:m,diagram:b}=await f();vm(m,b)}const{db:i,parser:o,renderer:l,init:u}=Xx(a);return o.parser&&(o.parser.yy=i),(d=i.clear)==null||d.call(i),u==null||u(r),n.title&&((h=i.setDiagramTitle)==null||h.call(i,n.title)),await o.parse(t),new ml(a,t,i,o,l)}async render(t,n){await this.renderer.draw(this.text,t,n,this)}getParser(){return this.parser}getType(){return this.type}},N(ml,"Diagram"),ml),M8=[],E2e=N(()=>{M8.forEach(e=>{e()}),M8=[]},"attachFunctions"),k2e=N(e=>e.replace(/^\s*%%(?!{)[^\n]+\n?/gm,"").trimStart(),"cleanupComments");function pU(e){const t=e.match(l9);if(!t)return{text:e,metadata:{}};let n=h0e(t[1],{schema:d0e})??{};n=typeof n=="object"&&!Array.isArray(n)?n:{};const r={};return n.displayMode&&(r.displayMode=n.displayMode.toString()),n.title&&(r.title=n.title.toString()),n.config&&(r.config=n.config),{text:e.slice(t[0].length),metadata:r}}N(pU,"extractFrontMatter");var T2e=N(e=>e.replace(/\r\n?/g,`
`).replace(/<(\w+)([^>]*)>/g,(t,n,r)=>"<"+n+r.replace(/="([^"]*)"/g,"='$1'")+">"),"cleanupText"),_2e=N(e=>{const{text:t,metadata:n}=pU(e),{displayMode:r,title:a,config:i={}}=n;return r&&(i.gantt||(i.gantt={}),i.gantt.displayMode=r),{title:a,config:i,text:t}},"processFrontmatter"),C2e=N(e=>{const t=ti.detectInit(e)??{},n=ti.detectDirective(e,"wrap");return Array.isArray(n)?t.wrap=n.some(({type:r})=>r==="wrap"):(n==null?void 0:n.type)==="wrap"&&(t.wrap=!0),{text:Xge(e),directive:t}},"processDirectives");function hC(e){const t=T2e(e),n=_2e(t),r=C2e(n.text),a=Y_(n.config,r.directive);return e=k2e(r.text),{code:e,title:n.title,config:a}}N(hC,"preprocessDiagram");function fU(e){const t=new TextEncoder().encode(e),n=Array.from(t,r=>String.fromCodePoint(r)).join("");return btoa(n)}N(fU,"toBase64");var A2e=5e4,R2e="graph TB;a[Maximum text size in diagram exceeded];style a fill:#faa",N2e="sandbox",O2e="loose",I2e="http://www.w3.org/2000/svg",L2e="http://www.w3.org/1999/xlink",D2e="http://www.w3.org/1999/xhtml",M2e="100%",B2e="100%",F2e="border:0;margin:0;",z2e="margin:0",$2e="allow-top-navigation-by-user-activation allow-popups",P2e='The "iframe" tag is not supported by your browser.',U2e=["foreignobject"],j2e=["dominant-baseline"];function pC(e){const t=hC(e);return bm(),Qce(t.config??{}),t}N(pC,"processAndSetConfigs");async function mU(e,t){ub();try{const{code:n,config:r}=pC(e);return{diagramType:(await bU(n)).type,config:r}}catch(n){if(t!=null&&t.suppressErrors)return!1;throw n}}N(mU,"parse");var B8=N((e,t,n=[])=>`
.${e} ${t} { ${n.join(" !important; ")} !important; }`,"cssImportantStyles"),H2e=N((e,t=new Map)=>{let n="";if(e.themeCSS!==void 0&&(n+=`
${e.themeCSS}`),e.fontFamily!==void 0&&(n+=`
:root { --mermaid-font-family: ${e.fontFamily}}`),e.altFontFamily!==void 0&&(n+=`
:root { --mermaid-alt-font-family: ${e.altFontFamily}}`),t instanceof Map){const o=xr(e)?["> *","span"]:["rect","polygon","ellipse","circle","path"];t.forEach(l=>{L8(l.styles)||o.forEach(u=>{n+=B8(l.id,u,l.styles)}),L8(l.textStyles)||(n+=B8(l.id,"tspan",((l==null?void 0:l.textStyles)||[]).map(u=>u.replace("color","fill"))))})}return n},"createCssStyles"),G2e=N((e,t,n,r)=>{const a=H2e(e,n),i=bue(t,a,e.themeVariables);return M2(Q1e(`${r}{${i}}`),eve)},"createUserStyles"),q2e=N((e="",t,n)=>{let r=e;return!n&&!t&&(r=r.replace(/marker-end="url\([\d+./:=?A-Za-z-]*?#/g,'marker-end="url(#')),r=Ou(r),r=r.replace(/<br>/g,"<br/>"),r},"cleanUpSvgCode"),W2e=N((e="",t)=>{var a,i;const n=(i=(a=t==null?void 0:t.viewBox)==null?void 0:a.baseVal)!=null&&i.height?t.viewBox.baseVal.height+"px":B2e,r=fU(`<body style="${z2e}">${e}</body>`);return`<iframe style="width:${M2e};height:${n};${F2e}" src="data:text/html;charset=UTF-8;base64,${r}" sandbox="${$2e}">
  ${P2e}
</iframe>`},"putIntoIFrame"),F8=N((e,t,n,r,a)=>{const i=e.append("div");i.attr("id",n),r&&i.attr("style",r);const o=i.append("svg").attr("id",t).attr("width","100%").attr("xmlns",I2e);return a&&o.attr("xmlns:xlink",a),o.append("g"),e},"appendDivSvgG");function U2(e,t){return e.append("iframe").attr("id",t).attr("style","width: 100%; height: 100%;").attr("sandbox","")}N(U2,"sandboxedIframe");var V2e=N((e,t,n,r)=>{var a,i,o;(a=e.getElementById(t))==null||a.remove(),(i=e.getElementById(n))==null||i.remove(),(o=e.getElementById(r))==null||o.remove()},"removeExistingElements"),Y2e=N(async function(e,t,n){var Z,V,q,X,$,Q;ub();const r=pC(t);t=r.code;const a=br();we.debug(a),t.length>((a==null?void 0:a.maxTextSize)??A2e)&&(t=R2e);const i="#"+e,o="i"+e,l="#"+o,u="d"+e,d="#"+u,h=N(()=>{const ie=Et(m?l:d).node();ie&&"remove"in ie&&ie.remove()},"removeTempElements");let f=Et("body");const m=a.securityLevel===N2e,b=a.securityLevel===O2e,y=a.fontFamily;if(n!==void 0){if(n&&(n.innerHTML=""),m){const J=U2(Et(n),o);f=Et(J.nodes()[0].contentDocument.body),f.node().style.margin=0}else f=Et(n);F8(f,e,u,`font-family: ${y}`,L2e)}else{if(V2e(document,e,u,o),m){const J=U2(Et("body"),o);f=Et(J.nodes()[0].contentDocument.body),f.node().style.margin=0}else f=Et("body");F8(f,e,u)}let v,w;try{v=await P2.fromText(t,{title:r.title})}catch(J){if(a.suppressErrorRendering)throw h(),J;v=await P2.fromText("error"),w=J}const S=f.select(d).node(),k=v.type,R=S.firstChild,I=R.firstChild,L=(V=(Z=v.renderer).getClasses)==null?void 0:V.call(Z,t,v),A=G2e(a,k,L,i),M=document.createElement("style");M.innerHTML=A,R.insertBefore(M,I);try{await v.renderer.draw(t,e,"11.13.0",v)}catch(J){throw a.suppressErrorRendering?h():Axe.draw(t,e,"11.13.0"),J}const P=f.select(`${d} svg`),G=(X=(q=v.db).getAccTitle)==null?void 0:X.call(q),B=(Q=($=v.db).getAccDescription)==null?void 0:Q.call($);yU(k,P,G,B),f.select(`[id="${e}"]`).selectAll("foreignobject > *").attr("xmlns",D2e);let H=f.select(d).node().innerHTML;if(we.debug("config.arrowMarkerAbsolute",a.arrowMarkerAbsolute),H=q2e(H,m,Ds(a.arrowMarkerAbsolute)),m){const J=f.select(d+" svg").node();H=W2e(H,J)}else b||(H=nu.sanitize(H,{ADD_TAGS:U2e,ADD_ATTR:j2e,HTML_INTEGRATION_POINTS:{foreignobject:!0}}));if(E2e(),w)throw w;return h(),{diagramType:k,svg:H,bindFunctions:v.db.bindFunctions}},"render");function gU(e={}){var r;const t=Yn({},e);t!=null&&t.fontFamily&&!((r=t.themeVariables)!=null&&r.fontFamily)&&(t.themeVariables||(t.themeVariables={}),t.themeVariables.fontFamily=t.fontFamily),Kce(t),t!=null&&t.theme&&t.theme in xo?t.themeVariables=xo[t.theme].getThemeVariables(t.themeVariables):t&&(t.themeVariables=xo.default.getThemeVariables(t.themeVariables));const n=typeof t=="object"?Xce(t):f9();h_(n.logLevel),ub()}N(gU,"initialize");var bU=N((e,t={})=>{const{code:n}=hC(e);return P2.fromText(n,t)},"getDiagramFromText");function yU(e,t,n,r){dU(t,e),hU(t,n,r,t.attr("id"))}N(yU,"addA11yInfo");var Tl=Object.freeze({render:Y2e,parse:mU,getDiagramFromText:bU,initialize:gU,getConfig:br,setConfig:m9,getSiteConfig:f9,updateSiteConfig:Zce,reset:N(()=>{bm()},"reset"),globalReset:N(()=>{bm(ru)},"globalReset"),defaultConfig:ru});h_(br().logLevel);bm(br());var X2e=N((e,t,n)=>{we.warn(e),V_(e)?(n&&n(e.str,e.hash),t.push({...e,message:e.str,error:e})):(n&&n(e),e instanceof Error&&t.push({str:e.message,message:e.message,hash:e.name,error:e}))},"handleError"),vU=N(async function(e={querySelector:".mermaid"}){try{await K2e(e)}catch(t){if(V_(t)&&we.error(t.str),ga.parseError&&ga.parseError(t),!e.suppressErrors)throw we.error("Use the suppressErrors option to suppress these errors"),t}},"run"),K2e=N(async function({postRenderCallback:e,querySelector:t,nodes:n}={querySelector:".mermaid"}){const r=Tl.getConfig();we.debug(`${e?"":"No "}Callback function found`);let a;if(n)a=n;else if(t)a=document.querySelectorAll(t);else throw new Error("Nodes and querySelector are both undefined");we.debug(`Found ${a.length} diagrams`),(r==null?void 0:r.startOnLoad)!==void 0&&(we.debug("Start On Load: "+(r==null?void 0:r.startOnLoad)),Tl.updateSiteConfig({startOnLoad:r==null?void 0:r.startOnLoad}));const i=new ti.InitIDGenerator(r.deterministicIds,r.deterministicIDSeed);let o;const l=[];for(const u of Array.from(a)){if(we.info("Rendering diagram: "+u.id),u.getAttribute("data-processed"))continue;u.setAttribute("data-processed","true");const d=`mermaid-${i.next()}`;o=u.innerHTML,o=zz(ti.entityDecode(o)).trim().replace(/<br\s*\/?>/gi,"<br/>");const h=ti.detectInit(o);h&&we.debug("Detected early reinit: ",h);try{const{svg:f,bindFunctions:m}=await EU(d,o,u);u.innerHTML=f,e&&await e(d),m&&m(u)}catch(f){X2e(f,l,ga.parseError)}}if(l.length>0)throw l[0]},"runThrowsErrors"),xU=N(function(e){Tl.initialize(e)},"initialize"),Z2e=N(async function(e,t,n){we.warn("mermaid.init is deprecated. Please use run instead."),e&&xU(e);const r={postRenderCallback:n,querySelector:".mermaid"};typeof t=="string"?r.querySelector=t:t&&(t instanceof HTMLElement?r.nodes=[t]:r.nodes=t),await vU(r)},"init"),Q2e=N(async(e,{lazyLoad:t=!0}={})=>{ub(),qx(...e),t===!1&&await S2e()},"registerExternalDiagrams"),SU=N(function(){if(ga.startOnLoad){const{startOnLoad:e}=Tl.getConfig();e&&ga.run().catch(t=>we.error("Mermaid failed to initialize",t))}},"contentLoaded");typeof document<"u"&&window.addEventListener("load",SU,!1);var J2e=N(function(e){ga.parseError=e},"setParseErrorHandler"),Xm=[],Qv=!1,wU=N(async()=>{if(!Qv){for(Qv=!0;Xm.length>0;){const e=Xm.shift();if(e)try{await e()}catch(t){we.error("Error executing queue",t)}}Qv=!1}},"executeQueue"),eSe=N(async(e,t)=>new Promise((n,r)=>{const a=N(()=>new Promise((i,o)=>{Tl.parse(e,t).then(l=>{i(l),n(l)},l=>{var u;we.error("Error parsing",l),(u=ga.parseError)==null||u.call(ga,l),o(l),r(l)})}),"performCall");Xm.push(a),wU().catch(r)}),"parse"),EU=N((e,t,n)=>new Promise((r,a)=>{const i=N(()=>new Promise((o,l)=>{Tl.render(e,t,n).then(u=>{o(u),r(u)},u=>{var d;we.error("Error parsing",u),(d=ga.parseError)==null||d.call(ga,u),l(u),a(u)})}),"performCall");Xm.push(i),wU().catch(a)}),"render"),tSe=N(()=>Object.keys(vl).map(e=>({id:e})),"getRegisteredDiagramsMetadata"),ga={startOnLoad:!0,mermaidAPI:Tl,parse:eSe,render:EU,init:Z2e,run:vU,registerExternalDiagrams:Q2e,registerLayoutLoaders:AP,initialize:xU,parseError:void 0,contentLoaded:SU,setParseErrorHandler:J2e,detectType:p_,registerIconPacks:mye,getRegisteredDiagramsMetadata:tSe},kU=ga;/*! Check if previously processed *//*!
 * Wait for document loaded before starting the execution
 */kU.initialize({startOnLoad:!1,theme:"default",securityLevel:"loose"});let nSe=0;function rSe({chart:e}){const t=_.useRef(null),[n,r]=_.useState(!1),[a,i]=_.useState(!1),[o,l]=_.useState("diagram");return _.useEffect(()=>{let u=!1;const d=`mermaid-${++nSe}`;return r(!1),i(!1),(async()=>{var h;try{const f=await kU.render(d,e);!u&&t.current&&(t.current.innerHTML=f.svg,r(!0))}catch{u||i(!0),(h=document.getElementById(`d${d}`))==null||h.remove()}})(),()=>{u=!0}},[e]),a?T.jsx(jx,{language:"mermaid",value:e}):T.jsxs("div",{className:"my-4",children:[T.jsx("div",{ref:t,className:`justify-center overflow-auto bg-white [&_svg]:max-w-full [&_svg]:h-auto ${o==="diagram"?"flex":"hidden"}`}),!n&&T.jsx("div",{className:`flex justify-center py-8 text-muted-foreground text-sm ${o==="diagram"?"":"hidden"}`,children:"Rendering diagram…"}),T.jsx("div",{className:o==="code"?"":"hidden",children:T.jsx(jx,{language:"mermaid",value:e})}),T.jsxs("div",{className:"flex items-center justify-end gap-1 mt-1",children:[T.jsx(kt,{variant:"ghost",size:"icon",className:`h-6 w-6 ${o==="diagram"?"text-foreground":"text-muted-foreground hover:text-foreground"}`,onClick:()=>l("diagram"),"aria-label":"Show diagram",children:T.jsx(xO,{className:"h-3.5 w-3.5"})}),T.jsx(kt,{variant:"ghost",size:"icon",className:`h-6 w-6 ${o==="code"?"text-foreground":"text-muted-foreground hover:text-foreground"}`,onClick:()=>l("code"),"aria-label":"Show code",children:T.jsx(QW,{className:"h-3.5 w-3.5"})})]})]})}const aSe={handlers:{inlineMath(e,t){return{type:"element",tagName:"code",properties:{className:["language-math","math-inline"]},children:[{type:"text",value:t.value}]}},math(e,t){return{type:"element",tagName:"pre",properties:{},children:[{type:"element",tagName:"code",properties:{className:["language-math","math-display"]},children:[{type:"text",value:t.value}]}]}}}};function iSe({children:e,...t}){const n=_.useRef(null),[r,a]=_.useState(!1),i=_.useCallback(async()=>{var d;const o=n.current;if(!o)return;const l=o.querySelectorAll("tr"),u=[];for(const h of l){const f=h.querySelectorAll("th, td"),m=Array.from(f).map(b=>(b.textContent??"").trim());u.push(`| ${m.join(" | ")} |`),((d=h.parentElement)==null?void 0:d.tagName)==="THEAD"&&u.push(`| ${m.map(()=>"---").join(" | ")} |`)}await navigator.clipboard.writeText(u.join(`
`)),a(!0),setTimeout(()=>a(!1),2e3)},[]);return T.jsxs("div",{className:"group/table relative my-4 overflow-auto",children:[T.jsx(kt,{variant:"ghost",size:"icon",className:"absolute right-1 top-1 z-10 h-7 w-7 opacity-0 transition-opacity group-hover/table:opacity-100",onClick:i,"aria-label":"Copy table as Markdown",children:r?T.jsx(rg,{className:"h-3.5 w-3.5"}):T.jsx(Q2,{className:"h-3.5 w-3.5"})}),T.jsx("table",{ref:n,className:"w-full border-collapse border border-border text-sm",...t,children:e})]})}const oSe={code({className:e,children:t,node:n,...r}){const a=/language-(\w+)/.exec(e||""),i=String(t).replace(/\n$/,"");if(!a)return T.jsx("code",{className:"rounded bg-muted px-1.5 py-0.5 font-mono text-[0.8125rem]",...r,children:t});const o=a[1];return o==="mermaid"?T.jsx(rSe,{chart:i}):T.jsx(jx,{language:o,value:i})},pre({children:e}){return T.jsx(T.Fragment,{children:e})},a({href:e,children:t,node:n,...r}){return T.jsx("a",{href:e,target:"_blank",rel:"noopener noreferrer",className:"text-blue-600 no-underline hover:underline text-[0.8125rem]",...r,children:t})},table({children:e,node:t,...n}){return T.jsx(iSe,{...n,children:e})},thead({children:e,node:t,...n}){return T.jsx("thead",{className:"bg-muted",...n,children:e})},th({children:e,node:t,...n}){return T.jsx("th",{className:"border border-border px-3 py-2 text-left font-semibold",...n,children:e})},td({children:e,node:t,...n}){return T.jsx("td",{className:"border border-border px-3 py-2",...n,children:e})},p({children:e,node:t,...n}){return T.jsx("p",{className:"mb-4 last:mb-0",...n,children:e})},h1({children:e,node:t,...n}){return T.jsx("h1",{className:"mt-6 mb-3 text-2xl font-bold first:mt-0",...n,children:e})},h2({children:e,node:t,...n}){return T.jsx("h2",{className:"mt-5 mb-3 text-xl font-bold first:mt-0",...n,children:e})},h3({children:e,node:t,...n}){return T.jsx("h3",{className:"mt-4 mb-2 text-lg font-semibold first:mt-0",...n,children:e})},ul({children:e,node:t,...n}){return T.jsx("ul",{className:"mb-4 ml-6 list-disc last:mb-0",...n,children:e})},ol({children:e,node:t,...n}){return T.jsx("ol",{className:"mb-4 ml-6 list-decimal last:mb-0",...n,children:e})},li({children:e,node:t,...n}){return T.jsx("li",{className:"mb-1",...n,children:e})},blockquote({children:e,node:t,...n}){return T.jsx("blockquote",{className:"my-4 border-l-4 border-border pl-4 italic text-muted-foreground",...n,children:e})},hr({node:e,...t}){return T.jsx("hr",{className:"my-6 border-border",...t})}};function sSe(e){let t=e.replace(/\\\[/g,"$$").replace(/\\\]/g,"$$");return t=t.replace(/\\\(/g,"$").replace(/\\\)/g,"$"),t}function TU({content:e}){return T.jsx(Tre,{remarkPlugins:[Zse,lle],rehypePlugins:[[Hie,{throwOnError:!1,trust:!0,strict:!1}]],remarkRehypeOptions:aSe,components:oSe,children:sSe(e)})}function lSe({block:e}){const[t,n]=_.useState(0),[r,a]=_.useState(!1),i=_.useRef(Date.now());_.useEffect(()=>{if(e.status==="thinking"){const u=setInterval(()=>{n(Math.floor((Date.now()-i.current)/1e3))},1e3);return()=>clearInterval(u)}},[e.status]);const o=e.status==="thinking",l=o?`Thinking${t>0?` (${t}s)`:"..."}`:`Thought for ${t}s`;return T.jsxs("div",{className:"mb-2",children:[T.jsxs("button",{type:"button",className:"flex items-center gap-1.5 text-sm text-muted-foreground hover:text-foreground transition-colors",onClick:()=>a(!r),children:[T.jsx(GW,{className:`h-3.5 w-3.5 ${o?"animate-pulse":""}`}),T.jsx("span",{children:l}),T.jsx(Z2,{className:`h-3 w-3 transition-transform ${r?"rotate-90":""}`})]}),r&&e.content&&T.jsx("div",{className:"mt-1 ml-5 max-h-48 overflow-y-auto rounded-md bg-muted/50 p-2.5 text-xs leading-relaxed text-muted-foreground [&_pre]:text-[0.7rem]",children:T.jsx(TU,{content:e.content})})]})}function cSe({reasoningBlocks:e}){return e.length===0?null:T.jsx("div",{className:"flex flex-col",children:e.map(t=>T.jsx(lSe,{block:t},t.id))})}const uSe={web_search_preview:{label:"Searching the web...",doneLabel:"Searched the web",icon:L6},web_search:{label:"Searching the web...",doneLabel:"Searched the web",icon:L6},get_coords_by_city:{label:"Looking up location...",doneLabel:"Looked up location",icon:J2},get_current_weather_by_coords:{label:"Fetching current weather...",doneLabel:"Fetched current weather",icon:gO},get_weather_next_week:{label:"Fetching weekly forecast...",doneLabel:"Fetched weekly forecast",icon:mO},file_read:{label:"Reading file...",doneLabel:"Read file",icon:uV},file_write:{label:"Writing file...",doneLabel:"Wrote file",icon:sV},bash_execute:{label:"Executing command...",doneLabel:"Executed command",icon:HV},file_glob:{label:"Searching files...",doneLabel:"Searched files",icon:hV},file_grep:{label:"Searching content...",doneLabel:"Searched content",icon:nS},generate_image:{label:"Generating image...",doneLabel:"Generated image",icon:bV},edit_image:{label:"Editing image...",doneLabel:"Edited image",icon:eS}};function z8(e){try{return JSON.stringify(JSON.parse(e),null,2)}catch{return e}}function dSe({toolCall:e}){const[t,n]=_.useState(!1),r=e.status==="running",a=uSe[e.name]??{label:`Running ${e.name}...`,doneLabel:`Used ${e.name}`,icon:nY},i=a.icon,o=r?a.label:a.doneLabel,l=e.args||e.result;return T.jsxs("div",{className:"mb-1",children:[T.jsxs("button",{type:"button",className:"flex items-center gap-1.5 text-sm text-muted-foreground hover:text-foreground transition-colors",onClick:()=>l&&n(!t),children:[T.jsx(i,{className:`h-3.5 w-3.5 ${r?"animate-pulse":""}`}),T.jsx("span",{children:o}),l&&T.jsx(Z2,{className:`h-3 w-3 transition-transform ${t?"rotate-90":""}`})]}),t&&l&&T.jsxs("div",{className:"mt-1 ml-5 max-h-60 overflow-y-auto rounded-md bg-muted/50 p-2.5 text-xs leading-relaxed text-muted-foreground",children:[e.args&&T.jsxs("div",{className:"mb-2",children:[T.jsx("div",{className:"mb-1 font-medium text-foreground/70",children:"Arguments"}),T.jsx("pre",{className:"whitespace-pre-wrap break-all font-mono text-[0.7rem]",children:z8(e.args)})]}),e.result&&T.jsxs("div",{children:[T.jsx("div",{className:"mb-1 font-medium text-foreground/70",children:"Result"}),T.jsx("pre",{className:"whitespace-pre-wrap break-all font-mono text-[0.7rem]",children:z8(e.result)})]})]})]})}function hSe({toolCalls:e,isWaiting:t}){return(!e||e.length===0)&&!t?null:T.jsxs("div",{className:"mb-2 flex flex-col",children:[e==null?void 0:e.map(n=>T.jsx(dSe,{toolCall:n},n.id)),(!e||e.length===0)&&t&&T.jsx("div",{className:"flex items-center text-sm text-muted-foreground",children:T.jsx(fu,{className:"h-3.5 w-3.5 animate-spin"})})]})}var db="Dialog",[_U,CU]=Os(db),[pSe,ui]=_U(db),AU=e=>{const{__scopeDialog:t,children:n,open:r,defaultOpen:a,onOpenChange:i,modal:o=!0}=e,l=_.useRef(null),u=_.useRef(null),[d,h]=lS({prop:r,defaultProp:a??!1,onChange:i,caller:db});return T.jsx(pSe,{scope:t,triggerRef:l,contentRef:u,contentId:Dc(),titleId:Dc(),descriptionId:Dc(),open:d,onOpenChange:h,onOpenToggle:_.useCallback(()=>h(f=>!f),[h]),modal:o,children:n})};AU.displayName=db;var RU="DialogTrigger",NU=_.forwardRef((e,t)=>{const{__scopeDialog:n,...r}=e,a=ui(RU,n),i=un(t,a.triggerRef);return T.jsx(dn.button,{type:"button","aria-haspopup":"dialog","aria-expanded":a.open,"aria-controls":a.contentId,"data-state":gC(a.open),...r,ref:i,onClick:ft(e.onClick,a.onOpenToggle)})});NU.displayName=RU;var fC="DialogPortal",[fSe,OU]=_U(fC,{forceMount:void 0}),IU=e=>{const{__scopeDialog:t,forceMount:n,children:r,container:a}=e,i=ui(fC,t);return T.jsx(fSe,{scope:t,forceMount:n,children:_.Children.map(r,o=>T.jsx(Wa,{present:n||i.open,children:T.jsx(xS,{asChild:!0,container:a,children:o})}))})};IU.displayName=fC;var Km="DialogOverlay",LU=_.forwardRef((e,t)=>{const n=OU(Km,e.__scopeDialog),{forceMount:r=n.forceMount,...a}=e,i=ui(Km,e.__scopeDialog);return i.modal?T.jsx(Wa,{present:r||i.open,children:T.jsx(gSe,{...a,ref:t})}):null});LU.displayName=Km;var mSe=xh("DialogOverlay.RemoveScroll"),gSe=_.forwardRef((e,t)=>{const{__scopeDialog:n,...r}=e,a=ui(Km,n);return T.jsx(SS,{as:mSe,allowPinchZoom:!0,shards:[a.contentRef],children:T.jsx(dn.div,{"data-state":gC(a.open),...r,ref:t,style:{pointerEvents:"auto",...r.style}})})}),_l="DialogContent",DU=_.forwardRef((e,t)=>{const n=OU(_l,e.__scopeDialog),{forceMount:r=n.forceMount,...a}=e,i=ui(_l,e.__scopeDialog);return T.jsx(Wa,{present:r||i.open,children:i.modal?T.jsx(bSe,{...a,ref:t}):T.jsx(ySe,{...a,ref:t})})});DU.displayName=_l;var bSe=_.forwardRef((e,t)=>{const n=ui(_l,e.__scopeDialog),r=_.useRef(null),a=un(t,n.contentRef,r);return _.useEffect(()=>{const i=r.current;if(i)return EI(i)},[]),T.jsx(MU,{...e,ref:a,trapFocus:n.open,disableOutsidePointerEvents:!0,onCloseAutoFocus:ft(e.onCloseAutoFocus,i=>{var o;i.preventDefault(),(o=n.triggerRef.current)==null||o.focus()}),onPointerDownOutside:ft(e.onPointerDownOutside,i=>{const o=i.detail.originalEvent,l=o.button===0&&o.ctrlKey===!0;(o.button===2||l)&&i.preventDefault()}),onFocusOutside:ft(e.onFocusOutside,i=>i.preventDefault())})}),ySe=_.forwardRef((e,t)=>{const n=ui(_l,e.__scopeDialog),r=_.useRef(!1),a=_.useRef(!1);return T.jsx(MU,{...e,ref:t,trapFocus:!1,disableOutsidePointerEvents:!1,onCloseAutoFocus:i=>{var o,l;(o=e.onCloseAutoFocus)==null||o.call(e,i),i.defaultPrevented||(r.current||(l=n.triggerRef.current)==null||l.focus(),i.preventDefault()),r.current=!1,a.current=!1},onInteractOutside:i=>{var u,d;(u=e.onInteractOutside)==null||u.call(e,i),i.defaultPrevented||(r.current=!0,i.detail.originalEvent.type==="pointerdown"&&(a.current=!0));const o=i.target;((d=n.triggerRef.current)==null?void 0:d.contains(o))&&i.preventDefault(),i.detail.originalEvent.type==="focusin"&&a.current&&i.preventDefault()}})}),MU=_.forwardRef((e,t)=>{const{__scopeDialog:n,trapFocus:r,onOpenAutoFocus:a,onCloseAutoFocus:i,...o}=e,l=ui(_l,n),u=_.useRef(null),d=un(t,u);return WO(),T.jsxs(T.Fragment,{children:[T.jsx(dS,{asChild:!0,loop:!0,trapped:r,onMountAutoFocus:a,onUnmountAutoFocus:i,children:T.jsx(uS,{role:"dialog",id:l.contentId,"aria-describedby":l.descriptionId,"aria-labelledby":l.titleId,"data-state":gC(l.open),...o,ref:d,onDismiss:()=>l.onOpenChange(!1)})}),T.jsxs(T.Fragment,{children:[T.jsx(xSe,{titleId:l.titleId}),T.jsx(wSe,{contentRef:u,descriptionId:l.descriptionId})]})]})}),mC="DialogTitle",BU=_.forwardRef((e,t)=>{const{__scopeDialog:n,...r}=e,a=ui(mC,n);return T.jsx(dn.h2,{id:a.titleId,...r,ref:t})});BU.displayName=mC;var FU="DialogDescription",zU=_.forwardRef((e,t)=>{const{__scopeDialog:n,...r}=e,a=ui(FU,n);return T.jsx(dn.p,{id:a.descriptionId,...r,ref:t})});zU.displayName=FU;var $U="DialogClose",PU=_.forwardRef((e,t)=>{const{__scopeDialog:n,...r}=e,a=ui($U,n);return T.jsx(dn.button,{type:"button",...r,ref:t,onClick:ft(e.onClick,()=>a.onOpenChange(!1))})});PU.displayName=$U;function gC(e){return e?"open":"closed"}var UU="DialogTitleWarning",[vSe,jU]=iX(UU,{contentName:_l,titleName:mC,docsSlug:"dialog"}),xSe=({titleId:e})=>{const t=jU(UU),n=`\`${t.contentName}\` requires a \`${t.titleName}\` for the component to be accessible for screen reader users.

If you want to hide the \`${t.titleName}\`, you can wrap it with our VisuallyHidden component.

For more information, see https://radix-ui.com/primitives/docs/components/${t.docsSlug}`;return _.useEffect(()=>{e&&(document.getElementById(e)||console.error(n))},[n,e]),null},SSe="DialogDescriptionWarning",wSe=({contentRef:e,descriptionId:t})=>{const r=`Warning: Missing \`Description\` or \`aria-describedby={undefined}\` for {${jU(SSe).contentName}}.`;return _.useEffect(()=>{var i;const a=(i=e.current)==null?void 0:i.getAttribute("aria-describedby");t&&a&&(document.getElementById(t)||console.warn(r))},[r,e,t]),null},HU=AU,ESe=NU,GU=IU,bC=LU,yC=DU,vC=BU,xC=zU,SC=PU,qU="AlertDialog",[kSe]=Os(qU,[CU]),Bo=CU(),WU=e=>{const{__scopeAlertDialog:t,...n}=e,r=Bo(t);return T.jsx(HU,{...r,...n,modal:!0})};WU.displayName=qU;var TSe="AlertDialogTrigger",_Se=_.forwardRef((e,t)=>{const{__scopeAlertDialog:n,...r}=e,a=Bo(n);return T.jsx(ESe,{...a,...r,ref:t})});_Se.displayName=TSe;var CSe="AlertDialogPortal",VU=e=>{const{__scopeAlertDialog:t,...n}=e,r=Bo(t);return T.jsx(GU,{...r,...n})};VU.displayName=CSe;var ASe="AlertDialogOverlay",YU=_.forwardRef((e,t)=>{const{__scopeAlertDialog:n,...r}=e,a=Bo(n);return T.jsx(bC,{...a,...r,ref:t})});YU.displayName=ASe;var jc="AlertDialogContent",[RSe,NSe]=kSe(jc),OSe=dX("AlertDialogContent"),XU=_.forwardRef((e,t)=>{const{__scopeAlertDialog:n,children:r,...a}=e,i=Bo(n),o=_.useRef(null),l=un(t,o),u=_.useRef(null);return T.jsx(vSe,{contentName:jc,titleName:KU,docsSlug:"alert-dialog",children:T.jsx(RSe,{scope:n,cancelRef:u,children:T.jsxs(yC,{role:"alertdialog",...i,...a,ref:l,onOpenAutoFocus:ft(a.onOpenAutoFocus,d=>{var h;d.preventDefault(),(h=u.current)==null||h.focus({preventScroll:!0})}),onPointerDownOutside:d=>d.preventDefault(),onInteractOutside:d=>d.preventDefault(),children:[T.jsx(OSe,{children:r}),T.jsx(LSe,{contentRef:o})]})})})});XU.displayName=jc;var KU="AlertDialogTitle",ZU=_.forwardRef((e,t)=>{const{__scopeAlertDialog:n,...r}=e,a=Bo(n);return T.jsx(vC,{...a,...r,ref:t})});ZU.displayName=KU;var QU="AlertDialogDescription",JU=_.forwardRef((e,t)=>{const{__scopeAlertDialog:n,...r}=e,a=Bo(n);return T.jsx(xC,{...a,...r,ref:t})});JU.displayName=QU;var ISe="AlertDialogAction",ej=_.forwardRef((e,t)=>{const{__scopeAlertDialog:n,...r}=e,a=Bo(n);return T.jsx(SC,{...a,...r,ref:t})});ej.displayName=ISe;var tj="AlertDialogCancel",nj=_.forwardRef((e,t)=>{const{__scopeAlertDialog:n,...r}=e,{cancelRef:a}=NSe(tj,n),i=Bo(n),o=un(t,a);return T.jsx(SC,{...i,...r,ref:o})});nj.displayName=tj;var LSe=({contentRef:e})=>{const t=`\`${jc}\` requires a description for the component to be accessible for screen reader users.

You can add a description to the \`${jc}\` by passing a \`${QU}\` component as a child, which also benefits sighted users by adding visible context to the dialog.

Alternatively, you can use your own component as a description by assigning it an \`id\` and passing the same value to the \`aria-describedby\` prop in \`${jc}\`. If the description is confusing or duplicative for sighted users, you can use the \`@radix-ui/react-visually-hidden\` primitive as a wrapper around your description component.

For more information, see https://radix-ui.com/primitives/docs/components/alert-dialog`;return _.useEffect(()=>{var r;document.getElementById((r=e.current)==null?void 0:r.getAttribute("aria-describedby"))||console.warn(t)},[t,e]),null},DSe=WU,MSe=VU,rj=YU,aj=XU,ij=ej,oj=nj,sj=ZU,lj=JU;const wC=DSe,BSe=MSe,cj=_.forwardRef(({className:e,...t},n)=>T.jsx(rj,{className:st("fixed inset-0 z-50 bg-black/80 data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0",e),...t,ref:n}));cj.displayName=rj.displayName;const hb=_.forwardRef(({className:e,...t},n)=>T.jsxs(BSe,{children:[T.jsx(cj,{}),T.jsx(aj,{ref:n,className:st("fixed left-[50%] top-[50%] z-50 grid w-full max-w-lg translate-x-[-50%] translate-y-[-50%] gap-4 border bg-background p-6 shadow-lg duration-200 data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 data-[state=closed]:slide-out-to-left-1/2 data-[state=closed]:slide-out-to-top-[48%] data-[state=open]:slide-in-from-left-1/2 data-[state=open]:slide-in-from-top-[48%] sm:rounded-lg",e),...t})]}));hb.displayName=aj.displayName;const pb=({className:e,...t})=>T.jsx("div",{className:st("flex flex-col space-y-2 text-center sm:text-left",e),...t});pb.displayName="AlertDialogHeader";const fb=({className:e,...t})=>T.jsx("div",{className:st("flex flex-col-reverse sm:flex-row sm:justify-end sm:space-x-2",e),...t});fb.displayName="AlertDialogFooter";const mb=_.forwardRef(({className:e,...t},n)=>T.jsx(sj,{ref:n,className:st("text-lg font-semibold",e),...t}));mb.displayName=sj.displayName;const gb=_.forwardRef(({className:e,...t},n)=>T.jsx(lj,{ref:n,className:st("text-sm text-muted-foreground",e),...t}));gb.displayName=lj.displayName;const bb=_.forwardRef(({className:e,...t},n)=>T.jsx(ij,{ref:n,className:st(sS(),e),...t}));bb.displayName=ij.displayName;const yb=_.forwardRef(({className:e,...t},n)=>T.jsx(oj,{ref:n,className:st(sS({variant:"outline"}),"mt-2 sm:mt-0",e),...t}));yb.displayName=oj.displayName;function FSe(e,t=[]){let n=[];function r(i,o){const l=_.createContext(o);l.displayName=i+"Context";const u=n.length;n=[...n,o];const d=f=>{var S;const{scope:m,children:b,...y}=f,v=((S=m==null?void 0:m[e])==null?void 0:S[u])||l,w=_.useMemo(()=>y,Object.values(y));return T.jsx(v.Provider,{value:w,children:b})};d.displayName=i+"Provider";function h(f,m){var v;const b=((v=m==null?void 0:m[e])==null?void 0:v[u])||l,y=_.useContext(b);if(y)return y;if(o!==void 0)return o;throw new Error(`\`${f}\` must be used within \`${i}\``)}return[d,h]}const a=()=>{const i=n.map(o=>_.createContext(o));return function(l){const u=(l==null?void 0:l[e])||i;return _.useMemo(()=>({[`__scope${e}`]:{...l,[e]:u}}),[l,u])}};return a.scopeName=e,[r,zSe(a,...t)]}function zSe(...e){const t=e[0];if(e.length===1)return t;const n=()=>{const r=e.map(a=>({useScope:a(),scopeName:a.scopeName}));return function(i){const o=r.reduce((l,{useScope:u,scopeName:d})=>{const f=u(i)[`__scope${d}`];return{...l,...f}},{});return _.useMemo(()=>({[`__scope${t.scopeName}`]:o}),[o])}};return n.scopeName=t.scopeName,n}var $Se=["a","button","div","form","h2","h3","img","input","label","li","nav","ol","p","select","span","svg","ul"],EC=$Se.reduce((e,t)=>{const n=PO(`Primitive.${t}`),r=_.forwardRef((a,i)=>{const{asChild:o,...l}=a,u=o?n:t;return typeof window<"u"&&(window[Symbol.for("radix-ui")]=!0),T.jsx(u,{...l,ref:i})});return r.displayName=`Primitive.${t}`,{...e,[t]:r}},{}),Jv={exports:{}},ex={};/**
 * @license React
 * use-sync-external-store-shim.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var $8;function PSe(){if($8)return ex;$8=1;var e=Jm();function t(f,m){return f===m&&(f!==0||1/f===1/m)||f!==f&&m!==m}var n=typeof Object.is=="function"?Object.is:t,r=e.useState,a=e.useEffect,i=e.useLayoutEffect,o=e.useDebugValue;function l(f,m){var b=m(),y=r({inst:{value:b,getSnapshot:m}}),v=y[0].inst,w=y[1];return i(function(){v.value=b,v.getSnapshot=m,u(v)&&w({inst:v})},[f,b,m]),a(function(){return u(v)&&w({inst:v}),f(function(){u(v)&&w({inst:v})})},[f]),o(b),b}function u(f){var m=f.getSnapshot;f=f.value;try{var b=m();return!n(f,b)}catch{return!0}}function d(f,m){return m()}var h=typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"?d:l;return ex.useSyncExternalStore=e.useSyncExternalStore!==void 0?e.useSyncExternalStore:h,ex}var P8;function USe(){return P8||(P8=1,Jv.exports=PSe()),Jv.exports}var jSe=USe();function HSe(){return jSe.useSyncExternalStore(GSe,()=>!0,()=>!1)}function GSe(){return()=>{}}var kC="Avatar",[qSe]=FSe(kC),[WSe,uj]=qSe(kC),dj=_.forwardRef((e,t)=>{const{__scopeAvatar:n,...r}=e,[a,i]=_.useState("idle");return T.jsx(WSe,{scope:n,imageLoadingStatus:a,onImageLoadingStatusChange:i,children:T.jsx(EC.span,{...r,ref:t})})});dj.displayName=kC;var hj="AvatarImage",VSe=_.forwardRef((e,t)=>{const{__scopeAvatar:n,src:r,onLoadingStatusChange:a=()=>{},...i}=e,o=uj(hj,n),l=YSe(r,i),u=lr(d=>{a(d),o.onImageLoadingStatusChange(d)});return ja(()=>{l!=="idle"&&u(l)},[l,u]),l==="loaded"?T.jsx(EC.img,{...i,ref:t,src:r}):null});VSe.displayName=hj;var pj="AvatarFallback",fj=_.forwardRef((e,t)=>{const{__scopeAvatar:n,delayMs:r,...a}=e,i=uj(pj,n),[o,l]=_.useState(r===void 0);return _.useEffect(()=>{if(r!==void 0){const u=window.setTimeout(()=>l(!0),r);return()=>window.clearTimeout(u)}},[r]),o&&i.imageLoadingStatus!=="loaded"?T.jsx(EC.span,{...a,ref:t}):null});fj.displayName=pj;function U8(e,t){return e?t?(e.src!==t&&(e.src=t),e.complete&&e.naturalWidth>0?"loaded":"loading"):"error":"idle"}function YSe(e,{referrerPolicy:t,crossOrigin:n}){const r=HSe(),a=_.useRef(null),i=r?(a.current||(a.current=new window.Image),a.current):null,[o,l]=_.useState(()=>U8(i,e));return ja(()=>{l(U8(i,e))},[i,e]),ja(()=>{const u=f=>()=>{l(f)};if(!i)return;const d=u("loaded"),h=u("error");return i.addEventListener("load",d),i.addEventListener("error",h),t&&(i.referrerPolicy=t),typeof n=="string"&&(i.crossOrigin=n),()=>{i.removeEventListener("load",d),i.removeEventListener("error",h)}},[i,n,t]),o}var XSe=dj,KSe=fj;function ZSe({className:e,...t}){return T.jsx(XSe,{className:st("relative flex h-10 w-10 shrink-0 overflow-hidden rounded-full",e),...t})}function QSe({className:e,...t}){return T.jsx(KSe,{className:st("flex h-full w-full items-center justify-center rounded-full bg-muted",e),...t})}const JSe={"Clear sky":"☀️","Mainly clear":"🌤️","Partly cloudy":"⛅",Overcast:"☁️",Foggy:"🌫️","Depositing rime fog":"🌫️","Light drizzle":"🌦️","Moderate drizzle":"🌦️","Dense drizzle":"🌧️","Slight rain":"🌧️","Moderate rain":"🌧️","Heavy rain":"🌧️","Light freezing rain":"🌨️","Heavy freezing rain":"🌨️","Slight snow fall":"🌨️","Moderate snow fall":"❄️","Heavy snow fall":"❄️","Snow grains":"❄️","Slight rain showers":"🌦️","Moderate rain showers":"🌧️","Violent rain showers":"⛈️","Slight snow showers":"🌨️","Heavy snow showers":"❄️",Thunderstorm:"⛈️","Thunderstorm with slight hail":"⛈️","Thunderstorm with heavy hail":"⛈️"};function mj(e){return JSe[e]??"🌡️"}function ewe({data:e}){return T.jsxs("div",{className:"my-2 w-full max-w-md rounded-xl border border-blue-200/50 bg-gradient-to-br from-blue-50 to-sky-50 p-4 shadow-sm dark:border-blue-800/50 dark:from-blue-950/30 dark:to-sky-950/30",children:[T.jsxs("div",{className:"mb-3 flex items-center gap-2 text-base font-semibold",children:[T.jsx(J2,{className:"h-4 w-4 text-blue-600 dark:text-blue-400"}),e.location]}),T.jsxs("div",{className:"mb-3 flex items-center gap-4",children:[T.jsx("span",{className:"text-4xl",children:mj(e.conditions)}),T.jsxs("div",{children:[T.jsx("div",{className:"text-3xl font-bold tracking-tight",children:e.temperature}),T.jsx("div",{className:"text-sm text-muted-foreground",children:e.conditions})]})]}),T.jsxs("div",{className:"mb-2 grid grid-cols-2 gap-2 text-sm",children:[T.jsxs("div",{className:"flex items-center gap-1.5 text-muted-foreground",children:[T.jsx(qV,{className:"h-3.5 w-3.5"}),T.jsxs("span",{children:["Feels like ",e.feelsLike]})]}),T.jsxs("div",{className:"flex items-center gap-1.5 text-muted-foreground",children:[T.jsx(yO,{className:"h-3.5 w-3.5"}),T.jsxs("span",{children:["Humidity ",e.humidity]})]}),T.jsxs("div",{className:"flex items-center gap-1.5 text-muted-foreground",children:[T.jsx(eY,{className:"h-3.5 w-3.5"}),T.jsx("span",{children:e.wind})]}),T.jsxs("div",{className:"flex items-center gap-1.5 text-muted-foreground",children:[T.jsx(gO,{className:"h-3.5 w-3.5"}),T.jsxs("span",{children:["Precip ",e.precipitation]})]})]}),T.jsx("div",{className:"text-xs text-muted-foreground/70",children:e.dataTime})]})}function twe({data:e}){return T.jsxs("div",{className:"my-2 w-full max-w-lg rounded-xl border border-indigo-200/50 bg-gradient-to-br from-indigo-50 to-purple-50 p-4 shadow-sm dark:border-indigo-800/50 dark:from-indigo-950/30 dark:to-purple-950/30",children:[T.jsxs("div",{className:"mb-3 flex items-center gap-2 text-base font-semibold",children:[T.jsx(mO,{className:"h-4 w-4 text-indigo-600 dark:text-indigo-400"}),e.location]}),T.jsx("div",{className:"space-y-1.5",children:e.days.map(t=>T.jsxs("div",{className:"flex items-center gap-3 rounded-md px-2 py-1.5 text-sm hover:bg-white/50 dark:hover:bg-white/5",children:[T.jsx("span",{className:"w-20 shrink-0 font-medium",children:rwe(t.date)}),T.jsx("span",{className:"w-6 text-center",children:mj(t.conditions)}),T.jsxs("span",{className:"w-24 shrink-0 text-muted-foreground",children:[t.tempMax," / ",t.tempMin]}),T.jsxs("span",{className:"flex items-center gap-1 text-muted-foreground",children:[T.jsx(yO,{className:"h-3 w-3"}),t.precipitationProbability]})]},t.date))}),T.jsxs("div",{className:"mt-2 text-xs text-muted-foreground/70",children:["Timezone: ",e.timezone]})]})}function nwe({data:e}){return T.jsx("div",{className:"my-2 w-full max-w-md rounded-xl border border-green-200/50 bg-gradient-to-br from-green-50 to-emerald-50 px-4 py-3 shadow-sm dark:border-green-800/50 dark:from-green-950/30 dark:to-emerald-950/30",children:T.jsxs("div",{className:"flex items-center gap-3",children:[T.jsx(J2,{className:"h-5 w-5 text-green-600 dark:text-green-400"}),T.jsxs("div",{children:[T.jsxs("div",{className:"font-medium",children:[e.name,", ",e.country]}),T.jsxs("div",{className:"text-xs text-muted-foreground",children:[e.region," (",e.coordinates.latitude.toFixed(4),", ",e.coordinates.longitude.toFixed(4),")"]})]})]})})}function rwe(e){return new Date(e).toLocaleDateString("en-US",{weekday:"short",month:"short",day:"numeric"})}const awe=new Set(["get_coords_by_city","get_current_weather_by_coords","get_weather_next_week"]);function iwe({toolCalls:e}){const t=_.useMemo(()=>e.filter(n=>awe.has(n.name)&&n.status==="completed"&&n.result),[e]);return t.length===0?null:T.jsx("div",{className:"flex flex-col gap-1",children:t.map(n=>T.jsx(owe,{toolCall:n},n.id))})}function owe({toolCall:e}){const t=_.useMemo(()=>{try{return JSON.parse(e.result??"")}catch{return null}},[e.result]);return!t||t.error?null:e.name==="get_coords_by_city"&&t.name?T.jsx(nwe,{data:t}):e.name==="get_current_weather_by_coords"&&t.temperature?T.jsx(ewe,{data:t}):e.name==="get_weather_next_week"&&t.days?T.jsx(twe,{data:t}):null}function swe({text:e}){const[t,n]=_.useState(!1),r=_.useCallback(async()=>{await navigator.clipboard.writeText(e),n(!0),setTimeout(()=>n(!1),2e3)},[e]);return T.jsx(kt,{variant:"ghost",size:"icon",className:"h-6 w-6 text-muted-foreground hover:text-foreground",onClick:r,"aria-label":"Copy message",children:t?T.jsx(rg,{className:"h-3 w-3"}):T.jsx(Q2,{className:"h-3 w-3"})})}function lwe({message:e,tts:t}){const n=t.playingMessageId===e.id&&t.ttsState==="playing",r=t.playingMessageId===e.id&&t.ttsState==="loading",[a,i]=_.useState(!1),o=_.useCallback(()=>{n?t.stop():t.play(e.content,e.id)},[n,t,e.content,e.id]);return T.jsx(kt,{variant:"ghost",size:"icon",className:"h-6 w-6 text-muted-foreground hover:text-foreground",onClick:o,onMouseEnter:()=>i(!0),onMouseLeave:()=>i(!1),"aria-label":n?"Stop playback":"Play message",children:r?T.jsx(fu,{className:"h-3 w-3 animate-spin"}):n&&a?T.jsx(rS,{className:"h-3 w-3"}):T.jsx(QV,{className:"h-3 w-3"})})}function cwe({message:e,messageIndex:t,tts:n}){const r=n.downloadingMessageId===e.id&&n.downloadState==="downloading",a=_.useCallback(()=>{n.download(e.content,e.id,`message-${t}.mp3`)},[n,e.content,e.id,t]);return T.jsx(kt,{variant:"ghost",size:"icon",className:"h-6 w-6 text-muted-foreground hover:text-foreground",onClick:a,disabled:r,"aria-label":"Download audio",children:r?T.jsx(fu,{className:"h-3 w-3 animate-spin"}):T.jsx(bO,{className:"h-3 w-3"})})}function uwe({message:e,messageIndex:t=0,compact:n,isLoading:r,tts:a,onEditUser:i,onEditAssistant:o,onRegenerateAssistant:l,onDelete:u,onBranch:d,onSaveAsTemplate:h,onMaskEdit:f}){var H,Z;const m=e.role==="user",b=e.content!=null&&e.content.trim().length>0,y=!m&&r&&!b,[v,w]=_.useState(!1),[S,k]=_.useState(""),[R,I]=_.useState(!1),L=_.useRef(null);_.useEffect(()=>{var V;v&&((V=L.current)==null||V.focus())},[v]);const A=_.useCallback(()=>{k(e.content),w(!0)},[e.content]),M=_.useCallback(()=>{const V=S.trim();if(!V||V===e.content){w(!1);return}m&&i?i(e.id,V):!m&&o&&o(e.id,V),w(!1)},[S,e.content,e.id,m,i,o]),P=_.useCallback(V=>{V.key==="Enter"&&!V.shiftKey&&(V.preventDefault(),M()),V.key==="Escape"&&w(!1)},[M]),G=_.useCallback(()=>{l==null||l(e.id)},[l,e.id]),B=()=>T.jsxs("div",{className:"flex flex-col gap-2",children:[T.jsx("textarea",{ref:L,value:S,onChange:V=>k(V.target.value),onKeyDown:P,className:"w-full resize-none rounded-lg border bg-background px-3 py-2 text-sm focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring",rows:3}),T.jsxs("div",{className:"flex gap-2",children:[T.jsx(kt,{size:"sm",onClick:M,children:"Submit"}),T.jsx(kt,{size:"sm",variant:"ghost",onClick:()=>w(!1),children:"Cancel"})]})]});return T.jsxs("div",{className:st("group/msg flex gap-3",n?"px-3 py-2":"px-4 py-2"),children:[T.jsx(ZSe,{className:st("mt-0.5 shrink-0",n?"h-6 w-6":"h-7 w-7"),children:T.jsx(QSe,{className:st(m?"bg-primary text-primary-foreground":"bg-muted"),children:m?T.jsx(KV,{className:st(n?"h-3 w-3":"h-3.5 w-3.5")}):T.jsx(jW,{className:st(n?"h-3 w-3":"h-3.5 w-3.5")})})}),T.jsxs("div",{className:st("min-w-0 flex-1 text-sm leading-relaxed"),children:[v?B():m?T.jsxs("div",{children:[e.images&&e.images.length>0&&T.jsx("div",{className:"mb-2 flex flex-wrap gap-2",children:e.images.map(V=>{const q=V.uri.includes("/generated_");return T.jsx("a",{href:V.uri,target:"_blank",rel:"noopener noreferrer",className:"block",children:T.jsx("img",{src:V.uri,alt:"Attached",className:q?"max-w-full rounded-lg border border-border/50 shadow-sm transition-shadow hover:shadow-md":"max-h-48 max-w-xs rounded-lg border object-contain"})},V.uri)})}),T.jsx("div",{className:"whitespace-pre-wrap",children:e.content})]}):T.jsxs(T.Fragment,{children:[e.reasoningBlocks&&e.reasoningBlocks.length>0&&T.jsx(cSe,{reasoningBlocks:e.reasoningBlocks}),T.jsx(hSe,{toolCalls:e.toolCalls,isWaiting:y}),e.toolCalls&&e.toolCalls.length>0&&T.jsx(iwe,{toolCalls:e.toolCalls}),e.toolCalls&&e.toolCalls.length>0&&T.jsx(bJ,{toolCalls:e.toolCalls,onMaskEdit:f}),e.content?T.jsx(TU,{content:e.content}):!y&&T.jsx("span",{className:"inline-block h-4 w-1 animate-pulse bg-current"})]}),!r&&!v&&e.content&&T.jsxs("div",{className:"mt-0.5 flex gap-0.5 opacity-0 transition-opacity group-hover/msg:opacity-100",children:[T.jsx(swe,{text:e.content}),a&&T.jsx(lwe,{message:e,tts:a}),a&&T.jsx(cwe,{message:e,messageIndex:t,tts:a}),(m?i:o)&&T.jsx(kt,{variant:"ghost",size:"icon",className:"h-6 w-6 text-muted-foreground hover:text-foreground",onClick:A,"aria-label":"Edit message",children:T.jsx(eS,{className:"h-3 w-3"})}),m&&h&&T.jsx(kt,{variant:"ghost",size:"icon",className:"h-6 w-6 text-muted-foreground hover:text-foreground",onClick:()=>h(e.content),"aria-label":"Save as template",children:T.jsx(vO,{className:"h-3 w-3"})}),!m&&l&&T.jsx(kt,{variant:"ghost",size:"icon",className:"h-6 w-6 text-muted-foreground hover:text-foreground",onClick:G,"aria-label":"Regenerate response",children:T.jsx(FV,{className:"h-3 w-3"})}),!m&&d&&T.jsx(kt,{variant:"ghost",size:"icon",className:"h-6 w-6 text-muted-foreground hover:text-foreground",onClick:d,"aria-label":"Branch in new chat",children:T.jsx(fV,{className:"h-3 w-3"})}),u&&T.jsx(kt,{variant:"ghost",size:"icon",className:"h-6 w-6 text-muted-foreground hover:text-destructive",onClick:()=>I(!0),"aria-label":"Delete message",children:T.jsx(aS,{className:"h-3 w-3"})}),!m&&e.usage&&T.jsxs("span",{className:"ml-1 text-[11px] tabular-nums text-muted-foreground/60",children:[((H=e.usage.input_token_count)==null?void 0:H.toLocaleString())??"?","in /"," ",((Z=e.usage.output_token_count)==null?void 0:Z.toLocaleString())??"?","out"]})]}),T.jsx(wC,{open:R,onOpenChange:I,children:T.jsxs(hb,{children:[T.jsxs(pb,{children:[T.jsx(mb,{children:"Delete this message?"}),T.jsx(gb,{children:"This action cannot be undone."})]}),T.jsxs(fb,{children:[T.jsx(yb,{children:"Cancel"}),T.jsx(bb,{className:"bg-destructive text-destructive-foreground hover:bg-destructive/90",onClick:()=>u==null?void 0:u(e.id),children:"Delete"})]})]})})]})]})}function j8(e){return e<1e3?String(e):`${Math.round(e/1e3)}K`}function dwe(e){return e>=95?"critical":e>=80?"warning":"normal"}const hwe={normal:"bg-muted-foreground/30",warning:"bg-amber-500",critical:"bg-red-500"},pwe={normal:"text-muted-foreground/60",warning:"text-amber-500",critical:"text-red-500"};function H8({usage:e,maxContextTokens:t}){const n=(e==null?void 0:e.max_context_tokens)??t;if(!n||n<=0)return null;const r=(e==null?void 0:e.input_token_count)??0,a=(e==null?void 0:e.output_token_count)??0,i=r+a,o=Math.min(i/n*100,100),l=dwe(o);return T.jsxs("div",{className:"flex items-center gap-2 px-1 py-0.5",children:[T.jsx("div",{className:"h-1.5 w-24 overflow-hidden rounded-full bg-muted",children:T.jsx("div",{className:st("h-full rounded-full transition-all",hwe[l]),style:{width:`${o}%`}})}),T.jsxs("span",{className:st("text-[11px] tabular-nums whitespace-nowrap",pwe[l]),children:[Math.round(o),"% (",j8(i)," / ",j8(n),")"]})]})}const vb=HU,fwe=GU,gj=_.forwardRef(({className:e,...t},n)=>T.jsx(bC,{ref:n,className:st("fixed inset-0 z-50 bg-black/80 data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0",e),...t}));gj.displayName=bC.displayName;const Ep=_.forwardRef(({className:e,children:t,...n},r)=>T.jsxs(fwe,{children:[T.jsx(gj,{}),T.jsxs(yC,{ref:r,className:st("fixed left-[50%] top-[50%] z-50 grid w-full max-w-lg translate-x-[-50%] translate-y-[-50%] gap-4 border bg-background p-6 shadow-lg duration-200 data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 data-[state=closed]:slide-out-to-left-1/2 data-[state=closed]:slide-out-to-top-[48%] data-[state=open]:slide-in-from-left-1/2 data-[state=open]:slide-in-from-top-[48%] sm:rounded-lg",e),...n,children:[t,T.jsxs(SC,{className:"absolute right-4 top-4 rounded-sm opacity-70 ring-offset-background transition-opacity hover:opacity-100 focus:outline-none focus:ring-2 focus:ring-ring focus:ring-offset-2 disabled:pointer-events-none data-[state=open]:bg-accent data-[state=open]:text-muted-foreground",children:[T.jsx(gl,{className:"h-4 w-4"}),T.jsx("span",{className:"sr-only",children:"Close"})]})]})]}));Ep.displayName=yC.displayName;function kp({className:e,...t}){return T.jsx("div",{className:st("flex flex-col space-y-1.5 text-center sm:text-left",e),...t})}kp.displayName="DialogHeader";function TC({className:e,...t}){return T.jsx("div",{className:st("flex flex-col-reverse sm:flex-row sm:justify-end sm:space-x-2",e),...t})}TC.displayName="DialogFooter";const Tp=_.forwardRef(({className:e,...t},n)=>T.jsx(vC,{ref:n,className:st("text-lg font-semibold leading-none tracking-tight",e),...t}));Tp.displayName=vC.displayName;const bj=_.forwardRef(({className:e,...t},n)=>T.jsx(xC,{ref:n,className:st("text-sm text-muted-foreground",e),...t}));bj.displayName=xC.displayName;const Ri=_.forwardRef(({className:e,type:t,...n},r)=>T.jsx("input",{type:t,className:st("flex h-9 w-full rounded-md border border-input bg-transparent px-3 py-1 text-sm shadow-sm transition-colors file:border-0 file:bg-transparent file:text-sm file:font-medium file:text-foreground placeholder:text-muted-foreground focus-visible:outline-none focus-visible:ring-1 focus-visible:ring-ring disabled:cursor-not-allowed disabled:opacity-50",e),ref:r,...n}));Ri.displayName="Input";const mwe="rgba(59, 130, 246, 0.4)",gwe="white",bwe=30;function ywe(){const e=_.useRef(null),t=_.useRef(null),[n,r]=_.useState(25),[a,i]=_.useState("brush"),[o,l]=_.useState(!1),[u,d]=_.useState(!1),h=_.useRef([]),f=_.useRef(-1),m=_.useRef(null),b=_.useCallback(()=>{const G=t.current;if(!G)return;const B=G.getContext("2d");if(!B)return;const H=B.getImageData(0,0,G.width,G.height),Z=f.current+1;h.current=h.current.slice(0,Z),h.current.push(H),h.current.length>bwe?h.current.shift():f.current=Z},[]),y=_.useCallback(G=>{const B=new Image;B.crossOrigin="anonymous",B.onload=()=>{const H=e.current,Z=t.current;if(!H||!Z)return;H.width=B.naturalWidth,H.height=B.naturalHeight,Z.width=B.naturalWidth,Z.height=B.naturalHeight;const V=H.getContext("2d");V==null||V.drawImage(B,0,0);const q=Z.getContext("2d");q==null||q.clearRect(0,0,Z.width,Z.height);const X=document.createElement("canvas");X.width=B.naturalWidth,X.height=B.naturalHeight;const $=X.getContext("2d");$&&($.fillStyle="black",$.fillRect(0,0,X.width,X.height)),m.current=X,h.current=[],f.current=-1,b(),d(!0)},B.src=G},[b]),v=_.useCallback(G=>{const B=t.current;if(!B)return null;const H=B.getBoundingClientRect(),Z=B.width/H.width,V=B.height/H.height;return{x:(G.clientX-H.left)*Z,y:(G.clientY-H.top)*V}},[]),w=_.useCallback((G,B)=>{const H=t.current,Z=m.current;if(!H||!Z)return;const V=H.getContext("2d"),q=Z.getContext("2d");!V||!q||(a==="eraser"?(V.globalCompositeOperation="destination-out",q.globalCompositeOperation="destination-out"):(V.globalCompositeOperation="source-over",q.globalCompositeOperation="source-over"),V.beginPath(),V.arc(G,B,n,0,Math.PI*2),V.fillStyle=a==="eraser"?"rgba(0,0,0,1)":mwe,V.fill(),q.beginPath(),q.arc(G,B,n,0,Math.PI*2),q.fillStyle=a==="eraser"?"rgba(0,0,0,1)":gwe,q.fill())},[n,a]),S=_.useCallback(G=>{const B=v(G);B&&(l(!0),w(B.x,B.y),G.target.setPointerCapture(G.pointerId))},[v,w]),k=_.useCallback(G=>{if(!o)return;const B=v(G);B&&w(B.x,B.y)},[o,v,w]),R=_.useCallback(()=>{if(!o)return;l(!1),b();const G=t.current,B=m.current;if(G&&B){const H=B.getContext("2d");if(H){H.globalCompositeOperation="source-over",H.fillStyle="black",H.fillRect(0,0,B.width,B.height),H.globalCompositeOperation="destination-over";const Z=G.getContext("2d");if(Z){const V=Z.getImageData(0,0,G.width,G.height);H.globalCompositeOperation="source-over",H.fillStyle="black",H.fillRect(0,0,B.width,B.height);for(let q=3;q<V.data.length;q+=4)V.data[q]>10?(V.data[q-3]=255,V.data[q-2]=255,V.data[q-1]=255,V.data[q]=255):(V.data[q-3]=0,V.data[q-2]=0,V.data[q-1]=0,V.data[q]=255);H.putImageData(V,0,0)}}}},[o,b]),I=_.useCallback(()=>{if(f.current<=0)return;f.current--;const G=t.current;if(!G)return;const B=G.getContext("2d");B&&B.putImageData(h.current[f.current],0,0)},[]),L=_.useCallback(()=>{if(f.current>=h.current.length-1)return;f.current++;const G=t.current;if(!G)return;const B=G.getContext("2d");B&&B.putImageData(h.current[f.current],0,0)},[]),A=_.useCallback(()=>{const G=t.current;if(!G)return;const B=G.getContext("2d");B&&(B.clearRect(0,0,G.width,G.height),b())},[b]),M=_.useCallback(async()=>{const G=e.current,B=t.current;if(!G||!B)throw new Error("Canvas not ready");const H=document.createElement("canvas");H.width=G.width,H.height=G.height;const Z=H.getContext("2d");if(!Z)throw new Error("Cannot create export context");Z.drawImage(G,0,0);const V=Z.getImageData(0,0,H.width,H.height),q=B.getContext("2d");if(!q)throw new Error("Cannot read mask");const X=q.getImageData(0,0,B.width,B.height);for(let $=0;$<X.data.length;$+=4)X.data[$+3]>10&&(V.data[$+3]=0);return Z.putImageData(V,0,0),new Promise(($,Q)=>{H.toBlob(J=>{J?$(J):Q(new Error("Failed to export composited image"))},"image/png")})},[]),P=_.useCallback(async()=>{const G=e.current,B=t.current;if(!G||!B)throw new Error("Canvas not ready");const H=document.createElement("canvas");H.width=G.width,H.height=G.height;const Z=H.getContext("2d");if(!Z)throw new Error("Cannot create preview context");return Z.drawImage(G,0,0),Z.drawImage(B,0,0),new Promise((V,q)=>{H.toBlob(X=>{X?V(X):q(new Error("Failed to export preview"))},"image/png")})},[]);return{imageCanvasRef:e,maskCanvasRef:t,brushSize:n,setBrushSize:r,tool:a,setTool:i,canvasReady:u,initCanvas:y,handlePointerDown:S,handlePointerMove:k,handlePointerUp:R,undo:I,redo:L,clear:A,exportCompositedImage:M,exportPreview:P}}function vwe({open:e,onOpenChange:t,imageUrl:n,onGenerate:r}){const{imageCanvasRef:a,maskCanvasRef:i,brushSize:o,setBrushSize:l,tool:u,setTool:d,canvasReady:h,initCanvas:f,handlePointerDown:m,handlePointerMove:b,handlePointerUp:y,undo:v,redo:w,clear:S,exportCompositedImage:k,exportPreview:R}=ywe(),[I,L]=_.useState("");_.useEffect(()=>{if(e&&n){L("");const P=setTimeout(()=>f(n),100);return()=>clearTimeout(P)}},[e,n,f]);const A=_.useCallback(async()=>{if(I.trim())try{const P=await k(),G=await R();t(!1),r(P,G,I.trim())}catch{}},[I,k,R,t,r]),M=[{size:10,label:"S"},{size:25,label:"M"},{size:50,label:"L"}];return T.jsx(vb,{open:e,onOpenChange:t,children:T.jsxs(Ep,{className:"flex max-h-[90vh] max-w-4xl flex-col",children:[T.jsxs(kp,{children:[T.jsx(Tp,{children:"Edit Image with Mask"}),T.jsx(bj,{children:"Paint over the areas you want to change, then describe the edit."})]}),T.jsx("div",{className:"relative mx-auto w-full overflow-auto rounded-lg border bg-muted/30",style:{maxHeight:"50vh"},children:T.jsxs("div",{className:"relative inline-block",children:[T.jsx("canvas",{ref:a,className:"block max-w-full",style:{maxHeight:"48vh"}}),T.jsx("canvas",{ref:i,className:"absolute inset-0 block max-w-full",style:{maxHeight:"48vh",cursor:"crosshair",touchAction:"none"},onPointerDown:m,onPointerMove:b,onPointerUp:y,onPointerLeave:y})]})}),T.jsxs("div",{className:"flex flex-wrap items-center gap-2",children:[T.jsx("span",{className:"mr-1 text-xs text-muted-foreground",children:"Brush:"}),M.map(P=>T.jsx(kt,{variant:u==="brush"&&o===P.size?"default":"outline",size:"sm",className:"h-7 w-7 p-0 text-xs",onClick:()=>{d("brush"),l(P.size)},children:P.label},P.size)),T.jsxs(kt,{variant:u==="eraser"?"default":"outline",size:"sm",className:"h-7 gap-1 px-2 text-xs",onClick:()=>d("eraser"),children:[T.jsx(iV,{className:"h-3 w-3"}),"Eraser"]}),T.jsx("div",{className:"mx-1 h-4 w-px bg-border"}),T.jsx(kt,{variant:"outline",size:"sm",className:"h-7 w-7 p-0",onClick:v,"aria-label":"Undo",children:T.jsx(YV,{className:"h-3 w-3"})}),T.jsx(kt,{variant:"outline",size:"sm",className:"h-7 w-7 p-0",onClick:w,"aria-label":"Redo",children:T.jsx(MV,{className:"h-3 w-3"})}),T.jsxs(kt,{variant:"outline",size:"sm",className:"h-7 gap-1 px-2 text-xs",onClick:S,children:[T.jsx(aS,{className:"h-3 w-3"}),"Clear"]})]}),T.jsx(Ri,{placeholder:"Describe what to put in the masked area...",value:I,onChange:P=>L(P.target.value),onKeyDown:P=>{P.key==="Enter"&&!P.shiftKey&&(P.preventDefault(),A())}}),T.jsxs(TC,{children:[T.jsx(kt,{variant:"ghost",onClick:()=>t(!1),children:"Cancel"}),T.jsxs(kt,{onClick:A,disabled:!h||!I.trim(),children:[T.jsx(wO,{className:"mr-2 h-4 w-4"}),"Generate"]})]})]})})}function xwe(e,[t,n]){return Math.min(n,Math.max(t,e))}function Swe(e,t){return _.useReducer((n,r)=>t[n][r]??n,e)}var _C="ScrollArea",[yj]=Os(_C),[wwe,Va]=yj(_C),vj=_.forwardRef((e,t)=>{const{__scopeScrollArea:n,type:r="hover",dir:a,scrollHideDelay:i=600,...o}=e,[l,u]=_.useState(null),[d,h]=_.useState(null),[f,m]=_.useState(null),[b,y]=_.useState(null),[v,w]=_.useState(null),[S,k]=_.useState(0),[R,I]=_.useState(0),[L,A]=_.useState(!1),[M,P]=_.useState(!1),G=un(t,H=>u(H)),B=cS(a);return T.jsx(wwe,{scope:n,type:r,dir:B,scrollHideDelay:i,scrollArea:l,viewport:d,onViewportChange:h,content:f,onContentChange:m,scrollbarX:b,onScrollbarXChange:y,scrollbarXEnabled:L,onScrollbarXEnabledChange:A,scrollbarY:v,onScrollbarYChange:w,scrollbarYEnabled:M,onScrollbarYEnabledChange:P,onCornerWidthChange:k,onCornerHeightChange:I,children:T.jsx(dn.div,{dir:B,...o,ref:G,style:{position:"relative","--radix-scroll-area-corner-width":S+"px","--radix-scroll-area-corner-height":R+"px",...e.style}})})});vj.displayName=_C;var xj="ScrollAreaViewport",Sj=_.forwardRef((e,t)=>{const{__scopeScrollArea:n,children:r,nonce:a,...i}=e,o=Va(xj,n),l=_.useRef(null),u=un(t,l,o.onViewportChange);return T.jsxs(T.Fragment,{children:[T.jsx("style",{dangerouslySetInnerHTML:{__html:"[data-radix-scroll-area-viewport]{scrollbar-width:none;-ms-overflow-style:none;-webkit-overflow-scrolling:touch;}[data-radix-scroll-area-viewport]::-webkit-scrollbar{display:none}"},nonce:a}),T.jsx(dn.div,{"data-radix-scroll-area-viewport":"",...i,ref:u,style:{overflowX:o.scrollbarXEnabled?"scroll":"hidden",overflowY:o.scrollbarYEnabled?"scroll":"hidden",...e.style},children:T.jsx("div",{ref:o.onContentChange,style:{minWidth:"100%",display:"table"},children:r})})]})});Sj.displayName=xj;var ji="ScrollAreaScrollbar",wj=_.forwardRef((e,t)=>{const{forceMount:n,...r}=e,a=Va(ji,e.__scopeScrollArea),{onScrollbarXEnabledChange:i,onScrollbarYEnabledChange:o}=a,l=e.orientation==="horizontal";return _.useEffect(()=>(l?i(!0):o(!0),()=>{l?i(!1):o(!1)}),[l,i,o]),a.type==="hover"?T.jsx(Ewe,{...r,ref:t,forceMount:n}):a.type==="scroll"?T.jsx(kwe,{...r,ref:t,forceMount:n}):a.type==="auto"?T.jsx(Ej,{...r,ref:t,forceMount:n}):a.type==="always"?T.jsx(CC,{...r,ref:t}):null});wj.displayName=ji;var Ewe=_.forwardRef((e,t)=>{const{forceMount:n,...r}=e,a=Va(ji,e.__scopeScrollArea),[i,o]=_.useState(!1);return _.useEffect(()=>{const l=a.scrollArea;let u=0;if(l){const d=()=>{window.clearTimeout(u),o(!0)},h=()=>{u=window.setTimeout(()=>o(!1),a.scrollHideDelay)};return l.addEventListener("pointerenter",d),l.addEventListener("pointerleave",h),()=>{window.clearTimeout(u),l.removeEventListener("pointerenter",d),l.removeEventListener("pointerleave",h)}}},[a.scrollArea,a.scrollHideDelay]),T.jsx(Wa,{present:n||i,children:T.jsx(Ej,{"data-state":i?"visible":"hidden",...r,ref:t})})}),kwe=_.forwardRef((e,t)=>{const{forceMount:n,...r}=e,a=Va(ji,e.__scopeScrollArea),i=e.orientation==="horizontal",o=Sb(()=>u("SCROLL_END"),100),[l,u]=Swe("hidden",{hidden:{SCROLL:"scrolling"},scrolling:{SCROLL_END:"idle",POINTER_ENTER:"interacting"},interacting:{SCROLL:"interacting",POINTER_LEAVE:"idle"},idle:{HIDE:"hidden",SCROLL:"scrolling",POINTER_ENTER:"interacting"}});return _.useEffect(()=>{if(l==="idle"){const d=window.setTimeout(()=>u("HIDE"),a.scrollHideDelay);return()=>window.clearTimeout(d)}},[l,a.scrollHideDelay,u]),_.useEffect(()=>{const d=a.viewport,h=i?"scrollLeft":"scrollTop";if(d){let f=d[h];const m=()=>{const b=d[h];f!==b&&(u("SCROLL"),o()),f=b};return d.addEventListener("scroll",m),()=>d.removeEventListener("scroll",m)}},[a.viewport,i,u,o]),T.jsx(Wa,{present:n||l!=="hidden",children:T.jsx(CC,{"data-state":l==="hidden"?"hidden":"visible",...r,ref:t,onPointerEnter:ft(e.onPointerEnter,()=>u("POINTER_ENTER")),onPointerLeave:ft(e.onPointerLeave,()=>u("POINTER_LEAVE"))})})}),Ej=_.forwardRef((e,t)=>{const n=Va(ji,e.__scopeScrollArea),{forceMount:r,...a}=e,[i,o]=_.useState(!1),l=e.orientation==="horizontal",u=Sb(()=>{if(n.viewport){const d=n.viewport.offsetWidth<n.viewport.scrollWidth,h=n.viewport.offsetHeight<n.viewport.scrollHeight;o(l?d:h)}},10);return uu(n.viewport,u),uu(n.content,u),T.jsx(Wa,{present:r||i,children:T.jsx(CC,{"data-state":i?"visible":"hidden",...a,ref:t})})}),CC=_.forwardRef((e,t)=>{const{orientation:n="vertical",...r}=e,a=Va(ji,e.__scopeScrollArea),i=_.useRef(null),o=_.useRef(0),[l,u]=_.useState({content:0,viewport:0,scrollbar:{size:0,paddingStart:0,paddingEnd:0}}),d=Aj(l.viewport,l.content),h={...r,sizes:l,onSizesChange:u,hasThumb:d>0&&d<1,onThumbChange:m=>i.current=m,onThumbPointerUp:()=>o.current=0,onThumbPointerDown:m=>o.current=m};function f(m,b){return Nwe(m,o.current,l,b)}return n==="horizontal"?T.jsx(Twe,{...h,ref:t,onThumbPositionChange:()=>{if(a.viewport&&i.current){const m=a.viewport.scrollLeft,b=G8(m,l,a.dir);i.current.style.transform=`translate3d(${b}px, 0, 0)`}},onWheelScroll:m=>{a.viewport&&(a.viewport.scrollLeft=m)},onDragScroll:m=>{a.viewport&&(a.viewport.scrollLeft=f(m,a.dir))}}):n==="vertical"?T.jsx(_we,{...h,ref:t,onThumbPositionChange:()=>{if(a.viewport&&i.current){const m=a.viewport.scrollTop,b=G8(m,l);i.current.style.transform=`translate3d(0, ${b}px, 0)`}},onWheelScroll:m=>{a.viewport&&(a.viewport.scrollTop=m)},onDragScroll:m=>{a.viewport&&(a.viewport.scrollTop=f(m))}}):null}),Twe=_.forwardRef((e,t)=>{const{sizes:n,onSizesChange:r,...a}=e,i=Va(ji,e.__scopeScrollArea),[o,l]=_.useState(),u=_.useRef(null),d=un(t,u,i.onScrollbarXChange);return _.useEffect(()=>{u.current&&l(getComputedStyle(u.current))},[u]),T.jsx(Tj,{"data-orientation":"horizontal",...a,ref:d,sizes:n,style:{bottom:0,left:i.dir==="rtl"?"var(--radix-scroll-area-corner-width)":0,right:i.dir==="ltr"?"var(--radix-scroll-area-corner-width)":0,"--radix-scroll-area-thumb-width":xb(n)+"px",...e.style},onThumbPointerDown:h=>e.onThumbPointerDown(h.x),onDragScroll:h=>e.onDragScroll(h.x),onWheelScroll:(h,f)=>{if(i.viewport){const m=i.viewport.scrollLeft+h.deltaX;e.onWheelScroll(m),Nj(m,f)&&h.preventDefault()}},onResize:()=>{u.current&&i.viewport&&o&&r({content:i.viewport.scrollWidth,viewport:i.viewport.offsetWidth,scrollbar:{size:u.current.clientWidth,paddingStart:Qm(o.paddingLeft),paddingEnd:Qm(o.paddingRight)}})}})}),_we=_.forwardRef((e,t)=>{const{sizes:n,onSizesChange:r,...a}=e,i=Va(ji,e.__scopeScrollArea),[o,l]=_.useState(),u=_.useRef(null),d=un(t,u,i.onScrollbarYChange);return _.useEffect(()=>{u.current&&l(getComputedStyle(u.current))},[u]),T.jsx(Tj,{"data-orientation":"vertical",...a,ref:d,sizes:n,style:{top:0,right:i.dir==="ltr"?0:void 0,left:i.dir==="rtl"?0:void 0,bottom:"var(--radix-scroll-area-corner-height)","--radix-scroll-area-thumb-height":xb(n)+"px",...e.style},onThumbPointerDown:h=>e.onThumbPointerDown(h.y),onDragScroll:h=>e.onDragScroll(h.y),onWheelScroll:(h,f)=>{if(i.viewport){const m=i.viewport.scrollTop+h.deltaY;e.onWheelScroll(m),Nj(m,f)&&h.preventDefault()}},onResize:()=>{u.current&&i.viewport&&o&&r({content:i.viewport.scrollHeight,viewport:i.viewport.offsetHeight,scrollbar:{size:u.current.clientHeight,paddingStart:Qm(o.paddingTop),paddingEnd:Qm(o.paddingBottom)}})}})}),[Cwe,kj]=yj(ji),Tj=_.forwardRef((e,t)=>{const{__scopeScrollArea:n,sizes:r,hasThumb:a,onThumbChange:i,onThumbPointerUp:o,onThumbPointerDown:l,onThumbPositionChange:u,onDragScroll:d,onWheelScroll:h,onResize:f,...m}=e,b=Va(ji,n),[y,v]=_.useState(null),w=un(t,G=>v(G)),S=_.useRef(null),k=_.useRef(""),R=b.viewport,I=r.content-r.viewport,L=lr(h),A=lr(u),M=Sb(f,10);function P(G){if(S.current){const B=G.clientX-S.current.left,H=G.clientY-S.current.top;d({x:B,y:H})}}return _.useEffect(()=>{const G=B=>{const H=B.target;(y==null?void 0:y.contains(H))&&L(B,I)};return document.addEventListener("wheel",G,{passive:!1}),()=>document.removeEventListener("wheel",G,{passive:!1})},[R,y,I,L]),_.useEffect(A,[r,A]),uu(y,M),uu(b.content,M),T.jsx(Cwe,{scope:n,scrollbar:y,hasThumb:a,onThumbChange:lr(i),onThumbPointerUp:lr(o),onThumbPositionChange:A,onThumbPointerDown:lr(l),children:T.jsx(dn.div,{...m,ref:w,style:{position:"absolute",...m.style},onPointerDown:ft(e.onPointerDown,G=>{G.button===0&&(G.target.setPointerCapture(G.pointerId),S.current=y.getBoundingClientRect(),k.current=document.body.style.webkitUserSelect,document.body.style.webkitUserSelect="none",b.viewport&&(b.viewport.style.scrollBehavior="auto"),P(G))}),onPointerMove:ft(e.onPointerMove,P),onPointerUp:ft(e.onPointerUp,G=>{const B=G.target;B.hasPointerCapture(G.pointerId)&&B.releasePointerCapture(G.pointerId),document.body.style.webkitUserSelect=k.current,b.viewport&&(b.viewport.style.scrollBehavior=""),S.current=null})})})}),Zm="ScrollAreaThumb",_j=_.forwardRef((e,t)=>{const{forceMount:n,...r}=e,a=kj(Zm,e.__scopeScrollArea);return T.jsx(Wa,{present:n||a.hasThumb,children:T.jsx(Awe,{ref:t,...r})})}),Awe=_.forwardRef((e,t)=>{const{__scopeScrollArea:n,style:r,...a}=e,i=Va(Zm,n),o=kj(Zm,n),{onThumbPositionChange:l}=o,u=un(t,f=>o.onThumbChange(f)),d=_.useRef(void 0),h=Sb(()=>{d.current&&(d.current(),d.current=void 0)},100);return _.useEffect(()=>{const f=i.viewport;if(f){const m=()=>{if(h(),!d.current){const b=Owe(f,l);d.current=b,l()}};return l(),f.addEventListener("scroll",m),()=>f.removeEventListener("scroll",m)}},[i.viewport,h,l]),T.jsx(dn.div,{"data-state":o.hasThumb?"visible":"hidden",...a,ref:u,style:{width:"var(--radix-scroll-area-thumb-width)",height:"var(--radix-scroll-area-thumb-height)",...r},onPointerDownCapture:ft(e.onPointerDownCapture,f=>{const b=f.target.getBoundingClientRect(),y=f.clientX-b.left,v=f.clientY-b.top;o.onThumbPointerDown({x:y,y:v})}),onPointerUp:ft(e.onPointerUp,o.onThumbPointerUp)})});_j.displayName=Zm;var AC="ScrollAreaCorner",Cj=_.forwardRef((e,t)=>{const n=Va(AC,e.__scopeScrollArea),r=!!(n.scrollbarX&&n.scrollbarY);return n.type!=="scroll"&&r?T.jsx(Rwe,{...e,ref:t}):null});Cj.displayName=AC;var Rwe=_.forwardRef((e,t)=>{const{__scopeScrollArea:n,...r}=e,a=Va(AC,n),[i,o]=_.useState(0),[l,u]=_.useState(0),d=!!(i&&l);return uu(a.scrollbarX,()=>{var f;const h=((f=a.scrollbarX)==null?void 0:f.offsetHeight)||0;a.onCornerHeightChange(h),u(h)}),uu(a.scrollbarY,()=>{var f;const h=((f=a.scrollbarY)==null?void 0:f.offsetWidth)||0;a.onCornerWidthChange(h),o(h)}),d?T.jsx(dn.div,{...r,ref:t,style:{width:i,height:l,position:"absolute",right:a.dir==="ltr"?0:void 0,left:a.dir==="rtl"?0:void 0,bottom:0,...e.style}}):null});function Qm(e){return e?parseInt(e,10):0}function Aj(e,t){const n=e/t;return isNaN(n)?0:n}function xb(e){const t=Aj(e.viewport,e.content),n=e.scrollbar.paddingStart+e.scrollbar.paddingEnd,r=(e.scrollbar.size-n)*t;return Math.max(r,18)}function Nwe(e,t,n,r="ltr"){const a=xb(n),i=a/2,o=t||i,l=a-o,u=n.scrollbar.paddingStart+o,d=n.scrollbar.size-n.scrollbar.paddingEnd-l,h=n.content-n.viewport,f=r==="ltr"?[0,h]:[h*-1,0];return Rj([u,d],f)(e)}function G8(e,t,n="ltr"){const r=xb(t),a=t.scrollbar.paddingStart+t.scrollbar.paddingEnd,i=t.scrollbar.size-a,o=t.content-t.viewport,l=i-r,u=n==="ltr"?[0,o]:[o*-1,0],d=xwe(e,u);return Rj([0,o],[0,l])(d)}function Rj(e,t){return n=>{if(e[0]===e[1]||t[0]===t[1])return t[0];const r=(t[1]-t[0])/(e[1]-e[0]);return t[0]+r*(n-e[0])}}function Nj(e,t){return e>0&&e<t}var Owe=(e,t=()=>{})=>{let n={left:e.scrollLeft,top:e.scrollTop},r=0;return(function a(){const i={left:e.scrollLeft,top:e.scrollTop},o=n.left!==i.left,l=n.top!==i.top;(o||l)&&t(),n=i,r=window.requestAnimationFrame(a)})(),()=>window.cancelAnimationFrame(r)};function Sb(e,t){const n=lr(e),r=_.useRef(0);return _.useEffect(()=>()=>window.clearTimeout(r.current),[]),_.useCallback(()=>{window.clearTimeout(r.current),r.current=window.setTimeout(n,t)},[n,t])}function uu(e,t){const n=lr(t);ja(()=>{let r=0;if(e){const a=new ResizeObserver(()=>{cancelAnimationFrame(r),r=window.requestAnimationFrame(n)});return a.observe(e),()=>{window.cancelAnimationFrame(r),a.unobserve(e)}}},[e,n])}var Iwe=vj,Lwe=Sj,Dwe=Cj;function Oj({className:e,children:t,...n}){return T.jsxs(Iwe,{className:st("relative overflow-hidden",e),...n,children:[T.jsx(Lwe,{className:"h-full w-full rounded-[inherit]",children:t}),T.jsx(Mwe,{}),T.jsx(Dwe,{})]})}function Mwe({className:e,orientation:t="vertical",...n}){return T.jsx(wj,{orientation:t,className:st("flex touch-none select-none transition-colors",t==="vertical"&&"h-full w-2.5 border-l border-l-transparent p-[1px]",t==="horizontal"&&"h-2.5 flex-col border-t border-t-transparent p-[1px]",e),...n,children:T.jsx(_j,{className:"relative flex-1 rounded-full bg-border"})})}function Bwe({template:e,isNew:t,onSave:n,onDelete:r,onInsert:a}){const[i,o]=_.useState(""),[l,u]=_.useState(""),[d,h]=_.useState(""),[f,m]=_.useState(""),[b,y]=_.useState(!1),[v,w]=_.useState({});_.useEffect(()=>{t?(o(""),u(""),h(""),m(""),w({})):e&&(o(e.name),u(e.description),h(e.category),m(e.body),w({}))},[e,t]);const S=_.useMemo(()=>t?!0:e?i!==e.name||l!==e.description||d!==e.category||f!==e.body:!1,[t,e,i,l,d,f]),k=_.useCallback(()=>{const I={};return i.trim()||(I.name="Name is required"),f.trim()||(I.body="Body is required"),w(I),Object.keys(I).length===0},[i,f]),R=_.useCallback(async()=>{k()&&await n({name:i.trim(),body:f.trim(),description:l.trim(),category:d.trim()})},[k,n,i,f,l,d]);return!t&&!e?T.jsx("div",{className:"flex h-full items-center justify-center text-sm text-muted-foreground",children:"Select a template or click + New"}):T.jsxs(Oj,{className:"h-full",children:[T.jsxs("div",{className:"flex flex-col gap-4 p-6",children:[T.jsxs("div",{className:"flex flex-col gap-1.5",children:[T.jsxs("label",{htmlFor:"tpl-name",className:"text-sm font-medium",children:["Name ",T.jsx("span",{className:"text-destructive",children:"*"})]}),T.jsx(Ri,{id:"tpl-name",value:i,onChange:I=>o(I.target.value),maxLength:100}),v.name&&T.jsx("p",{className:"text-xs text-destructive",children:v.name})]}),T.jsxs("div",{className:"flex flex-col gap-1.5",children:[T.jsx("label",{htmlFor:"tpl-category",className:"text-sm font-medium",children:"Category"}),T.jsx(Ri,{id:"tpl-category",value:d,onChange:I=>h(I.target.value),maxLength:50})]}),T.jsxs("div",{className:"flex flex-col gap-1.5",children:[T.jsx("label",{htmlFor:"tpl-desc",className:"text-sm font-medium",children:"Description"}),T.jsx(Ri,{id:"tpl-desc",value:l,onChange:I=>u(I.target.value),maxLength:500})]}),T.jsxs("div",{className:"flex flex-col gap-1.5",children:[T.jsxs("label",{htmlFor:"tpl-body",className:"text-sm font-medium",children:["Body ",T.jsx("span",{className:"text-destructive",children:"*"})]}),T.jsx("textarea",{id:"tpl-body",value:f,onChange:I=>m(I.target.value),rows:8,className:"min-h-[200px] w-full resize-y rounded-md border bg-background px-3 py-2 text-sm focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring"}),v.body&&T.jsx("p",{className:"text-xs text-destructive",children:v.body})]}),T.jsxs("div",{className:"flex gap-2",children:[T.jsx(kt,{onClick:R,children:"Save"}),!t&&e&&T.jsxs(T.Fragment,{children:[T.jsx(kt,{variant:"destructive",onClick:()=>y(!0),children:"Delete"}),T.jsx(kt,{variant:"outline",disabled:S,onClick:()=>a(e),children:"Insert to Chat"})]})]})]}),T.jsx(wC,{open:b,onOpenChange:y,children:T.jsxs(hb,{children:[T.jsxs(pb,{children:[T.jsx(mb,{children:"Delete this template?"}),T.jsx(gb,{children:"This action cannot be undone."})]}),T.jsxs(fb,{children:[T.jsx(yb,{children:"Cancel"}),T.jsx(bb,{className:"bg-destructive text-destructive-foreground hover:bg-destructive/90",onClick:()=>{r(),y(!1)},children:"Delete"})]})]})})]})}function Fwe(e){if(!e)return"";const t=new Date(e),n=r=>String(r).padStart(2,"0");return`${t.getFullYear()}-${n(t.getMonth()+1)}-${n(t.getDate())} ${n(t.getHours())}:${n(t.getMinutes())}:${n(t.getSeconds())}`}function zwe(e,t=35){let n=0;for(let r=0;r<e.length;r++)if(n+=e.charCodeAt(r)>127?2:1,n>t)return`${e.slice(0,r)}...`;return e}function $we({templates:e,selectedId:t,searchQuery:n,onSelect:r}){const a=_.useMemo(()=>{if(!n.trim())return e;const i=n.toLowerCase();return e.filter(o=>o.name.toLowerCase().includes(i)||o.description.toLowerCase().includes(i)||o.category.toLowerCase().includes(i)||o.body.toLowerCase().includes(i))},[e,n]);return e.length===0?T.jsxs("div",{className:"flex h-full items-center justify-center p-4 text-center text-sm text-muted-foreground",children:["No templates yet.",T.jsx("br",{}),"Click + New to create one."]}):a.length===0?T.jsx("div",{className:"flex h-full items-center justify-center p-4 text-center text-sm text-muted-foreground",children:"No matching templates."}):T.jsx(Oj,{className:"h-full",children:T.jsx("div",{className:"p-1",children:a.map(i=>T.jsxs("button",{type:"button",onClick:()=>r(i.id),className:st("flex w-full flex-col items-start gap-0.5 rounded-md px-3 py-2 text-left text-sm transition-colors","hover:bg-accent",t===i.id&&"bg-accent"),children:[T.jsx("span",{className:"w-full font-medium leading-tight",title:i.name,children:zwe(i.name)}),T.jsxs("div",{className:"flex w-full items-center gap-1.5",children:[i.category&&T.jsx("span",{className:"shrink-0 rounded bg-muted px-1.5 py-0.5 text-[10px] text-muted-foreground",children:i.category}),T.jsx("span",{className:"text-[10px] text-muted-foreground/60",children:Fwe(i.updated_at)})]})]},i.id))})})}function Ij(){const[e,t]=_.useState([]),[n,r]=_.useState(!1),[a,i]=_.useState(null),o=_.useCallback(async()=>{r(!0),i(null);try{const h=await fetch("/api/templates");if(!h.ok)throw new Error("Failed to fetch templates");const f=await h.json();t(f)}catch(h){i(h instanceof Error?h.message:"Failed to fetch templates")}finally{r(!1)}},[]),l=_.useCallback(async h=>{i(null);try{if(!(await fetch("/api/templates",{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify(h)})).ok)throw new Error("Failed to create template");return await o(),!0}catch(f){return i(f instanceof Error?f.message:"Failed to create template"),!1}},[o]),u=_.useCallback(async(h,f)=>{i(null);try{if(!(await fetch(`/api/templates/${h}`,{method:"PUT",headers:{"Content-Type":"application/json"},body:JSON.stringify(f)})).ok)throw new Error("Failed to update template");return await o(),!0}catch(m){return i(m instanceof Error?m.message:"Failed to update template"),!1}},[o]),d=_.useCallback(async h=>{i(null);try{if(!(await fetch(`/api/templates/${h}`,{method:"DELETE"})).ok)throw new Error("Failed to delete template");return await o(),!0}catch(f){return i(f instanceof Error?f.message:"Failed to delete template"),!1}},[o]);return _.useEffect(()=>{o()},[o]),{templates:e,isLoading:n,error:a,fetchTemplates:o,createTemplate:l,updateTemplate:u,deleteTemplate:d}}function Pwe({open:e,onOpenChange:t,onInsert:n,onNotify:r}){const{templates:a,fetchTemplates:i,createTemplate:o,updateTemplate:l,deleteTemplate:u}=Ij(),[d,h]=_.useState(null),[f,m]=_.useState(!1),[b,y]=_.useState("");_.useEffect(()=>{e&&(i(),h(null),m(!1),y(""))},[e,i]);const v=a.find(L=>L.id===d)??null,w=_.useCallback(()=>{h(null),m(!0)},[]),S=_.useCallback(L=>{h(L),m(!1)},[]),k=_.useCallback(async L=>{let A;if(f)A=await o(L),A&&(r("Template created","success"),m(!1));else if(d)A=await l(d,L),A&&r("Template updated","success");else return},[f,d,o,l,r]),R=_.useCallback(async()=>{if(!d)return;await u(d)&&(r("Template deleted","success"),h(null))},[d,u,r]),I=_.useCallback(L=>{n(L.body),t(!1)},[n,t]);return T.jsx(vb,{open:e,onOpenChange:t,children:T.jsxs(Ep,{className:"flex h-[80vh] max-w-4xl flex-col gap-0 p-0",children:[T.jsxs(kp,{className:"shrink-0 border-b px-6 py-4",children:[T.jsxs("div",{className:"flex items-center gap-3",children:[T.jsx(Tp,{className:"flex-1",children:"Prompt Templates"}),T.jsxs(kt,{size:"sm",variant:"outline",className:"mr-8",onClick:w,children:[T.jsx(tS,{className:"mr-1 h-3.5 w-3.5"}),"New"]})]}),T.jsxs("div",{className:"relative mt-2",children:[T.jsx(nS,{className:"absolute left-2.5 top-2.5 h-4 w-4 text-muted-foreground"}),T.jsx(Ri,{placeholder:"Search templates...",value:b,onChange:L=>y(L.target.value),className:"pl-9"})]})]}),T.jsxs("div",{className:"flex min-h-0 flex-1",children:[T.jsx("div",{className:"w-64 shrink-0 border-r",children:T.jsx($we,{templates:a,selectedId:d,searchQuery:b,onSelect:S})}),T.jsx("div",{className:"min-w-0 flex-1",children:T.jsx(Bwe,{template:f?null:v,isNew:f,onSave:k,onDelete:R,onInsert:I})})]})]})})}function Uwe({open:e,onOpenChange:t,initialBody:n,onSave:r,onNotify:a}){const[i,o]=_.useState(""),[l,u]=_.useState(""),[d,h]=_.useState(""),[f,m]=_.useState(""),[b,y]=_.useState(!1);_.useEffect(()=>{e&&(m(n),o(n.slice(0,50).replace(/\n/g," ").trim()),u(""),h(""))},[e,n]);const v=_.useCallback(async()=>{if(!i.trim()||!f.trim())return;y(!0);const w=await r({name:i.trim(),body:f.trim(),description:l.trim(),category:d.trim()});y(!1),w?(a("Template saved","success"),t(!1)):a("Failed to save template","error")},[i,f,l,d,r,a,t]);return T.jsx(vb,{open:e,onOpenChange:t,children:T.jsxs(Ep,{className:"max-w-lg",children:[T.jsx(kp,{children:T.jsx(Tp,{children:"Save as Template"})}),T.jsxs("div",{className:"flex flex-col gap-3",children:[T.jsxs("div",{className:"flex flex-col gap-1",children:[T.jsxs("label",{htmlFor:"sat-name",className:"text-sm font-medium",children:["Name ",T.jsx("span",{className:"text-destructive",children:"*"})]}),T.jsx(Ri,{id:"sat-name",value:i,onChange:w=>o(w.target.value),maxLength:100})]}),T.jsxs("div",{className:"flex flex-col gap-1",children:[T.jsx("label",{htmlFor:"sat-category",className:"text-sm font-medium",children:"Category"}),T.jsx(Ri,{id:"sat-category",value:d,onChange:w=>h(w.target.value),maxLength:50})]}),T.jsxs("div",{className:"flex flex-col gap-1",children:[T.jsx("label",{htmlFor:"sat-desc",className:"text-sm font-medium",children:"Description"}),T.jsx(Ri,{id:"sat-desc",value:l,onChange:w=>u(w.target.value),maxLength:500})]}),T.jsxs("div",{className:"flex flex-col gap-1",children:[T.jsxs("label",{htmlFor:"sat-body",className:"text-sm font-medium",children:["Body ",T.jsx("span",{className:"text-destructive",children:"*"})]}),T.jsx("textarea",{id:"sat-body",value:f,onChange:w=>m(w.target.value),rows:5,className:"w-full resize-y rounded-md border bg-background px-3 py-2 text-sm focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring"})]})]}),T.jsx(TC,{children:T.jsx(kt,{onClick:v,disabled:b||!i.trim()||!f.trim(),children:b?"Saving...":"Save"})})]})})}function jwe(e){const[t,n]=_.useState((e==null?void 0:e.initialMessages)??[]),[r,a]=_.useState(!1),i=_.useRef(null),o=_.useRef((e==null?void 0:e.threadId)??crypto.randomUUID()),l=_.useRef(e==null?void 0:e.onStreamComplete),u=_.useRef((e==null?void 0:e.bgEnabled)??!1);_.useEffect(()=>{e!=null&&e.threadId&&(o.current=e.threadId)},[e==null?void 0:e.threadId]),_.useEffect(()=>{e!=null&&e.initialMessages&&e.initialMessages.length>0&&n(R=>R.length===0?e.initialMessages??[]:R)},[e==null?void 0:e.initialMessages]),_.useEffect(()=>{l.current=e==null?void 0:e.onStreamComplete},[e==null?void 0:e.onStreamComplete]),_.useEffect(()=>{u.current=(e==null?void 0:e.bgEnabled)??!1},[e==null?void 0:e.bgEnabled]);const d=_.useCallback(async(R,I,L)=>{var H;const A={id:crypto.randomUUID(),role:"user",content:R,createdAt:new Date().toISOString(),...L!=null&&L.images&&L.images.length>0?{images:L.images}:{}},M=crypto.randomUUID(),P={id:M,role:"assistant",content:"",createdAt:new Date().toISOString()};L!=null&&L.skipUserMessage?n([...I,P]):n([...I,A,P]),a(!0),i.current=new AbortController;let G=!1,B=!0;try{!(L!=null&&L.skipUserMessage)&&!(L!=null&&L.resumeToken)&&await fetch(`/api/sessions/${o.current}/init`,{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({title:R.slice(0,100)})}).catch(()=>{});const Z={};u.current&&(Z.background=!0),L!=null&&L.resumeToken&&(Z.continuation_token=L.resumeToken);const V=await fetch("/ag-ui/",{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({thread_id:o.current,run_id:crypto.randomUUID(),messages:L!=null&&L.resumeToken?[]:[{id:A.id,role:"user",content:R,...L!=null&&L.images&&L.images.length>0?{images:L.images}:{}}],...Object.keys(Z).length>0?{state:Z}:{}}),signal:i.current.signal});if(!V.ok)throw new Error(`HTTP ${V.status}: ${V.statusText}`);const q=(H=V.body)==null?void 0:H.getReader();if(!q)throw new Error("No response body");const X=new TextDecoder;let $="",Q="";const J=[],ie=[];let F="",Y;for(;;){const{done:oe,value:U}=await q.read();if(oe)break;$+=X.decode(U,{stream:!0});const be=$.split(`
`);$=be.pop()??"";let ge="";for(const fe of be){if(fe.startsWith("event: ")){ge=fe.slice(7).trim();continue}if(!fe.startsWith("data: "))continue;const Ee=fe.slice(6).trim();if(Ee)try{const Ae=JSON.parse(Ee);switch(ge||Ae.type){case"TEXT_MESSAGE_CONTENT":{const ve=Ae.delta??"";Q+=ve,n(De=>De.map(Le=>Le.id===M?{...Le,content:Le.content+ve}:Le));break}case"REASONING_MESSAGE_START":{F="";const ve={id:Ae.messageId??crypto.randomUUID(),content:"",status:"thinking"};n(De=>De.map(Le=>Le.id===M?{...Le,reasoningBlocks:[...Le.reasoningBlocks??[],ve]}:Le));break}case"REASONING_MESSAGE_CONTENT":{const ve=Ae.messageId,De=Ae.delta??"";F+=De,n(Le=>Le.map(rt=>{var Xe;return rt.id===M?{...rt,reasoningBlocks:(Xe=rt.reasoningBlocks)==null?void 0:Xe.map(gt=>gt.id===ve?{...gt,content:gt.content+De}:gt)}:rt}));break}case"REASONING_MESSAGE_END":{const ve=Ae.messageId;J.push({content:F}),F="",n(De=>De.map(Le=>{var rt;return Le.id===M?{...Le,reasoningBlocks:(rt=Le.reasoningBlocks)==null?void 0:rt.map(Xe=>Xe.id===ve?{...Xe,status:"done"}:Xe)}:Le}));break}case"TOOL_CALL_START":{const ve=Ae.toolCallId??crypto.randomUUID(),De=Ae.toolCallName??"unknown",Le={id:ve,name:De,status:"running",args:""};ie.push({id:ve,name:De,status:"completed"}),n(rt=>rt.map(Xe=>Xe.id===M?{...Xe,toolCalls:[...Xe.toolCalls??[],Le]}:Xe));break}case"TOOL_CALL_ARGS":{const ve=Ae.toolCallId,De=Ae.delta??"";if(ve){const Le=ie.find(rt=>rt.id===ve);Le&&(Le.args=(Le.args??"")+De),n(rt=>rt.map(Xe=>{var gt;return Xe.id===M?{...Xe,toolCalls:(gt=Xe.toolCalls)==null?void 0:gt.map(Xt=>Xt.id===ve?{...Xt,args:(Xt.args??"")+De}:Xt)}:Xe}))}break}case"TOOL_CALL_END":{const ve=Ae.toolCallId;n(De=>De.map(Le=>{var rt;return Le.id===M?{...Le,toolCalls:(rt=Le.toolCalls)==null?void 0:rt.map(Xe=>Xe.id===ve?{...Xe,status:"completed"}:Xe)}:Le}));break}case"TOOL_CALL_RESULT":{const ve=Ae.toolCallId,De=Ae.content??"";if(ve){const Le=ie.find(rt=>rt.id===ve);Le&&(Le.result=De),n(rt=>rt.map(Xe=>{var gt;return Xe.id===M?{...Xe,toolCalls:(gt=Xe.toolCalls)==null?void 0:gt.map(Xt=>Xt.id===ve?{...Xt,result:De}:Xt)}:Xe}))}break}case"RUN_ERROR":{B=!1;const ve=Ae.message??"An error occurred";n(De=>De.map(Le=>Le.id===M?{...Le,content:`Error: ${ve}`}:Le));break}case"CUSTOM":{Ae.name==="usage"&&Ae.value&&(Y=Ae.value,n(ve=>ve.map(De=>De.id===M?{...De,usage:Ae.value}:De))),Ae.name==="continuation_token"&&Ae.value&&(G=!0,fetch(`/api/sessions/${o.current}/continuation-token`,{method:"PATCH",headers:{"Content-Type":"application/json"},body:JSON.stringify({continuation_token:Ae.value})}).catch(()=>{}));break}}}catch{}}}if(Q){const oe={role:"assistant",content:Q};J.length>0&&(oe.reasoning=J),ie.length>0&&(oe.tool_calls=ie),Y&&(oe.usage=Y);const U={role:"user",content:R};L!=null&&L.images&&L.images.length>0&&(U.images=L.images);const be=L!=null&&L.skipUserMessage?[oe]:[U,oe];fetch(`/api/sessions/${o.current}/messages`,{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({messages:be})}).then(()=>{var ge;return(ge=l.current)==null?void 0:ge.call(l)}).catch(()=>{})}}catch(Z){if(!(Z instanceof DOMException&&Z.name==="AbortError")){B=!1;const V=Z instanceof Error?Z.message:"An unexpected error occurred";n(q=>q.map(X=>X.id===M?{...X,content:`Error: ${V}`}:X))}}finally{n(Z=>Z.map(V=>{var q,X;return V.id===M&&((q=V.reasoningBlocks)!=null&&q.some($=>$.status==="thinking"))?{...V,reasoningBlocks:(X=V.reasoningBlocks)==null?void 0:X.map($=>$.status==="thinking"?{...$,status:"done"}:$)}:V})),a(!1),i.current=null,(G||L!=null&&L.resumeToken)&&fetch(`/api/sessions/${o.current}/continuation-token`,{method:"PATCH",headers:{"Content-Type":"application/json"},body:JSON.stringify({continuation_token:null})}).catch(()=>{})}return B},[]),h=_.useRef((e==null?void 0:e.initialMessages)??[]);_.useEffect(()=>{h.current=t},[t]);const f=_.useCallback(async(R,I)=>{!R.trim()&&(!I||I.length===0)||await d(R.trim(),h.current,{images:I})},[d]),m=_.useCallback(async(R,I)=>{const L=h.current,A=L.findIndex(P=>P.id===R);if(A===-1)return;const M=L.slice(0,A);fetch(`/api/sessions/${o.current}/truncate`,{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({after_index:A>0?A-1:0,delete_from:A})}).catch(()=>{}),await d(I,M)},[d]),b=_.useCallback(async R=>{const I=h.current,L=I.findIndex(P=>P.id===R);if(L===-1)return;let A="";for(let P=L-1;P>=0;P--)if(I[P].role==="user"){A=I[P].content;break}if(!A)return;const M=I.slice(0,L);fetch(`/api/sessions/${o.current}/truncate`,{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({after_index:L>0?L-1:0,delete_from:L})}).catch(()=>{}),await d(A,M,{skipUserMessage:!0})},[d]),y=_.useCallback(R=>{const L=h.current.findIndex(A=>A.id===R);L!==-1&&(n(A=>A.filter(M=>M.id!==R)),fetch(`/api/sessions/${o.current}/messages/${L}`,{method:"DELETE"}).then(()=>{var A;return(A=l.current)==null?void 0:A.call(l)}).catch(()=>{}))},[]),v=_.useCallback((R,I)=>{n(M=>M.map(P=>P.id===R?{...P,content:I}:P));const A=h.current.findIndex(M=>M.id===R);A!==-1&&fetch(`/api/sessions/${o.current}/truncate`,{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({after_index:A>0?A-1:0,delete_from:A})}).then(()=>fetch(`/api/sessions/${o.current}/messages`,{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({messages:[{role:"assistant",content:I}]})})).catch(()=>{})},[]),w=_.useCallback(async R=>d("",h.current,{skipUserMessage:!0,resumeToken:R}),[d]),S=_.useCallback(()=>{var R;(R=i.current)==null||R.abort()},[]),k=_.useCallback(()=>{n([])},[]);return{messages:t,isLoading:r,sendMessage:f,stopGeneration:S,clearMessages:k,editUserMessage:m,regenerateAssistantMessage:b,editAssistantMessage:v,deleteMessage:y,resumeFromToken:w}}const Hwe=new Set(["image/jpeg","image/png","image/gif","image/webp"]),Gwe=20*1024*1024;function qwe(){const[e,t]=_.useState([]),n=_.useCallback(async(o,l)=>{const u=Array.from(o).filter(h=>Hwe.has(h.type)&&h.size<=Gwe);if(u.length===0)return;const d=u.map(h=>({id:crypto.randomUUID(),file:h,previewUrl:URL.createObjectURL(h),uploadedUri:null,mediaType:h.type,status:"uploading"}));t(h=>[...h,...d]);for(const h of d)try{const f=new FormData;f.append("file",h.file);const m=await fetch(`/api/upload/${l}`,{method:"POST",body:f});if(!m.ok)throw new Error(`Upload failed: ${m.status}`);const b=await m.json();t(y=>y.map(v=>v.id===h.id?{...v,uploadedUri:b.uri,status:"ready"}:v))}catch{t(f=>f.map(m=>m.id===h.id?{...m,status:"error"}:m))}},[]),r=_.useCallback(o=>{t(l=>{const u=l.find(d=>d.id===o);return u&&URL.revokeObjectURL(u.previewUrl),l.filter(d=>d.id!==o)})},[]),a=_.useCallback(()=>{t(o=>{for(const l of o)URL.revokeObjectURL(l.previewUrl);return[]})},[]),i=_.useCallback(()=>e.filter(o=>o.status==="ready"&&o.uploadedUri).map(o=>({uri:o.uploadedUri,media_type:o.mediaType})),[e]);return{attachments:e,addFiles:n,removeAttachment:r,clearAttachments:a,getImageRefs:i,hasReadyAttachments:e.some(o=>o.status==="ready"),isUploading:e.some(o=>o.status==="uploading")}}function Wwe(e){let t=e;return t=t.replace(/```[\s\S]*?```/g,""),t=t.replace(/\$\$[\s\S]*?\$\$/g,""),t=t.replace(/\$[^$\n]+?\$/g,""),t=t.replace(/\\\[[\s\S]*?\\\]/g,""),t=t.replace(/\\\([\s\S]*?\\\)/g,""),t=t.replace(/`[^`]+`/g,""),t=t.replace(/<[^>]+>/g,""),t=t.replace(/!\[[^\]]*\]\([^)]*\)/g,""),t=t.replace(/\[([^\]]*)\]\([^)]*\)/g,"$1"),t=t.replace(/^#{1,6}\s+/gm,""),t=t.replace(/(\*\*|__)(.*?)\1/g,"$2"),t=t.replace(/(\*|_)(.*?)\1/g,"$2"),t=t.replace(/~~(.*?)~~/g,"$1"),t=t.replace(/^[-*_]{3,}\s*$/gm,""),t=t.replace(/^>\s?/gm,""),t=t.replace(/^[\s]*[-*+]\s+/gm,""),t=t.replace(/^[\s]*\d+\.\s+/gm,""),t=t.replace(/\s+/g," "),t=t.trim(),t}async function q8(e){const t=Wwe(e),n=await fetch("/api/tts",{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({text:t})});if(!n.ok){const r=await n.text();throw new Error(n.status===503?"TTS is not configured":`Speech synthesis failed: ${r}`)}return n.blob()}function Vwe(){const[e,t]=_.useState("idle"),[n,r]=_.useState("idle"),[a,i]=_.useState(null),[o,l]=_.useState(null),[u,d]=_.useState(null),h=_.useRef(null),f=_.useRef(new Map),m=_.useCallback(()=>{h.current&&(h.current.pause(),h.current.currentTime=0,h.current=null),t("idle"),i(null)},[]),b=_.useCallback(async(v,w)=>{if(d(null),h.current&&a===w){m();return}m(),t("loading"),i(w);try{let S=f.current.get(w);if(!S){const R=await q8(v);S=URL.createObjectURL(R),f.current.set(w,S)}const k=new Audio(S);h.current=k,k.onended=()=>{h.current=null,t("idle"),i(null)},k.onerror=()=>{h.current=null,t("idle"),i(null),d("Audio playback failed")},await k.play(),t("playing")}catch(S){t("idle"),i(null),d(S instanceof Error?S.message:"TTS failed")}},[a,m]),y=_.useCallback(async(v,w,S)=>{d(null),r("downloading"),l(w);try{let k=f.current.get(w);if(!k){const I=await q8(v);k=URL.createObjectURL(I),f.current.set(w,k)}const R=document.createElement("a");R.href=k,R.download=S,document.body.appendChild(R),R.click(),document.body.removeChild(R)}catch(k){d(k instanceof Error?k.message:"Download failed")}finally{r("idle"),l(null)}},[]);return{ttsState:e,downloadState:n,playingMessageId:a,downloadingMessageId:o,play:b,stop:m,download:y,error:u}}const W8="openchatci-bg-enabled";function Ywe(e,t){var u,d,h,f,m;const n=_.useRef(null),r=_.useRef(""),a=e.at(-1),i=((u=a==null?void 0:a.toolCalls)==null?void 0:u.length)??0,o=((h=(d=a==null?void 0:a.toolCalls)==null?void 0:d.at(-1))==null?void 0:h.status)??"",l=`${e.length}:${((f=a==null?void 0:a.content)==null?void 0:f.length)??0}:${i}:${o}:${((m=a==null?void 0:a.reasoningBlocks)==null?void 0:m.length)??0}:${t}`;return r.current!==l&&(r.current=l,requestAnimationFrame(()=>{const b=n.current;b&&(b.scrollTop=b.scrollHeight)})),n}function RC({compact:e,emptyMessage:t="How can I help you today?",className:n,threadId:r,initialMessages:a,continuationToken:i,onStreamComplete:o,onBranchFromMessage:l}){const[u,d]=_.useState(()=>localStorage.getItem(W8)==="true"),[h,f]=_.useState(null),m=_.useCallback(qe=>{d(qe),localStorage.setItem(W8,String(qe))},[]);_.useEffect(()=>{if(h){const qe=setTimeout(()=>f(null),5e3);return()=>clearTimeout(qe)}},[h]);const b=_.useCallback(qe=>{f(qe?{type:"success",message:"Background response resumed"}:{type:"error",message:"Background response expired. Please resend your message."})},[]),{messages:y,isLoading:v,sendMessage:w,stopGeneration:S,editUserMessage:k,regenerateAssistantMessage:R,editAssistantMessage:I,deleteMessage:L,resumeFromToken:A}=jwe({threadId:r,initialMessages:a,onStreamComplete:o,bgEnabled:u}),M=_.useRef({resume:A,notify:b});M.current.resume=A,M.current.notify=b,_.useEffect(()=>{if(!i)return;const qe=i,yt=setTimeout(async()=>{const ur=await M.current.resume(qe);M.current.notify(ur)},800);return()=>clearTimeout(yt)},[i]);const{attachments:P,addFiles:G,removeAttachment:B,clearAttachments:H,getImageRefs:Z,isUploading:V}=qwe(),q=Vwe(),X=_.useRef(null),[$,Q]=_.useState(!1),[J,ie]=_.useState(!1),[F,Y]=_.useState(""),{createTemplate:oe}=Ij(),U=_.useCallback(()=>Q(!0),[]),be=_.useCallback(qe=>{var yt;(yt=X.current)==null||yt.insertText(qe)},[]),ge=_.useCallback(qe=>{Y(qe),ie(!0)},[]),[fe,Ee]=_.useState(null),Ae=_.useCallback(qe=>{Ee({imageUrl:qe})},[]),ve=_.useCallback(async(qe,yt,ur)=>{if(Ee(null),!!r)try{const me=new FormData;me.append("file",new File([yt],"mask_preview.png",{type:"image/png"}));const Te=await fetch(`/api/upload/${r}`,{method:"POST",body:me}),We=Te.ok?await Te.json():null,ut=new FormData;ut.append("file",new File([qe],`mask_source_${Date.now()}.png`,{type:"image/png"}));const It=await fetch(`/api/upload/${r}`,{method:"POST",body:ut}),En=It.ok?await It.json():null;if(!(En!=null&&En.filename)){f({type:"error",message:"Failed to upload source image"});return}const _r=[];We!=null&&We.uri&&_r.push({uri:We.uri,media_type:"image/png"}),w(`Edit the masked areas of the image "${En.filename}": ${ur}`,_r)}catch(me){f({type:"error",message:me instanceof Error?me.message:"Failed to start mask edit"})}},[r,w]),[De,Le]=_.useState(!1),rt=_.useRef(0),[Xe,gt]=_.useState();_.useEffect(()=>{fetch("/api/model").then(qe=>qe.ok?qe.json():null).then(qe=>{qe!=null&&qe.max_context_tokens&&gt(qe.max_context_tokens)}).catch(()=>{})},[]);const Xt=Ywe(y,v),er=_.useMemo(()=>{for(let qe=y.length-1;qe>=0;qe--)if(y[qe].usage)return y[qe].usage},[y]),Tr=_.useCallback((qe,yt)=>{w(qe,yt),H()},[w,H]),Hn=_.useCallback(qe=>{r&&G(qe,r)},[G,r]),Cn=_.useCallback(qe=>{qe.preventDefault(),rt.current++,qe.dataTransfer.types.includes("Files")&&Le(!0)},[]),Zn=_.useCallback(qe=>{qe.preventDefault(),rt.current--,rt.current===0&&Le(!1)},[]),wa=_.useCallback(qe=>{qe.preventDefault()},[]),di=_.useCallback(qe=>{qe.preventDefault(),rt.current=0,Le(!1);const yt=qe.dataTransfer.files;yt.length>0&&r&&G(yt,r)},[G,r]);return T.jsxs("div",{className:st("relative flex flex-1 flex-col overflow-hidden",n),onDragEnter:Cn,onDragLeave:Zn,onDragOver:wa,onDrop:di,children:[T.jsx("div",{ref:Xt,className:"flex-1 overflow-y-auto",children:T.jsxs("div",{className:st("mx-auto px-4 pt-4",e?"max-w-full pb-4":"max-w-3xl pb-36"),children:[y.length===0&&T.jsx("div",{className:st("flex items-center justify-center text-muted-foreground",e?"h-40":"h-[60vh]"),children:T.jsx("p",{className:st(e?"text-xs":"text-sm"),children:t})}),y.map((qe,yt)=>T.jsx(uwe,{message:qe,messageIndex:yt,compact:e,isLoading:v&&yt===y.length-1,tts:q,onEditUser:k,onEditAssistant:I,onRegenerateAssistant:R,onDelete:L,onBranch:l?()=>l(yt):void 0,onSaveAsTemplate:ge,onMaskEdit:Ae},qe.id))]})}),h&&T.jsx("div",{className:st("absolute right-3 top-3 z-30 rounded-md px-4 py-2 text-sm shadow-md",h.type==="success"?"bg-green-500/10 text-green-600 border border-green-500/20":"bg-red-500/10 text-red-600 border border-red-500/20"),children:h.message}),e?T.jsxs("div",{children:[T.jsxs("div",{className:"flex items-center justify-end gap-1 px-4",children:[T.jsx(U6,{enabled:u,onToggle:m}),T.jsx(H8,{usage:er,maxContextTokens:Xe})]}),T.jsx(gR,{ref:X,onSend:Tr,onStop:S,isLoading:v,attachments:P,onAddFiles:Hn,onRemoveAttachment:B,getImageRefs:Z,isUploading:V,bgEnabled:u,onOpenTemplates:U})]}):T.jsxs("div",{className:"absolute inset-x-0 bottom-0 z-20",children:[T.jsx("div",{className:"pointer-events-none bg-gradient-to-t from-background from-60% to-transparent pt-6"}),T.jsxs("div",{className:"relative bg-background",children:[T.jsxs("div",{className:"mx-auto flex max-w-3xl items-center justify-end gap-1 px-4",children:[T.jsx(U6,{enabled:u,onToggle:m}),T.jsx(H8,{usage:er,maxContextTokens:Xe})]}),T.jsx(gR,{ref:X,onSend:Tr,onStop:S,isLoading:v,attachments:P,onAddFiles:Hn,onRemoveAttachment:B,getImageRefs:Z,isUploading:V,bgEnabled:u,onOpenTemplates:U})]})]}),De&&T.jsx("div",{className:"absolute inset-0 z-50 flex items-center justify-center bg-background/80 backdrop-blur-sm",children:T.jsxs("div",{className:"flex flex-col items-center gap-3 rounded-xl border-2 border-dashed border-primary p-12",children:[T.jsx(xO,{className:"h-10 w-10 text-primary"}),T.jsx("p",{className:"text-sm font-medium text-primary",children:"Drop images here to attach"})]})}),T.jsx(Pwe,{open:$,onOpenChange:Q,onInsert:be,onNotify:(qe,yt)=>f({type:yt,message:qe})}),T.jsx(Uwe,{open:J,onOpenChange:ie,initialBody:F,onSave:oe,onNotify:(qe,yt)=>f({type:yt,message:qe})}),fe&&T.jsx(vwe,{open:!!fe,onOpenChange:qe=>!qe&&Ee(null),imageUrl:fe.imageUrl,onGenerate:ve})]})}function V8({text:e,query:t}){if(!t.trim())return T.jsx(T.Fragment,{children:e});const n=e.toLowerCase(),r=t.toLowerCase(),a=n.indexOf(r);return a===-1?T.jsx(T.Fragment,{children:e}):T.jsxs(T.Fragment,{children:[e.slice(0,a),T.jsx("mark",{className:"bg-yellow-200 dark:bg-yellow-800",children:e.slice(a,a+t.length)}),e.slice(a+t.length)]})}function Xwe(e){return e?new Date(e).toLocaleString(void 0,{year:"numeric",month:"2-digit",day:"2-digit",hour:"2-digit",minute:"2-digit",second:"2-digit"}):""}function Kwe({sessions:e,open:t,onOpenChange:n,onSelect:r}){const[a,i]=_.useState(""),[o,l]=_.useState(null),[u,d]=_.useState(!1),h=_.useRef(null),f=_.useRef(null);_.useEffect(()=>{t&&requestAnimationFrame(()=>{var S;return(S=h.current)==null?void 0:S.focus()})},[t]);const m=_.useCallback(S=>{if(f.current&&clearTimeout(f.current),!S.trim()){l(null),d(!1);return}d(!0),f.current=setTimeout(async()=>{try{const k=await fetch(`/api/sessions/search?q=${encodeURIComponent(S.trim())}`);k.ok&&l(await k.json())}catch{}finally{d(!1)}},300)},[]),b=_.useCallback(S=>{i(S),m(S)},[m]),y=_.useMemo(()=>o!==null?o:e,[o,e]),v=S=>{r(S),n(!1),i(""),l(null)},w=S=>{S.key==="Enter"&&y.length>0&&v(y[0].thread_id)};return T.jsx(vb,{open:t,onOpenChange:S=>{n(S),S||(i(""),l(null))},children:T.jsxs(Ep,{className:"max-w-2xl",children:[T.jsx(kp,{children:T.jsx(Tp,{children:"Search sessions"})}),T.jsx(Ri,{ref:h,placeholder:"Search by title or content...",value:a,onChange:S=>b(S.target.value),onKeyDown:w}),T.jsxs("div",{className:"h-[60vh] overflow-y-auto",children:[u&&T.jsx("p",{className:"py-4 text-center text-sm text-muted-foreground",children:"Searching..."}),!u&&y.length===0&&T.jsx("p",{className:"py-4 text-center text-sm text-muted-foreground",children:"No sessions found"}),!u&&y.map(S=>T.jsxs("button",{type:"button",className:"flex w-full flex-col rounded-md px-3 py-2 text-left text-sm transition-colors hover:bg-muted",onClick:()=>v(S.thread_id),children:[T.jsxs("div",{className:"flex w-full items-center justify-between",children:[T.jsx("span",{className:"min-w-0 flex-1 truncate",children:T.jsx(V8,{text:S.title||"New session",query:a})}),T.jsxs("span",{className:"ml-2 shrink-0 text-xs text-muted-foreground",children:[Xwe(S.updated_at),S.message_count>0&&` · ${S.message_count} msgs`,S.image_count>0&&` · ${S.image_count} imgs`]})]}),S.snippet&&T.jsx("p",{className:"mt-0.5 truncate text-xs text-muted-foreground",children:T.jsx(V8,{text:S.snippet,query:a})})]},S.thread_id))]})]})})}function Zwe(e){return e?new Date(e).toLocaleString(void 0,{year:"numeric",month:"2-digit",day:"2-digit",hour:"2-digit",minute:"2-digit",second:"2-digit"}):""}function Qwe(e){const t=e.filter(r=>r.pinned_at).sort((r,a)=>(r.pinned_at??"")<(a.pinned_at??"")?-1:1),n=e.filter(r=>!r.pinned_at).sort((r,a)=>r.updated_at>a.updated_at?-1:1);return[...t,...n]}function Jwe({sessions:e,currentThreadId:t,onSwitch:n,onDelete:r,onRename:a,onArchive:i,onPin:o,onCreate:l,onClose:u}){const d=Qwe(e),[h,f]=_.useState(null),[m,b]=_.useState(!1),[y,v]=_.useState(null),[w,S]=_.useState(""),k=_.useRef(null);_.useEffect(()=>{var M;y&&((M=k.current)==null||M.focus())},[y]);const R=_.useCallback(M=>{v(M.thread_id),S(M.title||"")},[]),I=_.useCallback(()=>{if(!y)return;const M=w.trim();M&&a(y,M),v(null),S("")},[y,w,a]),L=_.useCallback(()=>{v(null),S("")},[]),A=_.useCallback(M=>{M.key==="Enter"&&(M.preventDefault(),I()),M.key==="Escape"&&(M.preventDefault(),L())},[I,L]);return T.jsxs("aside",{className:"flex h-full w-[307px] shrink-0 flex-col border-r bg-muted/30",children:[T.jsxs("div",{className:"flex h-12 shrink-0 items-center justify-between border-b px-3",children:[T.jsxs("div",{className:"flex items-center gap-2",children:[T.jsx("img",{src:"/favicon.svg",alt:"OpenChatCi",className:"h-5 w-5"}),T.jsx("span",{className:"text-sm font-medium",children:"OpenChatCi"})]}),T.jsxs("div",{className:"flex items-center gap-1",children:[T.jsx(kt,{variant:"ghost",size:"icon",className:"h-7 w-7",onClick:()=>b(!0),"aria-label":"Search sessions",children:T.jsx(nS,{className:"h-4 w-4"})}),T.jsx(kt,{variant:"ghost",size:"icon",className:"h-7 w-7",onClick:l,"aria-label":"New session",children:T.jsx(tS,{className:"h-4 w-4"})}),T.jsx(kt,{variant:"ghost",size:"icon",className:"h-7 w-7",onClick:u,"aria-label":"Close sidebar",children:T.jsx(gl,{className:"h-4 w-4"})})]})]}),T.jsxs("div",{className:"flex-1 overflow-y-auto",children:[d.length===0&&T.jsx("div",{className:"flex items-center justify-center p-4 text-xs text-muted-foreground",children:"No sessions yet"}),d.map(M=>{const P=M.thread_id===t,G=y===M.thread_id;return T.jsxs("div",{className:st("group flex w-full items-start gap-2 border-b border-border/30 px-3 py-2.5 transition-colors hover:bg-muted/50",P&&"bg-muted"),children:[T.jsx("button",{type:"button",className:"min-w-0 flex-1 cursor-pointer text-left",onClick:()=>!G&&n(M.thread_id),children:G?T.jsx("input",{ref:k,type:"text",value:w,onChange:B=>S(B.target.value),onKeyDown:A,onBlur:I,className:"w-full rounded border bg-background px-1.5 py-0.5 text-sm focus-visible:outline-none focus-visible:ring-1 focus-visible:ring-ring"}):T.jsxs(T.Fragment,{children:[T.jsxs("p",{className:"flex items-center gap-1 truncate text-sm",children:[M.pinned_at&&T.jsx(D6,{className:"h-3 w-3 shrink-0 text-muted-foreground"}),M.title||"New session"]}),T.jsxs("p",{className:"text-xs text-muted-foreground",children:[Zwe(M.updated_at),M.message_count>0&&` · ${M.message_count} msgs`,M.image_count>0&&` · ${M.image_count} imgs`]})]})}),!G&&T.jsxs(kL,{children:[T.jsx(TL,{asChild:!0,children:T.jsx("span",{role:"button",tabIndex:-1,className:"inline-flex h-6 w-6 shrink-0 items-center justify-center rounded-md opacity-0 transition-opacity hover:bg-accent group-hover:opacity-100","aria-label":"Session options",children:T.jsx(rV,{className:"h-3 w-3"})})}),T.jsxs(RS,{align:"end",className:"w-36",children:[T.jsx(cl,{onClick:()=>o(M.thread_id,!M.pinned_at),children:M.pinned_at?T.jsxs(T.Fragment,{children:[T.jsx(OV,{className:"mr-2 h-3.5 w-3.5"}),"Unpin"]}):T.jsxs(T.Fragment,{children:[T.jsx(D6,{className:"mr-2 h-3.5 w-3.5"}),"Pin"]})}),T.jsxs(cl,{onClick:()=>R(M),children:[T.jsx(eS,{className:"mr-2 h-3.5 w-3.5"}),"Rename"]}),T.jsxs(cl,{onClick:()=>i(M.thread_id),children:[T.jsx(PW,{className:"mr-2 h-3.5 w-3.5"}),"Archive"]}),T.jsxs(cl,{className:"text-destructive focus:text-destructive",onClick:()=>f(M),children:[T.jsx(aS,{className:"mr-2 h-3.5 w-3.5"}),"Delete"]})]})]})]},M.thread_id)})]}),T.jsx(wC,{open:h!==null,onOpenChange:M=>!M&&f(null),children:T.jsxs(hb,{children:[T.jsxs(pb,{children:[T.jsx(mb,{children:"Delete session?"}),T.jsxs(gb,{children:['"',(h==null?void 0:h.title)||"New session",'" will be permanently deleted. This action cannot be undone.']})]}),T.jsxs(fb,{children:[T.jsx(yb,{children:"Cancel"}),T.jsx(bb,{className:"bg-destructive text-destructive-foreground hover:bg-destructive/90",onClick:()=>{h&&(r(h.thread_id),f(null))},children:"Delete"})]})]})}),T.jsx(Kwe,{sessions:e,open:m,onOpenChange:b,onSelect:n})]})}const Y8="openchatci-thread-id";function X8(e){const t=[];for(const n of e){const r=n.role;if(r!=="user"&&r!=="assistant")continue;const a=n.contents;let i="";const o=[],l=[];if(a)for(const m of a)(m.type==="text"||m.type==="text_content")&&typeof m.text=="string"?i+=m.text:(m.type==="text_reasoning"||m.type==="reasoning_content")&&typeof m.text=="string"?o.push({id:crypto.randomUUID(),content:m.text,status:"done"}):m.type==="image_url"&&typeof m.uri=="string"&&l.push({uri:m.uri,media_type:m.media_type||""});const u=n.tool_calls,d=[];if(u)for(const m of u)d.push({id:m.id??crypto.randomUUID(),name:m.name??"unknown",status:"completed",...typeof m.args=="string"?{args:m.args}:{},...typeof m.result=="string"?{result:m.result}:{}});const h=n.usage;let f;h&&typeof h=="object"&&(f=h),t.push({id:n.message_id??crypto.randomUUID(),role:r,content:i,createdAt:new Date().toISOString(),...o.length>0?{reasoningBlocks:o}:{},...l.length>0?{images:l}:{},...d.length>0?{toolCalls:d}:{},...f?{usage:f}:{}})}return t}function eEe(){const e=Vh(),[t]=CW(),n=t.get("session"),[r,a]=_.useState(()=>{if(n)return n;const B=crypto.randomUUID();return localStorage.setItem(Y8,B),B}),[i,o]=_.useState([]),[l,u]=_.useState([]),[d,h]=_.useState(null),[f,m]=_.useState(!1),[b,y]=_.useState(!1),v=_.useRef(null),w=_.useRef(!1);_.useEffect(()=>{localStorage.setItem(Y8,r)},[r]);const S=_.useCallback(async()=>{try{const B=await fetch("/api/sessions");B.ok&&o(await B.json())}catch{}},[]);_.useEffect(()=>{S()},[S]),_.useEffect(()=>{if(!n)return;if(w.current){w.current=!1;return}let B=!1;async function H(){try{const Z=await fetch(`/api/sessions/${n}`);if(!Z.ok||B)return;const V=await Z.json(),q=X8(V.messages??[]);B||(u(q),h(V.continuation_token??null))}catch{B||u([])}}return H(),()=>{B=!0}},[n]);const k=_.useCallback(B=>{v.current=B},[]),R=_.useCallback(()=>{var H;(H=v.current)==null||H.call(v);const B=crypto.randomUUID();u([]),h(null),a(B),e("/chat",{replace:!0}),y(!1)},[e]),I=_.useCallback(async B=>{var H;if(B===r){y(!1);return}(H=v.current)==null||H.call(v),m(!0);try{const Z=await fetch(`/api/sessions/${B}`);if(Z.ok){const V=await Z.json(),q=X8(V.messages??[]);u(q),h(V.continuation_token??null)}else u([]),h(null)}catch{u([])}a(B),w.current=!0,e(`/chat?session=${B}`,{replace:!0}),m(!1),y(!1)},[r,e]),L=_.useCallback(async B=>{try{(await fetch(`/api/sessions/${B}`,{method:"DELETE"})).ok&&(o(Z=>Z.filter(V=>V.thread_id!==B)),B===r&&R())}catch{}},[r,R]),A=_.useCallback(async(B,H)=>{try{const Z=await fetch(`/api/sessions/${B}/fork`,{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({up_to_index:H})});if(!Z.ok)return;const q=(await Z.json()).new_thread_id;await I(q),await S()}catch{}},[I,S]),M=_.useCallback(async(B,H)=>{try{const Z=await fetch(`/api/sessions/${B}/rename`,{method:"PATCH",headers:{"Content-Type":"application/json"},body:JSON.stringify({title:H})});if(Z.ok){const V=await Z.json();o(q=>q.map(X=>X.thread_id===B?{...X,title:V.title}:X))}}catch{}},[]),P=_.useCallback(async B=>{try{(await fetch(`/api/sessions/${B}/archive`,{method:"POST"})).ok&&(o(Z=>Z.filter(V=>V.thread_id!==B)),B===r&&R())}catch{}},[r,R]),G=_.useCallback(async(B,H)=>{try{const Z=await fetch(`/api/sessions/${B}/pin`,{method:"PATCH",headers:{"Content-Type":"application/json"},body:JSON.stringify({pinned:H})});if(Z.ok){const V=await Z.json();o(q=>q.map(X=>X.thread_id===B?{...X,pinned_at:V.pinned_at??null}:X))}}catch{}},[]);return{threadId:r,sessions:i,initialMessages:l,continuationToken:d,isSwitching:f,sidebarOpen:b,setSidebarOpen:y,createSession:R,switchSession:I,deleteSession:L,forkSession:A,renameSession:M,archiveSession:P,pinSession:G,refreshSessions:S,registerAbort:k}}function tEe(){const e=Vh(),{threadId:t,sessions:n,initialMessages:r,continuationToken:a,isSwitching:i,sidebarOpen:o,setSidebarOpen:l,createSession:u,switchSession:d,deleteSession:h,forkSession:f,renameSession:m,archiveSession:b,pinSession:y,refreshSessions:v}=eEe(),w=_.useCallback(()=>{v(),e(`/chat?session=${t}`,{replace:!0})},[v,e,t]),S=_.useCallback(k=>{f(t,k)},[f,t]);return T.jsxs("div",{className:"flex h-screen",children:[o&&T.jsx(Jwe,{sessions:n,currentThreadId:t,onSwitch:d,onDelete:h,onRename:m,onArchive:b,onPin:y,onCreate:u,onClose:()=>l(!1)}),T.jsxs("div",{className:"relative flex flex-1 flex-col",children:[!o&&T.jsx(kt,{variant:"ghost",size:"icon",className:"absolute left-3 top-3 z-10 h-8 w-8",onClick:()=>l(!0),"aria-label":"Open sessions",children:T.jsx(wV,{className:"h-4 w-4"})}),i?T.jsxs("div",{className:"flex flex-1 items-center justify-center",children:[T.jsx(fu,{className:"h-5 w-5 animate-spin text-muted-foreground"}),T.jsx("span",{className:"ml-2 text-sm text-muted-foreground",children:"Loading session..."})]}):T.jsx(RC,{threadId:t,initialMessages:r,continuationToken:a,onStreamComplete:w,onBranchFromMessage:S},t)]})]})}function nEe(){return T.jsxs("div",{className:"flex h-screen flex-col items-center justify-center gap-4",children:[T.jsx("h1",{className:"text-4xl font-bold",children:"404"}),T.jsx("p",{className:"text-muted-foreground",children:"Page Not Found"}),T.jsx(kt,{asChild:!0,children:T.jsx(X2,{to:"/chat",children:"Go to Chat"})})]})}function rEe(){const[e,t]=_.useState(!1);return T.jsxs("div",{className:"flex h-screen flex-col",children:[T.jsx("header",{className:"flex h-12 shrink-0 items-center border-b px-4",children:T.jsx("h1",{className:"text-sm font-semibold",children:"OpenChatCi - Popup"})}),T.jsx("div",{className:"flex flex-1 items-center justify-center text-muted-foreground",children:T.jsx("p",{className:"text-sm",children:"Click the chat icon in the bottom-right corner to start."})}),e&&T.jsxs("div",{className:"fixed right-4 bottom-20 z-50 flex h-[500px] w-[380px] flex-col rounded-xl border bg-background shadow-lg",children:[T.jsxs("div",{className:"flex h-10 shrink-0 items-center justify-between border-b px-3",children:[T.jsx("span",{className:"text-sm font-medium",children:"OpenChatCi"}),T.jsx(kt,{variant:"ghost",size:"icon",className:"h-7 w-7",onClick:()=>t(!1),children:T.jsx(gl,{className:"h-4 w-4"})})]}),T.jsx(RC,{compact:!0})]}),T.jsx(kt,{className:"fixed right-4 bottom-4 z-50 h-14 w-14 rounded-full shadow-lg",size:"icon",onClick:()=>t(n=>!n),"aria-label":e?"Close chat":"Open chat",children:e?T.jsx(gl,{className:"h-6 w-6"}):T.jsx(SO,{className:"h-6 w-6"})})]})}function aEe(){const[e,t]=_.useState(!1);return T.jsxs("div",{className:"flex h-screen",children:[T.jsxs("div",{className:"flex flex-1 flex-col",children:[T.jsxs("header",{className:"flex h-12 shrink-0 items-center border-b px-4",children:[T.jsx("h1",{className:"text-sm font-semibold",children:"OpenChatCi - Sidebar"}),T.jsx(kt,{variant:"ghost",size:"icon",className:"ml-auto",onClick:()=>t(n=>!n),children:e?T.jsx(gl,{className:"h-4 w-4"}):T.jsx(SO,{className:"h-4 w-4"})})]}),T.jsx("div",{className:"flex flex-1 items-center justify-center text-muted-foreground",children:T.jsx("p",{className:"text-sm",children:"Click the chat icon in the header to open the sidebar panel."})})]}),e&&T.jsxs("aside",{className:"flex h-full w-[380px] shrink-0 flex-col border-l bg-background",children:[T.jsxs("div",{className:"flex h-12 shrink-0 items-center justify-between border-b px-3",children:[T.jsx("span",{className:"text-sm font-medium",children:"OpenChatCi"}),T.jsx(kt,{variant:"ghost",size:"icon",className:"h-7 w-7",onClick:()=>t(!1),children:T.jsx(gl,{className:"h-4 w-4"})})]}),T.jsx(RC,{compact:!0})]})]})}function iEe(){return T.jsx(wW,{children:T.jsxs(Zq,{children:[T.jsx(Ac,{path:"/",element:T.jsx(Xq,{to:"/chat",replace:!0})}),T.jsx(Ac,{path:"/chat",element:T.jsx(tEe,{})}),T.jsx(Ac,{path:"/popup",element:T.jsx(rEe,{})}),T.jsx(Ac,{path:"/sidebar",element:T.jsx(aEe,{})}),T.jsx(Ac,{path:"*",element:T.jsx(nEe,{})})]})})}const Lj=document.getElementById("root");if(!Lj)throw new Error("Root element not found");JG.createRoot(Lj).render(T.jsx(_.StrictMode,{children:T.jsx(iEe,{})}));export{k9 as $,hEe as A,ph as B,oce as C,_ue as D,Y_ as E,p9 as F,br as G,ebe as H,ife as I,d0e as J,jce as K,Oh as L,uEe as M,tb as N,oue as O,w9 as P,p7 as Q,Kpe as R,i2 as S,Jge as T,hp as U,fue as V,dp as W,Ue as X,nt as Y,qge as Z,N as _,xue as a,dz as a$,Wpe as a0,L7 as a1,I7 as a2,SEe as a3,gEe as a4,vEe as a5,yEe as a6,fEe as a7,__ as a8,xEe as a9,h1e as aA,d1e as aB,Uge as aC,Lme as aD,Dge as aE,$_ as aF,L8 as aG,bye as aH,r9 as aI,Vpe as aJ,cEe as aK,qh as aL,xp as aM,mye as aN,fye as aO,w_ as aP,fs as aQ,Dh as aR,_7 as aS,_he as aT,Dl as aU,jge as aV,hz as aW,Kg as aX,eb as aY,zm as aZ,fz as a_,mEe as aa,_c as ab,EEe as ac,wEe as ad,bEe as ae,jye as af,kP as ag,LEe as ah,p0e as ai,xr as aj,Do as ak,Gd as al,X_ as am,xz as an,Ou as ao,kz as ap,pt as aq,Ni as ar,Ge as as,M1e as at,IEe as au,DEe as av,NEe as aw,Qe as ax,OEe as ay,b1e as az,vue as b,yge as b0,Ye as b1,Tz as b2,ea as b3,vhe as b4,S_ as b5,z9 as b6,mp as b7,U9 as b8,pEe as b9,Y7 as bA,j_ as bB,sz as bC,z2 as bD,Hge as bE,Jg as bF,sEe as bG,Ut as bH,ice as ba,Pge as bb,Lge as bc,xme as bd,P_ as be,fge as bf,Gge as bg,yp as bh,Ru as bi,Mm as bj,Tge as bk,ave as bl,bp as bm,Fm as bn,vge as bo,iz as bp,Eme as bq,kme as br,ll as bs,J7 as bt,Tme as bu,U_ as bv,wme as bw,Ame as bx,Nu as by,Ms as bz,qt as c,Et as d,E9 as e,Yn as f,wue as g,Co as h,li as i,g0e as j,pp as k,we as l,wz as m,dEe as n,BEe as o,Eue as p,kue as q,MEe as r,Sue as s,h0e as t,ti as u,s1e as v,rbe as w,kEe as x,nu as y,yue as z};
